"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var models_1 = require("../models");
var iotile_common_1 = require("iotile-common");
var config_1 = require("../config");
var axios = require("axios");
var lodash = require('lodash');
var IOTileCloud = /** @class */ (function () {
    function IOTileCloud(Config) {
        this.Config = Config;
        this.inProgressConnections = 0;
        this.event = new iotile_common_1.BlockingEvent();
        this.initialized = this.event.wait();
    }
    IOTileCloud.prototype.serverList = function () {
        return this.Config.ENV.SERVER_URLS;
    };
    IOTileCloud.prototype.defaultServer = function () {
        for (var _i = 0, _a = this.serverList(); _i < _a.length; _i++) {
            var server = _a[_i];
            if ("default" in server) {
                return server;
            }
        }
        config_1.catCloud.info('No Default Server specified; targeting iotile.cloud');
        return {
            "shortName": "PRODUCTION",
            "longName": "Production Server",
            "url": "https://iotile.cloud/api/v1",
            "default": true
        };
    };
    IOTileCloud.prototype.isDefault = function () {
        var defServer = this.defaultServer();
        if (defServer) {
            return (this.server.url == defServer.url);
        }
        else {
            return false;
        }
    };
    Object.defineProperty(IOTileCloud.prototype, "server", {
        get: function () {
            if (this._server) {
                return this._server;
            }
            else {
                throw new iotile_common_1.ArgumentError("No Server has been set.");
            }
        },
        set: function (server) {
            this._server = server;
            this.event.set();
        },
        enumerable: true,
        configurable: true
    });
    IOTileCloud.prototype.Project = function (item) {
        return new models_1.Project(item);
    };
    ;
    IOTileCloud.prototype.Org = function (item) {
        return new models_1.Org(item);
    };
    ;
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProject
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a single project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Project object
     *
     * @example
     * <pre>
     * // Get an array of all projects available
     * var projects = await IOTileCloud.fetchProjects();
     * console.log("Found " + projects.length + " IOTile Projects!");
     * </pre>
     *
     * @returns {Project[]} A list of the IOTile projects.
     */
    IOTileCloud.prototype.fetchProject = function (projectID) {
        return __awaiter(this, void 0, void 0, function () {
            var that, projData;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        that = this;
                        return [4 /*yield*/, that.fetchFromServer('/project/' + projectID + '/')];
                    case 1:
                        projData = _a.sent();
                        return [2 /*return*/, new models_1.Project(projData)];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjects
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available projects from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Project objects with all projects retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all projects available
     * var projects = await IOTileCloud.fetchProjects();
     * console.log("Found " + projects.length + " IOTile Projects!");
     * </pre>
     *
     * @returns {Project[]} A list of the IOTile projects.
     */
    IOTileCloud.prototype.fetchProjects = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/project/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newProject = new models_1.Project(item);
                                list.push(newProject);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    //Create a new org
    IOTileCloud.prototype.createOrg = function (name, about) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'name': name,
                            'about': about
                        };
                        return [4 /*yield*/, this.postToServer('/org/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    //Create a new project in an org and return the project id
    IOTileCloud.prototype.createProject = function (orgSlug, name) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            name: name,
                            org: orgSlug
                        };
                        return [4 /*yield*/, this.postToServer('/project/new/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response['id']];
                }
            });
        });
    };
    IOTileCloud.prototype.checkClaimable = function (data) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.postToServer('/device/claimable/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    //FIXME: Verify that we use the project id here and not the slug
    IOTileCloud.prototype.claimDevice = function (deviceSlug, projectID) {
        return __awaiter(this, void 0, void 0, function () {
            var data;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            device: deviceSlug,
                            project: projectID
                        };
                        return [4 /*yield*/, this.postToServer('/device/claim/', data)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchOrgs
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available organizations from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Org objects with all organizations retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all orgs available
     * var orgs = await IOTileCloud.fetchOrgs();
     * console.log("Found " + orgs.length + " IOTile Orgs!");
     * </pre>
     *
     * @returns {Org[]} A list of the IOTile organizations.
     */
    IOTileCloud.prototype.fetchOrgs = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/org/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newOrg = new models_1.Org(item);
                                list.push(newOrg);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchOrgMembership
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches user membership information from a given Org
     *
     * **This is an async method!**
     *
     * Returns a Membership object: the user's membership information for the given Org
     *
     * @example
     * <pre>
     * // Get membership information for org
     * var membership = await IOTileCloud.fetchOrgMembership(org.slug);
     * </pre>
     *
     * @returns {Membership} The membership information of the User in the given Org
     */
    IOTileCloud.prototype.fetchOrgMembership = function (org) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/org/' + org.slug + '/membership/')
                            .then(function (result) {
                            var membership = new models_1.Membership(result);
                            resolve(membership);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchOrgList
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a list of OrgMetaData objects with the names and ids
     * of all projects in all orgs.
     *
     * **This is an async method!**
     *
     * Returns an array of OrgMetaData objects with all organizations retrieved.
     */
    IOTileCloud.prototype.fetchOrgMetaData = function () {
        return __awaiter(this, void 0, void 0, function () {
            var orgs, projects, projectMap, orgMap, _i, projects_1, project, _a, orgs_1, org, projectID, project, orgSlug, orgList, orgSlug;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, this.fetchOrgs()];
                    case 1:
                        orgs = _b.sent();
                        return [4 /*yield*/, this.fetchProjects()];
                    case 2:
                        projects = _b.sent();
                        projectMap = {};
                        orgMap = {};
                        for (_i = 0, projects_1 = projects; _i < projects_1.length; _i++) {
                            project = projects_1[_i];
                            projectMap[project.id] = project;
                        }
                        for (_a = 0, orgs_1 = orgs; _a < orgs_1.length; _a++) {
                            org = orgs_1[_a];
                            orgMap[org.slug] = {
                                name: org.name,
                                slug: org.slug,
                                projects: []
                            };
                        }
                        for (projectID in projectMap) {
                            project = projectMap[projectID];
                            orgSlug = project.orgSlug;
                            if (!(orgSlug in orgMap)) {
                                config_1.catCloud.debug("Received a project from IOTile.cloud that did not have an org: " + project + " " + orgSlug);
                                continue;
                            }
                            orgMap[orgSlug].projects.push({
                                name: project.name,
                                id: project.id
                            });
                        }
                        orgList = [];
                        for (orgSlug in orgMap) {
                            orgList.push(orgMap[orgSlug]);
                        }
                        return [2 /*return*/, orgList];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllDevices
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available devices from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Device objects with all devices retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all devices available
     * var devices = await IOTileCloud.fetchAllDevices();
     * console.log("Found " + devices.length + " IOTile Devices!");
     * </pre>
     *
     * @returns {Device[]} A list of the IOTile devices.
     */
    IOTileCloud.prototype.fetchAllDevices = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/device/?page_size=1000') //The default limit of devices returned per page is apparently 100
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newDevice = new models_1.Device(item);
                                list.push(newDevice);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjectDevices
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all devices for a given project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Device objects with all devices retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all devices available for project with ID: projId
     * var projDevices = await IOTileCloud.fetchProjectDevices(projId);
     * console.log("Found " + projDevices.length + " IOTile Devices!");
     * </pre>
     *
     * @param {string} projectId The id property of the project object that
     *                           devices will be fetched from.
     *
     * @returns {Device[]} A list of the IOTile devices.
     */
    IOTileCloud.prototype.fetchProjectDevices = function (projectId) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/device/?project=' + projectId + '&page_size=1000')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newDevice = new models_1.Device(item);
                                list.push(newDevice);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchDevice
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific device from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Device object with the device requested.
     *
     * @example
     * <pre>
     * // Get a device object for device with slug: devSlug
     * var device = await IOTileCloud.fetchDevice(devSlug);
     * console.log("Found device with label: " + device.label);
     * </pre>
     *
     * @param {string} deviceSlug The slug property of the device that will
     *                            be fetched.
     *
     * @returns {Device} An IOTile Device.
     */
    IOTileCloud.prototype.fetchDevice = function (deviceSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/device/' + deviceSlug + '/')
                            .then(function (item) {
                            var newDevice = new models_1.Device(item);
                            resolve(newDevice);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllStreams
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available streams from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Stream objects with all streams retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all streams available
     * var streams = await IOTileCloud.fetchAllStreams();
     * console.log("Found " + streams.length + " IOTile Streams!");
     * </pre>
     *
     * @returns {Stream[]} A list of the IOTile streams.
     */
    IOTileCloud.prototype.fetchAllStreams = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/stream/?page_size=3000')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newStream = new models_1.Stream(item);
                                list.push(newStream);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjectStreams
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all streams for a given project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Stream objects with all streams retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all streams available for project with ID: projId
     * var projStreams = await IOTileCloud.fetchProjectStreams(projId);
     * console.log("Found " + projStreams.length + " IOTile Streams!");
     * </pre>
     *
     * @param {string} projectId The id property of the project object that
     *                           streams will be fetched from.
     *
     * @returns {Stream[]} A list of the IOTile streams.
     */
    IOTileCloud.prototype.fetchProjectStreams = function (projectId, virtual) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var uri = '/stream/?project=' + projectId + '&page_size=3000';
                        if (virtual) {
                            uri += '&virtual=1';
                        }
                        that.fetchFromServer(uri)
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newStream = new models_1.Stream(item);
                                list.push(newStream);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchStream
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific stream from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Stream object with the stream requested.
     *
     * @example
     * <pre>
     * // Get a stream object for stream with slug: streamSlug
     * var stream = await IOTileCloud.fetchStream(streamSlug);
     * console.log("Found stream with slug: " + stream.slug);
     * </pre>
     *
     * @param {string} streamSlug The slug property of the stream that will
     *                            be fetched.
     *
     * @returns {Stream} An IOTile Stream.
     */
    IOTileCloud.prototype.fetchStream = function (streamSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/stream/' + streamSlug + '/')
                            .then(function (item) {
                            var newStream = new models_1.Stream(item);
                            resolve(newStream);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.deleteStream = function (streamSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.deleteFromServer('/stream/' + streamSlug + '/')
                            .then(function (resp) {
                            resolve(resp);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchStreamData
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific stream's datapoints from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a list of DataPoints from the stream requested.
     *
     * @example
     * <pre>
     * // Get an array of DataPoints for stream with slug: streamSlug
     * var datapoints = await IOTileCloud.fetchStreamData(streamSlug);
     * console.log(`Found ${datapoints.length} datapoints from stream with slug: ${stream.slug}`);
     * </pre>
     *
     * @param {string} streamSlug The slug property of the stream that will
     *                            be fetched.
     *
     * @returns {Array<DataPoint>} An array of DataPoints.
     */
    IOTileCloud.prototype.fetchStreamData = function (streamSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that, datapoints;
            return __generator(this, function (_a) {
                that = this;
                datapoints = [];
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/stream/' + streamSlug + '/')
                            .then(function (result) {
                            lodash.forEach(result, function (item) {
                                var newData = new models_1.DataPoint(item);
                                datapoints.push(newData);
                            });
                            resolve(datapoints);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.createStream = function (variable, dataLabel) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'variable': variable,
                            'data_label': dataLabel
                        };
                        return [4 /*yield*/, this.postToServer('/stream/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    IOTileCloud.prototype.createVariable = function (name, project, lid) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'name': name,
                            'project': project,
                            'lid': lid
                        };
                        return [4 /*yield*/, this.postToServer('/variable/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    IOTileCloud.prototype.postStreamData = function (streamSlug, type, value) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'stream': streamSlug,
                            'type': type,
                            'timestamp': new Date(),
                            'int_value': value
                        };
                        return [4 /*yield*/, this.postToServer('/data/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllVariables
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available variables from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Variable objects with all variables retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all variables available
     * var variables = await IOTileCloud.fetchAllVariables();
     * console.log("Found " + variables.length + " IOTile Variables!");
     * </pre>
     *
     * @returns {Variable[]} A list of the IOTile variables.
     */
    IOTileCloud.prototype.fetchAllVariables = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newVariable = new models_1.Variable(item);
                                list.push(newVariable);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjectVariables
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all variables for a given project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Variable objects with all variables retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all variables available for project with ID: projId
     * var projVariables = await IOTileCloud.fetchProjectVariables(projId);
     * console.log("Found " + projVariables.length + " IOTile Variables!");
     * </pre>
     *
     * @param {string} projectId The id property of the project object that
     *                           variables will be fetched from.
     *
     * @returns {Variable[]} A list of the IOTile variables.
     */
    IOTileCloud.prototype.fetchProjectVariables = function (projectId) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/?project=' + projectId)
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newVariable = new models_1.Variable(item);
                                list.push(newVariable);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchVariable
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific variable from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Variable object with the variable requested.
     *
     * @example
     * <pre>
     * // Get a Variable object for variable with slug: variableSlug
     * var variable = await IOTileCloud.fetchVariable(variableSlug);
     * console.log("Found variable with slug: " + variable.slug);
     * </pre>
     *
     * @param {string} variableSlug The slug property of the variable that will
     *                            be fetched.
     *
     * @returns {Variable} An IOTile Variable.
     */
    IOTileCloud.prototype.fetchVariable = function (variableSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/' + variableSlug + '/')
                            .then(function (item) {
                            var newVariable = new models_1.Variable(item);
                            resolve(newVariable);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllVarTypes
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available vartypes from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of VarType objects with all vartypes retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all vartypes available
     * var vartypes = await IOTileCloud.fetchAllVarTypes();
     * console.log("Found " + vartypes.length + " IOTile VarTypes!");
     * </pre>
     *
     * @returns {VarType[]} A list of the IOTile vartypes.
     */
    IOTileCloud.prototype.fetchAllVarTypes = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/vartype/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newVarType = new models_1.VarType(item);
                                list.push(newVarType);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllProjectTemplates
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available project templates from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of ProjectTemplate objects with all project templates retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all project templates available
     * var project_templates = await IOTileCloud.fetchAllProjectTemplates();
     * console.log("Found " + project_templates.length + " IOTile ProjectTemplates!");
     * </pre>
     *
     * @returns {ProjectTemplate[]} A list of the IOTile project templates.
     */
    IOTileCloud.prototype.fetchAllProjectTemplates = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/pt/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newProjectTemplate = new models_1.ProjectTemplate(item);
                                list.push(newProjectTemplate);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
   * @ngdoc method
   * @name iotile.cloud.service:IOTileCloud#fetchAllPropertyTemplates
   * @methodOf iotile.cloud.service:IOTileCloud
   *
   * @description
   * Fetches all available property templates from the IOTile Cloud.
   *
   * **This is an async method!**
   *
   * Returns an array of PropertyTemplate objects with all property templates retrieved.
   *
   * @example
   * <pre>
   * // Get an array of all property templates available
   * var property_templates = await IOTileCloud.fetchAllPropertyTemplates();
   * console.log("Found " + property_templates.length + " IOTile PropertyTemplates!");
   * </pre>
   *
   * @returns {PropertyTemplate[]} A list of the IOTile property templates.
   */
    IOTileCloud.prototype.fetchAllPropertyTemplates = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/propertytemplate/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newPropertyTemplate = new models_1.PropertyTemplate(item);
                                list.push(newPropertyTemplate);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
   * @ngdoc method
   * @name iotile.cloud.service:IOTileCloud#fetchProperties
   * @methodOf iotile.cloud.service:IOTileCloud
   *
   * @description
   * Fetches properties for a given target from the IOTile Cloud.
   *
   * **This is an async method!**
   *
   * Returns a Property object for the target requested.
   *
   * @example
   * <pre>
   * // Get the Properties for a target with slug: slug
   * var properties = await IOTileCloud.fetchProperties(slug);
   * </pre>
   *
   * @param {string} deviceSlug The slug property of the device for which
   *                              the property is associated.
   *
   * @returns {Property[]} An IOTile Property.
   */
    IOTileCloud.prototype.fetchProperties = function (deviceSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/property/?target=' + deviceSlug)
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newProperty = new models_1.Property(item);
                                list.push(newProperty);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchVarType
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific variable type from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a VarType object with the variable type requested.
     *
     * @example
     * <pre>
     * // Get a VarType object for variable with slug: variableSlug
     * var vartype = await IOTileCloud.fetchVarType(variableSlug);
     * console.log("Found vartype with slug: " + vartype.slug);
     * </pre>
     *
     * @param {string} variableSlug The slug property of the variable for which
     *                              the vartype is associated.
     *
     * @returns {Variable} An IOTile Variable.
     */
    IOTileCloud.prototype.fetchVarType = function (variableSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/' + variableSlug + '/type/')
                            .then(function (item) {
                            var newVarType = new models_1.VarType(item);
                            resolve(newVarType);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.fetchSensorGraphs = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/sg/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newSG = new models_1.SensorGraph(item);
                                list.push(newSG);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.refreshToken = function (currentToken) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.postToServer('/auth/api-jwt-refresh/', { token: currentToken })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response['token']];
                }
            });
        });
    };
    IOTileCloud.prototype.logout = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.postToServer('/auth/logout/', undefined)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.login = function (email, password) {
        return __awaiter(this, void 0, void 0, function () {
            var response, user, err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 3, , 4]);
                        return [4 /*yield*/, this.postToServer('/auth/api-jwt-auth/', { username: email, password: password })];
                    case 1:
                        response = _a.sent();
                        return [4 /*yield*/, this.fetchUserData(response['token'])];
                    case 2:
                        user = _a.sent();
                        return [2 /*return*/, user];
                    case 3:
                        err_1 = _a.sent();
                        if (!(err_1 instanceof models_1.HttpError)) {
                            err_1 = new models_1.HttpError(err_1);
                        }
                        throw err_1;
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.register = function (username, name, email, password1, password2) {
        try {
            return this.postToServer('/account/', {
                username: username,
                name: name,
                email: email,
                password: password1,
                confirm_password: password2
            });
        }
        catch (err) {
            if (!(err instanceof models_1.HttpError)) {
                err = new models_1.HttpError(err);
            }
            throw err;
        }
    };
    IOTileCloud.prototype.fetchUserData = function (token) {
        return __awaiter(this, void 0, void 0, function () {
            var response, info;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetchFromServer('/account/', { 'Authorization': "JWT " + token })];
                    case 1:
                        response = _a.sent();
                        if (!response['length']) {
                            throw new iotile_common_1.UserNotLoggedInError("No information for logged in user token");
                        }
                        info = response[0];
                        return [2 /*return*/, new models_1.User(info, token)];
                }
            });
        });
    };
    IOTileCloud.prototype.setToken = function (token) {
        axios.defaults.headers.common['Authorization'] = token;
    };
    IOTileCloud.prototype.deleteFromServer = function (uri, headers) {
        return __awaiter(this, void 0, void 0, function () {
            var request, that;
            return __generator(this, function (_a) {
                if (!this._server) {
                    throw new Error("Cannot delete " + uri + ": unknown server address");
                }
                request = {
                    method: 'DELETE',
                    url: this._server.url + uri,
                    timeout: this.Config.ENV.HTTP_TIMEOUT
                };
                if (headers) {
                    request['headers'] = headers;
                }
                config_1.catCloud.debug("[IOTileCloud] Delete request: " + request);
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(request).then(function (response) {
                            config_1.catCloud.debug("[IOTileCloud] Response: " + response);
                            that.inProgressConnections -= 1;
                            if (response.data['results'] !== undefined) {
                                resolve(response.data['results']);
                            }
                            else {
                                resolve(response.data);
                            }
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new models_1.HttpError(err));
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.fetchFromServer = function (uri, headers) {
        return __awaiter(this, void 0, void 0, function () {
            var request, that;
            return __generator(this, function (_a) {
                if (!this._server) {
                    throw new Error("Cannot fetch " + uri + ": unknown server address");
                }
                request = {
                    method: 'GET',
                    url: this._server.url + uri,
                    timeout: this.Config.ENV.HTTP_TIMEOUT
                };
                if (headers) {
                    request['headers'] = headers;
                }
                config_1.catCloud.debug("[IOTileCloud] Fetch request: " + request);
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(request).then(function (response) {
                            config_1.catCloud.debug("[IOTileCloud] Response: " + response);
                            that.inProgressConnections -= 1;
                            if (response.data['results'] !== undefined) {
                                resolve(response.data['results']);
                            }
                            else {
                                resolve(response.data);
                            }
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new models_1.HttpError(err));
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.postToServer = function (uri, data) {
        return __awaiter(this, void 0, void 0, function () {
            var request, that;
            return __generator(this, function (_a) {
                if (!this._server) {
                    throw new Error("Cannot post to " + uri + ": unknown server address");
                }
                ;
                request = { method: 'POST',
                    url: this._server.url + uri,
                    timeout: this.Config.ENV.HTTP_TIMEOUT };
                if (data !== null) {
                    request['data'] = data;
                }
                config_1.catCloud.debug("[IOTileCloud] Post request: " + request);
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(request).then(function (response) {
                            config_1.catCloud.debug("[IOTileCloud] Response: " + response);
                            that.inProgressConnections -= 1;
                            if (response.data['results'] !== undefined) {
                                resolve(response.data['results']);
                            }
                            else {
                                resolve(response.data);
                            }
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new models_1.HttpError(err));
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.postFirmwareUpgrade = function (slug, version) {
        return __awaiter(this, void 0, void 0, function () {
            var payload;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            firmware: version
                        };
                        return [4 /*yield*/, this.postToServer("/device/" + slug + "/upgrade/", payload)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.postEvent = function (stream, extra_data) {
        return __awaiter(this, void 0, void 0, function () {
            var payload;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            "stream": stream,
                            "timestamp": new Date(),
                            //"streamer_local_id": 0,
                            "extra_data": extra_data
                        };
                        return [4 /*yield*/, this.postToServer('/event/', payload)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.postFileToNote = function (note_id, file) {
        return __awaiter(this, void 0, void 0, function () {
            var url_payload, resp, formData, metaData, key, value, s3Response, err_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        url_payload = {
                            "name": file.name
                        };
                        return [4 /*yield*/, this.postToServer("/note/" + note_id + "/uploadurl/", url_payload)];
                    case 1:
                        resp = _a.sent();
                        if (!resp) return [3 /*break*/, 7];
                        formData = new FormData();
                        metaData = resp['fields'];
                        for (key in metaData) {
                            value = metaData[key];
                            formData.append(key, value);
                        }
                        formData.append('file', file, file.name);
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 6, , 7]);
                        return [4 /*yield*/, axios({
                                method: 'POST',
                                url: resp['url'],
                                data: formData,
                                transformRequest: [function (data, headers) {
                                        delete headers.common.Authorization;
                                        return data;
                                    }]
                            })];
                    case 3:
                        s3Response = _a.sent();
                        if (!(s3Response.status == 204)) return [3 /*break*/, 5];
                        return [4 /*yield*/, this.postToServer("/note/" + note_id + "/uploadsuccess/", { "name": file.name, "uuid": resp['uuid'] })];
                    case 4:
                        _a.sent();
                        _a.label = 5;
                    case 5: return [3 /*break*/, 7];
                    case 6:
                        err_2 = _a.sent();
                        config_1.catCloud.error("S3 Upload failed on " + file.name, err_2);
                        return [3 /*break*/, 7];
                    case 7: return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.postNote = function (target, timestamp, note) {
        return __awaiter(this, void 0, void 0, function () {
            var payload, resp;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            "target": target,
                            "timestamp": timestamp || new Date(),
                            "note": note
                        };
                        return [4 /*yield*/, this.postToServer('/note/', payload)];
                    case 1:
                        resp = _a.sent();
                        return [2 /*return*/, resp];
                }
            });
        });
    };
    IOTileCloud.prototype.postLocation = function (target, timestamp, lat, lon) {
        return __awaiter(this, void 0, void 0, function () {
            var payload;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            "target": target,
                            "timestamp": timestamp || new Date(),
                            "lat": lat,
                            "lon": lon
                        };
                        return [4 /*yield*/, this.postToServer('/location/', payload)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchStreamer
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific variable type from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Streamer object with the slug requested.
     *
     * @example
     * <pre>
     * // Get a Streamer object for variable with slug: streamerSlug
     * var streamer = await IOTileCloud.fetchStreamer(streamerSlug);
     * console.log("Found streamer with slug: " + streamer.slug);
     * </pre>
     *
     * @param {string} streamerSlug The slug property of the streamer we're requesting.
     *
     * @returns {Streamer} An IOTile Streamer.
     */
    IOTileCloud.prototype.fetchStreamer = function (streamerSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/streamer/' + streamerSlug + '/')
                            .then(function (item) {
                            var newStreamer = new models_1.Streamer(item);
                            resolve(newStreamer);
                        }, function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.fetchAcknowledgements = function (deviceSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var filter, acks;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        filter = "?";
                        if (deviceSlug != null)
                            filter = "?device=" + deviceSlug + "&";
                        filter += 'page_size=1000';
                        return [4 /*yield*/, this.fetchFromServer('/streamer/' + filter)];
                    case 1:
                        acks = _a.sent();
                        return [2 /*return*/, acks.map(function (val) {
                                return {
                                    deviceSlug: val['device'],
                                    index: val['index'],
                                    highestAck: val['last_id']
                                };
                            })];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#patchStream
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Updates the IOTile Cloud with any changes made to a Stream object.
     *
     * **This is an async method!**
     *
     * Returns a promise that will resolve with the status of the http call.
     *
     * @example
     * <pre>
     * // Patch our changed Stream object (streamObj) up to the cloud
     * var status = await IOTileCloud.patchStream(streamObj);
     * console.log("Patched stream with status: " + status.status);
     * </pre>
     *
     * @param {Stream} streamObj The stream object that has been updated.
     *
     * @returns {Promise} A promise that will resolve with the http status.
     */
    IOTileCloud.prototype.patchModel = function (slug, patchPayload) {
        return __awaiter(this, void 0, void 0, function () {
            var that, modelType, payload;
            return __generator(this, function (_a) {
                that = this;
                modelType = null;
                if (iotile_common_1.startsWith(slug, 's--')) {
                    modelType = '/stream/';
                }
                else if (iotile_common_1.startsWith(slug, 'd--')) {
                    modelType = '/device/';
                }
                else {
                    throw new iotile_common_1.ArgumentError("Unknown slug type in patchModel: " + slug);
                }
                if (!this._server) {
                    throw new Error("Cannot patch " + slug + ": unknown server address");
                }
                payload = {
                    url: this._server.url + modelType + slug + '/',
                    method: 'PATCH',
                    data: patchPayload,
                    timeout: this.Config.ENV.HTTP_TIMEOUT
                };
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(payload).then(function (result) {
                            that.inProgressConnections -= 1;
                            resolve(result);
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new models_1.HttpError(err));
                        });
                    })];
            });
        });
    };
    return IOTileCloud;
}());
exports.IOTileCloud = IOTileCloud;
//# sourceMappingURL=iotile-cloud-serv.js.map