var ApiFilter = /** @class */ (function () {
    function ApiFilter() {
        this.filters = [];
    }
    ApiFilter.prototype.filterString = function () {
        // Build a '?name1=val1&name2=val2' string
        if (this.filters.length) {
            var dataFilter = '?' + this.filters.join('&');
            return dataFilter;
        }
        return '';
    };
    ApiFilter.prototype.addFilter = function (name, value, unique) {
        if (unique === void 0) { unique = false; }
        var arg = name + '=' + value;
        if (unique) {
            this.removeFilter(name);
        }
        this.filters.push(arg);
    };
    ApiFilter.prototype.removeFilter = function (name) {
        var arg = name + '=';
        this.filters = this.filters.filter(function (item) {
            return item.indexOf(arg) !== 0;
        });
    };
    return ApiFilter;
}());

var Credentials = /** @class */ (function () {
    function Credentials(username, password) {
        this.username = username;
        this.password = password;
        this.token = '';
    }
    Credentials.prototype.getPayload = function () {
        return {
            username: this.username,
            password: this.password
        };
    };
    Credentials.prototype.setToken = function (token) {
        this.token = token;
    };
    Credentials.prototype.getToken = function () {
        return this.token;
    };
    Credentials.prototype.clearToken = function () {
        this.token = '';
    };
    return Credentials;
}());

var DataBlock = /** @class */ (function () {
    function DataBlock(data) {
        this.description = '';
        this.pid = '';
        this.id = data.id;
        this.slug = data.slug;
        this.title = data.title;
        this.org = data.org;
        this.block = data.block;
        this.sensorGraphSlug = data.sg;
        this.createdOn = new Date(data.created_on);
        this.createdBy = data.created_by;
        if ('description' in data) {
            this.description = data.description;
        }
        if ('pid' in data) {
            this.pid = data.pid;
        }
    }
    DataBlock.prototype.getPostPayload = function () {
        var payload = {
            title: this.title,
            device: this.slug,
            description: ''
        };
        if (this.description) {
            payload.description = this.description;
        }
        if (this.onComplete) {
            payload['on_complete'] = this.onComplete;
        }
        return payload;
    };
    return DataBlock;
}());

var DataFilterArgs = /** @class */ (function () {
    function DataFilterArgs() {
    }
    DataFilterArgs.prototype.buildFilterString = function () {
        var parameters = [];
        if (this.startDate) {
            parameters.push('start=' + this.startDate.toISOString());
        }
        var now = new Date();
        if (!this.endDate || this.endDate > now) {
            this.endDate = now;
        }
        if (this.endDate) {
            parameters.push('end=' + this.endDate.toISOString());
        }
        if (this.lastN) {
            parameters.push('lastn=' + this.lastN);
        }
        if (this.page) {
            parameters.push('page=' + this.page);
        }
        if (this.pageSize) {
            parameters.push('page_size=' + this.pageSize);
        }
        if (this.filter) {
            parameters.push('filter=' + this.filter);
        }
        if (this.startIncrementalId) {
            parameters.push('streamer_id_0=' + this.startIncrementalId);
        }
        if (this.endIncrementalId) {
            parameters.push('streamer_id_1=' + this.endIncrementalId);
        }
        if (this.extras && this.extras.length > 0) {
            this.extras.forEach(function (p) {
                parameters.push(p);
            });
        }
        if (parameters.length) {
            var dataFilter = '?' + parameters.join('&');
            return dataFilter;
        }
        return '';
    };
    DataFilterArgs.prototype.buildFilterLabel = function () {
        var filterLabel = '';
        if (this.startDate) {
            filterLabel += ' from ' + this.startDate.toLocaleDateString();
        }
        if (this.endDate) {
            filterLabel += ' to ' + this.endDate.toLocaleDateString();
        }
        if (this.lastN) {
            filterLabel += ' last ' + this.lastN + ' entries';
        }
        if (!this.startDate && !this.endDate && !this.lastN) {
            filterLabel = '';
        }
        return filterLabel;
    };
    return DataFilterArgs;
}());

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}











function __awaiter(thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var Page = /** @class */ (function () {
    function Page(url, thisPage, pageCount) {
        this.baseUrl = url;
        this.page = thisPage;
        this.pageCount = pageCount;
    }
    Page.prototype.pageUrl = function () {
        var url = this.baseUrl;
        url += '&page=' + this.page;
        return url;
    };
    return Page;
}());

var DataPage = /** @class */ (function (_super) {
    __extends(DataPage, _super);
    function DataPage(url, thisPage, pageCount, stream) {
        var _this = _super.call(this, url, thisPage, pageCount) || this;
        _this.stream = stream;
        _this.data = [];
        return _this;
    }
    return DataPage;
}(Page));
var DataPoint = /** @class */ (function () {
    function DataPoint(data) {
        if (data === void 0) { data = {}; }
        this.timestamp = new Date(data.timestamp);
        if ('stream' in data) {
            // Only getData returns a stream slug
            this.stream = data.stream;
        }
        if ('value' in data) {
            // NewScheme: Value represents a number as per the Stream's VarType
            this.value = data.value;
        }
        if ('int_value' in data) {
            // OldScheme: We only store the raw number from the device
            this.rawValue = data.int_value;
        }
        if ('output_value' in data) {
            this.outValue = data.output_value;
        }
        if ('display_value' in data) {
            this.displayValue = data.display_value;
        }
        if ('streamer_local_id' in data) {
            this.incrementalId = data.streamer_local_id;
        }
        if ('dirty_ts' in data) {
            this.dirtyTimestamp = data.dirty_ts;
        }
    }
    return DataPoint;
}());

var ObjectBase = /** @class */ (function () {
    function ObjectBase(name, $injector) {
        this.className = name;
        this.$log = $injector.get("$log");
        this.$injector = $injector;
    }
    ObjectBase.prototype.log_debug = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        (_a = this.$log).debug.apply(_a, ["[" + this.className + "] " + message].concat(args));
        var _a;
    };
    ObjectBase.prototype.log_warn = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        (_a = this.$log).warn.apply(_a, ["[" + this.className + "] " + message].concat(args));
        var _a;
    };
    ObjectBase.prototype.log_error = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        (_a = this.$log).error.apply(_a, ["[" + this.className + "] " + message].concat(args));
        var _a;
    };
    ObjectBase.prototype.log_info = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        (_a = this.$log).info.apply(_a, ["[" + this.className + "] " + message].concat(args));
        var _a;
    };
    return ObjectBase;
}());

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics$1 = Object.setPrototypeOf ||
    ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
    function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };

function __extends$1(d, b) {
    extendStatics$1(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}











function __awaiter$1(thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator$1(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

/**
 * @ngdoc object
 * @name Errors.type:BaseError
 * @description
 * The base error class for all exceptions.  All exceptions must
 * have a name that should match the name of their class and a user
 * settable message.  Typically, subclasses of BaseError will fill in the
 * name field in their own constructor, so users do not have to set it.
 *
 * @property {string} name The name of of the exception, which is intended
 *   to be used as a method of filtering different exceptions.
 * @property {string} message A freeform message that provides more detail
 *   into what caused this error.
 */
var BaseError = /** @class */ (function () {
    function BaseError(name, message) {
        this.name = name;
        this.message = message;
    }
    return BaseError;
}());
/**
 * @ngdoc object
 * @name Errors.type:ArgumentError
 * @description
 * There was an issue with one of the parameters passed to this function.
 * The parameter was invalid.  The included message should contain more
 * details about what was expected vs received.
 */
var ArgumentError = /** @class */ (function (_super) {
    __extends$1(ArgumentError, _super);
    function ArgumentError(message) {
        return _super.call(this, 'ArgumentError', message) || this;
    }
    return ArgumentError;
}(BaseError));
/**
 * @ngdoc object
 * @name Errors.type:InvalidOperationError
 * @description
 * The operation could not be performed at the time that it
 * was requested.  This may be because the application's state
 * did not allow its preconditions to be met.
 */
var InvalidOperationError = /** @class */ (function (_super) {
    __extends$1(InvalidOperationError, _super);
    function InvalidOperationError(message) {
        return _super.call(this, 'InvalidOperationError', message) || this;
    }
    return InvalidOperationError;
}(BaseError));
/**
 * @ngdoc object
 * @name Errors.type:UnknownError
 * @description
 * There was an unspecified error with the operation.
 * See the message property for more details.
 */
var UnknownError = /** @class */ (function (_super) {
    __extends$1(UnknownError, _super);
    function UnknownError(message) {
        return _super.call(this, 'UnknownError', message) || this;
    }
    return UnknownError;
}(BaseError));
/**
 * @ngdoc object
 * @name Errors.type:InsufficientSpaceError
 * @description
 * There was not sufficient space to perform this operation.  This error
 * could be thrown, if, for example, you were trying to append data to a fixed
 * size buffer and there was not room in the buffer for all the data you wanted
 * to append.
 */
var InsufficientSpaceError = /** @class */ (function (_super) {
    __extends$1(InsufficientSpaceError, _super);
    function InsufficientSpaceError(message) {
        return _super.call(this, 'InsufficientSpaceError', message) || this;
    }
    return InsufficientSpaceError;
}(BaseError));
/**
 * @ngdoc object
 * @name Errors.type:UnknownKeyError
 * @description
 * A key was passed to a lookup table and it was not found.
 */
var UnknownKeyError = /** @class */ (function (_super) {
    __extends$1(UnknownKeyError, _super);
    function UnknownKeyError(message) {
        return _super.call(this, 'UnknownKeyError', message) || this;
    }
    return UnknownKeyError;
}(BaseError));
/**
 * @ngdoc object
 * @name Errors.type:FileSystemError
 * @description
 * There was an error interacting with the file system on
 * the device.
 */
var FileSystemError = /** @class */ (function () {
    function FileSystemError(name, message, code) {
        this.name = name;
        this.message = message;
        this.code = code;
    }
    FileSystemError.NOT_FOUND_ERR = 1;
    FileSystemError.SECURITY_ERR = 2;
    FileSystemError.ABORT_ERR = 3;
    FileSystemError.NOT_READABLE_ERR = 4;
    FileSystemError.ENCODING_ERR = 5;
    FileSystemError.NO_MODIFICATION_ALLOWED_ERR = 6;
    FileSystemError.INVALID_STATE_ERR = 7;
    FileSystemError.SYNTAX_ERR = 8;
    FileSystemError.INVALID_MODIFICATION_ERR = 9;
    FileSystemError.QUOTA_EXCEEDED_ERR = 10;
    FileSystemError.TYPE_MISMATCH_ERR = 11;
    FileSystemError.PATH_EXISTS_ERR = 12;
    return FileSystemError;
}());
/**
 * @ngdoc object
 * @name Errors.type:UnknownFileSystemError
 *
 * @description
 * There was an error interacting with the file system on
 * the device.
 */
var UnknownFileSystemError = /** @class */ (function (_super) {
    __extends$1(UnknownFileSystemError, _super);
    function UnknownFileSystemError(code, path) {
        return _super.call(this, 'UnknownFileSystemError', "Unknown filesystem error: " + code + " path: " + path, code) || this;
    }
    return UnknownFileSystemError;
}(FileSystemError));
var InvalidDataError = /** @class */ (function () {
    function InvalidDataError(name, message) {
        this.name = name;
        this.message = message;
    }
    return InvalidDataError;
}());
var UserNotLoggedInError = /** @class */ (function () {
    function UserNotLoggedInError(message) {
        this.message = message;
    }
    return UserNotLoggedInError;
}());
var DataCorruptedError = /** @class */ (function (_super) {
    __extends$1(DataCorruptedError, _super);
    function DataCorruptedError(message) {
        return _super.call(this, "DataCorruptedError", message) || this;
    }
    return DataCorruptedError;
}(InvalidDataError));
var DataStaleError = /** @class */ (function (_super) {
    __extends$1(DataStaleError, _super);
    function DataStaleError(message) {
        return _super.call(this, "DataStaleError", message) || this;
    }
    return DataStaleError;
}(InvalidDataError));
var CorruptDeviceError = /** @class */ (function (_super) {
    __extends$1(CorruptDeviceError, _super);
    function CorruptDeviceError(message) {
        return _super.call(this, "CorruptDeviceError", message) || this;
    }
    return CorruptDeviceError;
}(InvalidDataError));

/*
 * Classes for reporting progress about complex
 * multistep operations.
 */
var ProgressNotifier = /** @class */ (function () {
    function ProgressNotifier() {
    }
    ProgressNotifier.prototype.finishOne = function () {
    };
    ProgressNotifier.prototype.startOne = function (desc, subparts) {
        return null;
    };
    ProgressNotifier.prototype.setTotal = function (total) {
    };
    ProgressNotifier.prototype.addMessage = function (severity, message, priority) {
        if (priority === void 0) { priority = false; }
    };
    ProgressNotifier.prototype.fatalError = function (message) {
    };
    ProgressNotifier.prototype.updateDescription = function (desc) {
    };
    Object.defineProperty(ProgressNotifier.prototype, "hasErrors", {
        get: function () {
            return false;
        },
        enumerable: true,
        configurable: true
    });
    return ProgressNotifier;
}());
var TaskProgressNotifier = /** @class */ (function (_super) {
    __extends$1(TaskProgressNotifier, _super);
    function TaskProgressNotifier(manager) {
        var _this = _super.call(this) || this;
        _this.manager = manager;
        return _this;
    }
    TaskProgressNotifier.prototype.finishOne = function () {
        this.manager.finishTask();
    };
    TaskProgressNotifier.prototype.startOne = function (desc, subparts) {
        return this.manager.startTask(desc, subparts);
    };
    TaskProgressNotifier.prototype.updateDescription = function (desc) {
        this.manager.subTaskDescription = desc;
        this.manager.updateScope();
    };
    TaskProgressNotifier.prototype.setTotal = function (total) {
        this.manager.totalTasks = total;
    };
    TaskProgressNotifier.prototype.addMessage = function (severity, message, priority) {
        if (priority === void 0) { priority = false; }
        this.manager.addMessage(severity, message, priority);
    };
    TaskProgressNotifier.prototype.fatalError = function (message) {
        this.manager.fatalError(message);
    };
    Object.defineProperty(TaskProgressNotifier.prototype, "hasErrors", {
        get: function () {
            return this.manager.hasErrors;
        },
        enumerable: true,
        configurable: true
    });
    return TaskProgressNotifier;
}(ProgressNotifier));
var SubTaskProgressNotifier = /** @class */ (function (_super) {
    __extends$1(SubTaskProgressNotifier, _super);
    function SubTaskProgressNotifier(manager) {
        var _this = _super.call(this) || this;
        _this.manager = manager;
        return _this;
    }
    SubTaskProgressNotifier.prototype.finishOne = function () {
        this.manager.updateSubtask();
    };
    SubTaskProgressNotifier.prototype.startOne = function (desc, subparts) {
        this.manager.subSubTaskDescription = desc;
        return new ProgressNotifier();
    };
    SubTaskProgressNotifier.prototype.setTotal = function (total) {
        this.manager.subTaskTotal = total;
    };
    SubTaskProgressNotifier.prototype.addMessage = function (severity, message, priority) {
        if (priority === void 0) { priority = false; }
        this.manager.addMessage(severity, message, priority);
    };
    SubTaskProgressNotifier.prototype.fatalError = function (message) {
        this.manager.fatalError(message);
    };
    SubTaskProgressNotifier.prototype.updateDescription = function (desc) {
        this.manager.subSubTaskDescription = desc;
        this.manager.updateScope();
    };
    return SubTaskProgressNotifier;
}(ProgressNotifier));
var MessageSeverity;
(function (MessageSeverity) {
    MessageSeverity[MessageSeverity["Info"] = 0] = "Info";
    MessageSeverity[MessageSeverity["Warn"] = 1] = "Warn";
    MessageSeverity[MessageSeverity["Error"] = 2] = "Error";
    MessageSeverity[MessageSeverity["Success"] = 3] = "Success";
})(MessageSeverity || (MessageSeverity = {}));
var UISeverity;
(function (UISeverity) {
    UISeverity["Info"] = "info";
    UISeverity["Warn"] = "warn";
    UISeverity["Error"] = "error";
    UISeverity["Success"] = "success";
})(UISeverity || (UISeverity = {}));
var OperationMessage = /** @class */ (function () {
    function OperationMessage(severity, message) {
        this.message = message;
        this.severity = severity;
    }
    Object.defineProperty(OperationMessage.prototype, "iconClass", {
        get: function () {
            switch (this.severity) {
                case MessageSeverity.Info:
                    return 'ion-information-circled positive';
                case MessageSeverity.Warn:
                    return 'ion-alert-circled energized';
                case MessageSeverity.Error:
                    return 'ion-minus-circled assertive';
                case MessageSeverity.Success:
                    return 'ion-checkmark-circled balanced';
            }
        },
        enumerable: true,
        configurable: true
    });
    return OperationMessage;
}());
var ProgressManager = /** @class */ (function () {
    function ProgressManager(totalTasks, $scope) {
        this.totalTasks = totalTasks;
        this.finishedTasks = 0;
        this.subTaskDescription = null;
        this.subSubTaskDescription = null;
        this.subTaskTotal = 0;
        this.subTaskFinished = 0;
        this.subTaskInProgress = false;
        this.messages = [];
        this.errorState = false;
        //If we need to autoupdate some bindings on a scope
        //by triggering a digest cycle
        this.scope = $scope;
    }
    ProgressManager.prototype.clear = function () {
        this.finishedTasks = 0;
        this.subTaskDescription = null;
        this.subTaskTotal = 0;
        this.subTaskFinished = 0;
        this.subTaskInProgress = false;
        this.priorityMessage = undefined;
        this.messages = [];
        this.errorState = false;
    };
    ProgressManager.prototype.getNotifier = function () {
        return new TaskProgressNotifier(this);
    };
    ProgressManager.prototype.startTask = function (desc, totalParts) {
        if (this.errorState) {
            return null;
        }
        this.subTaskTotal = totalParts;
        this.subTaskFinished = 0;
        this.subTaskDescription = desc;
        this.subTaskInProgress = true;
        this.updateScope();
        return new SubTaskProgressNotifier(this);
    };
    ProgressManager.prototype.finishTask = function () {
        if (this.errorState) {
            return;
        }
        if (this.subTaskInProgress) {
            this.subTaskInProgress = false;
            this.subTaskTotal = 0;
            this.subSubTaskDescription = null;
        }
        if (this.finishedTasks < this.totalTasks) {
            this.finishedTasks += 1;
        }
        this.updateScope();
    };
    ProgressManager.prototype.addMessage = function (severity, message, priority) {
        if (priority === void 0) { priority = false; }
        if (priority) {
            this.priorityMessage = new OperationMessage(severity, message);
        }
        else {
            this.messages.push(new OperationMessage(severity, message));
        }
    };
    ProgressManager.prototype.fatalError = function (message) {
        this.subTaskInProgress = false;
        this.finishedTasks = this.totalTasks;
        this.errorState = true;
        this.addMessage(MessageSeverity.Error, message);
        this.updateScope();
    };
    ProgressManager.prototype.updateSubtask = function () {
        if (this.errorState) {
            return;
        }
        if (this.subTaskFinished < this.subTaskTotal) {
            this.subTaskFinished += 1;
            this.subTaskInProgress = true;
        }
        this.updateScope();
    };
    Object.defineProperty(ProgressManager.prototype, "hasErrors", {
        get: function () {
            for (var _i = 0, _a = this.messages; _i < _a.length; _i++) {
                var msg = _a[_i];
                if (msg.severity === MessageSeverity.Error) {
                    return true;
                }
            }
            return false;
        },
        enumerable: true,
        configurable: true
    });
    ProgressManager.prototype.updateScope = function () {
        if (this.scope) {
            this.scope.$applyAsync();
        }
    };
    return ProgressManager;
}());

var ControllerBase = /** @class */ (function (_super) {
    __extends$1(ControllerBase, _super);
    function ControllerBase(name, $injector, $scope, options) {
        if (options === void 0) { options = { manualInitCleanup: false }; }
        var _this = _super.call(this, name, $injector) || this;
        _this.$scope = $scope;
        _this.$ionicPopup = $injector.get("$ionicPopup");
        _this.$ionicHistory = $injector.get("$ionicHistory");
        _this.$ionicLoading = $injector.get("$ionicLoading");
        _this.$ionicModal = $injector.get("$ionicModal");
        _this.$cordovaInAppBrowser = $injector.get("$cordovaInAppBrowser");
        _this.net = $injector.get('NetService');
        _this.error = null;
        _this.currentModal = null;
        var that = _this;
        /*
            * For generally good practice as well as for testability we need to know when the controller
            * has been properly initialized.  So we have an initialized promise that can be awaited to
            * make sure the controller has been properly initialized.
            *
            * NB the promise executor runs synchronously so there is no race condition here
            * setting resolve and reject handler and using them in the $scope.on clause below.  If a subclass
            * wants to manually initialize itself, it needs to assign a promise to this.initialized in the
            * constructor.
            */
        _this.initialized = null;
        if (options.manualInitCleanup === false) {
            var resolveInitialized_1;
            var rejectInitialized_1;
            _this.initialized = new Promise(function (resolve, reject) {
                resolveInitialized_1 = resolve;
                rejectInitialized_1 = reject;
            });
            $scope.$on('$ionicView.beforeEnter', function (ev) {
                return __awaiter$1(this, void 0, void 0, function () {
                    var err_1;
                    return __generator$1(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                that.error = null;
                                _a.label = 1;
                            case 1:
                                _a.trys.push([1, 3, , 4]);
                                return [4 /*yield*/, that.initialize()];
                            case 2:
                                _a.sent();
                                resolveInitialized_1();
                                return [3 /*break*/, 4];
                            case 3:
                                err_1 = _a.sent();
                                rejectInitialized_1(err_1);
                                return [3 /*break*/, 4];
                            case 4: return [2 /*return*/];
                        }
                    });
                });
            });
            $scope.$on('$ionicView.beforeLeave', function () {
                return __awaiter$1(this, void 0, void 0, function () {
                    return __generator$1(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, that.cleanup()];
                            case 1:
                                _a.sent();
                                return [2 /*return*/];
                        }
                    });
                });
            });
        }
        return _this;
    }
    ControllerBase.prototype.showLoading = function (message, autoCloseOnTransition) {
        if (autoCloseOnTransition === void 0) { autoCloseOnTransition = false; }
        return this.showLoadingEx({ template: message, hideOnStateChange: autoCloseOnTransition });
    };
    ControllerBase.prototype.showLoadingEx = function (details) {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.$ionicLoading.show(details).then(function () {
                            resolve();
                        }).catch(function (err) { return resolve(); });
                    })];
            });
        });
    };
    ControllerBase.prototype.hideLoading = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.$ionicLoading.hide().then(function () {
                            resolve();
                        }).catch(function (err) { return resolve(); });
                    })];
            });
        });
    };
    //FIXME: We may want to eliminate this function
    ControllerBase.prototype.showIsolatedModal = function (modalController) {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.currentModal = modalController;
                        return [4 /*yield*/, modalController.show()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    ControllerBase.prototype.hideIsolatedModal = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (this.currentModal === null) {
                            throw new InvalidOperationError('Hiding modal when there is no modal shown.');
                        }
                        return [4 /*yield*/, this.currentModal.hide()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    ControllerBase.prototype.openExternal = function (url) {
        var browserOptions = {
            location: 'yes',
            clearcache: 'yes',
            toolbar: 'yes'
        };
        var that = this;
        return new Promise(function (resolve, reject) {
            that.$cordovaInAppBrowser.open(url, '_blank', browserOptions).then(function () {
                resolve();
            }).catch(function (err) {
                reject(err);
            });
        });
    };
    //Deprecated, we should be using isolated modals now
    ControllerBase.prototype.showModal = function (templateURL) {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.$ionicModal.fromTemplateUrl(templateURL, { scope: that.$scope, animation: 'slide-in-up' }).then(function (modal) {
                            that.currentModal = modal;
                            modal.show().then(function () {
                                resolve();
                            });
                        });
                    })];
            });
        });
    };
    //Deprecated, we should be using isolated modals now
    ControllerBase.prototype.hideModal = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                if (this.currentModal === null) {
                    throw new InvalidOperationError('Hiding modal when there is no modal shown.');
                }
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.currentModal.hide().then(function () {
                            that.currentModal.remove();
                            that.currentModal = null;
                            resolve();
                        });
                    })];
            });
        });
    };
    ControllerBase.prototype.setError = function (message) {
        this.error = message;
        if (!this.$scope.$$phase) {
            this.$scope.$apply();
        }
    };
    ControllerBase.prototype.isOnline = function () {
        return this.net.isOnline();
    };
    ControllerBase.prototype.initialize = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                return [2 /*return*/];
            });
        });
    };
    ControllerBase.prototype.cleanup = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                return [2 /*return*/];
            });
        });
    };
    ControllerBase.prototype.leaveFromError = function (message, title) {
        return __awaiter$1(this, void 0, void 0, function () {
            var err_2;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.hideLoading()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 4, , 5]);
                        return [4 /*yield*/, this.hideModal()];
                    case 3:
                        _a.sent();
                        return [3 /*break*/, 5];
                    case 4:
                        err_2 = _a.sent();
                        return [3 /*break*/, 5];
                    case 5:
                        if (!title) {
                            title = "Fatal Error";
                        }
                        return [4 /*yield*/, this.alert(title, message)];
                    case 6:
                        _a.sent();
                        this.$ionicHistory.goBack();
                        return [2 /*return*/];
                }
            });
        });
    };
    ControllerBase.prototype.confirm = function (title, message, severity) {
        if (severity === void 0) { severity = UISeverity.Info; }
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.$ionicPopup.confirm({
                            title: title,
                            template: message,
                            cssClass: severity + '-popup',
                            buttons: [{
                                    text: "Cancel",
                                    type: "button-assertive",
                                    onTap: function (e) { return false; }
                                }, {
                                    text: "Okay",
                                    type: "button-balanced",
                                    onTap: function (e) { return true; }
                                }]
                        }).then(function (res) {
                            resolve(res);
                        });
                    })];
            });
        });
    };
    ControllerBase.prototype.alert = function (title, message, severity) {
        if (severity === void 0) { severity = UISeverity.Info; }
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.$ionicPopup.alert({
                            title: title,
                            cssClass: severity + '-popup',
                            template: message
                        }).then(function () {
                            resolve();
                        });
                    })];
            });
        });
    };
    return ControllerBase;
}(ObjectBase));

/**
 * ComponentBase should be used to create components
 * that can be invoked dynamically by name rather than having
 * to know the component's name at compile time.
 */
var ComponentBase = /** @class */ (function (_super) {
    __extends$1(ComponentBase, _super);
    function ComponentBase(name, $injector, $scope) {
        var _this = _super.call(this, name, $injector, $scope, { manualInitCleanup: true }) || this;
        var that = _this;
        _this.initialized = new Promise(function (resolve, reject) {
            that.resolve = resolve;
            that.reject = reject;
        });
        return _this;
    }
    ComponentBase.prototype.$onInit = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var initialized, error_1;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, this.initialize()];
                    case 1:
                        initialized = _a.sent();
                        if (this.resolve) {
                            this.resolve();
                        }
                        return [3 /*break*/, 3];
                    case 2:
                        error_1 = _a.sent();
                        this.log_error("Unable to initialize component; " + error_1);
                        if (this.reject) {
                            this.reject();
                        }
                        return [3 /*break*/, 3];
                    case 3: return [2 /*return*/];
                }
            });
        });
    };
    ComponentBase.prototype.$onDestroy = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                this.cleanup();
                return [2 /*return*/];
            });
        });
    };
    ComponentBase.prototype.initialize = function () {
        return __awaiter$1(this, void 0, void 0, function () { return __generator$1(this, function (_a) {
            return [2 /*return*/];
        }); });
    };
    ComponentBase.prototype.cleanup = function () {
        return __awaiter$1(this, void 0, void 0, function () { return __generator$1(this, function (_a) {
            return [2 /*return*/];
        }); });
    };
    return ComponentBase;
}(ControllerBase));

/**
 * CustomModalBase should be used to create modal controllers
 * that can be invoked dynamically by name rather than having
 * to know the modal's name at compile time.
 */
var CustomModalBase = /** @class */ (function (_super) {
    __extends$1(CustomModalBase, _super);
    function CustomModalBase(name, $injector, $scope) {
        var _this = _super.call(this, name, $injector, $scope, { manualInitCleanup: true }) || this;
        _this.modal = null;
        return _this;
    }
    //We need initialize to be accessible publically since it will be called by ModalBase 
    //when we are created
    CustomModalBase.prototype.initialize = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                return [2 /*return*/];
            });
        });
    };
    //We need initialize to be accessible publically since it will be called by ModalBase 
    //when we are created
    CustomModalBase.prototype.cleanup = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                return [2 /*return*/];
            });
        });
    };
    CustomModalBase.prototype.hide = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                if (!this.modal) {
                    this.log_error("Custom modal improperly constructed with no modal member");
                    return [2 /*return*/];
                }
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.modal.hide().then(resolve);
                    })];
            });
        });
    };
    CustomModalBase.prototype.remove = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                if (!this.modal) {
                    this.log_error("Custom modal improperly constructed with no modal member");
                    return [2 /*return*/];
                }
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.modal.remove().then(resolve);
                    })];
            });
        });
    };
    return CustomModalBase;
}(ControllerBase));

var ModalBase = /** @class */ (function (_super) {
    __extends$1(ModalBase, _super);
    function ModalBase(name, templateURL, $injector, options) {
        var _this = this;
        var $rootScope = $injector.get("$rootScope");
        var $scope = $rootScope.$new();
        _this = _super.call(this, name, $injector, $scope, { manualInitCleanup: true }) || this;
        _this.modal = null;
        _this.customController = null;
        _this.templateURL = templateURL;
        _this.options = options;
        //Normally we expect users to subclass ModalBase in order to create custom controllers.
        //However if we need to dynamically create new controllers based on a string name like in the
        //gateway page, we need a way to find the appropriate controller programmatically using angular's
        //$injector.
        //
        //If we should use a custom controller, create that and attach it to our scope instead of ourselves
        if (options.customController != null) {
            var controllerService = $injector.get("$controller");
            _this.customController = controllerService(options.customController, { $scope: $scope });
            if (!(_this.customController instanceof CustomModalBase)) {
                _this.log_error("Attempted to create a modal with a custom controller that did not inherit from CustomModalBase", options.customController);
                throw new ArgumentError("Invalid controller type specified: " + options.customController);
            }
            $scope.vm = _this.customController;
        }
        else {
            $scope.vm = _this; //Inject ourselves as vm so we can access our data from the template
        }
        _this.initialized = _this.createModal();
        var that = _this;
        $scope.$on('modal.removed', function () {
            return __awaiter$1(this, void 0, void 0, function () {
                return __generator$1(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(that.customController != null)) return [3 /*break*/, 2];
                            return [4 /*yield*/, that.customController.cleanup()];
                        case 1:
                            _a.sent();
                            return [3 /*break*/, 4];
                        case 2: return [4 /*yield*/, that.cleanup()];
                        case 3:
                            _a.sent();
                            _a.label = 4;
                        case 4: return [2 /*return*/];
                    }
                });
            });
        });
        return _this;
    }
    ModalBase.prototype.createModal = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var _this = this;
            var that;
            return __generator$1(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.$ionicModal.fromTemplateUrl(_this.templateURL, {
                            scope: _this.$scope,
                            animation: _this.options.animation,
                            backdropClickToClose: _this.options.backdropClickToClose,
                            hardwareBackButtonClose: _this.options.hardwareBackButtonClose
                        }).then(function (modal) {
                            that.modal = modal;
                            if (that.customController) {
                                that.customController.modal = modal;
                            }
                            resolve();
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    ModalBase.prototype.show = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.initialized];
                    case 1:
                        _a.sent();
                        that = this;
                        if (this.modal.isShown()) {
                            this.log_error("Show called multiple times");
                            return [2 /*return*/];
                        }
                        return [2 /*return*/, new Promise(function (resolve, reject) {
                                that.modal.show().then(function () {
                                    return __awaiter$1(this, void 0, void 0, function () {
                                        var err_1;
                                        return __generator$1(this, function (_a) {
                                            switch (_a.label) {
                                                case 0:
                                                    _a.trys.push([0, 5, , 6]);
                                                    if (!(that.customController != null)) return [3 /*break*/, 2];
                                                    return [4 /*yield*/, that.customController.initialize()];
                                                case 1:
                                                    _a.sent();
                                                    return [3 /*break*/, 4];
                                                case 2: return [4 /*yield*/, that.initialize()];
                                                case 3:
                                                    _a.sent();
                                                    _a.label = 4;
                                                case 4:
                                                    resolve();
                                                    return [3 /*break*/, 6];
                                                case 5:
                                                    err_1 = _a.sent();
                                                    reject(err_1);
                                                    return [3 /*break*/, 6];
                                                case 6: return [2 /*return*/];
                                            }
                                        });
                                    });
                                });
                            })];
                }
            });
        });
    };
    ModalBase.prototype.hide = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.initialized];
                    case 1:
                        _a.sent();
                        that = this;
                        return [2 /*return*/, new Promise(function (resolve, reject) {
                                that.modal.hide().then(resolve);
                            })];
                }
            });
        });
    };
    ModalBase.prototype.remove = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.initialized];
                    case 1:
                        _a.sent();
                        that = this;
                        return [2 /*return*/, new Promise(function (resolve, reject) {
                                that.modal.remove().then(resolve);
                            })];
                }
            });
        });
    };
    return ModalBase;
}(ControllerBase));

var DataGatheringModal = /** @class */ (function (_super) {
    __extends$1(DataGatheringModal, _super);
    function DataGatheringModal($injector, name, templateURL) {
        var _this = _super.call(this, name, templateURL, $injector, { animation: 'slide-in-up', backdropClickToClose: false, hardwareBackButtonClose: false }) || this;
        _this.deferredReject = null;
        _this.deferredResolve = null;
        _this.args = null;
        return _this;
    }
    DataGatheringModal.prototype.launch = function (args) {
        return __awaiter$1(this, void 0, void 0, function () {
            var that;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.args = args;
                        return [4 /*yield*/, this.show()];
                    case 1:
                        _a.sent();
                        that = this;
                        this.promise = new Promise(function (resolve, reject) {
                            that.deferredResolve = resolve;
                            that.deferredReject = reject;
                        });
                        return [2 /*return*/];
                }
            });
        });
    };
    DataGatheringModal.prototype.wait = function () {
        if (this.promise == null) {
            return Promise.reject(new ArgumentError("You must call show before calling wait"));
        }
        return this.promise;
    };
    DataGatheringModal.prototype.run = function (args) {
        return __awaiter$1(this, void 0, void 0, function () {
            var result;
            return __generator$1(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.launch(args)];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.wait()];
                    case 2:
                        result = _a.sent();
                        this.remove();
                        return [2 /*return*/, result];
                }
            });
        });
    };
    DataGatheringModal.prototype.closeWithData = function (result) {
        if (!this.deferredResolve) {
            throw new ArgumentError("closeWithData called on data modal before run had return");
        }
        this.deferredResolve(result);
    };
    DataGatheringModal.prototype.closeWithError = function (error) {
        if (!this.deferredReject) {
            throw new ArgumentError("closeWithError called on data modal before run had return");
        }
        this.deferredReject(error);
    };
    return DataGatheringModal;
}(ModalBase));

var WidgetBase = /** @class */ (function (_super) {
    __extends$1(WidgetBase, _super);
    function WidgetBase(name, $injector, $scope) {
        return _super.call(this, name, $injector, $scope) || this;
    }
    WidgetBase.prototype.initialize = function () {
        return __awaiter$1(this, void 0, void 0, function () { return __generator$1(this, function (_a) {
            return [2 /*return*/];
        }); });
    };
    WidgetBase.prototype.cleanup = function () {
        return __awaiter$1(this, void 0, void 0, function () { return __generator$1(this, function (_a) {
            return [2 /*return*/];
        }); });
    };
    return WidgetBase;
}(ComponentBase));

var ServiceBase = /** @class */ (function (_super) {
    __extends$1(ServiceBase, _super);
    function ServiceBase(name, $injector) {
        var _this = _super.call(this, name, $injector) || this;
        _this.initialized = null;
        return _this;
    }
    ServiceBase.prototype.beginInitialization = function () {
        this.initialized = this.initialize();
    };
    //Subclasses that need to do asynchronous initialization should
    //override this function.  It must return a void promise.
    ServiceBase.prototype.initialize = function () {
        return __awaiter$1(this, void 0, void 0, function () {
            return __generator$1(this, function (_a) {
                return [2 /*return*/];
            });
        });
    };
    return ServiceBase;
}(ObjectBase));

/**
 * @ngdoc object
 * @name Utilities
 *
 * @description
 * The utilities namespace contains common routines that are used in other modules
 * including delays and generic parsing functions.
 */
/**
 * @ngdoc object
 * @name Utilities.function:endsWith
 * @description
 * Check if a string ends with another string
 *
 *
 * @param {string} str The input string
 * @param {string} suffix The suffix to check
 * @returns {bool} Whether the string ends with the suffix
 */
function endsWith(str, suffix) {
    return str.indexOf(suffix, str.length - suffix.length) !== -1;
}
/**
 * @ngdoc object
 * @name Utilities.function:startsWith
 * @description
 * Check if a string ends with another string
 *
 *
 * @param {string} str The input string
 * @param {string} prefix The prefix to check
 * @returns {bool} Whether the string ends with the suffix
 */
function startsWith(str, prefix) {
    return str.indexOf(prefix, 0) == 0;
}
//From https://stackoverflow.com/questions/105034/create-guid-uuid-in-javascript
function guid() {
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
        var r = Math.random() * 16 | 0, v = c == 'x' ? r : (r & 0x3 | 0x8);
        return v.toString(16);
    });
}
var commonjsGlobal = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};





function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var core = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory();
	}
}(commonjsGlobal, function () {

	/**
	 * CryptoJS core components.
	 */
	var CryptoJS = CryptoJS || (function (Math, undefined) {
	    /*
	     * Local polyfil of Object.create
	     */
	    var create = Object.create || (function () {
	        function F() {}

	        return function (obj) {
	            var subtype;

	            F.prototype = obj;

	            subtype = new F();

	            F.prototype = null;

	            return subtype;
	        };
	    }());

	    /**
	     * CryptoJS namespace.
	     */
	    var C = {};

	    /**
	     * Library namespace.
	     */
	    var C_lib = C.lib = {};

	    /**
	     * Base object for prototypal inheritance.
	     */
	    var Base = C_lib.Base = (function () {


	        return {
	            /**
	             * Creates a new object that inherits from this object.
	             *
	             * @param {Object} overrides Properties to copy into the new object.
	             *
	             * @return {Object} The new object.
	             *
	             * @static
	             *
	             * @example
	             *
	             *     var MyType = CryptoJS.lib.Base.extend({
	             *         field: 'value',
	             *
	             *         method: function () {
	             *         }
	             *     });
	             */
	            extend: function (overrides) {
	                // Spawn
	                var subtype = create(this);

	                // Augment
	                if (overrides) {
	                    subtype.mixIn(overrides);
	                }

	                // Create default initializer
	                if (!subtype.hasOwnProperty('init') || this.init === subtype.init) {
	                    subtype.init = function () {
	                        subtype.$super.init.apply(this, arguments);
	                    };
	                }

	                // Initializer's prototype is the subtype object
	                subtype.init.prototype = subtype;

	                // Reference supertype
	                subtype.$super = this;

	                return subtype;
	            },

	            /**
	             * Extends this object and runs the init method.
	             * Arguments to create() will be passed to init().
	             *
	             * @return {Object} The new object.
	             *
	             * @static
	             *
	             * @example
	             *
	             *     var instance = MyType.create();
	             */
	            create: function () {
	                var instance = this.extend();
	                instance.init.apply(instance, arguments);

	                return instance;
	            },

	            /**
	             * Initializes a newly created object.
	             * Override this method to add some logic when your objects are created.
	             *
	             * @example
	             *
	             *     var MyType = CryptoJS.lib.Base.extend({
	             *         init: function () {
	             *             // ...
	             *         }
	             *     });
	             */
	            init: function () {
	            },

	            /**
	             * Copies properties into this object.
	             *
	             * @param {Object} properties The properties to mix in.
	             *
	             * @example
	             *
	             *     MyType.mixIn({
	             *         field: 'value'
	             *     });
	             */
	            mixIn: function (properties) {
	                for (var propertyName in properties) {
	                    if (properties.hasOwnProperty(propertyName)) {
	                        this[propertyName] = properties[propertyName];
	                    }
	                }

	                // IE won't copy toString using the loop above
	                if (properties.hasOwnProperty('toString')) {
	                    this.toString = properties.toString;
	                }
	            },

	            /**
	             * Creates a copy of this object.
	             *
	             * @return {Object} The clone.
	             *
	             * @example
	             *
	             *     var clone = instance.clone();
	             */
	            clone: function () {
	                return this.init.prototype.extend(this);
	            }
	        };
	    }());

	    /**
	     * An array of 32-bit words.
	     *
	     * @property {Array} words The array of 32-bit words.
	     * @property {number} sigBytes The number of significant bytes in this word array.
	     */
	    var WordArray = C_lib.WordArray = Base.extend({
	        /**
	         * Initializes a newly created word array.
	         *
	         * @param {Array} words (Optional) An array of 32-bit words.
	         * @param {number} sigBytes (Optional) The number of significant bytes in the words.
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.lib.WordArray.create();
	         *     var wordArray = CryptoJS.lib.WordArray.create([0x00010203, 0x04050607]);
	         *     var wordArray = CryptoJS.lib.WordArray.create([0x00010203, 0x04050607], 6);
	         */
	        init: function (words, sigBytes) {
	            words = this.words = words || [];

	            if (sigBytes != undefined) {
	                this.sigBytes = sigBytes;
	            } else {
	                this.sigBytes = words.length * 4;
	            }
	        },

	        /**
	         * Converts this word array to a string.
	         *
	         * @param {Encoder} encoder (Optional) The encoding strategy to use. Default: CryptoJS.enc.Hex
	         *
	         * @return {string} The stringified word array.
	         *
	         * @example
	         *
	         *     var string = wordArray + '';
	         *     var string = wordArray.toString();
	         *     var string = wordArray.toString(CryptoJS.enc.Utf8);
	         */
	        toString: function (encoder) {
	            return (encoder || Hex).stringify(this);
	        },

	        /**
	         * Concatenates a word array to this word array.
	         *
	         * @param {WordArray} wordArray The word array to append.
	         *
	         * @return {WordArray} This word array.
	         *
	         * @example
	         *
	         *     wordArray1.concat(wordArray2);
	         */
	        concat: function (wordArray) {
	            // Shortcuts
	            var thisWords = this.words;
	            var thatWords = wordArray.words;
	            var thisSigBytes = this.sigBytes;
	            var thatSigBytes = wordArray.sigBytes;

	            // Clamp excess bits
	            this.clamp();

	            // Concat
	            if (thisSigBytes % 4) {
	                // Copy one byte at a time
	                for (var i = 0; i < thatSigBytes; i++) {
	                    var thatByte = (thatWords[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff;
	                    thisWords[(thisSigBytes + i) >>> 2] |= thatByte << (24 - ((thisSigBytes + i) % 4) * 8);
	                }
	            } else {
	                // Copy one word at a time
	                for (var i = 0; i < thatSigBytes; i += 4) {
	                    thisWords[(thisSigBytes + i) >>> 2] = thatWords[i >>> 2];
	                }
	            }
	            this.sigBytes += thatSigBytes;

	            // Chainable
	            return this;
	        },

	        /**
	         * Removes insignificant bits.
	         *
	         * @example
	         *
	         *     wordArray.clamp();
	         */
	        clamp: function () {
	            // Shortcuts
	            var words = this.words;
	            var sigBytes = this.sigBytes;

	            // Clamp
	            words[sigBytes >>> 2] &= 0xffffffff << (32 - (sigBytes % 4) * 8);
	            words.length = Math.ceil(sigBytes / 4);
	        },

	        /**
	         * Creates a copy of this word array.
	         *
	         * @return {WordArray} The clone.
	         *
	         * @example
	         *
	         *     var clone = wordArray.clone();
	         */
	        clone: function () {
	            var clone = Base.clone.call(this);
	            clone.words = this.words.slice(0);

	            return clone;
	        },

	        /**
	         * Creates a word array filled with random bytes.
	         *
	         * @param {number} nBytes The number of random bytes to generate.
	         *
	         * @return {WordArray} The random word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.lib.WordArray.random(16);
	         */
	        random: function (nBytes) {
	            var words = [];

	            var r = (function (m_w) {
	                var m_w = m_w;
	                var m_z = 0x3ade68b1;
	                var mask = 0xffffffff;

	                return function () {
	                    m_z = (0x9069 * (m_z & 0xFFFF) + (m_z >> 0x10)) & mask;
	                    m_w = (0x4650 * (m_w & 0xFFFF) + (m_w >> 0x10)) & mask;
	                    var result = ((m_z << 0x10) + m_w) & mask;
	                    result /= 0x100000000;
	                    result += 0.5;
	                    return result * (Math.random() > .5 ? 1 : -1);
	                }
	            });

	            for (var i = 0, rcache; i < nBytes; i += 4) {
	                var _r = r((rcache || Math.random()) * 0x100000000);

	                rcache = _r() * 0x3ade67b7;
	                words.push((_r() * 0x100000000) | 0);
	            }

	            return new WordArray.init(words, nBytes);
	        }
	    });

	    /**
	     * Encoder namespace.
	     */
	    var C_enc = C.enc = {};

	    /**
	     * Hex encoding strategy.
	     */
	    var Hex = C_enc.Hex = {
	        /**
	         * Converts a word array to a hex string.
	         *
	         * @param {WordArray} wordArray The word array.
	         *
	         * @return {string} The hex string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var hexString = CryptoJS.enc.Hex.stringify(wordArray);
	         */
	        stringify: function (wordArray) {
	            // Shortcuts
	            var words = wordArray.words;
	            var sigBytes = wordArray.sigBytes;

	            // Convert
	            var hexChars = [];
	            for (var i = 0; i < sigBytes; i++) {
	                var bite = (words[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff;
	                hexChars.push((bite >>> 4).toString(16));
	                hexChars.push((bite & 0x0f).toString(16));
	            }

	            return hexChars.join('');
	        },

	        /**
	         * Converts a hex string to a word array.
	         *
	         * @param {string} hexStr The hex string.
	         *
	         * @return {WordArray} The word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.enc.Hex.parse(hexString);
	         */
	        parse: function (hexStr) {
	            // Shortcut
	            var hexStrLength = hexStr.length;

	            // Convert
	            var words = [];
	            for (var i = 0; i < hexStrLength; i += 2) {
	                words[i >>> 3] |= parseInt(hexStr.substr(i, 2), 16) << (24 - (i % 8) * 4);
	            }

	            return new WordArray.init(words, hexStrLength / 2);
	        }
	    };

	    /**
	     * Latin1 encoding strategy.
	     */
	    var Latin1 = C_enc.Latin1 = {
	        /**
	         * Converts a word array to a Latin1 string.
	         *
	         * @param {WordArray} wordArray The word array.
	         *
	         * @return {string} The Latin1 string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var latin1String = CryptoJS.enc.Latin1.stringify(wordArray);
	         */
	        stringify: function (wordArray) {
	            // Shortcuts
	            var words = wordArray.words;
	            var sigBytes = wordArray.sigBytes;

	            // Convert
	            var latin1Chars = [];
	            for (var i = 0; i < sigBytes; i++) {
	                var bite = (words[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff;
	                latin1Chars.push(String.fromCharCode(bite));
	            }

	            return latin1Chars.join('');
	        },

	        /**
	         * Converts a Latin1 string to a word array.
	         *
	         * @param {string} latin1Str The Latin1 string.
	         *
	         * @return {WordArray} The word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.enc.Latin1.parse(latin1String);
	         */
	        parse: function (latin1Str) {
	            // Shortcut
	            var latin1StrLength = latin1Str.length;

	            // Convert
	            var words = [];
	            for (var i = 0; i < latin1StrLength; i++) {
	                words[i >>> 2] |= (latin1Str.charCodeAt(i) & 0xff) << (24 - (i % 4) * 8);
	            }

	            return new WordArray.init(words, latin1StrLength);
	        }
	    };

	    /**
	     * UTF-8 encoding strategy.
	     */
	    var Utf8 = C_enc.Utf8 = {
	        /**
	         * Converts a word array to a UTF-8 string.
	         *
	         * @param {WordArray} wordArray The word array.
	         *
	         * @return {string} The UTF-8 string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var utf8String = CryptoJS.enc.Utf8.stringify(wordArray);
	         */
	        stringify: function (wordArray) {
	            try {
	                return decodeURIComponent(escape(Latin1.stringify(wordArray)));
	            } catch (e) {
	                throw new Error('Malformed UTF-8 data');
	            }
	        },

	        /**
	         * Converts a UTF-8 string to a word array.
	         *
	         * @param {string} utf8Str The UTF-8 string.
	         *
	         * @return {WordArray} The word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.enc.Utf8.parse(utf8String);
	         */
	        parse: function (utf8Str) {
	            return Latin1.parse(unescape(encodeURIComponent(utf8Str)));
	        }
	    };

	    /**
	     * Abstract buffered block algorithm template.
	     *
	     * The property blockSize must be implemented in a concrete subtype.
	     *
	     * @property {number} _minBufferSize The number of blocks that should be kept unprocessed in the buffer. Default: 0
	     */
	    var BufferedBlockAlgorithm = C_lib.BufferedBlockAlgorithm = Base.extend({
	        /**
	         * Resets this block algorithm's data buffer to its initial state.
	         *
	         * @example
	         *
	         *     bufferedBlockAlgorithm.reset();
	         */
	        reset: function () {
	            // Initial values
	            this._data = new WordArray.init();
	            this._nDataBytes = 0;
	        },

	        /**
	         * Adds new data to this block algorithm's buffer.
	         *
	         * @param {WordArray|string} data The data to append. Strings are converted to a WordArray using UTF-8.
	         *
	         * @example
	         *
	         *     bufferedBlockAlgorithm._append('data');
	         *     bufferedBlockAlgorithm._append(wordArray);
	         */
	        _append: function (data) {
	            // Convert string to WordArray, else assume WordArray already
	            if (typeof data == 'string') {
	                data = Utf8.parse(data);
	            }

	            // Append
	            this._data.concat(data);
	            this._nDataBytes += data.sigBytes;
	        },

	        /**
	         * Processes available data blocks.
	         *
	         * This method invokes _doProcessBlock(offset), which must be implemented by a concrete subtype.
	         *
	         * @param {boolean} doFlush Whether all blocks and partial blocks should be processed.
	         *
	         * @return {WordArray} The processed data.
	         *
	         * @example
	         *
	         *     var processedData = bufferedBlockAlgorithm._process();
	         *     var processedData = bufferedBlockAlgorithm._process(!!'flush');
	         */
	        _process: function (doFlush) {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;
	            var dataSigBytes = data.sigBytes;
	            var blockSize = this.blockSize;
	            var blockSizeBytes = blockSize * 4;

	            // Count blocks ready
	            var nBlocksReady = dataSigBytes / blockSizeBytes;
	            if (doFlush) {
	                // Round up to include partial blocks
	                nBlocksReady = Math.ceil(nBlocksReady);
	            } else {
	                // Round down to include only full blocks,
	                // less the number of blocks that must remain in the buffer
	                nBlocksReady = Math.max((nBlocksReady | 0) - this._minBufferSize, 0);
	            }

	            // Count words ready
	            var nWordsReady = nBlocksReady * blockSize;

	            // Count bytes ready
	            var nBytesReady = Math.min(nWordsReady * 4, dataSigBytes);

	            // Process blocks
	            if (nWordsReady) {
	                for (var offset = 0; offset < nWordsReady; offset += blockSize) {
	                    // Perform concrete-algorithm logic
	                    this._doProcessBlock(dataWords, offset);
	                }

	                // Remove processed words
	                var processedWords = dataWords.splice(0, nWordsReady);
	                data.sigBytes -= nBytesReady;
	            }

	            // Return processed words
	            return new WordArray.init(processedWords, nBytesReady);
	        },

	        /**
	         * Creates a copy of this object.
	         *
	         * @return {Object} The clone.
	         *
	         * @example
	         *
	         *     var clone = bufferedBlockAlgorithm.clone();
	         */
	        clone: function () {
	            var clone = Base.clone.call(this);
	            clone._data = this._data.clone();

	            return clone;
	        },

	        _minBufferSize: 0
	    });

	    /**
	     * Abstract hasher template.
	     *
	     * @property {number} blockSize The number of 32-bit words this hasher operates on. Default: 16 (512 bits)
	     */
	    var Hasher = C_lib.Hasher = BufferedBlockAlgorithm.extend({
	        /**
	         * Configuration options.
	         */
	        cfg: Base.extend(),

	        /**
	         * Initializes a newly created hasher.
	         *
	         * @param {Object} cfg (Optional) The configuration options to use for this hash computation.
	         *
	         * @example
	         *
	         *     var hasher = CryptoJS.algo.SHA256.create();
	         */
	        init: function (cfg) {
	            // Apply config defaults
	            this.cfg = this.cfg.extend(cfg);

	            // Set initial values
	            this.reset();
	        },

	        /**
	         * Resets this hasher to its initial state.
	         *
	         * @example
	         *
	         *     hasher.reset();
	         */
	        reset: function () {
	            // Reset data buffer
	            BufferedBlockAlgorithm.reset.call(this);

	            // Perform concrete-hasher logic
	            this._doReset();
	        },

	        /**
	         * Updates this hasher with a message.
	         *
	         * @param {WordArray|string} messageUpdate The message to append.
	         *
	         * @return {Hasher} This hasher.
	         *
	         * @example
	         *
	         *     hasher.update('message');
	         *     hasher.update(wordArray);
	         */
	        update: function (messageUpdate) {
	            // Append
	            this._append(messageUpdate);

	            // Update the hash
	            this._process();

	            // Chainable
	            return this;
	        },

	        /**
	         * Finalizes the hash computation.
	         * Note that the finalize operation is effectively a destructive, read-once operation.
	         *
	         * @param {WordArray|string} messageUpdate (Optional) A final message update.
	         *
	         * @return {WordArray} The hash.
	         *
	         * @example
	         *
	         *     var hash = hasher.finalize();
	         *     var hash = hasher.finalize('message');
	         *     var hash = hasher.finalize(wordArray);
	         */
	        finalize: function (messageUpdate) {
	            // Final message update
	            if (messageUpdate) {
	                this._append(messageUpdate);
	            }

	            // Perform concrete-hasher logic
	            var hash = this._doFinalize();

	            return hash;
	        },

	        blockSize: 512/32,

	        /**
	         * Creates a shortcut function to a hasher's object interface.
	         *
	         * @param {Hasher} hasher The hasher to create a helper for.
	         *
	         * @return {Function} The shortcut function.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var SHA256 = CryptoJS.lib.Hasher._createHelper(CryptoJS.algo.SHA256);
	         */
	        _createHelper: function (hasher) {
	            return function (message, cfg) {
	                return new hasher.init(cfg).finalize(message);
	            };
	        },

	        /**
	         * Creates a shortcut function to the HMAC's object interface.
	         *
	         * @param {Hasher} hasher The hasher to use in this HMAC helper.
	         *
	         * @return {Function} The shortcut function.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var HmacSHA256 = CryptoJS.lib.Hasher._createHmacHelper(CryptoJS.algo.SHA256);
	         */
	        _createHmacHelper: function (hasher) {
	            return function (message, key) {
	                return new C_algo.HMAC.init(hasher, key).finalize(message);
	            };
	        }
	    });

	    /**
	     * Algorithm namespace.
	     */
	    var C_algo = C.algo = {};

	    return C;
	}(Math));


	return CryptoJS;

}));
});

var x64Core = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function (undefined) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var Base = C_lib.Base;
	    var X32WordArray = C_lib.WordArray;

	    /**
	     * x64 namespace.
	     */
	    var C_x64 = C.x64 = {};

	    /**
	     * A 64-bit word.
	     */
	    var X64Word = C_x64.Word = Base.extend({
	        /**
	         * Initializes a newly created 64-bit word.
	         *
	         * @param {number} high The high 32 bits.
	         * @param {number} low The low 32 bits.
	         *
	         * @example
	         *
	         *     var x64Word = CryptoJS.x64.Word.create(0x00010203, 0x04050607);
	         */
	        init: function (high, low) {
	            this.high = high;
	            this.low = low;
	        }

	        /**
	         * Bitwise NOTs this word.
	         *
	         * @return {X64Word} A new x64-Word object after negating.
	         *
	         * @example
	         *
	         *     var negated = x64Word.not();
	         */
	        // not: function () {
	            // var high = ~this.high;
	            // var low = ~this.low;

	            // return X64Word.create(high, low);
	        // },

	        /**
	         * Bitwise ANDs this word with the passed word.
	         *
	         * @param {X64Word} word The x64-Word to AND with this word.
	         *
	         * @return {X64Word} A new x64-Word object after ANDing.
	         *
	         * @example
	         *
	         *     var anded = x64Word.and(anotherX64Word);
	         */
	        // and: function (word) {
	            // var high = this.high & word.high;
	            // var low = this.low & word.low;

	            // return X64Word.create(high, low);
	        // },

	        /**
	         * Bitwise ORs this word with the passed word.
	         *
	         * @param {X64Word} word The x64-Word to OR with this word.
	         *
	         * @return {X64Word} A new x64-Word object after ORing.
	         *
	         * @example
	         *
	         *     var ored = x64Word.or(anotherX64Word);
	         */
	        // or: function (word) {
	            // var high = this.high | word.high;
	            // var low = this.low | word.low;

	            // return X64Word.create(high, low);
	        // },

	        /**
	         * Bitwise XORs this word with the passed word.
	         *
	         * @param {X64Word} word The x64-Word to XOR with this word.
	         *
	         * @return {X64Word} A new x64-Word object after XORing.
	         *
	         * @example
	         *
	         *     var xored = x64Word.xor(anotherX64Word);
	         */
	        // xor: function (word) {
	            // var high = this.high ^ word.high;
	            // var low = this.low ^ word.low;

	            // return X64Word.create(high, low);
	        // },

	        /**
	         * Shifts this word n bits to the left.
	         *
	         * @param {number} n The number of bits to shift.
	         *
	         * @return {X64Word} A new x64-Word object after shifting.
	         *
	         * @example
	         *
	         *     var shifted = x64Word.shiftL(25);
	         */
	        // shiftL: function (n) {
	            // if (n < 32) {
	                // var high = (this.high << n) | (this.low >>> (32 - n));
	                // var low = this.low << n;
	            // } else {
	                // var high = this.low << (n - 32);
	                // var low = 0;
	            // }

	            // return X64Word.create(high, low);
	        // },

	        /**
	         * Shifts this word n bits to the right.
	         *
	         * @param {number} n The number of bits to shift.
	         *
	         * @return {X64Word} A new x64-Word object after shifting.
	         *
	         * @example
	         *
	         *     var shifted = x64Word.shiftR(7);
	         */
	        // shiftR: function (n) {
	            // if (n < 32) {
	                // var low = (this.low >>> n) | (this.high << (32 - n));
	                // var high = this.high >>> n;
	            // } else {
	                // var low = this.high >>> (n - 32);
	                // var high = 0;
	            // }

	            // return X64Word.create(high, low);
	        // },

	        /**
	         * Rotates this word n bits to the left.
	         *
	         * @param {number} n The number of bits to rotate.
	         *
	         * @return {X64Word} A new x64-Word object after rotating.
	         *
	         * @example
	         *
	         *     var rotated = x64Word.rotL(25);
	         */
	        // rotL: function (n) {
	            // return this.shiftL(n).or(this.shiftR(64 - n));
	        // },

	        /**
	         * Rotates this word n bits to the right.
	         *
	         * @param {number} n The number of bits to rotate.
	         *
	         * @return {X64Word} A new x64-Word object after rotating.
	         *
	         * @example
	         *
	         *     var rotated = x64Word.rotR(7);
	         */
	        // rotR: function (n) {
	            // return this.shiftR(n).or(this.shiftL(64 - n));
	        // },

	        /**
	         * Adds this word with the passed word.
	         *
	         * @param {X64Word} word The x64-Word to add with this word.
	         *
	         * @return {X64Word} A new x64-Word object after adding.
	         *
	         * @example
	         *
	         *     var added = x64Word.add(anotherX64Word);
	         */
	        // add: function (word) {
	            // var low = (this.low + word.low) | 0;
	            // var carry = (low >>> 0) < (this.low >>> 0) ? 1 : 0;
	            // var high = (this.high + word.high + carry) | 0;

	            // return X64Word.create(high, low);
	        // }
	    });

	    /**
	     * An array of 64-bit words.
	     *
	     * @property {Array} words The array of CryptoJS.x64.Word objects.
	     * @property {number} sigBytes The number of significant bytes in this word array.
	     */
	    var X64WordArray = C_x64.WordArray = Base.extend({
	        /**
	         * Initializes a newly created word array.
	         *
	         * @param {Array} words (Optional) An array of CryptoJS.x64.Word objects.
	         * @param {number} sigBytes (Optional) The number of significant bytes in the words.
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.x64.WordArray.create();
	         *
	         *     var wordArray = CryptoJS.x64.WordArray.create([
	         *         CryptoJS.x64.Word.create(0x00010203, 0x04050607),
	         *         CryptoJS.x64.Word.create(0x18191a1b, 0x1c1d1e1f)
	         *     ]);
	         *
	         *     var wordArray = CryptoJS.x64.WordArray.create([
	         *         CryptoJS.x64.Word.create(0x00010203, 0x04050607),
	         *         CryptoJS.x64.Word.create(0x18191a1b, 0x1c1d1e1f)
	         *     ], 10);
	         */
	        init: function (words, sigBytes) {
	            words = this.words = words || [];

	            if (sigBytes != undefined) {
	                this.sigBytes = sigBytes;
	            } else {
	                this.sigBytes = words.length * 8;
	            }
	        },

	        /**
	         * Converts this 64-bit word array to a 32-bit word array.
	         *
	         * @return {CryptoJS.lib.WordArray} This word array's data as a 32-bit word array.
	         *
	         * @example
	         *
	         *     var x32WordArray = x64WordArray.toX32();
	         */
	        toX32: function () {
	            // Shortcuts
	            var x64Words = this.words;
	            var x64WordsLength = x64Words.length;

	            // Convert
	            var x32Words = [];
	            for (var i = 0; i < x64WordsLength; i++) {
	                var x64Word = x64Words[i];
	                x32Words.push(x64Word.high);
	                x32Words.push(x64Word.low);
	            }

	            return X32WordArray.create(x32Words, this.sigBytes);
	        },

	        /**
	         * Creates a copy of this word array.
	         *
	         * @return {X64WordArray} The clone.
	         *
	         * @example
	         *
	         *     var clone = x64WordArray.clone();
	         */
	        clone: function () {
	            var clone = Base.clone.call(this);

	            // Clone "words" array
	            var words = clone.words = this.words.slice(0);

	            // Clone each X64Word object
	            var wordsLength = words.length;
	            for (var i = 0; i < wordsLength; i++) {
	                words[i] = words[i].clone();
	            }

	            return clone;
	        }
	    });
	}());


	return CryptoJS;

}));
});

var libTypedarrays = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Check if typed arrays are supported
	    if (typeof ArrayBuffer != 'function') {
	        return;
	    }

	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;

	    // Reference original init
	    var superInit = WordArray.init;

	    // Augment WordArray.init to handle typed arrays
	    var subInit = WordArray.init = function (typedArray) {
	        // Convert buffers to uint8
	        if (typedArray instanceof ArrayBuffer) {
	            typedArray = new Uint8Array(typedArray);
	        }

	        // Convert other array views to uint8
	        if (
	            typedArray instanceof Int8Array ||
	            (typeof Uint8ClampedArray !== "undefined" && typedArray instanceof Uint8ClampedArray) ||
	            typedArray instanceof Int16Array ||
	            typedArray instanceof Uint16Array ||
	            typedArray instanceof Int32Array ||
	            typedArray instanceof Uint32Array ||
	            typedArray instanceof Float32Array ||
	            typedArray instanceof Float64Array
	        ) {
	            typedArray = new Uint8Array(typedArray.buffer, typedArray.byteOffset, typedArray.byteLength);
	        }

	        // Handle Uint8Array
	        if (typedArray instanceof Uint8Array) {
	            // Shortcut
	            var typedArrayByteLength = typedArray.byteLength;

	            // Extract bytes
	            var words = [];
	            for (var i = 0; i < typedArrayByteLength; i++) {
	                words[i >>> 2] |= typedArray[i] << (24 - (i % 4) * 8);
	            }

	            // Initialize this word array
	            superInit.call(this, words, typedArrayByteLength);
	        } else {
	            // Else call normal init
	            superInit.apply(this, arguments);
	        }
	    };

	    subInit.prototype = WordArray;
	}());


	return CryptoJS.lib.WordArray;

}));
});

var encUtf16 = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var C_enc = C.enc;

	    /**
	     * UTF-16 BE encoding strategy.
	     */
	    var Utf16BE = C_enc.Utf16 = C_enc.Utf16BE = {
	        /**
	         * Converts a word array to a UTF-16 BE string.
	         *
	         * @param {WordArray} wordArray The word array.
	         *
	         * @return {string} The UTF-16 BE string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var utf16String = CryptoJS.enc.Utf16.stringify(wordArray);
	         */
	        stringify: function (wordArray) {
	            // Shortcuts
	            var words = wordArray.words;
	            var sigBytes = wordArray.sigBytes;

	            // Convert
	            var utf16Chars = [];
	            for (var i = 0; i < sigBytes; i += 2) {
	                var codePoint = (words[i >>> 2] >>> (16 - (i % 4) * 8)) & 0xffff;
	                utf16Chars.push(String.fromCharCode(codePoint));
	            }

	            return utf16Chars.join('');
	        },

	        /**
	         * Converts a UTF-16 BE string to a word array.
	         *
	         * @param {string} utf16Str The UTF-16 BE string.
	         *
	         * @return {WordArray} The word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.enc.Utf16.parse(utf16String);
	         */
	        parse: function (utf16Str) {
	            // Shortcut
	            var utf16StrLength = utf16Str.length;

	            // Convert
	            var words = [];
	            for (var i = 0; i < utf16StrLength; i++) {
	                words[i >>> 1] |= utf16Str.charCodeAt(i) << (16 - (i % 2) * 16);
	            }

	            return WordArray.create(words, utf16StrLength * 2);
	        }
	    };

	    /**
	     * UTF-16 LE encoding strategy.
	     */
	    C_enc.Utf16LE = {
	        /**
	         * Converts a word array to a UTF-16 LE string.
	         *
	         * @param {WordArray} wordArray The word array.
	         *
	         * @return {string} The UTF-16 LE string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var utf16Str = CryptoJS.enc.Utf16LE.stringify(wordArray);
	         */
	        stringify: function (wordArray) {
	            // Shortcuts
	            var words = wordArray.words;
	            var sigBytes = wordArray.sigBytes;

	            // Convert
	            var utf16Chars = [];
	            for (var i = 0; i < sigBytes; i += 2) {
	                var codePoint = swapEndian((words[i >>> 2] >>> (16 - (i % 4) * 8)) & 0xffff);
	                utf16Chars.push(String.fromCharCode(codePoint));
	            }

	            return utf16Chars.join('');
	        },

	        /**
	         * Converts a UTF-16 LE string to a word array.
	         *
	         * @param {string} utf16Str The UTF-16 LE string.
	         *
	         * @return {WordArray} The word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.enc.Utf16LE.parse(utf16Str);
	         */
	        parse: function (utf16Str) {
	            // Shortcut
	            var utf16StrLength = utf16Str.length;

	            // Convert
	            var words = [];
	            for (var i = 0; i < utf16StrLength; i++) {
	                words[i >>> 1] |= swapEndian(utf16Str.charCodeAt(i) << (16 - (i % 2) * 16));
	            }

	            return WordArray.create(words, utf16StrLength * 2);
	        }
	    };

	    function swapEndian(word) {
	        return ((word << 8) & 0xff00ff00) | ((word >>> 8) & 0x00ff00ff);
	    }
	}());


	return CryptoJS.enc.Utf16;

}));
});

var encBase64 = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var C_enc = C.enc;

	    /**
	     * Base64 encoding strategy.
	     */
	    var Base64 = C_enc.Base64 = {
	        /**
	         * Converts a word array to a Base64 string.
	         *
	         * @param {WordArray} wordArray The word array.
	         *
	         * @return {string} The Base64 string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var base64String = CryptoJS.enc.Base64.stringify(wordArray);
	         */
	        stringify: function (wordArray) {
	            // Shortcuts
	            var words = wordArray.words;
	            var sigBytes = wordArray.sigBytes;
	            var map = this._map;

	            // Clamp excess bits
	            wordArray.clamp();

	            // Convert
	            var base64Chars = [];
	            for (var i = 0; i < sigBytes; i += 3) {
	                var byte1 = (words[i >>> 2]       >>> (24 - (i % 4) * 8))       & 0xff;
	                var byte2 = (words[(i + 1) >>> 2] >>> (24 - ((i + 1) % 4) * 8)) & 0xff;
	                var byte3 = (words[(i + 2) >>> 2] >>> (24 - ((i + 2) % 4) * 8)) & 0xff;

	                var triplet = (byte1 << 16) | (byte2 << 8) | byte3;

	                for (var j = 0; (j < 4) && (i + j * 0.75 < sigBytes); j++) {
	                    base64Chars.push(map.charAt((triplet >>> (6 * (3 - j))) & 0x3f));
	                }
	            }

	            // Add padding
	            var paddingChar = map.charAt(64);
	            if (paddingChar) {
	                while (base64Chars.length % 4) {
	                    base64Chars.push(paddingChar);
	                }
	            }

	            return base64Chars.join('');
	        },

	        /**
	         * Converts a Base64 string to a word array.
	         *
	         * @param {string} base64Str The Base64 string.
	         *
	         * @return {WordArray} The word array.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var wordArray = CryptoJS.enc.Base64.parse(base64String);
	         */
	        parse: function (base64Str) {
	            // Shortcuts
	            var base64StrLength = base64Str.length;
	            var map = this._map;
	            var reverseMap = this._reverseMap;

	            if (!reverseMap) {
	                    reverseMap = this._reverseMap = [];
	                    for (var j = 0; j < map.length; j++) {
	                        reverseMap[map.charCodeAt(j)] = j;
	                    }
	            }

	            // Ignore padding
	            var paddingChar = map.charAt(64);
	            if (paddingChar) {
	                var paddingIndex = base64Str.indexOf(paddingChar);
	                if (paddingIndex !== -1) {
	                    base64StrLength = paddingIndex;
	                }
	            }

	            // Convert
	            return parseLoop(base64Str, base64StrLength, reverseMap);

	        },

	        _map: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/='
	    };

	    function parseLoop(base64Str, base64StrLength, reverseMap) {
	      var words = [];
	      var nBytes = 0;
	      for (var i = 0; i < base64StrLength; i++) {
	          if (i % 4) {
	              var bits1 = reverseMap[base64Str.charCodeAt(i - 1)] << ((i % 4) * 2);
	              var bits2 = reverseMap[base64Str.charCodeAt(i)] >>> (6 - (i % 4) * 2);
	              words[nBytes >>> 2] |= (bits1 | bits2) << (24 - (nBytes % 4) * 8);
	              nBytes++;
	          }
	      }
	      return WordArray.create(words, nBytes);
	    }
	}());


	return CryptoJS.enc.Base64;

}));
});

var md5 = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function (Math) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var Hasher = C_lib.Hasher;
	    var C_algo = C.algo;

	    // Constants table
	    var T = [];

	    // Compute constants
	    (function () {
	        for (var i = 0; i < 64; i++) {
	            T[i] = (Math.abs(Math.sin(i + 1)) * 0x100000000) | 0;
	        }
	    }());

	    /**
	     * MD5 hash algorithm.
	     */
	    var MD5 = C_algo.MD5 = Hasher.extend({
	        _doReset: function () {
	            this._hash = new WordArray.init([
	                0x67452301, 0xefcdab89,
	                0x98badcfe, 0x10325476
	            ]);
	        },

	        _doProcessBlock: function (M, offset) {
	            // Swap endian
	            for (var i = 0; i < 16; i++) {
	                // Shortcuts
	                var offset_i = offset + i;
	                var M_offset_i = M[offset_i];

	                M[offset_i] = (
	                    (((M_offset_i << 8)  | (M_offset_i >>> 24)) & 0x00ff00ff) |
	                    (((M_offset_i << 24) | (M_offset_i >>> 8))  & 0xff00ff00)
	                );
	            }

	            // Shortcuts
	            var H = this._hash.words;

	            var M_offset_0  = M[offset + 0];
	            var M_offset_1  = M[offset + 1];
	            var M_offset_2  = M[offset + 2];
	            var M_offset_3  = M[offset + 3];
	            var M_offset_4  = M[offset + 4];
	            var M_offset_5  = M[offset + 5];
	            var M_offset_6  = M[offset + 6];
	            var M_offset_7  = M[offset + 7];
	            var M_offset_8  = M[offset + 8];
	            var M_offset_9  = M[offset + 9];
	            var M_offset_10 = M[offset + 10];
	            var M_offset_11 = M[offset + 11];
	            var M_offset_12 = M[offset + 12];
	            var M_offset_13 = M[offset + 13];
	            var M_offset_14 = M[offset + 14];
	            var M_offset_15 = M[offset + 15];

	            // Working varialbes
	            var a = H[0];
	            var b = H[1];
	            var c = H[2];
	            var d = H[3];

	            // Computation
	            a = FF(a, b, c, d, M_offset_0,  7,  T[0]);
	            d = FF(d, a, b, c, M_offset_1,  12, T[1]);
	            c = FF(c, d, a, b, M_offset_2,  17, T[2]);
	            b = FF(b, c, d, a, M_offset_3,  22, T[3]);
	            a = FF(a, b, c, d, M_offset_4,  7,  T[4]);
	            d = FF(d, a, b, c, M_offset_5,  12, T[5]);
	            c = FF(c, d, a, b, M_offset_6,  17, T[6]);
	            b = FF(b, c, d, a, M_offset_7,  22, T[7]);
	            a = FF(a, b, c, d, M_offset_8,  7,  T[8]);
	            d = FF(d, a, b, c, M_offset_9,  12, T[9]);
	            c = FF(c, d, a, b, M_offset_10, 17, T[10]);
	            b = FF(b, c, d, a, M_offset_11, 22, T[11]);
	            a = FF(a, b, c, d, M_offset_12, 7,  T[12]);
	            d = FF(d, a, b, c, M_offset_13, 12, T[13]);
	            c = FF(c, d, a, b, M_offset_14, 17, T[14]);
	            b = FF(b, c, d, a, M_offset_15, 22, T[15]);

	            a = GG(a, b, c, d, M_offset_1,  5,  T[16]);
	            d = GG(d, a, b, c, M_offset_6,  9,  T[17]);
	            c = GG(c, d, a, b, M_offset_11, 14, T[18]);
	            b = GG(b, c, d, a, M_offset_0,  20, T[19]);
	            a = GG(a, b, c, d, M_offset_5,  5,  T[20]);
	            d = GG(d, a, b, c, M_offset_10, 9,  T[21]);
	            c = GG(c, d, a, b, M_offset_15, 14, T[22]);
	            b = GG(b, c, d, a, M_offset_4,  20, T[23]);
	            a = GG(a, b, c, d, M_offset_9,  5,  T[24]);
	            d = GG(d, a, b, c, M_offset_14, 9,  T[25]);
	            c = GG(c, d, a, b, M_offset_3,  14, T[26]);
	            b = GG(b, c, d, a, M_offset_8,  20, T[27]);
	            a = GG(a, b, c, d, M_offset_13, 5,  T[28]);
	            d = GG(d, a, b, c, M_offset_2,  9,  T[29]);
	            c = GG(c, d, a, b, M_offset_7,  14, T[30]);
	            b = GG(b, c, d, a, M_offset_12, 20, T[31]);

	            a = HH(a, b, c, d, M_offset_5,  4,  T[32]);
	            d = HH(d, a, b, c, M_offset_8,  11, T[33]);
	            c = HH(c, d, a, b, M_offset_11, 16, T[34]);
	            b = HH(b, c, d, a, M_offset_14, 23, T[35]);
	            a = HH(a, b, c, d, M_offset_1,  4,  T[36]);
	            d = HH(d, a, b, c, M_offset_4,  11, T[37]);
	            c = HH(c, d, a, b, M_offset_7,  16, T[38]);
	            b = HH(b, c, d, a, M_offset_10, 23, T[39]);
	            a = HH(a, b, c, d, M_offset_13, 4,  T[40]);
	            d = HH(d, a, b, c, M_offset_0,  11, T[41]);
	            c = HH(c, d, a, b, M_offset_3,  16, T[42]);
	            b = HH(b, c, d, a, M_offset_6,  23, T[43]);
	            a = HH(a, b, c, d, M_offset_9,  4,  T[44]);
	            d = HH(d, a, b, c, M_offset_12, 11, T[45]);
	            c = HH(c, d, a, b, M_offset_15, 16, T[46]);
	            b = HH(b, c, d, a, M_offset_2,  23, T[47]);

	            a = II(a, b, c, d, M_offset_0,  6,  T[48]);
	            d = II(d, a, b, c, M_offset_7,  10, T[49]);
	            c = II(c, d, a, b, M_offset_14, 15, T[50]);
	            b = II(b, c, d, a, M_offset_5,  21, T[51]);
	            a = II(a, b, c, d, M_offset_12, 6,  T[52]);
	            d = II(d, a, b, c, M_offset_3,  10, T[53]);
	            c = II(c, d, a, b, M_offset_10, 15, T[54]);
	            b = II(b, c, d, a, M_offset_1,  21, T[55]);
	            a = II(a, b, c, d, M_offset_8,  6,  T[56]);
	            d = II(d, a, b, c, M_offset_15, 10, T[57]);
	            c = II(c, d, a, b, M_offset_6,  15, T[58]);
	            b = II(b, c, d, a, M_offset_13, 21, T[59]);
	            a = II(a, b, c, d, M_offset_4,  6,  T[60]);
	            d = II(d, a, b, c, M_offset_11, 10, T[61]);
	            c = II(c, d, a, b, M_offset_2,  15, T[62]);
	            b = II(b, c, d, a, M_offset_9,  21, T[63]);

	            // Intermediate hash value
	            H[0] = (H[0] + a) | 0;
	            H[1] = (H[1] + b) | 0;
	            H[2] = (H[2] + c) | 0;
	            H[3] = (H[3] + d) | 0;
	        },

	        _doFinalize: function () {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;

	            var nBitsTotal = this._nDataBytes * 8;
	            var nBitsLeft = data.sigBytes * 8;

	            // Add padding
	            dataWords[nBitsLeft >>> 5] |= 0x80 << (24 - nBitsLeft % 32);

	            var nBitsTotalH = Math.floor(nBitsTotal / 0x100000000);
	            var nBitsTotalL = nBitsTotal;
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 15] = (
	                (((nBitsTotalH << 8)  | (nBitsTotalH >>> 24)) & 0x00ff00ff) |
	                (((nBitsTotalH << 24) | (nBitsTotalH >>> 8))  & 0xff00ff00)
	            );
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 14] = (
	                (((nBitsTotalL << 8)  | (nBitsTotalL >>> 24)) & 0x00ff00ff) |
	                (((nBitsTotalL << 24) | (nBitsTotalL >>> 8))  & 0xff00ff00)
	            );

	            data.sigBytes = (dataWords.length + 1) * 4;

	            // Hash final blocks
	            this._process();

	            // Shortcuts
	            var hash = this._hash;
	            var H = hash.words;

	            // Swap endian
	            for (var i = 0; i < 4; i++) {
	                // Shortcut
	                var H_i = H[i];

	                H[i] = (((H_i << 8)  | (H_i >>> 24)) & 0x00ff00ff) |
	                       (((H_i << 24) | (H_i >>> 8))  & 0xff00ff00);
	            }

	            // Return final computed hash
	            return hash;
	        },

	        clone: function () {
	            var clone = Hasher.clone.call(this);
	            clone._hash = this._hash.clone();

	            return clone;
	        }
	    });

	    function FF(a, b, c, d, x, s, t) {
	        var n = a + ((b & c) | (~b & d)) + x + t;
	        return ((n << s) | (n >>> (32 - s))) + b;
	    }

	    function GG(a, b, c, d, x, s, t) {
	        var n = a + ((b & d) | (c & ~d)) + x + t;
	        return ((n << s) | (n >>> (32 - s))) + b;
	    }

	    function HH(a, b, c, d, x, s, t) {
	        var n = a + (b ^ c ^ d) + x + t;
	        return ((n << s) | (n >>> (32 - s))) + b;
	    }

	    function II(a, b, c, d, x, s, t) {
	        var n = a + (c ^ (b | ~d)) + x + t;
	        return ((n << s) | (n >>> (32 - s))) + b;
	    }

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.MD5('message');
	     *     var hash = CryptoJS.MD5(wordArray);
	     */
	    C.MD5 = Hasher._createHelper(MD5);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacMD5(message, key);
	     */
	    C.HmacMD5 = Hasher._createHmacHelper(MD5);
	}(Math));


	return CryptoJS.MD5;

}));
});

var sha1 = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var Hasher = C_lib.Hasher;
	    var C_algo = C.algo;

	    // Reusable object
	    var W = [];

	    /**
	     * SHA-1 hash algorithm.
	     */
	    var SHA1 = C_algo.SHA1 = Hasher.extend({
	        _doReset: function () {
	            this._hash = new WordArray.init([
	                0x67452301, 0xefcdab89,
	                0x98badcfe, 0x10325476,
	                0xc3d2e1f0
	            ]);
	        },

	        _doProcessBlock: function (M, offset) {
	            // Shortcut
	            var H = this._hash.words;

	            // Working variables
	            var a = H[0];
	            var b = H[1];
	            var c = H[2];
	            var d = H[3];
	            var e = H[4];

	            // Computation
	            for (var i = 0; i < 80; i++) {
	                if (i < 16) {
	                    W[i] = M[offset + i] | 0;
	                } else {
	                    var n = W[i - 3] ^ W[i - 8] ^ W[i - 14] ^ W[i - 16];
	                    W[i] = (n << 1) | (n >>> 31);
	                }

	                var t = ((a << 5) | (a >>> 27)) + e + W[i];
	                if (i < 20) {
	                    t += ((b & c) | (~b & d)) + 0x5a827999;
	                } else if (i < 40) {
	                    t += (b ^ c ^ d) + 0x6ed9eba1;
	                } else if (i < 60) {
	                    t += ((b & c) | (b & d) | (c & d)) - 0x70e44324;
	                } else /* if (i < 80) */ {
	                    t += (b ^ c ^ d) - 0x359d3e2a;
	                }

	                e = d;
	                d = c;
	                c = (b << 30) | (b >>> 2);
	                b = a;
	                a = t;
	            }

	            // Intermediate hash value
	            H[0] = (H[0] + a) | 0;
	            H[1] = (H[1] + b) | 0;
	            H[2] = (H[2] + c) | 0;
	            H[3] = (H[3] + d) | 0;
	            H[4] = (H[4] + e) | 0;
	        },

	        _doFinalize: function () {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;

	            var nBitsTotal = this._nDataBytes * 8;
	            var nBitsLeft = data.sigBytes * 8;

	            // Add padding
	            dataWords[nBitsLeft >>> 5] |= 0x80 << (24 - nBitsLeft % 32);
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 14] = Math.floor(nBitsTotal / 0x100000000);
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 15] = nBitsTotal;
	            data.sigBytes = dataWords.length * 4;

	            // Hash final blocks
	            this._process();

	            // Return final computed hash
	            return this._hash;
	        },

	        clone: function () {
	            var clone = Hasher.clone.call(this);
	            clone._hash = this._hash.clone();

	            return clone;
	        }
	    });

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.SHA1('message');
	     *     var hash = CryptoJS.SHA1(wordArray);
	     */
	    C.SHA1 = Hasher._createHelper(SHA1);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacSHA1(message, key);
	     */
	    C.HmacSHA1 = Hasher._createHmacHelper(SHA1);
	}());


	return CryptoJS.SHA1;

}));
});

var sha256 = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function (Math) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var Hasher = C_lib.Hasher;
	    var C_algo = C.algo;

	    // Initialization and round constants tables
	    var H = [];
	    var K = [];

	    // Compute constants
	    (function () {
	        function isPrime(n) {
	            var sqrtN = Math.sqrt(n);
	            for (var factor = 2; factor <= sqrtN; factor++) {
	                if (!(n % factor)) {
	                    return false;
	                }
	            }

	            return true;
	        }

	        function getFractionalBits(n) {
	            return ((n - (n | 0)) * 0x100000000) | 0;
	        }

	        var n = 2;
	        var nPrime = 0;
	        while (nPrime < 64) {
	            if (isPrime(n)) {
	                if (nPrime < 8) {
	                    H[nPrime] = getFractionalBits(Math.pow(n, 1 / 2));
	                }
	                K[nPrime] = getFractionalBits(Math.pow(n, 1 / 3));

	                nPrime++;
	            }

	            n++;
	        }
	    }());

	    // Reusable object
	    var W = [];

	    /**
	     * SHA-256 hash algorithm.
	     */
	    var SHA256 = C_algo.SHA256 = Hasher.extend({
	        _doReset: function () {
	            this._hash = new WordArray.init(H.slice(0));
	        },

	        _doProcessBlock: function (M, offset) {
	            // Shortcut
	            var H = this._hash.words;

	            // Working variables
	            var a = H[0];
	            var b = H[1];
	            var c = H[2];
	            var d = H[3];
	            var e = H[4];
	            var f = H[5];
	            var g = H[6];
	            var h = H[7];

	            // Computation
	            for (var i = 0; i < 64; i++) {
	                if (i < 16) {
	                    W[i] = M[offset + i] | 0;
	                } else {
	                    var gamma0x = W[i - 15];
	                    var gamma0  = ((gamma0x << 25) | (gamma0x >>> 7))  ^
	                                  ((gamma0x << 14) | (gamma0x >>> 18)) ^
	                                   (gamma0x >>> 3);

	                    var gamma1x = W[i - 2];
	                    var gamma1  = ((gamma1x << 15) | (gamma1x >>> 17)) ^
	                                  ((gamma1x << 13) | (gamma1x >>> 19)) ^
	                                   (gamma1x >>> 10);

	                    W[i] = gamma0 + W[i - 7] + gamma1 + W[i - 16];
	                }

	                var ch  = (e & f) ^ (~e & g);
	                var maj = (a & b) ^ (a & c) ^ (b & c);

	                var sigma0 = ((a << 30) | (a >>> 2)) ^ ((a << 19) | (a >>> 13)) ^ ((a << 10) | (a >>> 22));
	                var sigma1 = ((e << 26) | (e >>> 6)) ^ ((e << 21) | (e >>> 11)) ^ ((e << 7)  | (e >>> 25));

	                var t1 = h + sigma1 + ch + K[i] + W[i];
	                var t2 = sigma0 + maj;

	                h = g;
	                g = f;
	                f = e;
	                e = (d + t1) | 0;
	                d = c;
	                c = b;
	                b = a;
	                a = (t1 + t2) | 0;
	            }

	            // Intermediate hash value
	            H[0] = (H[0] + a) | 0;
	            H[1] = (H[1] + b) | 0;
	            H[2] = (H[2] + c) | 0;
	            H[3] = (H[3] + d) | 0;
	            H[4] = (H[4] + e) | 0;
	            H[5] = (H[5] + f) | 0;
	            H[6] = (H[6] + g) | 0;
	            H[7] = (H[7] + h) | 0;
	        },

	        _doFinalize: function () {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;

	            var nBitsTotal = this._nDataBytes * 8;
	            var nBitsLeft = data.sigBytes * 8;

	            // Add padding
	            dataWords[nBitsLeft >>> 5] |= 0x80 << (24 - nBitsLeft % 32);
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 14] = Math.floor(nBitsTotal / 0x100000000);
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 15] = nBitsTotal;
	            data.sigBytes = dataWords.length * 4;

	            // Hash final blocks
	            this._process();

	            // Return final computed hash
	            return this._hash;
	        },

	        clone: function () {
	            var clone = Hasher.clone.call(this);
	            clone._hash = this._hash.clone();

	            return clone;
	        }
	    });

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.SHA256('message');
	     *     var hash = CryptoJS.SHA256(wordArray);
	     */
	    C.SHA256 = Hasher._createHelper(SHA256);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacSHA256(message, key);
	     */
	    C.HmacSHA256 = Hasher._createHmacHelper(SHA256);
	}(Math));


	return CryptoJS.SHA256;

}));
});

var sha224 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, sha256);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var C_algo = C.algo;
	    var SHA256 = C_algo.SHA256;

	    /**
	     * SHA-224 hash algorithm.
	     */
	    var SHA224 = C_algo.SHA224 = SHA256.extend({
	        _doReset: function () {
	            this._hash = new WordArray.init([
	                0xc1059ed8, 0x367cd507, 0x3070dd17, 0xf70e5939,
	                0xffc00b31, 0x68581511, 0x64f98fa7, 0xbefa4fa4
	            ]);
	        },

	        _doFinalize: function () {
	            var hash = SHA256._doFinalize.call(this);

	            hash.sigBytes -= 4;

	            return hash;
	        }
	    });

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.SHA224('message');
	     *     var hash = CryptoJS.SHA224(wordArray);
	     */
	    C.SHA224 = SHA256._createHelper(SHA224);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacSHA224(message, key);
	     */
	    C.HmacSHA224 = SHA256._createHmacHelper(SHA224);
	}());


	return CryptoJS.SHA224;

}));
});

var sha512 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, x64Core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var Hasher = C_lib.Hasher;
	    var C_x64 = C.x64;
	    var X64Word = C_x64.Word;
	    var X64WordArray = C_x64.WordArray;
	    var C_algo = C.algo;

	    function X64Word_create() {
	        return X64Word.create.apply(X64Word, arguments);
	    }

	    // Constants
	    var K = [
	        X64Word_create(0x428a2f98, 0xd728ae22), X64Word_create(0x71374491, 0x23ef65cd),
	        X64Word_create(0xb5c0fbcf, 0xec4d3b2f), X64Word_create(0xe9b5dba5, 0x8189dbbc),
	        X64Word_create(0x3956c25b, 0xf348b538), X64Word_create(0x59f111f1, 0xb605d019),
	        X64Word_create(0x923f82a4, 0xaf194f9b), X64Word_create(0xab1c5ed5, 0xda6d8118),
	        X64Word_create(0xd807aa98, 0xa3030242), X64Word_create(0x12835b01, 0x45706fbe),
	        X64Word_create(0x243185be, 0x4ee4b28c), X64Word_create(0x550c7dc3, 0xd5ffb4e2),
	        X64Word_create(0x72be5d74, 0xf27b896f), X64Word_create(0x80deb1fe, 0x3b1696b1),
	        X64Word_create(0x9bdc06a7, 0x25c71235), X64Word_create(0xc19bf174, 0xcf692694),
	        X64Word_create(0xe49b69c1, 0x9ef14ad2), X64Word_create(0xefbe4786, 0x384f25e3),
	        X64Word_create(0x0fc19dc6, 0x8b8cd5b5), X64Word_create(0x240ca1cc, 0x77ac9c65),
	        X64Word_create(0x2de92c6f, 0x592b0275), X64Word_create(0x4a7484aa, 0x6ea6e483),
	        X64Word_create(0x5cb0a9dc, 0xbd41fbd4), X64Word_create(0x76f988da, 0x831153b5),
	        X64Word_create(0x983e5152, 0xee66dfab), X64Word_create(0xa831c66d, 0x2db43210),
	        X64Word_create(0xb00327c8, 0x98fb213f), X64Word_create(0xbf597fc7, 0xbeef0ee4),
	        X64Word_create(0xc6e00bf3, 0x3da88fc2), X64Word_create(0xd5a79147, 0x930aa725),
	        X64Word_create(0x06ca6351, 0xe003826f), X64Word_create(0x14292967, 0x0a0e6e70),
	        X64Word_create(0x27b70a85, 0x46d22ffc), X64Word_create(0x2e1b2138, 0x5c26c926),
	        X64Word_create(0x4d2c6dfc, 0x5ac42aed), X64Word_create(0x53380d13, 0x9d95b3df),
	        X64Word_create(0x650a7354, 0x8baf63de), X64Word_create(0x766a0abb, 0x3c77b2a8),
	        X64Word_create(0x81c2c92e, 0x47edaee6), X64Word_create(0x92722c85, 0x1482353b),
	        X64Word_create(0xa2bfe8a1, 0x4cf10364), X64Word_create(0xa81a664b, 0xbc423001),
	        X64Word_create(0xc24b8b70, 0xd0f89791), X64Word_create(0xc76c51a3, 0x0654be30),
	        X64Word_create(0xd192e819, 0xd6ef5218), X64Word_create(0xd6990624, 0x5565a910),
	        X64Word_create(0xf40e3585, 0x5771202a), X64Word_create(0x106aa070, 0x32bbd1b8),
	        X64Word_create(0x19a4c116, 0xb8d2d0c8), X64Word_create(0x1e376c08, 0x5141ab53),
	        X64Word_create(0x2748774c, 0xdf8eeb99), X64Word_create(0x34b0bcb5, 0xe19b48a8),
	        X64Word_create(0x391c0cb3, 0xc5c95a63), X64Word_create(0x4ed8aa4a, 0xe3418acb),
	        X64Word_create(0x5b9cca4f, 0x7763e373), X64Word_create(0x682e6ff3, 0xd6b2b8a3),
	        X64Word_create(0x748f82ee, 0x5defb2fc), X64Word_create(0x78a5636f, 0x43172f60),
	        X64Word_create(0x84c87814, 0xa1f0ab72), X64Word_create(0x8cc70208, 0x1a6439ec),
	        X64Word_create(0x90befffa, 0x23631e28), X64Word_create(0xa4506ceb, 0xde82bde9),
	        X64Word_create(0xbef9a3f7, 0xb2c67915), X64Word_create(0xc67178f2, 0xe372532b),
	        X64Word_create(0xca273ece, 0xea26619c), X64Word_create(0xd186b8c7, 0x21c0c207),
	        X64Word_create(0xeada7dd6, 0xcde0eb1e), X64Word_create(0xf57d4f7f, 0xee6ed178),
	        X64Word_create(0x06f067aa, 0x72176fba), X64Word_create(0x0a637dc5, 0xa2c898a6),
	        X64Word_create(0x113f9804, 0xbef90dae), X64Word_create(0x1b710b35, 0x131c471b),
	        X64Word_create(0x28db77f5, 0x23047d84), X64Word_create(0x32caab7b, 0x40c72493),
	        X64Word_create(0x3c9ebe0a, 0x15c9bebc), X64Word_create(0x431d67c4, 0x9c100d4c),
	        X64Word_create(0x4cc5d4be, 0xcb3e42b6), X64Word_create(0x597f299c, 0xfc657e2a),
	        X64Word_create(0x5fcb6fab, 0x3ad6faec), X64Word_create(0x6c44198c, 0x4a475817)
	    ];

	    // Reusable objects
	    var W = [];
	    (function () {
	        for (var i = 0; i < 80; i++) {
	            W[i] = X64Word_create();
	        }
	    }());

	    /**
	     * SHA-512 hash algorithm.
	     */
	    var SHA512 = C_algo.SHA512 = Hasher.extend({
	        _doReset: function () {
	            this._hash = new X64WordArray.init([
	                new X64Word.init(0x6a09e667, 0xf3bcc908), new X64Word.init(0xbb67ae85, 0x84caa73b),
	                new X64Word.init(0x3c6ef372, 0xfe94f82b), new X64Word.init(0xa54ff53a, 0x5f1d36f1),
	                new X64Word.init(0x510e527f, 0xade682d1), new X64Word.init(0x9b05688c, 0x2b3e6c1f),
	                new X64Word.init(0x1f83d9ab, 0xfb41bd6b), new X64Word.init(0x5be0cd19, 0x137e2179)
	            ]);
	        },

	        _doProcessBlock: function (M, offset) {
	            // Shortcuts
	            var H = this._hash.words;

	            var H0 = H[0];
	            var H1 = H[1];
	            var H2 = H[2];
	            var H3 = H[3];
	            var H4 = H[4];
	            var H5 = H[5];
	            var H6 = H[6];
	            var H7 = H[7];

	            var H0h = H0.high;
	            var H0l = H0.low;
	            var H1h = H1.high;
	            var H1l = H1.low;
	            var H2h = H2.high;
	            var H2l = H2.low;
	            var H3h = H3.high;
	            var H3l = H3.low;
	            var H4h = H4.high;
	            var H4l = H4.low;
	            var H5h = H5.high;
	            var H5l = H5.low;
	            var H6h = H6.high;
	            var H6l = H6.low;
	            var H7h = H7.high;
	            var H7l = H7.low;

	            // Working variables
	            var ah = H0h;
	            var al = H0l;
	            var bh = H1h;
	            var bl = H1l;
	            var ch = H2h;
	            var cl = H2l;
	            var dh = H3h;
	            var dl = H3l;
	            var eh = H4h;
	            var el = H4l;
	            var fh = H5h;
	            var fl = H5l;
	            var gh = H6h;
	            var gl = H6l;
	            var hh = H7h;
	            var hl = H7l;

	            // Rounds
	            for (var i = 0; i < 80; i++) {
	                // Shortcut
	                var Wi = W[i];

	                // Extend message
	                if (i < 16) {
	                    var Wih = Wi.high = M[offset + i * 2]     | 0;
	                    var Wil = Wi.low  = M[offset + i * 2 + 1] | 0;
	                } else {
	                    // Gamma0
	                    var gamma0x  = W[i - 15];
	                    var gamma0xh = gamma0x.high;
	                    var gamma0xl = gamma0x.low;
	                    var gamma0h  = ((gamma0xh >>> 1) | (gamma0xl << 31)) ^ ((gamma0xh >>> 8) | (gamma0xl << 24)) ^ (gamma0xh >>> 7);
	                    var gamma0l  = ((gamma0xl >>> 1) | (gamma0xh << 31)) ^ ((gamma0xl >>> 8) | (gamma0xh << 24)) ^ ((gamma0xl >>> 7) | (gamma0xh << 25));

	                    // Gamma1
	                    var gamma1x  = W[i - 2];
	                    var gamma1xh = gamma1x.high;
	                    var gamma1xl = gamma1x.low;
	                    var gamma1h  = ((gamma1xh >>> 19) | (gamma1xl << 13)) ^ ((gamma1xh << 3) | (gamma1xl >>> 29)) ^ (gamma1xh >>> 6);
	                    var gamma1l  = ((gamma1xl >>> 19) | (gamma1xh << 13)) ^ ((gamma1xl << 3) | (gamma1xh >>> 29)) ^ ((gamma1xl >>> 6) | (gamma1xh << 26));

	                    // W[i] = gamma0 + W[i - 7] + gamma1 + W[i - 16]
	                    var Wi7  = W[i - 7];
	                    var Wi7h = Wi7.high;
	                    var Wi7l = Wi7.low;

	                    var Wi16  = W[i - 16];
	                    var Wi16h = Wi16.high;
	                    var Wi16l = Wi16.low;

	                    var Wil = gamma0l + Wi7l;
	                    var Wih = gamma0h + Wi7h + ((Wil >>> 0) < (gamma0l >>> 0) ? 1 : 0);
	                    var Wil = Wil + gamma1l;
	                    var Wih = Wih + gamma1h + ((Wil >>> 0) < (gamma1l >>> 0) ? 1 : 0);
	                    var Wil = Wil + Wi16l;
	                    var Wih = Wih + Wi16h + ((Wil >>> 0) < (Wi16l >>> 0) ? 1 : 0);

	                    Wi.high = Wih;
	                    Wi.low  = Wil;
	                }

	                var chh  = (eh & fh) ^ (~eh & gh);
	                var chl  = (el & fl) ^ (~el & gl);
	                var majh = (ah & bh) ^ (ah & ch) ^ (bh & ch);
	                var majl = (al & bl) ^ (al & cl) ^ (bl & cl);

	                var sigma0h = ((ah >>> 28) | (al << 4))  ^ ((ah << 30)  | (al >>> 2)) ^ ((ah << 25) | (al >>> 7));
	                var sigma0l = ((al >>> 28) | (ah << 4))  ^ ((al << 30)  | (ah >>> 2)) ^ ((al << 25) | (ah >>> 7));
	                var sigma1h = ((eh >>> 14) | (el << 18)) ^ ((eh >>> 18) | (el << 14)) ^ ((eh << 23) | (el >>> 9));
	                var sigma1l = ((el >>> 14) | (eh << 18)) ^ ((el >>> 18) | (eh << 14)) ^ ((el << 23) | (eh >>> 9));

	                // t1 = h + sigma1 + ch + K[i] + W[i]
	                var Ki  = K[i];
	                var Kih = Ki.high;
	                var Kil = Ki.low;

	                var t1l = hl + sigma1l;
	                var t1h = hh + sigma1h + ((t1l >>> 0) < (hl >>> 0) ? 1 : 0);
	                var t1l = t1l + chl;
	                var t1h = t1h + chh + ((t1l >>> 0) < (chl >>> 0) ? 1 : 0);
	                var t1l = t1l + Kil;
	                var t1h = t1h + Kih + ((t1l >>> 0) < (Kil >>> 0) ? 1 : 0);
	                var t1l = t1l + Wil;
	                var t1h = t1h + Wih + ((t1l >>> 0) < (Wil >>> 0) ? 1 : 0);

	                // t2 = sigma0 + maj
	                var t2l = sigma0l + majl;
	                var t2h = sigma0h + majh + ((t2l >>> 0) < (sigma0l >>> 0) ? 1 : 0);

	                // Update working variables
	                hh = gh;
	                hl = gl;
	                gh = fh;
	                gl = fl;
	                fh = eh;
	                fl = el;
	                el = (dl + t1l) | 0;
	                eh = (dh + t1h + ((el >>> 0) < (dl >>> 0) ? 1 : 0)) | 0;
	                dh = ch;
	                dl = cl;
	                ch = bh;
	                cl = bl;
	                bh = ah;
	                bl = al;
	                al = (t1l + t2l) | 0;
	                ah = (t1h + t2h + ((al >>> 0) < (t1l >>> 0) ? 1 : 0)) | 0;
	            }

	            // Intermediate hash value
	            H0l = H0.low  = (H0l + al);
	            H0.high = (H0h + ah + ((H0l >>> 0) < (al >>> 0) ? 1 : 0));
	            H1l = H1.low  = (H1l + bl);
	            H1.high = (H1h + bh + ((H1l >>> 0) < (bl >>> 0) ? 1 : 0));
	            H2l = H2.low  = (H2l + cl);
	            H2.high = (H2h + ch + ((H2l >>> 0) < (cl >>> 0) ? 1 : 0));
	            H3l = H3.low  = (H3l + dl);
	            H3.high = (H3h + dh + ((H3l >>> 0) < (dl >>> 0) ? 1 : 0));
	            H4l = H4.low  = (H4l + el);
	            H4.high = (H4h + eh + ((H4l >>> 0) < (el >>> 0) ? 1 : 0));
	            H5l = H5.low  = (H5l + fl);
	            H5.high = (H5h + fh + ((H5l >>> 0) < (fl >>> 0) ? 1 : 0));
	            H6l = H6.low  = (H6l + gl);
	            H6.high = (H6h + gh + ((H6l >>> 0) < (gl >>> 0) ? 1 : 0));
	            H7l = H7.low  = (H7l + hl);
	            H7.high = (H7h + hh + ((H7l >>> 0) < (hl >>> 0) ? 1 : 0));
	        },

	        _doFinalize: function () {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;

	            var nBitsTotal = this._nDataBytes * 8;
	            var nBitsLeft = data.sigBytes * 8;

	            // Add padding
	            dataWords[nBitsLeft >>> 5] |= 0x80 << (24 - nBitsLeft % 32);
	            dataWords[(((nBitsLeft + 128) >>> 10) << 5) + 30] = Math.floor(nBitsTotal / 0x100000000);
	            dataWords[(((nBitsLeft + 128) >>> 10) << 5) + 31] = nBitsTotal;
	            data.sigBytes = dataWords.length * 4;

	            // Hash final blocks
	            this._process();

	            // Convert hash to 32-bit word array before returning
	            var hash = this._hash.toX32();

	            // Return final computed hash
	            return hash;
	        },

	        clone: function () {
	            var clone = Hasher.clone.call(this);
	            clone._hash = this._hash.clone();

	            return clone;
	        },

	        blockSize: 1024/32
	    });

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.SHA512('message');
	     *     var hash = CryptoJS.SHA512(wordArray);
	     */
	    C.SHA512 = Hasher._createHelper(SHA512);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacSHA512(message, key);
	     */
	    C.HmacSHA512 = Hasher._createHmacHelper(SHA512);
	}());


	return CryptoJS.SHA512;

}));
});

var sha384 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, x64Core, sha512);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_x64 = C.x64;
	    var X64Word = C_x64.Word;
	    var X64WordArray = C_x64.WordArray;
	    var C_algo = C.algo;
	    var SHA512 = C_algo.SHA512;

	    /**
	     * SHA-384 hash algorithm.
	     */
	    var SHA384 = C_algo.SHA384 = SHA512.extend({
	        _doReset: function () {
	            this._hash = new X64WordArray.init([
	                new X64Word.init(0xcbbb9d5d, 0xc1059ed8), new X64Word.init(0x629a292a, 0x367cd507),
	                new X64Word.init(0x9159015a, 0x3070dd17), new X64Word.init(0x152fecd8, 0xf70e5939),
	                new X64Word.init(0x67332667, 0xffc00b31), new X64Word.init(0x8eb44a87, 0x68581511),
	                new X64Word.init(0xdb0c2e0d, 0x64f98fa7), new X64Word.init(0x47b5481d, 0xbefa4fa4)
	            ]);
	        },

	        _doFinalize: function () {
	            var hash = SHA512._doFinalize.call(this);

	            hash.sigBytes -= 16;

	            return hash;
	        }
	    });

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.SHA384('message');
	     *     var hash = CryptoJS.SHA384(wordArray);
	     */
	    C.SHA384 = SHA512._createHelper(SHA384);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacSHA384(message, key);
	     */
	    C.HmacSHA384 = SHA512._createHmacHelper(SHA384);
	}());


	return CryptoJS.SHA384;

}));
});

var sha3 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, x64Core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function (Math) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var Hasher = C_lib.Hasher;
	    var C_x64 = C.x64;
	    var X64Word = C_x64.Word;
	    var C_algo = C.algo;

	    // Constants tables
	    var RHO_OFFSETS = [];
	    var PI_INDEXES  = [];
	    var ROUND_CONSTANTS = [];

	    // Compute Constants
	    (function () {
	        // Compute rho offset constants
	        var x = 1, y = 0;
	        for (var t = 0; t < 24; t++) {
	            RHO_OFFSETS[x + 5 * y] = ((t + 1) * (t + 2) / 2) % 64;

	            var newX = y % 5;
	            var newY = (2 * x + 3 * y) % 5;
	            x = newX;
	            y = newY;
	        }

	        // Compute pi index constants
	        for (var x = 0; x < 5; x++) {
	            for (var y = 0; y < 5; y++) {
	                PI_INDEXES[x + 5 * y] = y + ((2 * x + 3 * y) % 5) * 5;
	            }
	        }

	        // Compute round constants
	        var LFSR = 0x01;
	        for (var i = 0; i < 24; i++) {
	            var roundConstantMsw = 0;
	            var roundConstantLsw = 0;

	            for (var j = 0; j < 7; j++) {
	                if (LFSR & 0x01) {
	                    var bitPosition = (1 << j) - 1;
	                    if (bitPosition < 32) {
	                        roundConstantLsw ^= 1 << bitPosition;
	                    } else /* if (bitPosition >= 32) */ {
	                        roundConstantMsw ^= 1 << (bitPosition - 32);
	                    }
	                }

	                // Compute next LFSR
	                if (LFSR & 0x80) {
	                    // Primitive polynomial over GF(2): x^8 + x^6 + x^5 + x^4 + 1
	                    LFSR = (LFSR << 1) ^ 0x71;
	                } else {
	                    LFSR <<= 1;
	                }
	            }

	            ROUND_CONSTANTS[i] = X64Word.create(roundConstantMsw, roundConstantLsw);
	        }
	    }());

	    // Reusable objects for temporary values
	    var T = [];
	    (function () {
	        for (var i = 0; i < 25; i++) {
	            T[i] = X64Word.create();
	        }
	    }());

	    /**
	     * SHA-3 hash algorithm.
	     */
	    var SHA3 = C_algo.SHA3 = Hasher.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {number} outputLength
	         *   The desired number of bits in the output hash.
	         *   Only values permitted are: 224, 256, 384, 512.
	         *   Default: 512
	         */
	        cfg: Hasher.cfg.extend({
	            outputLength: 512
	        }),

	        _doReset: function () {
	            var state = this._state = [];
	            for (var i = 0; i < 25; i++) {
	                state[i] = new X64Word.init();
	            }

	            this.blockSize = (1600 - 2 * this.cfg.outputLength) / 32;
	        },

	        _doProcessBlock: function (M, offset) {
	            // Shortcuts
	            var state = this._state;
	            var nBlockSizeLanes = this.blockSize / 2;

	            // Absorb
	            for (var i = 0; i < nBlockSizeLanes; i++) {
	                // Shortcuts
	                var M2i  = M[offset + 2 * i];
	                var M2i1 = M[offset + 2 * i + 1];

	                // Swap endian
	                M2i = (
	                    (((M2i << 8)  | (M2i >>> 24)) & 0x00ff00ff) |
	                    (((M2i << 24) | (M2i >>> 8))  & 0xff00ff00)
	                );
	                M2i1 = (
	                    (((M2i1 << 8)  | (M2i1 >>> 24)) & 0x00ff00ff) |
	                    (((M2i1 << 24) | (M2i1 >>> 8))  & 0xff00ff00)
	                );

	                // Absorb message into state
	                var lane = state[i];
	                lane.high ^= M2i1;
	                lane.low  ^= M2i;
	            }

	            // Rounds
	            for (var round = 0; round < 24; round++) {
	                // Theta
	                for (var x = 0; x < 5; x++) {
	                    // Mix column lanes
	                    var tMsw = 0, tLsw = 0;
	                    for (var y = 0; y < 5; y++) {
	                        var lane = state[x + 5 * y];
	                        tMsw ^= lane.high;
	                        tLsw ^= lane.low;
	                    }

	                    // Temporary values
	                    var Tx = T[x];
	                    Tx.high = tMsw;
	                    Tx.low  = tLsw;
	                }
	                for (var x = 0; x < 5; x++) {
	                    // Shortcuts
	                    var Tx4 = T[(x + 4) % 5];
	                    var Tx1 = T[(x + 1) % 5];
	                    var Tx1Msw = Tx1.high;
	                    var Tx1Lsw = Tx1.low;

	                    // Mix surrounding columns
	                    var tMsw = Tx4.high ^ ((Tx1Msw << 1) | (Tx1Lsw >>> 31));
	                    var tLsw = Tx4.low  ^ ((Tx1Lsw << 1) | (Tx1Msw >>> 31));
	                    for (var y = 0; y < 5; y++) {
	                        var lane = state[x + 5 * y];
	                        lane.high ^= tMsw;
	                        lane.low  ^= tLsw;
	                    }
	                }

	                // Rho Pi
	                for (var laneIndex = 1; laneIndex < 25; laneIndex++) {
	                    // Shortcuts
	                    var lane = state[laneIndex];
	                    var laneMsw = lane.high;
	                    var laneLsw = lane.low;
	                    var rhoOffset = RHO_OFFSETS[laneIndex];

	                    // Rotate lanes
	                    if (rhoOffset < 32) {
	                        var tMsw = (laneMsw << rhoOffset) | (laneLsw >>> (32 - rhoOffset));
	                        var tLsw = (laneLsw << rhoOffset) | (laneMsw >>> (32 - rhoOffset));
	                    } else /* if (rhoOffset >= 32) */ {
	                        var tMsw = (laneLsw << (rhoOffset - 32)) | (laneMsw >>> (64 - rhoOffset));
	                        var tLsw = (laneMsw << (rhoOffset - 32)) | (laneLsw >>> (64 - rhoOffset));
	                    }

	                    // Transpose lanes
	                    var TPiLane = T[PI_INDEXES[laneIndex]];
	                    TPiLane.high = tMsw;
	                    TPiLane.low  = tLsw;
	                }

	                // Rho pi at x = y = 0
	                var T0 = T[0];
	                var state0 = state[0];
	                T0.high = state0.high;
	                T0.low  = state0.low;

	                // Chi
	                for (var x = 0; x < 5; x++) {
	                    for (var y = 0; y < 5; y++) {
	                        // Shortcuts
	                        var laneIndex = x + 5 * y;
	                        var lane = state[laneIndex];
	                        var TLane = T[laneIndex];
	                        var Tx1Lane = T[((x + 1) % 5) + 5 * y];
	                        var Tx2Lane = T[((x + 2) % 5) + 5 * y];

	                        // Mix rows
	                        lane.high = TLane.high ^ (~Tx1Lane.high & Tx2Lane.high);
	                        lane.low  = TLane.low  ^ (~Tx1Lane.low  & Tx2Lane.low);
	                    }
	                }

	                // Iota
	                var lane = state[0];
	                var roundConstant = ROUND_CONSTANTS[round];
	                lane.high ^= roundConstant.high;
	                lane.low  ^= roundConstant.low;
	            }
	        },

	        _doFinalize: function () {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;
	            var nBitsTotal = this._nDataBytes * 8;
	            var nBitsLeft = data.sigBytes * 8;
	            var blockSizeBits = this.blockSize * 32;

	            // Add padding
	            dataWords[nBitsLeft >>> 5] |= 0x1 << (24 - nBitsLeft % 32);
	            dataWords[((Math.ceil((nBitsLeft + 1) / blockSizeBits) * blockSizeBits) >>> 5) - 1] |= 0x80;
	            data.sigBytes = dataWords.length * 4;

	            // Hash final blocks
	            this._process();

	            // Shortcuts
	            var state = this._state;
	            var outputLengthBytes = this.cfg.outputLength / 8;
	            var outputLengthLanes = outputLengthBytes / 8;

	            // Squeeze
	            var hashWords = [];
	            for (var i = 0; i < outputLengthLanes; i++) {
	                // Shortcuts
	                var lane = state[i];
	                var laneMsw = lane.high;
	                var laneLsw = lane.low;

	                // Swap endian
	                laneMsw = (
	                    (((laneMsw << 8)  | (laneMsw >>> 24)) & 0x00ff00ff) |
	                    (((laneMsw << 24) | (laneMsw >>> 8))  & 0xff00ff00)
	                );
	                laneLsw = (
	                    (((laneLsw << 8)  | (laneLsw >>> 24)) & 0x00ff00ff) |
	                    (((laneLsw << 24) | (laneLsw >>> 8))  & 0xff00ff00)
	                );

	                // Squeeze state to retrieve hash
	                hashWords.push(laneLsw);
	                hashWords.push(laneMsw);
	            }

	            // Return final computed hash
	            return new WordArray.init(hashWords, outputLengthBytes);
	        },

	        clone: function () {
	            var clone = Hasher.clone.call(this);

	            var state = clone._state = this._state.slice(0);
	            for (var i = 0; i < 25; i++) {
	                state[i] = state[i].clone();
	            }

	            return clone;
	        }
	    });

	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.SHA3('message');
	     *     var hash = CryptoJS.SHA3(wordArray);
	     */
	    C.SHA3 = Hasher._createHelper(SHA3);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacSHA3(message, key);
	     */
	    C.HmacSHA3 = Hasher._createHmacHelper(SHA3);
	}(Math));


	return CryptoJS.SHA3;

}));
});

var ripemd160 = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	/** @preserve
	(c) 2012 by Cédric Mesnil. All rights reserved.

	Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

	    - Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
	    - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
	*/

	(function (Math) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var Hasher = C_lib.Hasher;
	    var C_algo = C.algo;

	    // Constants table
	    var _zl = WordArray.create([
	        0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15,
	        7,  4, 13,  1, 10,  6, 15,  3, 12,  0,  9,  5,  2, 14, 11,  8,
	        3, 10, 14,  4,  9, 15,  8,  1,  2,  7,  0,  6, 13, 11,  5, 12,
	        1,  9, 11, 10,  0,  8, 12,  4, 13,  3,  7, 15, 14,  5,  6,  2,
	        4,  0,  5,  9,  7, 12,  2, 10, 14,  1,  3,  8, 11,  6, 15, 13]);
	    var _zr = WordArray.create([
	        5, 14,  7,  0,  9,  2, 11,  4, 13,  6, 15,  8,  1, 10,  3, 12,
	        6, 11,  3,  7,  0, 13,  5, 10, 14, 15,  8, 12,  4,  9,  1,  2,
	        15,  5,  1,  3,  7, 14,  6,  9, 11,  8, 12,  2, 10,  0,  4, 13,
	        8,  6,  4,  1,  3, 11, 15,  0,  5, 12,  2, 13,  9,  7, 10, 14,
	        12, 15, 10,  4,  1,  5,  8,  7,  6,  2, 13, 14,  0,  3,  9, 11]);
	    var _sl = WordArray.create([
	         11, 14, 15, 12,  5,  8,  7,  9, 11, 13, 14, 15,  6,  7,  9,  8,
	        7, 6,   8, 13, 11,  9,  7, 15,  7, 12, 15,  9, 11,  7, 13, 12,
	        11, 13,  6,  7, 14,  9, 13, 15, 14,  8, 13,  6,  5, 12,  7,  5,
	          11, 12, 14, 15, 14, 15,  9,  8,  9, 14,  5,  6,  8,  6,  5, 12,
	        9, 15,  5, 11,  6,  8, 13, 12,  5, 12, 13, 14, 11,  8,  5,  6 ]);
	    var _sr = WordArray.create([
	        8,  9,  9, 11, 13, 15, 15,  5,  7,  7,  8, 11, 14, 14, 12,  6,
	        9, 13, 15,  7, 12,  8,  9, 11,  7,  7, 12,  7,  6, 15, 13, 11,
	        9,  7, 15, 11,  8,  6,  6, 14, 12, 13,  5, 14, 13, 13,  7,  5,
	        15,  5,  8, 11, 14, 14,  6, 14,  6,  9, 12,  9, 12,  5, 15,  8,
	        8,  5, 12,  9, 12,  5, 14,  6,  8, 13,  6,  5, 15, 13, 11, 11 ]);

	    var _hl =  WordArray.create([ 0x00000000, 0x5A827999, 0x6ED9EBA1, 0x8F1BBCDC, 0xA953FD4E]);
	    var _hr =  WordArray.create([ 0x50A28BE6, 0x5C4DD124, 0x6D703EF3, 0x7A6D76E9, 0x00000000]);

	    /**
	     * RIPEMD160 hash algorithm.
	     */
	    var RIPEMD160 = C_algo.RIPEMD160 = Hasher.extend({
	        _doReset: function () {
	            this._hash  = WordArray.create([0x67452301, 0xEFCDAB89, 0x98BADCFE, 0x10325476, 0xC3D2E1F0]);
	        },

	        _doProcessBlock: function (M, offset) {

	            // Swap endian
	            for (var i = 0; i < 16; i++) {
	                // Shortcuts
	                var offset_i = offset + i;
	                var M_offset_i = M[offset_i];

	                // Swap
	                M[offset_i] = (
	                    (((M_offset_i << 8)  | (M_offset_i >>> 24)) & 0x00ff00ff) |
	                    (((M_offset_i << 24) | (M_offset_i >>> 8))  & 0xff00ff00)
	                );
	            }
	            // Shortcut
	            var H  = this._hash.words;
	            var hl = _hl.words;
	            var hr = _hr.words;
	            var zl = _zl.words;
	            var zr = _zr.words;
	            var sl = _sl.words;
	            var sr = _sr.words;

	            // Working variables
	            var al, bl, cl, dl, el;
	            var ar, br, cr, dr, er;

	            ar = al = H[0];
	            br = bl = H[1];
	            cr = cl = H[2];
	            dr = dl = H[3];
	            er = el = H[4];
	            // Computation
	            var t;
	            for (var i = 0; i < 80; i += 1) {
	                t = (al +  M[offset+zl[i]])|0;
	                if (i<16){
		            t +=  f1(bl,cl,dl) + hl[0];
	                } else if (i<32) {
		            t +=  f2(bl,cl,dl) + hl[1];
	                } else if (i<48) {
		            t +=  f3(bl,cl,dl) + hl[2];
	                } else if (i<64) {
		            t +=  f4(bl,cl,dl) + hl[3];
	                } else {// if (i<80) {
		            t +=  f5(bl,cl,dl) + hl[4];
	                }
	                t = t|0;
	                t =  rotl(t,sl[i]);
	                t = (t+el)|0;
	                al = el;
	                el = dl;
	                dl = rotl(cl, 10);
	                cl = bl;
	                bl = t;

	                t = (ar + M[offset+zr[i]])|0;
	                if (i<16){
		            t +=  f5(br,cr,dr) + hr[0];
	                } else if (i<32) {
		            t +=  f4(br,cr,dr) + hr[1];
	                } else if (i<48) {
		            t +=  f3(br,cr,dr) + hr[2];
	                } else if (i<64) {
		            t +=  f2(br,cr,dr) + hr[3];
	                } else {// if (i<80) {
		            t +=  f1(br,cr,dr) + hr[4];
	                }
	                t = t|0;
	                t =  rotl(t,sr[i]) ;
	                t = (t+er)|0;
	                ar = er;
	                er = dr;
	                dr = rotl(cr, 10);
	                cr = br;
	                br = t;
	            }
	            // Intermediate hash value
	            t    = (H[1] + cl + dr)|0;
	            H[1] = (H[2] + dl + er)|0;
	            H[2] = (H[3] + el + ar)|0;
	            H[3] = (H[4] + al + br)|0;
	            H[4] = (H[0] + bl + cr)|0;
	            H[0] =  t;
	        },

	        _doFinalize: function () {
	            // Shortcuts
	            var data = this._data;
	            var dataWords = data.words;

	            var nBitsTotal = this._nDataBytes * 8;
	            var nBitsLeft = data.sigBytes * 8;

	            // Add padding
	            dataWords[nBitsLeft >>> 5] |= 0x80 << (24 - nBitsLeft % 32);
	            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 14] = (
	                (((nBitsTotal << 8)  | (nBitsTotal >>> 24)) & 0x00ff00ff) |
	                (((nBitsTotal << 24) | (nBitsTotal >>> 8))  & 0xff00ff00)
	            );
	            data.sigBytes = (dataWords.length + 1) * 4;

	            // Hash final blocks
	            this._process();

	            // Shortcuts
	            var hash = this._hash;
	            var H = hash.words;

	            // Swap endian
	            for (var i = 0; i < 5; i++) {
	                // Shortcut
	                var H_i = H[i];

	                // Swap
	                H[i] = (((H_i << 8)  | (H_i >>> 24)) & 0x00ff00ff) |
	                       (((H_i << 24) | (H_i >>> 8))  & 0xff00ff00);
	            }

	            // Return final computed hash
	            return hash;
	        },

	        clone: function () {
	            var clone = Hasher.clone.call(this);
	            clone._hash = this._hash.clone();

	            return clone;
	        }
	    });


	    function f1(x, y, z) {
	        return ((x) ^ (y) ^ (z));

	    }

	    function f2(x, y, z) {
	        return (((x)&(y)) | ((~x)&(z)));
	    }

	    function f3(x, y, z) {
	        return (((x) | (~(y))) ^ (z));
	    }

	    function f4(x, y, z) {
	        return (((x) & (z)) | ((y)&(~(z))));
	    }

	    function f5(x, y, z) {
	        return ((x) ^ ((y) |(~(z))));

	    }

	    function rotl(x,n) {
	        return (x<<n) | (x>>>(32-n));
	    }


	    /**
	     * Shortcut function to the hasher's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     *
	     * @return {WordArray} The hash.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hash = CryptoJS.RIPEMD160('message');
	     *     var hash = CryptoJS.RIPEMD160(wordArray);
	     */
	    C.RIPEMD160 = Hasher._createHelper(RIPEMD160);

	    /**
	     * Shortcut function to the HMAC's object interface.
	     *
	     * @param {WordArray|string} message The message to hash.
	     * @param {WordArray|string} key The secret key.
	     *
	     * @return {WordArray} The HMAC.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var hmac = CryptoJS.HmacRIPEMD160(message, key);
	     */
	    C.HmacRIPEMD160 = Hasher._createHmacHelper(RIPEMD160);
	}(Math));


	return CryptoJS.RIPEMD160;

}));
});

var hmac = createCommonjsModule(function (module, exports) {
(function (root, factory) {
	{
		// CommonJS
		module.exports = exports = factory(core);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var Base = C_lib.Base;
	    var C_enc = C.enc;
	    var Utf8 = C_enc.Utf8;
	    var C_algo = C.algo;

	    /**
	     * HMAC algorithm.
	     */
	    var HMAC = C_algo.HMAC = Base.extend({
	        /**
	         * Initializes a newly created HMAC.
	         *
	         * @param {Hasher} hasher The hash algorithm to use.
	         * @param {WordArray|string} key The secret key.
	         *
	         * @example
	         *
	         *     var hmacHasher = CryptoJS.algo.HMAC.create(CryptoJS.algo.SHA256, key);
	         */
	        init: function (hasher, key) {
	            // Init hasher
	            hasher = this._hasher = new hasher.init();

	            // Convert string to WordArray, else assume WordArray already
	            if (typeof key == 'string') {
	                key = Utf8.parse(key);
	            }

	            // Shortcuts
	            var hasherBlockSize = hasher.blockSize;
	            var hasherBlockSizeBytes = hasherBlockSize * 4;

	            // Allow arbitrary length keys
	            if (key.sigBytes > hasherBlockSizeBytes) {
	                key = hasher.finalize(key);
	            }

	            // Clamp excess bits
	            key.clamp();

	            // Clone key for inner and outer pads
	            var oKey = this._oKey = key.clone();
	            var iKey = this._iKey = key.clone();

	            // Shortcuts
	            var oKeyWords = oKey.words;
	            var iKeyWords = iKey.words;

	            // XOR keys with pad constants
	            for (var i = 0; i < hasherBlockSize; i++) {
	                oKeyWords[i] ^= 0x5c5c5c5c;
	                iKeyWords[i] ^= 0x36363636;
	            }
	            oKey.sigBytes = iKey.sigBytes = hasherBlockSizeBytes;

	            // Set initial values
	            this.reset();
	        },

	        /**
	         * Resets this HMAC to its initial state.
	         *
	         * @example
	         *
	         *     hmacHasher.reset();
	         */
	        reset: function () {
	            // Shortcut
	            var hasher = this._hasher;

	            // Reset
	            hasher.reset();
	            hasher.update(this._iKey);
	        },

	        /**
	         * Updates this HMAC with a message.
	         *
	         * @param {WordArray|string} messageUpdate The message to append.
	         *
	         * @return {HMAC} This HMAC instance.
	         *
	         * @example
	         *
	         *     hmacHasher.update('message');
	         *     hmacHasher.update(wordArray);
	         */
	        update: function (messageUpdate) {
	            this._hasher.update(messageUpdate);

	            // Chainable
	            return this;
	        },

	        /**
	         * Finalizes the HMAC computation.
	         * Note that the finalize operation is effectively a destructive, read-once operation.
	         *
	         * @param {WordArray|string} messageUpdate (Optional) A final message update.
	         *
	         * @return {WordArray} The HMAC.
	         *
	         * @example
	         *
	         *     var hmac = hmacHasher.finalize();
	         *     var hmac = hmacHasher.finalize('message');
	         *     var hmac = hmacHasher.finalize(wordArray);
	         */
	        finalize: function (messageUpdate) {
	            // Shortcut
	            var hasher = this._hasher;

	            // Compute HMAC
	            var innerHash = hasher.finalize(messageUpdate);
	            hasher.reset();
	            var hmac = hasher.finalize(this._oKey.clone().concat(innerHash));

	            return hmac;
	        }
	    });
	}());


}));
});

var pbkdf2 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, sha1, hmac);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var Base = C_lib.Base;
	    var WordArray = C_lib.WordArray;
	    var C_algo = C.algo;
	    var SHA1 = C_algo.SHA1;
	    var HMAC = C_algo.HMAC;

	    /**
	     * Password-Based Key Derivation Function 2 algorithm.
	     */
	    var PBKDF2 = C_algo.PBKDF2 = Base.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {number} keySize The key size in words to generate. Default: 4 (128 bits)
	         * @property {Hasher} hasher The hasher to use. Default: SHA1
	         * @property {number} iterations The number of iterations to perform. Default: 1
	         */
	        cfg: Base.extend({
	            keySize: 128/32,
	            hasher: SHA1,
	            iterations: 1
	        }),

	        /**
	         * Initializes a newly created key derivation function.
	         *
	         * @param {Object} cfg (Optional) The configuration options to use for the derivation.
	         *
	         * @example
	         *
	         *     var kdf = CryptoJS.algo.PBKDF2.create();
	         *     var kdf = CryptoJS.algo.PBKDF2.create({ keySize: 8 });
	         *     var kdf = CryptoJS.algo.PBKDF2.create({ keySize: 8, iterations: 1000 });
	         */
	        init: function (cfg) {
	            this.cfg = this.cfg.extend(cfg);
	        },

	        /**
	         * Computes the Password-Based Key Derivation Function 2.
	         *
	         * @param {WordArray|string} password The password.
	         * @param {WordArray|string} salt A salt.
	         *
	         * @return {WordArray} The derived key.
	         *
	         * @example
	         *
	         *     var key = kdf.compute(password, salt);
	         */
	        compute: function (password, salt) {
	            // Shortcut
	            var cfg = this.cfg;

	            // Init HMAC
	            var hmac$$1 = HMAC.create(cfg.hasher, password);

	            // Initial values
	            var derivedKey = WordArray.create();
	            var blockIndex = WordArray.create([0x00000001]);

	            // Shortcuts
	            var derivedKeyWords = derivedKey.words;
	            var blockIndexWords = blockIndex.words;
	            var keySize = cfg.keySize;
	            var iterations = cfg.iterations;

	            // Generate key
	            while (derivedKeyWords.length < keySize) {
	                var block = hmac$$1.update(salt).finalize(blockIndex);
	                hmac$$1.reset();

	                // Shortcuts
	                var blockWords = block.words;
	                var blockWordsLength = blockWords.length;

	                // Iterations
	                var intermediate = block;
	                for (var i = 1; i < iterations; i++) {
	                    intermediate = hmac$$1.finalize(intermediate);
	                    hmac$$1.reset();

	                    // Shortcut
	                    var intermediateWords = intermediate.words;

	                    // XOR intermediate with block
	                    for (var j = 0; j < blockWordsLength; j++) {
	                        blockWords[j] ^= intermediateWords[j];
	                    }
	                }

	                derivedKey.concat(block);
	                blockIndexWords[0]++;
	            }
	            derivedKey.sigBytes = keySize * 4;

	            return derivedKey;
	        }
	    });

	    /**
	     * Computes the Password-Based Key Derivation Function 2.
	     *
	     * @param {WordArray|string} password The password.
	     * @param {WordArray|string} salt A salt.
	     * @param {Object} cfg (Optional) The configuration options to use for this computation.
	     *
	     * @return {WordArray} The derived key.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var key = CryptoJS.PBKDF2(password, salt);
	     *     var key = CryptoJS.PBKDF2(password, salt, { keySize: 8 });
	     *     var key = CryptoJS.PBKDF2(password, salt, { keySize: 8, iterations: 1000 });
	     */
	    C.PBKDF2 = function (password, salt, cfg) {
	        return PBKDF2.create(cfg).compute(password, salt);
	    };
	}());


	return CryptoJS.PBKDF2;

}));
});

var evpkdf = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, sha1, hmac);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var Base = C_lib.Base;
	    var WordArray = C_lib.WordArray;
	    var C_algo = C.algo;
	    var MD5 = C_algo.MD5;

	    /**
	     * This key derivation function is meant to conform with EVP_BytesToKey.
	     * www.openssl.org/docs/crypto/EVP_BytesToKey.html
	     */
	    var EvpKDF = C_algo.EvpKDF = Base.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {number} keySize The key size in words to generate. Default: 4 (128 bits)
	         * @property {Hasher} hasher The hash algorithm to use. Default: MD5
	         * @property {number} iterations The number of iterations to perform. Default: 1
	         */
	        cfg: Base.extend({
	            keySize: 128/32,
	            hasher: MD5,
	            iterations: 1
	        }),

	        /**
	         * Initializes a newly created key derivation function.
	         *
	         * @param {Object} cfg (Optional) The configuration options to use for the derivation.
	         *
	         * @example
	         *
	         *     var kdf = CryptoJS.algo.EvpKDF.create();
	         *     var kdf = CryptoJS.algo.EvpKDF.create({ keySize: 8 });
	         *     var kdf = CryptoJS.algo.EvpKDF.create({ keySize: 8, iterations: 1000 });
	         */
	        init: function (cfg) {
	            this.cfg = this.cfg.extend(cfg);
	        },

	        /**
	         * Derives a key from a password.
	         *
	         * @param {WordArray|string} password The password.
	         * @param {WordArray|string} salt A salt.
	         *
	         * @return {WordArray} The derived key.
	         *
	         * @example
	         *
	         *     var key = kdf.compute(password, salt);
	         */
	        compute: function (password, salt) {
	            // Shortcut
	            var cfg = this.cfg;

	            // Init hasher
	            var hasher = cfg.hasher.create();

	            // Initial values
	            var derivedKey = WordArray.create();

	            // Shortcuts
	            var derivedKeyWords = derivedKey.words;
	            var keySize = cfg.keySize;
	            var iterations = cfg.iterations;

	            // Generate key
	            while (derivedKeyWords.length < keySize) {
	                if (block) {
	                    hasher.update(block);
	                }
	                var block = hasher.update(password).finalize(salt);
	                hasher.reset();

	                // Iterations
	                for (var i = 1; i < iterations; i++) {
	                    block = hasher.finalize(block);
	                    hasher.reset();
	                }

	                derivedKey.concat(block);
	            }
	            derivedKey.sigBytes = keySize * 4;

	            return derivedKey;
	        }
	    });

	    /**
	     * Derives a key from a password.
	     *
	     * @param {WordArray|string} password The password.
	     * @param {WordArray|string} salt A salt.
	     * @param {Object} cfg (Optional) The configuration options to use for this computation.
	     *
	     * @return {WordArray} The derived key.
	     *
	     * @static
	     *
	     * @example
	     *
	     *     var key = CryptoJS.EvpKDF(password, salt);
	     *     var key = CryptoJS.EvpKDF(password, salt, { keySize: 8 });
	     *     var key = CryptoJS.EvpKDF(password, salt, { keySize: 8, iterations: 1000 });
	     */
	    C.EvpKDF = function (password, salt, cfg) {
	        return EvpKDF.create(cfg).compute(password, salt);
	    };
	}());


	return CryptoJS.EvpKDF;

}));
});

var cipherCore = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, evpkdf);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * Cipher core components.
	 */
	CryptoJS.lib.Cipher || (function (undefined) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var Base = C_lib.Base;
	    var WordArray = C_lib.WordArray;
	    var BufferedBlockAlgorithm = C_lib.BufferedBlockAlgorithm;
	    var C_enc = C.enc;
	    var Utf8 = C_enc.Utf8;
	    var Base64 = C_enc.Base64;
	    var C_algo = C.algo;
	    var EvpKDF = C_algo.EvpKDF;

	    /**
	     * Abstract base cipher template.
	     *
	     * @property {number} keySize This cipher's key size. Default: 4 (128 bits)
	     * @property {number} ivSize This cipher's IV size. Default: 4 (128 bits)
	     * @property {number} _ENC_XFORM_MODE A constant representing encryption mode.
	     * @property {number} _DEC_XFORM_MODE A constant representing decryption mode.
	     */
	    var Cipher = C_lib.Cipher = BufferedBlockAlgorithm.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {WordArray} iv The IV to use for this operation.
	         */
	        cfg: Base.extend(),

	        /**
	         * Creates this cipher in encryption mode.
	         *
	         * @param {WordArray} key The key.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @return {Cipher} A cipher instance.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var cipher = CryptoJS.algo.AES.createEncryptor(keyWordArray, { iv: ivWordArray });
	         */
	        createEncryptor: function (key, cfg) {
	            return this.create(this._ENC_XFORM_MODE, key, cfg);
	        },

	        /**
	         * Creates this cipher in decryption mode.
	         *
	         * @param {WordArray} key The key.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @return {Cipher} A cipher instance.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var cipher = CryptoJS.algo.AES.createDecryptor(keyWordArray, { iv: ivWordArray });
	         */
	        createDecryptor: function (key, cfg) {
	            return this.create(this._DEC_XFORM_MODE, key, cfg);
	        },

	        /**
	         * Initializes a newly created cipher.
	         *
	         * @param {number} xformMode Either the encryption or decryption transormation mode constant.
	         * @param {WordArray} key The key.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @example
	         *
	         *     var cipher = CryptoJS.algo.AES.create(CryptoJS.algo.AES._ENC_XFORM_MODE, keyWordArray, { iv: ivWordArray });
	         */
	        init: function (xformMode, key, cfg) {
	            // Apply config defaults
	            this.cfg = this.cfg.extend(cfg);

	            // Store transform mode and key
	            this._xformMode = xformMode;
	            this._key = key;

	            // Set initial values
	            this.reset();
	        },

	        /**
	         * Resets this cipher to its initial state.
	         *
	         * @example
	         *
	         *     cipher.reset();
	         */
	        reset: function () {
	            // Reset data buffer
	            BufferedBlockAlgorithm.reset.call(this);

	            // Perform concrete-cipher logic
	            this._doReset();
	        },

	        /**
	         * Adds data to be encrypted or decrypted.
	         *
	         * @param {WordArray|string} dataUpdate The data to encrypt or decrypt.
	         *
	         * @return {WordArray} The data after processing.
	         *
	         * @example
	         *
	         *     var encrypted = cipher.process('data');
	         *     var encrypted = cipher.process(wordArray);
	         */
	        process: function (dataUpdate) {
	            // Append
	            this._append(dataUpdate);

	            // Process available blocks
	            return this._process();
	        },

	        /**
	         * Finalizes the encryption or decryption process.
	         * Note that the finalize operation is effectively a destructive, read-once operation.
	         *
	         * @param {WordArray|string} dataUpdate The final data to encrypt or decrypt.
	         *
	         * @return {WordArray} The data after final processing.
	         *
	         * @example
	         *
	         *     var encrypted = cipher.finalize();
	         *     var encrypted = cipher.finalize('data');
	         *     var encrypted = cipher.finalize(wordArray);
	         */
	        finalize: function (dataUpdate) {
	            // Final data update
	            if (dataUpdate) {
	                this._append(dataUpdate);
	            }

	            // Perform concrete-cipher logic
	            var finalProcessedData = this._doFinalize();

	            return finalProcessedData;
	        },

	        keySize: 128/32,

	        ivSize: 128/32,

	        _ENC_XFORM_MODE: 1,

	        _DEC_XFORM_MODE: 2,

	        /**
	         * Creates shortcut functions to a cipher's object interface.
	         *
	         * @param {Cipher} cipher The cipher to create a helper for.
	         *
	         * @return {Object} An object with encrypt and decrypt shortcut functions.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var AES = CryptoJS.lib.Cipher._createHelper(CryptoJS.algo.AES);
	         */
	        _createHelper: (function () {
	            function selectCipherStrategy(key) {
	                if (typeof key == 'string') {
	                    return PasswordBasedCipher;
	                } else {
	                    return SerializableCipher;
	                }
	            }

	            return function (cipher) {
	                return {
	                    encrypt: function (message, key, cfg) {
	                        return selectCipherStrategy(key).encrypt(cipher, message, key, cfg);
	                    },

	                    decrypt: function (ciphertext, key, cfg) {
	                        return selectCipherStrategy(key).decrypt(cipher, ciphertext, key, cfg);
	                    }
	                };
	            };
	        }())
	    });

	    /**
	     * Abstract base stream cipher template.
	     *
	     * @property {number} blockSize The number of 32-bit words this cipher operates on. Default: 1 (32 bits)
	     */
	    var StreamCipher = C_lib.StreamCipher = Cipher.extend({
	        _doFinalize: function () {
	            // Process partial blocks
	            var finalProcessedBlocks = this._process(!!'flush');

	            return finalProcessedBlocks;
	        },

	        blockSize: 1
	    });

	    /**
	     * Mode namespace.
	     */
	    var C_mode = C.mode = {};

	    /**
	     * Abstract base block cipher mode template.
	     */
	    var BlockCipherMode = C_lib.BlockCipherMode = Base.extend({
	        /**
	         * Creates this mode for encryption.
	         *
	         * @param {Cipher} cipher A block cipher instance.
	         * @param {Array} iv The IV words.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var mode = CryptoJS.mode.CBC.createEncryptor(cipher, iv.words);
	         */
	        createEncryptor: function (cipher, iv) {
	            return this.Encryptor.create(cipher, iv);
	        },

	        /**
	         * Creates this mode for decryption.
	         *
	         * @param {Cipher} cipher A block cipher instance.
	         * @param {Array} iv The IV words.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var mode = CryptoJS.mode.CBC.createDecryptor(cipher, iv.words);
	         */
	        createDecryptor: function (cipher, iv) {
	            return this.Decryptor.create(cipher, iv);
	        },

	        /**
	         * Initializes a newly created mode.
	         *
	         * @param {Cipher} cipher A block cipher instance.
	         * @param {Array} iv The IV words.
	         *
	         * @example
	         *
	         *     var mode = CryptoJS.mode.CBC.Encryptor.create(cipher, iv.words);
	         */
	        init: function (cipher, iv) {
	            this._cipher = cipher;
	            this._iv = iv;
	        }
	    });

	    /**
	     * Cipher Block Chaining mode.
	     */
	    var CBC = C_mode.CBC = (function () {
	        /**
	         * Abstract base CBC mode.
	         */
	        var CBC = BlockCipherMode.extend();

	        /**
	         * CBC encryptor.
	         */
	        CBC.Encryptor = CBC.extend({
	            /**
	             * Processes the data block at offset.
	             *
	             * @param {Array} words The data words to operate on.
	             * @param {number} offset The offset where the block starts.
	             *
	             * @example
	             *
	             *     mode.processBlock(data.words, offset);
	             */
	            processBlock: function (words, offset) {
	                // Shortcuts
	                var cipher = this._cipher;
	                var blockSize = cipher.blockSize;

	                // XOR and encrypt
	                xorBlock.call(this, words, offset, blockSize);
	                cipher.encryptBlock(words, offset);

	                // Remember this block to use with next block
	                this._prevBlock = words.slice(offset, offset + blockSize);
	            }
	        });

	        /**
	         * CBC decryptor.
	         */
	        CBC.Decryptor = CBC.extend({
	            /**
	             * Processes the data block at offset.
	             *
	             * @param {Array} words The data words to operate on.
	             * @param {number} offset The offset where the block starts.
	             *
	             * @example
	             *
	             *     mode.processBlock(data.words, offset);
	             */
	            processBlock: function (words, offset) {
	                // Shortcuts
	                var cipher = this._cipher;
	                var blockSize = cipher.blockSize;

	                // Remember this block to use with next block
	                var thisBlock = words.slice(offset, offset + blockSize);

	                // Decrypt and XOR
	                cipher.decryptBlock(words, offset);
	                xorBlock.call(this, words, offset, blockSize);

	                // This block becomes the previous block
	                this._prevBlock = thisBlock;
	            }
	        });

	        function xorBlock(words, offset, blockSize) {
	            // Shortcut
	            var iv = this._iv;

	            // Choose mixing block
	            if (iv) {
	                var block = iv;

	                // Remove IV for subsequent blocks
	                this._iv = undefined;
	            } else {
	                var block = this._prevBlock;
	            }

	            // XOR blocks
	            for (var i = 0; i < blockSize; i++) {
	                words[offset + i] ^= block[i];
	            }
	        }

	        return CBC;
	    }());

	    /**
	     * Padding namespace.
	     */
	    var C_pad = C.pad = {};

	    /**
	     * PKCS #5/7 padding strategy.
	     */
	    var Pkcs7 = C_pad.Pkcs7 = {
	        /**
	         * Pads data using the algorithm defined in PKCS #5/7.
	         *
	         * @param {WordArray} data The data to pad.
	         * @param {number} blockSize The multiple that the data should be padded to.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     CryptoJS.pad.Pkcs7.pad(wordArray, 4);
	         */
	        pad: function (data, blockSize) {
	            // Shortcut
	            var blockSizeBytes = blockSize * 4;

	            // Count padding bytes
	            var nPaddingBytes = blockSizeBytes - data.sigBytes % blockSizeBytes;

	            // Create padding word
	            var paddingWord = (nPaddingBytes << 24) | (nPaddingBytes << 16) | (nPaddingBytes << 8) | nPaddingBytes;

	            // Create padding
	            var paddingWords = [];
	            for (var i = 0; i < nPaddingBytes; i += 4) {
	                paddingWords.push(paddingWord);
	            }
	            var padding = WordArray.create(paddingWords, nPaddingBytes);

	            // Add padding
	            data.concat(padding);
	        },

	        /**
	         * Unpads data that had been padded using the algorithm defined in PKCS #5/7.
	         *
	         * @param {WordArray} data The data to unpad.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     CryptoJS.pad.Pkcs7.unpad(wordArray);
	         */
	        unpad: function (data) {
	            // Get number of padding bytes from last byte
	            var nPaddingBytes = data.words[(data.sigBytes - 1) >>> 2] & 0xff;

	            // Remove padding
	            data.sigBytes -= nPaddingBytes;
	        }
	    };

	    /**
	     * Abstract base block cipher template.
	     *
	     * @property {number} blockSize The number of 32-bit words this cipher operates on. Default: 4 (128 bits)
	     */
	    var BlockCipher = C_lib.BlockCipher = Cipher.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {Mode} mode The block mode to use. Default: CBC
	         * @property {Padding} padding The padding strategy to use. Default: Pkcs7
	         */
	        cfg: Cipher.cfg.extend({
	            mode: CBC,
	            padding: Pkcs7
	        }),

	        reset: function () {
	            // Reset cipher
	            Cipher.reset.call(this);

	            // Shortcuts
	            var cfg = this.cfg;
	            var iv = cfg.iv;
	            var mode = cfg.mode;

	            // Reset block mode
	            if (this._xformMode == this._ENC_XFORM_MODE) {
	                var modeCreator = mode.createEncryptor;
	            } else /* if (this._xformMode == this._DEC_XFORM_MODE) */ {
	                var modeCreator = mode.createDecryptor;
	                // Keep at least one block in the buffer for unpadding
	                this._minBufferSize = 1;
	            }

	            if (this._mode && this._mode.__creator == modeCreator) {
	                this._mode.init(this, iv && iv.words);
	            } else {
	                this._mode = modeCreator.call(mode, this, iv && iv.words);
	                this._mode.__creator = modeCreator;
	            }
	        },

	        _doProcessBlock: function (words, offset) {
	            this._mode.processBlock(words, offset);
	        },

	        _doFinalize: function () {
	            // Shortcut
	            var padding = this.cfg.padding;

	            // Finalize
	            if (this._xformMode == this._ENC_XFORM_MODE) {
	                // Pad data
	                padding.pad(this._data, this.blockSize);

	                // Process final blocks
	                var finalProcessedBlocks = this._process(!!'flush');
	            } else /* if (this._xformMode == this._DEC_XFORM_MODE) */ {
	                // Process final blocks
	                var finalProcessedBlocks = this._process(!!'flush');

	                // Unpad data
	                padding.unpad(finalProcessedBlocks);
	            }

	            return finalProcessedBlocks;
	        },

	        blockSize: 128/32
	    });

	    /**
	     * A collection of cipher parameters.
	     *
	     * @property {WordArray} ciphertext The raw ciphertext.
	     * @property {WordArray} key The key to this ciphertext.
	     * @property {WordArray} iv The IV used in the ciphering operation.
	     * @property {WordArray} salt The salt used with a key derivation function.
	     * @property {Cipher} algorithm The cipher algorithm.
	     * @property {Mode} mode The block mode used in the ciphering operation.
	     * @property {Padding} padding The padding scheme used in the ciphering operation.
	     * @property {number} blockSize The block size of the cipher.
	     * @property {Format} formatter The default formatting strategy to convert this cipher params object to a string.
	     */
	    var CipherParams = C_lib.CipherParams = Base.extend({
	        /**
	         * Initializes a newly created cipher params object.
	         *
	         * @param {Object} cipherParams An object with any of the possible cipher parameters.
	         *
	         * @example
	         *
	         *     var cipherParams = CryptoJS.lib.CipherParams.create({
	         *         ciphertext: ciphertextWordArray,
	         *         key: keyWordArray,
	         *         iv: ivWordArray,
	         *         salt: saltWordArray,
	         *         algorithm: CryptoJS.algo.AES,
	         *         mode: CryptoJS.mode.CBC,
	         *         padding: CryptoJS.pad.PKCS7,
	         *         blockSize: 4,
	         *         formatter: CryptoJS.format.OpenSSL
	         *     });
	         */
	        init: function (cipherParams) {
	            this.mixIn(cipherParams);
	        },

	        /**
	         * Converts this cipher params object to a string.
	         *
	         * @param {Format} formatter (Optional) The formatting strategy to use.
	         *
	         * @return {string} The stringified cipher params.
	         *
	         * @throws Error If neither the formatter nor the default formatter is set.
	         *
	         * @example
	         *
	         *     var string = cipherParams + '';
	         *     var string = cipherParams.toString();
	         *     var string = cipherParams.toString(CryptoJS.format.OpenSSL);
	         */
	        toString: function (formatter) {
	            return (formatter || this.formatter).stringify(this);
	        }
	    });

	    /**
	     * Format namespace.
	     */
	    var C_format = C.format = {};

	    /**
	     * OpenSSL formatting strategy.
	     */
	    var OpenSSLFormatter = C_format.OpenSSL = {
	        /**
	         * Converts a cipher params object to an OpenSSL-compatible string.
	         *
	         * @param {CipherParams} cipherParams The cipher params object.
	         *
	         * @return {string} The OpenSSL-compatible string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var openSSLString = CryptoJS.format.OpenSSL.stringify(cipherParams);
	         */
	        stringify: function (cipherParams) {
	            // Shortcuts
	            var ciphertext = cipherParams.ciphertext;
	            var salt = cipherParams.salt;

	            // Format
	            if (salt) {
	                var wordArray = WordArray.create([0x53616c74, 0x65645f5f]).concat(salt).concat(ciphertext);
	            } else {
	                var wordArray = ciphertext;
	            }

	            return wordArray.toString(Base64);
	        },

	        /**
	         * Converts an OpenSSL-compatible string to a cipher params object.
	         *
	         * @param {string} openSSLStr The OpenSSL-compatible string.
	         *
	         * @return {CipherParams} The cipher params object.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var cipherParams = CryptoJS.format.OpenSSL.parse(openSSLString);
	         */
	        parse: function (openSSLStr) {
	            // Parse base64
	            var ciphertext = Base64.parse(openSSLStr);

	            // Shortcut
	            var ciphertextWords = ciphertext.words;

	            // Test for salt
	            if (ciphertextWords[0] == 0x53616c74 && ciphertextWords[1] == 0x65645f5f) {
	                // Extract salt
	                var salt = WordArray.create(ciphertextWords.slice(2, 4));

	                // Remove salt from ciphertext
	                ciphertextWords.splice(0, 4);
	                ciphertext.sigBytes -= 16;
	            }

	            return CipherParams.create({ ciphertext: ciphertext, salt: salt });
	        }
	    };

	    /**
	     * A cipher wrapper that returns ciphertext as a serializable cipher params object.
	     */
	    var SerializableCipher = C_lib.SerializableCipher = Base.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {Formatter} format The formatting strategy to convert cipher param objects to and from a string. Default: OpenSSL
	         */
	        cfg: Base.extend({
	            format: OpenSSLFormatter
	        }),

	        /**
	         * Encrypts a message.
	         *
	         * @param {Cipher} cipher The cipher algorithm to use.
	         * @param {WordArray|string} message The message to encrypt.
	         * @param {WordArray} key The key.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @return {CipherParams} A cipher params object.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var ciphertextParams = CryptoJS.lib.SerializableCipher.encrypt(CryptoJS.algo.AES, message, key);
	         *     var ciphertextParams = CryptoJS.lib.SerializableCipher.encrypt(CryptoJS.algo.AES, message, key, { iv: iv });
	         *     var ciphertextParams = CryptoJS.lib.SerializableCipher.encrypt(CryptoJS.algo.AES, message, key, { iv: iv, format: CryptoJS.format.OpenSSL });
	         */
	        encrypt: function (cipher, message, key, cfg) {
	            // Apply config defaults
	            cfg = this.cfg.extend(cfg);

	            // Encrypt
	            var encryptor = cipher.createEncryptor(key, cfg);
	            var ciphertext = encryptor.finalize(message);

	            // Shortcut
	            var cipherCfg = encryptor.cfg;

	            // Create and return serializable cipher params
	            return CipherParams.create({
	                ciphertext: ciphertext,
	                key: key,
	                iv: cipherCfg.iv,
	                algorithm: cipher,
	                mode: cipherCfg.mode,
	                padding: cipherCfg.padding,
	                blockSize: cipher.blockSize,
	                formatter: cfg.format
	            });
	        },

	        /**
	         * Decrypts serialized ciphertext.
	         *
	         * @param {Cipher} cipher The cipher algorithm to use.
	         * @param {CipherParams|string} ciphertext The ciphertext to decrypt.
	         * @param {WordArray} key The key.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @return {WordArray} The plaintext.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var plaintext = CryptoJS.lib.SerializableCipher.decrypt(CryptoJS.algo.AES, formattedCiphertext, key, { iv: iv, format: CryptoJS.format.OpenSSL });
	         *     var plaintext = CryptoJS.lib.SerializableCipher.decrypt(CryptoJS.algo.AES, ciphertextParams, key, { iv: iv, format: CryptoJS.format.OpenSSL });
	         */
	        decrypt: function (cipher, ciphertext, key, cfg) {
	            // Apply config defaults
	            cfg = this.cfg.extend(cfg);

	            // Convert string to CipherParams
	            ciphertext = this._parse(ciphertext, cfg.format);

	            // Decrypt
	            var plaintext = cipher.createDecryptor(key, cfg).finalize(ciphertext.ciphertext);

	            return plaintext;
	        },

	        /**
	         * Converts serialized ciphertext to CipherParams,
	         * else assumed CipherParams already and returns ciphertext unchanged.
	         *
	         * @param {CipherParams|string} ciphertext The ciphertext.
	         * @param {Formatter} format The formatting strategy to use to parse serialized ciphertext.
	         *
	         * @return {CipherParams} The unserialized ciphertext.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var ciphertextParams = CryptoJS.lib.SerializableCipher._parse(ciphertextStringOrParams, format);
	         */
	        _parse: function (ciphertext, format) {
	            if (typeof ciphertext == 'string') {
	                return format.parse(ciphertext, this);
	            } else {
	                return ciphertext;
	            }
	        }
	    });

	    /**
	     * Key derivation function namespace.
	     */
	    var C_kdf = C.kdf = {};

	    /**
	     * OpenSSL key derivation function.
	     */
	    var OpenSSLKdf = C_kdf.OpenSSL = {
	        /**
	         * Derives a key and IV from a password.
	         *
	         * @param {string} password The password to derive from.
	         * @param {number} keySize The size in words of the key to generate.
	         * @param {number} ivSize The size in words of the IV to generate.
	         * @param {WordArray|string} salt (Optional) A 64-bit salt to use. If omitted, a salt will be generated randomly.
	         *
	         * @return {CipherParams} A cipher params object with the key, IV, and salt.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var derivedParams = CryptoJS.kdf.OpenSSL.execute('Password', 256/32, 128/32);
	         *     var derivedParams = CryptoJS.kdf.OpenSSL.execute('Password', 256/32, 128/32, 'saltsalt');
	         */
	        execute: function (password, keySize, ivSize, salt) {
	            // Generate random salt
	            if (!salt) {
	                salt = WordArray.random(64/8);
	            }

	            // Derive key and IV
	            var key = EvpKDF.create({ keySize: keySize + ivSize }).compute(password, salt);

	            // Separate key and IV
	            var iv = WordArray.create(key.words.slice(keySize), ivSize * 4);
	            key.sigBytes = keySize * 4;

	            // Return params
	            return CipherParams.create({ key: key, iv: iv, salt: salt });
	        }
	    };

	    /**
	     * A serializable cipher wrapper that derives the key from a password,
	     * and returns ciphertext as a serializable cipher params object.
	     */
	    var PasswordBasedCipher = C_lib.PasswordBasedCipher = SerializableCipher.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {KDF} kdf The key derivation function to use to generate a key and IV from a password. Default: OpenSSL
	         */
	        cfg: SerializableCipher.cfg.extend({
	            kdf: OpenSSLKdf
	        }),

	        /**
	         * Encrypts a message using a password.
	         *
	         * @param {Cipher} cipher The cipher algorithm to use.
	         * @param {WordArray|string} message The message to encrypt.
	         * @param {string} password The password.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @return {CipherParams} A cipher params object.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var ciphertextParams = CryptoJS.lib.PasswordBasedCipher.encrypt(CryptoJS.algo.AES, message, 'password');
	         *     var ciphertextParams = CryptoJS.lib.PasswordBasedCipher.encrypt(CryptoJS.algo.AES, message, 'password', { format: CryptoJS.format.OpenSSL });
	         */
	        encrypt: function (cipher, message, password, cfg) {
	            // Apply config defaults
	            cfg = this.cfg.extend(cfg);

	            // Derive key and other params
	            var derivedParams = cfg.kdf.execute(password, cipher.keySize, cipher.ivSize);

	            // Add IV to config
	            cfg.iv = derivedParams.iv;

	            // Encrypt
	            var ciphertext = SerializableCipher.encrypt.call(this, cipher, message, derivedParams.key, cfg);

	            // Mix in derived params
	            ciphertext.mixIn(derivedParams);

	            return ciphertext;
	        },

	        /**
	         * Decrypts serialized ciphertext using a password.
	         *
	         * @param {Cipher} cipher The cipher algorithm to use.
	         * @param {CipherParams|string} ciphertext The ciphertext to decrypt.
	         * @param {string} password The password.
	         * @param {Object} cfg (Optional) The configuration options to use for this operation.
	         *
	         * @return {WordArray} The plaintext.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var plaintext = CryptoJS.lib.PasswordBasedCipher.decrypt(CryptoJS.algo.AES, formattedCiphertext, 'password', { format: CryptoJS.format.OpenSSL });
	         *     var plaintext = CryptoJS.lib.PasswordBasedCipher.decrypt(CryptoJS.algo.AES, ciphertextParams, 'password', { format: CryptoJS.format.OpenSSL });
	         */
	        decrypt: function (cipher, ciphertext, password, cfg) {
	            // Apply config defaults
	            cfg = this.cfg.extend(cfg);

	            // Convert string to CipherParams
	            ciphertext = this._parse(ciphertext, cfg.format);

	            // Derive key and other params
	            var derivedParams = cfg.kdf.execute(password, cipher.keySize, cipher.ivSize, ciphertext.salt);

	            // Add IV to config
	            cfg.iv = derivedParams.iv;

	            // Decrypt
	            var plaintext = SerializableCipher.decrypt.call(this, cipher, ciphertext, derivedParams.key, cfg);

	            return plaintext;
	        }
	    });
	}());


}));
});

var modeCfb = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * Cipher Feedback block mode.
	 */
	CryptoJS.mode.CFB = (function () {
	    var CFB = CryptoJS.lib.BlockCipherMode.extend();

	    CFB.Encryptor = CFB.extend({
	        processBlock: function (words, offset) {
	            // Shortcuts
	            var cipher = this._cipher;
	            var blockSize = cipher.blockSize;

	            generateKeystreamAndEncrypt.call(this, words, offset, blockSize, cipher);

	            // Remember this block to use with next block
	            this._prevBlock = words.slice(offset, offset + blockSize);
	        }
	    });

	    CFB.Decryptor = CFB.extend({
	        processBlock: function (words, offset) {
	            // Shortcuts
	            var cipher = this._cipher;
	            var blockSize = cipher.blockSize;

	            // Remember this block to use with next block
	            var thisBlock = words.slice(offset, offset + blockSize);

	            generateKeystreamAndEncrypt.call(this, words, offset, blockSize, cipher);

	            // This block becomes the previous block
	            this._prevBlock = thisBlock;
	        }
	    });

	    function generateKeystreamAndEncrypt(words, offset, blockSize, cipher) {
	        // Shortcut
	        var iv = this._iv;

	        // Generate keystream
	        if (iv) {
	            var keystream = iv.slice(0);

	            // Remove IV for subsequent blocks
	            this._iv = undefined;
	        } else {
	            var keystream = this._prevBlock;
	        }
	        cipher.encryptBlock(keystream, 0);

	        // Encrypt
	        for (var i = 0; i < blockSize; i++) {
	            words[offset + i] ^= keystream[i];
	        }
	    }

	    return CFB;
	}());


	return CryptoJS.mode.CFB;

}));
});

var modeCtr = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * Counter block mode.
	 */
	CryptoJS.mode.CTR = (function () {
	    var CTR = CryptoJS.lib.BlockCipherMode.extend();

	    var Encryptor = CTR.Encryptor = CTR.extend({
	        processBlock: function (words, offset) {
	            // Shortcuts
	            var cipher = this._cipher;
	            var blockSize = cipher.blockSize;
	            var iv = this._iv;
	            var counter = this._counter;

	            // Generate keystream
	            if (iv) {
	                counter = this._counter = iv.slice(0);

	                // Remove IV for subsequent blocks
	                this._iv = undefined;
	            }
	            var keystream = counter.slice(0);
	            cipher.encryptBlock(keystream, 0);

	            // Increment counter
	            counter[blockSize - 1] = (counter[blockSize - 1] + 1) | 0;

	            // Encrypt
	            for (var i = 0; i < blockSize; i++) {
	                words[offset + i] ^= keystream[i];
	            }
	        }
	    });

	    CTR.Decryptor = Encryptor;

	    return CTR;
	}());


	return CryptoJS.mode.CTR;

}));
});

var modeCtrGladman = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/** @preserve
	 * Counter block mode compatible with  Dr Brian Gladman fileenc.c
	 * derived from CryptoJS.mode.CTR
	 * Jan Hruby jhruby.web@gmail.com
	 */
	CryptoJS.mode.CTRGladman = (function () {
	    var CTRGladman = CryptoJS.lib.BlockCipherMode.extend();

		function incWord(word)
		{
			if (((word >> 24) & 0xff) === 0xff) { //overflow
			var b1 = (word >> 16)&0xff;
			var b2 = (word >> 8)&0xff;
			var b3 = word & 0xff;

			if (b1 === 0xff) // overflow b1
			{
			b1 = 0;
			if (b2 === 0xff)
			{
				b2 = 0;
				if (b3 === 0xff)
				{
					b3 = 0;
				}
				else
				{
					++b3;
				}
			}
			else
			{
				++b2;
			}
			}
			else
			{
			++b1;
			}

			word = 0;
			word += (b1 << 16);
			word += (b2 << 8);
			word += b3;
			}
			else
			{
			word += (0x01 << 24);
			}
			return word;
		}

		function incCounter(counter)
		{
			if ((counter[0] = incWord(counter[0])) === 0)
			{
				// encr_data in fileenc.c from  Dr Brian Gladman's counts only with DWORD j < 8
				counter[1] = incWord(counter[1]);
			}
			return counter;
		}

	    var Encryptor = CTRGladman.Encryptor = CTRGladman.extend({
	        processBlock: function (words, offset) {
	            // Shortcuts
	            var cipher = this._cipher;
	            var blockSize = cipher.blockSize;
	            var iv = this._iv;
	            var counter = this._counter;

	            // Generate keystream
	            if (iv) {
	                counter = this._counter = iv.slice(0);

	                // Remove IV for subsequent blocks
	                this._iv = undefined;
	            }

				incCounter(counter);

				var keystream = counter.slice(0);
	            cipher.encryptBlock(keystream, 0);

	            // Encrypt
	            for (var i = 0; i < blockSize; i++) {
	                words[offset + i] ^= keystream[i];
	            }
	        }
	    });

	    CTRGladman.Decryptor = Encryptor;

	    return CTRGladman;
	}());




	return CryptoJS.mode.CTRGladman;

}));
});

var modeOfb = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * Output Feedback block mode.
	 */
	CryptoJS.mode.OFB = (function () {
	    var OFB = CryptoJS.lib.BlockCipherMode.extend();

	    var Encryptor = OFB.Encryptor = OFB.extend({
	        processBlock: function (words, offset) {
	            // Shortcuts
	            var cipher = this._cipher;
	            var blockSize = cipher.blockSize;
	            var iv = this._iv;
	            var keystream = this._keystream;

	            // Generate keystream
	            if (iv) {
	                keystream = this._keystream = iv.slice(0);

	                // Remove IV for subsequent blocks
	                this._iv = undefined;
	            }
	            cipher.encryptBlock(keystream, 0);

	            // Encrypt
	            for (var i = 0; i < blockSize; i++) {
	                words[offset + i] ^= keystream[i];
	            }
	        }
	    });

	    OFB.Decryptor = Encryptor;

	    return OFB;
	}());


	return CryptoJS.mode.OFB;

}));
});

var modeEcb = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * Electronic Codebook block mode.
	 */
	CryptoJS.mode.ECB = (function () {
	    var ECB = CryptoJS.lib.BlockCipherMode.extend();

	    ECB.Encryptor = ECB.extend({
	        processBlock: function (words, offset) {
	            this._cipher.encryptBlock(words, offset);
	        }
	    });

	    ECB.Decryptor = ECB.extend({
	        processBlock: function (words, offset) {
	            this._cipher.decryptBlock(words, offset);
	        }
	    });

	    return ECB;
	}());


	return CryptoJS.mode.ECB;

}));
});

var padAnsix923 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * ANSI X.923 padding strategy.
	 */
	CryptoJS.pad.AnsiX923 = {
	    pad: function (data, blockSize) {
	        // Shortcuts
	        var dataSigBytes = data.sigBytes;
	        var blockSizeBytes = blockSize * 4;

	        // Count padding bytes
	        var nPaddingBytes = blockSizeBytes - dataSigBytes % blockSizeBytes;

	        // Compute last byte position
	        var lastBytePos = dataSigBytes + nPaddingBytes - 1;

	        // Pad
	        data.clamp();
	        data.words[lastBytePos >>> 2] |= nPaddingBytes << (24 - (lastBytePos % 4) * 8);
	        data.sigBytes += nPaddingBytes;
	    },

	    unpad: function (data) {
	        // Get number of padding bytes from last byte
	        var nPaddingBytes = data.words[(data.sigBytes - 1) >>> 2] & 0xff;

	        // Remove padding
	        data.sigBytes -= nPaddingBytes;
	    }
	};


	return CryptoJS.pad.Ansix923;

}));
});

var padIso10126 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * ISO 10126 padding strategy.
	 */
	CryptoJS.pad.Iso10126 = {
	    pad: function (data, blockSize) {
	        // Shortcut
	        var blockSizeBytes = blockSize * 4;

	        // Count padding bytes
	        var nPaddingBytes = blockSizeBytes - data.sigBytes % blockSizeBytes;

	        // Pad
	        data.concat(CryptoJS.lib.WordArray.random(nPaddingBytes - 1)).
	             concat(CryptoJS.lib.WordArray.create([nPaddingBytes << 24], 1));
	    },

	    unpad: function (data) {
	        // Get number of padding bytes from last byte
	        var nPaddingBytes = data.words[(data.sigBytes - 1) >>> 2] & 0xff;

	        // Remove padding
	        data.sigBytes -= nPaddingBytes;
	    }
	};


	return CryptoJS.pad.Iso10126;

}));
});

var padIso97971 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * ISO/IEC 9797-1 Padding Method 2.
	 */
	CryptoJS.pad.Iso97971 = {
	    pad: function (data, blockSize) {
	        // Add 0x80 byte
	        data.concat(CryptoJS.lib.WordArray.create([0x80000000], 1));

	        // Zero pad the rest
	        CryptoJS.pad.ZeroPadding.pad(data, blockSize);
	    },

	    unpad: function (data) {
	        // Remove zero padding
	        CryptoJS.pad.ZeroPadding.unpad(data);

	        // Remove one more byte -- the 0x80 byte
	        data.sigBytes--;
	    }
	};


	return CryptoJS.pad.Iso97971;

}));
});

var padZeropadding = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * Zero padding strategy.
	 */
	CryptoJS.pad.ZeroPadding = {
	    pad: function (data, blockSize) {
	        // Shortcut
	        var blockSizeBytes = blockSize * 4;

	        // Pad
	        data.clamp();
	        data.sigBytes += blockSizeBytes - ((data.sigBytes % blockSizeBytes) || blockSizeBytes);
	    },

	    unpad: function (data) {
	        // Shortcut
	        var dataWords = data.words;

	        // Unpad
	        var i = data.sigBytes - 1;
	        while (!((dataWords[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff)) {
	            i--;
	        }
	        data.sigBytes = i + 1;
	    }
	};


	return CryptoJS.pad.ZeroPadding;

}));
});

var padNopadding = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	/**
	 * A noop padding strategy.
	 */
	CryptoJS.pad.NoPadding = {
	    pad: function () {
	    },

	    unpad: function () {
	    }
	};


	return CryptoJS.pad.NoPadding;

}));
});

var formatHex = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function (undefined) {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var CipherParams = C_lib.CipherParams;
	    var C_enc = C.enc;
	    var Hex = C_enc.Hex;
	    var C_format = C.format;

	    var HexFormatter = C_format.Hex = {
	        /**
	         * Converts the ciphertext of a cipher params object to a hexadecimally encoded string.
	         *
	         * @param {CipherParams} cipherParams The cipher params object.
	         *
	         * @return {string} The hexadecimally encoded string.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var hexString = CryptoJS.format.Hex.stringify(cipherParams);
	         */
	        stringify: function (cipherParams) {
	            return cipherParams.ciphertext.toString(Hex);
	        },

	        /**
	         * Converts a hexadecimally encoded ciphertext string to a cipher params object.
	         *
	         * @param {string} input The hexadecimally encoded string.
	         *
	         * @return {CipherParams} The cipher params object.
	         *
	         * @static
	         *
	         * @example
	         *
	         *     var cipherParams = CryptoJS.format.Hex.parse(hexString);
	         */
	        parse: function (input) {
	            var ciphertext = Hex.parse(input);
	            return CipherParams.create({ ciphertext: ciphertext });
	        }
	    };
	}());


	return CryptoJS.format.Hex;

}));
});

var aes = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, encBase64, md5, evpkdf, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var BlockCipher = C_lib.BlockCipher;
	    var C_algo = C.algo;

	    // Lookup tables
	    var SBOX = [];
	    var INV_SBOX = [];
	    var SUB_MIX_0 = [];
	    var SUB_MIX_1 = [];
	    var SUB_MIX_2 = [];
	    var SUB_MIX_3 = [];
	    var INV_SUB_MIX_0 = [];
	    var INV_SUB_MIX_1 = [];
	    var INV_SUB_MIX_2 = [];
	    var INV_SUB_MIX_3 = [];

	    // Compute lookup tables
	    (function () {
	        // Compute double table
	        var d = [];
	        for (var i = 0; i < 256; i++) {
	            if (i < 128) {
	                d[i] = i << 1;
	            } else {
	                d[i] = (i << 1) ^ 0x11b;
	            }
	        }

	        // Walk GF(2^8)
	        var x = 0;
	        var xi = 0;
	        for (var i = 0; i < 256; i++) {
	            // Compute sbox
	            var sx = xi ^ (xi << 1) ^ (xi << 2) ^ (xi << 3) ^ (xi << 4);
	            sx = (sx >>> 8) ^ (sx & 0xff) ^ 0x63;
	            SBOX[x] = sx;
	            INV_SBOX[sx] = x;

	            // Compute multiplication
	            var x2 = d[x];
	            var x4 = d[x2];
	            var x8 = d[x4];

	            // Compute sub bytes, mix columns tables
	            var t = (d[sx] * 0x101) ^ (sx * 0x1010100);
	            SUB_MIX_0[x] = (t << 24) | (t >>> 8);
	            SUB_MIX_1[x] = (t << 16) | (t >>> 16);
	            SUB_MIX_2[x] = (t << 8)  | (t >>> 24);
	            SUB_MIX_3[x] = t;

	            // Compute inv sub bytes, inv mix columns tables
	            var t = (x8 * 0x1010101) ^ (x4 * 0x10001) ^ (x2 * 0x101) ^ (x * 0x1010100);
	            INV_SUB_MIX_0[sx] = (t << 24) | (t >>> 8);
	            INV_SUB_MIX_1[sx] = (t << 16) | (t >>> 16);
	            INV_SUB_MIX_2[sx] = (t << 8)  | (t >>> 24);
	            INV_SUB_MIX_3[sx] = t;

	            // Compute next counter
	            if (!x) {
	                x = xi = 1;
	            } else {
	                x = x2 ^ d[d[d[x8 ^ x2]]];
	                xi ^= d[d[xi]];
	            }
	        }
	    }());

	    // Precomputed Rcon lookup
	    var RCON = [0x00, 0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80, 0x1b, 0x36];

	    /**
	     * AES block cipher algorithm.
	     */
	    var AES = C_algo.AES = BlockCipher.extend({
	        _doReset: function () {
	            // Skip reset of nRounds has been set before and key did not change
	            if (this._nRounds && this._keyPriorReset === this._key) {
	                return;
	            }

	            // Shortcuts
	            var key = this._keyPriorReset = this._key;
	            var keyWords = key.words;
	            var keySize = key.sigBytes / 4;

	            // Compute number of rounds
	            var nRounds = this._nRounds = keySize + 6;

	            // Compute number of key schedule rows
	            var ksRows = (nRounds + 1) * 4;

	            // Compute key schedule
	            var keySchedule = this._keySchedule = [];
	            for (var ksRow = 0; ksRow < ksRows; ksRow++) {
	                if (ksRow < keySize) {
	                    keySchedule[ksRow] = keyWords[ksRow];
	                } else {
	                    var t = keySchedule[ksRow - 1];

	                    if (!(ksRow % keySize)) {
	                        // Rot word
	                        t = (t << 8) | (t >>> 24);

	                        // Sub word
	                        t = (SBOX[t >>> 24] << 24) | (SBOX[(t >>> 16) & 0xff] << 16) | (SBOX[(t >>> 8) & 0xff] << 8) | SBOX[t & 0xff];

	                        // Mix Rcon
	                        t ^= RCON[(ksRow / keySize) | 0] << 24;
	                    } else if (keySize > 6 && ksRow % keySize == 4) {
	                        // Sub word
	                        t = (SBOX[t >>> 24] << 24) | (SBOX[(t >>> 16) & 0xff] << 16) | (SBOX[(t >>> 8) & 0xff] << 8) | SBOX[t & 0xff];
	                    }

	                    keySchedule[ksRow] = keySchedule[ksRow - keySize] ^ t;
	                }
	            }

	            // Compute inv key schedule
	            var invKeySchedule = this._invKeySchedule = [];
	            for (var invKsRow = 0; invKsRow < ksRows; invKsRow++) {
	                var ksRow = ksRows - invKsRow;

	                if (invKsRow % 4) {
	                    var t = keySchedule[ksRow];
	                } else {
	                    var t = keySchedule[ksRow - 4];
	                }

	                if (invKsRow < 4 || ksRow <= 4) {
	                    invKeySchedule[invKsRow] = t;
	                } else {
	                    invKeySchedule[invKsRow] = INV_SUB_MIX_0[SBOX[t >>> 24]] ^ INV_SUB_MIX_1[SBOX[(t >>> 16) & 0xff]] ^
	                                               INV_SUB_MIX_2[SBOX[(t >>> 8) & 0xff]] ^ INV_SUB_MIX_3[SBOX[t & 0xff]];
	                }
	            }
	        },

	        encryptBlock: function (M, offset) {
	            this._doCryptBlock(M, offset, this._keySchedule, SUB_MIX_0, SUB_MIX_1, SUB_MIX_2, SUB_MIX_3, SBOX);
	        },

	        decryptBlock: function (M, offset) {
	            // Swap 2nd and 4th rows
	            var t = M[offset + 1];
	            M[offset + 1] = M[offset + 3];
	            M[offset + 3] = t;

	            this._doCryptBlock(M, offset, this._invKeySchedule, INV_SUB_MIX_0, INV_SUB_MIX_1, INV_SUB_MIX_2, INV_SUB_MIX_3, INV_SBOX);

	            // Inv swap 2nd and 4th rows
	            var t = M[offset + 1];
	            M[offset + 1] = M[offset + 3];
	            M[offset + 3] = t;
	        },

	        _doCryptBlock: function (M, offset, keySchedule, SUB_MIX_0, SUB_MIX_1, SUB_MIX_2, SUB_MIX_3, SBOX) {
	            // Shortcut
	            var nRounds = this._nRounds;

	            // Get input, add round key
	            var s0 = M[offset]     ^ keySchedule[0];
	            var s1 = M[offset + 1] ^ keySchedule[1];
	            var s2 = M[offset + 2] ^ keySchedule[2];
	            var s3 = M[offset + 3] ^ keySchedule[3];

	            // Key schedule row counter
	            var ksRow = 4;

	            // Rounds
	            for (var round = 1; round < nRounds; round++) {
	                // Shift rows, sub bytes, mix columns, add round key
	                var t0 = SUB_MIX_0[s0 >>> 24] ^ SUB_MIX_1[(s1 >>> 16) & 0xff] ^ SUB_MIX_2[(s2 >>> 8) & 0xff] ^ SUB_MIX_3[s3 & 0xff] ^ keySchedule[ksRow++];
	                var t1 = SUB_MIX_0[s1 >>> 24] ^ SUB_MIX_1[(s2 >>> 16) & 0xff] ^ SUB_MIX_2[(s3 >>> 8) & 0xff] ^ SUB_MIX_3[s0 & 0xff] ^ keySchedule[ksRow++];
	                var t2 = SUB_MIX_0[s2 >>> 24] ^ SUB_MIX_1[(s3 >>> 16) & 0xff] ^ SUB_MIX_2[(s0 >>> 8) & 0xff] ^ SUB_MIX_3[s1 & 0xff] ^ keySchedule[ksRow++];
	                var t3 = SUB_MIX_0[s3 >>> 24] ^ SUB_MIX_1[(s0 >>> 16) & 0xff] ^ SUB_MIX_2[(s1 >>> 8) & 0xff] ^ SUB_MIX_3[s2 & 0xff] ^ keySchedule[ksRow++];

	                // Update state
	                s0 = t0;
	                s1 = t1;
	                s2 = t2;
	                s3 = t3;
	            }

	            // Shift rows, sub bytes, add round key
	            var t0 = ((SBOX[s0 >>> 24] << 24) | (SBOX[(s1 >>> 16) & 0xff] << 16) | (SBOX[(s2 >>> 8) & 0xff] << 8) | SBOX[s3 & 0xff]) ^ keySchedule[ksRow++];
	            var t1 = ((SBOX[s1 >>> 24] << 24) | (SBOX[(s2 >>> 16) & 0xff] << 16) | (SBOX[(s3 >>> 8) & 0xff] << 8) | SBOX[s0 & 0xff]) ^ keySchedule[ksRow++];
	            var t2 = ((SBOX[s2 >>> 24] << 24) | (SBOX[(s3 >>> 16) & 0xff] << 16) | (SBOX[(s0 >>> 8) & 0xff] << 8) | SBOX[s1 & 0xff]) ^ keySchedule[ksRow++];
	            var t3 = ((SBOX[s3 >>> 24] << 24) | (SBOX[(s0 >>> 16) & 0xff] << 16) | (SBOX[(s1 >>> 8) & 0xff] << 8) | SBOX[s2 & 0xff]) ^ keySchedule[ksRow++];

	            // Set output
	            M[offset]     = t0;
	            M[offset + 1] = t1;
	            M[offset + 2] = t2;
	            M[offset + 3] = t3;
	        },

	        keySize: 256/32
	    });

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.AES.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.AES.decrypt(ciphertext, key, cfg);
	     */
	    C.AES = BlockCipher._createHelper(AES);
	}());


	return CryptoJS.AES;

}));
});

var tripledes = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, encBase64, md5, evpkdf, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var WordArray = C_lib.WordArray;
	    var BlockCipher = C_lib.BlockCipher;
	    var C_algo = C.algo;

	    // Permuted Choice 1 constants
	    var PC1 = [
	        57, 49, 41, 33, 25, 17, 9,  1,
	        58, 50, 42, 34, 26, 18, 10, 2,
	        59, 51, 43, 35, 27, 19, 11, 3,
	        60, 52, 44, 36, 63, 55, 47, 39,
	        31, 23, 15, 7,  62, 54, 46, 38,
	        30, 22, 14, 6,  61, 53, 45, 37,
	        29, 21, 13, 5,  28, 20, 12, 4
	    ];

	    // Permuted Choice 2 constants
	    var PC2 = [
	        14, 17, 11, 24, 1,  5,
	        3,  28, 15, 6,  21, 10,
	        23, 19, 12, 4,  26, 8,
	        16, 7,  27, 20, 13, 2,
	        41, 52, 31, 37, 47, 55,
	        30, 40, 51, 45, 33, 48,
	        44, 49, 39, 56, 34, 53,
	        46, 42, 50, 36, 29, 32
	    ];

	    // Cumulative bit shift constants
	    var BIT_SHIFTS = [1,  2,  4,  6,  8,  10, 12, 14, 15, 17, 19, 21, 23, 25, 27, 28];

	    // SBOXes and round permutation constants
	    var SBOX_P = [
	        {
	            0x0: 0x808200,
	            0x10000000: 0x8000,
	            0x20000000: 0x808002,
	            0x30000000: 0x2,
	            0x40000000: 0x200,
	            0x50000000: 0x808202,
	            0x60000000: 0x800202,
	            0x70000000: 0x800000,
	            0x80000000: 0x202,
	            0x90000000: 0x800200,
	            0xa0000000: 0x8200,
	            0xb0000000: 0x808000,
	            0xc0000000: 0x8002,
	            0xd0000000: 0x800002,
	            0xe0000000: 0x0,
	            0xf0000000: 0x8202,
	            0x8000000: 0x0,
	            0x18000000: 0x808202,
	            0x28000000: 0x8202,
	            0x38000000: 0x8000,
	            0x48000000: 0x808200,
	            0x58000000: 0x200,
	            0x68000000: 0x808002,
	            0x78000000: 0x2,
	            0x88000000: 0x800200,
	            0x98000000: 0x8200,
	            0xa8000000: 0x808000,
	            0xb8000000: 0x800202,
	            0xc8000000: 0x800002,
	            0xd8000000: 0x8002,
	            0xe8000000: 0x202,
	            0xf8000000: 0x800000,
	            0x1: 0x8000,
	            0x10000001: 0x2,
	            0x20000001: 0x808200,
	            0x30000001: 0x800000,
	            0x40000001: 0x808002,
	            0x50000001: 0x8200,
	            0x60000001: 0x200,
	            0x70000001: 0x800202,
	            0x80000001: 0x808202,
	            0x90000001: 0x808000,
	            0xa0000001: 0x800002,
	            0xb0000001: 0x8202,
	            0xc0000001: 0x202,
	            0xd0000001: 0x800200,
	            0xe0000001: 0x8002,
	            0xf0000001: 0x0,
	            0x8000001: 0x808202,
	            0x18000001: 0x808000,
	            0x28000001: 0x800000,
	            0x38000001: 0x200,
	            0x48000001: 0x8000,
	            0x58000001: 0x800002,
	            0x68000001: 0x2,
	            0x78000001: 0x8202,
	            0x88000001: 0x8002,
	            0x98000001: 0x800202,
	            0xa8000001: 0x202,
	            0xb8000001: 0x808200,
	            0xc8000001: 0x800200,
	            0xd8000001: 0x0,
	            0xe8000001: 0x8200,
	            0xf8000001: 0x808002
	        },
	        {
	            0x0: 0x40084010,
	            0x1000000: 0x4000,
	            0x2000000: 0x80000,
	            0x3000000: 0x40080010,
	            0x4000000: 0x40000010,
	            0x5000000: 0x40084000,
	            0x6000000: 0x40004000,
	            0x7000000: 0x10,
	            0x8000000: 0x84000,
	            0x9000000: 0x40004010,
	            0xa000000: 0x40000000,
	            0xb000000: 0x84010,
	            0xc000000: 0x80010,
	            0xd000000: 0x0,
	            0xe000000: 0x4010,
	            0xf000000: 0x40080000,
	            0x800000: 0x40004000,
	            0x1800000: 0x84010,
	            0x2800000: 0x10,
	            0x3800000: 0x40004010,
	            0x4800000: 0x40084010,
	            0x5800000: 0x40000000,
	            0x6800000: 0x80000,
	            0x7800000: 0x40080010,
	            0x8800000: 0x80010,
	            0x9800000: 0x0,
	            0xa800000: 0x4000,
	            0xb800000: 0x40080000,
	            0xc800000: 0x40000010,
	            0xd800000: 0x84000,
	            0xe800000: 0x40084000,
	            0xf800000: 0x4010,
	            0x10000000: 0x0,
	            0x11000000: 0x40080010,
	            0x12000000: 0x40004010,
	            0x13000000: 0x40084000,
	            0x14000000: 0x40080000,
	            0x15000000: 0x10,
	            0x16000000: 0x84010,
	            0x17000000: 0x4000,
	            0x18000000: 0x4010,
	            0x19000000: 0x80000,
	            0x1a000000: 0x80010,
	            0x1b000000: 0x40000010,
	            0x1c000000: 0x84000,
	            0x1d000000: 0x40004000,
	            0x1e000000: 0x40000000,
	            0x1f000000: 0x40084010,
	            0x10800000: 0x84010,
	            0x11800000: 0x80000,
	            0x12800000: 0x40080000,
	            0x13800000: 0x4000,
	            0x14800000: 0x40004000,
	            0x15800000: 0x40084010,
	            0x16800000: 0x10,
	            0x17800000: 0x40000000,
	            0x18800000: 0x40084000,
	            0x19800000: 0x40000010,
	            0x1a800000: 0x40004010,
	            0x1b800000: 0x80010,
	            0x1c800000: 0x0,
	            0x1d800000: 0x4010,
	            0x1e800000: 0x40080010,
	            0x1f800000: 0x84000
	        },
	        {
	            0x0: 0x104,
	            0x100000: 0x0,
	            0x200000: 0x4000100,
	            0x300000: 0x10104,
	            0x400000: 0x10004,
	            0x500000: 0x4000004,
	            0x600000: 0x4010104,
	            0x700000: 0x4010000,
	            0x800000: 0x4000000,
	            0x900000: 0x4010100,
	            0xa00000: 0x10100,
	            0xb00000: 0x4010004,
	            0xc00000: 0x4000104,
	            0xd00000: 0x10000,
	            0xe00000: 0x4,
	            0xf00000: 0x100,
	            0x80000: 0x4010100,
	            0x180000: 0x4010004,
	            0x280000: 0x0,
	            0x380000: 0x4000100,
	            0x480000: 0x4000004,
	            0x580000: 0x10000,
	            0x680000: 0x10004,
	            0x780000: 0x104,
	            0x880000: 0x4,
	            0x980000: 0x100,
	            0xa80000: 0x4010000,
	            0xb80000: 0x10104,
	            0xc80000: 0x10100,
	            0xd80000: 0x4000104,
	            0xe80000: 0x4010104,
	            0xf80000: 0x4000000,
	            0x1000000: 0x4010100,
	            0x1100000: 0x10004,
	            0x1200000: 0x10000,
	            0x1300000: 0x4000100,
	            0x1400000: 0x100,
	            0x1500000: 0x4010104,
	            0x1600000: 0x4000004,
	            0x1700000: 0x0,
	            0x1800000: 0x4000104,
	            0x1900000: 0x4000000,
	            0x1a00000: 0x4,
	            0x1b00000: 0x10100,
	            0x1c00000: 0x4010000,
	            0x1d00000: 0x104,
	            0x1e00000: 0x10104,
	            0x1f00000: 0x4010004,
	            0x1080000: 0x4000000,
	            0x1180000: 0x104,
	            0x1280000: 0x4010100,
	            0x1380000: 0x0,
	            0x1480000: 0x10004,
	            0x1580000: 0x4000100,
	            0x1680000: 0x100,
	            0x1780000: 0x4010004,
	            0x1880000: 0x10000,
	            0x1980000: 0x4010104,
	            0x1a80000: 0x10104,
	            0x1b80000: 0x4000004,
	            0x1c80000: 0x4000104,
	            0x1d80000: 0x4010000,
	            0x1e80000: 0x4,
	            0x1f80000: 0x10100
	        },
	        {
	            0x0: 0x80401000,
	            0x10000: 0x80001040,
	            0x20000: 0x401040,
	            0x30000: 0x80400000,
	            0x40000: 0x0,
	            0x50000: 0x401000,
	            0x60000: 0x80000040,
	            0x70000: 0x400040,
	            0x80000: 0x80000000,
	            0x90000: 0x400000,
	            0xa0000: 0x40,
	            0xb0000: 0x80001000,
	            0xc0000: 0x80400040,
	            0xd0000: 0x1040,
	            0xe0000: 0x1000,
	            0xf0000: 0x80401040,
	            0x8000: 0x80001040,
	            0x18000: 0x40,
	            0x28000: 0x80400040,
	            0x38000: 0x80001000,
	            0x48000: 0x401000,
	            0x58000: 0x80401040,
	            0x68000: 0x0,
	            0x78000: 0x80400000,
	            0x88000: 0x1000,
	            0x98000: 0x80401000,
	            0xa8000: 0x400000,
	            0xb8000: 0x1040,
	            0xc8000: 0x80000000,
	            0xd8000: 0x400040,
	            0xe8000: 0x401040,
	            0xf8000: 0x80000040,
	            0x100000: 0x400040,
	            0x110000: 0x401000,
	            0x120000: 0x80000040,
	            0x130000: 0x0,
	            0x140000: 0x1040,
	            0x150000: 0x80400040,
	            0x160000: 0x80401000,
	            0x170000: 0x80001040,
	            0x180000: 0x80401040,
	            0x190000: 0x80000000,
	            0x1a0000: 0x80400000,
	            0x1b0000: 0x401040,
	            0x1c0000: 0x80001000,
	            0x1d0000: 0x400000,
	            0x1e0000: 0x40,
	            0x1f0000: 0x1000,
	            0x108000: 0x80400000,
	            0x118000: 0x80401040,
	            0x128000: 0x0,
	            0x138000: 0x401000,
	            0x148000: 0x400040,
	            0x158000: 0x80000000,
	            0x168000: 0x80001040,
	            0x178000: 0x40,
	            0x188000: 0x80000040,
	            0x198000: 0x1000,
	            0x1a8000: 0x80001000,
	            0x1b8000: 0x80400040,
	            0x1c8000: 0x1040,
	            0x1d8000: 0x80401000,
	            0x1e8000: 0x400000,
	            0x1f8000: 0x401040
	        },
	        {
	            0x0: 0x80,
	            0x1000: 0x1040000,
	            0x2000: 0x40000,
	            0x3000: 0x20000000,
	            0x4000: 0x20040080,
	            0x5000: 0x1000080,
	            0x6000: 0x21000080,
	            0x7000: 0x40080,
	            0x8000: 0x1000000,
	            0x9000: 0x20040000,
	            0xa000: 0x20000080,
	            0xb000: 0x21040080,
	            0xc000: 0x21040000,
	            0xd000: 0x0,
	            0xe000: 0x1040080,
	            0xf000: 0x21000000,
	            0x800: 0x1040080,
	            0x1800: 0x21000080,
	            0x2800: 0x80,
	            0x3800: 0x1040000,
	            0x4800: 0x40000,
	            0x5800: 0x20040080,
	            0x6800: 0x21040000,
	            0x7800: 0x20000000,
	            0x8800: 0x20040000,
	            0x9800: 0x0,
	            0xa800: 0x21040080,
	            0xb800: 0x1000080,
	            0xc800: 0x20000080,
	            0xd800: 0x21000000,
	            0xe800: 0x1000000,
	            0xf800: 0x40080,
	            0x10000: 0x40000,
	            0x11000: 0x80,
	            0x12000: 0x20000000,
	            0x13000: 0x21000080,
	            0x14000: 0x1000080,
	            0x15000: 0x21040000,
	            0x16000: 0x20040080,
	            0x17000: 0x1000000,
	            0x18000: 0x21040080,
	            0x19000: 0x21000000,
	            0x1a000: 0x1040000,
	            0x1b000: 0x20040000,
	            0x1c000: 0x40080,
	            0x1d000: 0x20000080,
	            0x1e000: 0x0,
	            0x1f000: 0x1040080,
	            0x10800: 0x21000080,
	            0x11800: 0x1000000,
	            0x12800: 0x1040000,
	            0x13800: 0x20040080,
	            0x14800: 0x20000000,
	            0x15800: 0x1040080,
	            0x16800: 0x80,
	            0x17800: 0x21040000,
	            0x18800: 0x40080,
	            0x19800: 0x21040080,
	            0x1a800: 0x0,
	            0x1b800: 0x21000000,
	            0x1c800: 0x1000080,
	            0x1d800: 0x40000,
	            0x1e800: 0x20040000,
	            0x1f800: 0x20000080
	        },
	        {
	            0x0: 0x10000008,
	            0x100: 0x2000,
	            0x200: 0x10200000,
	            0x300: 0x10202008,
	            0x400: 0x10002000,
	            0x500: 0x200000,
	            0x600: 0x200008,
	            0x700: 0x10000000,
	            0x800: 0x0,
	            0x900: 0x10002008,
	            0xa00: 0x202000,
	            0xb00: 0x8,
	            0xc00: 0x10200008,
	            0xd00: 0x202008,
	            0xe00: 0x2008,
	            0xf00: 0x10202000,
	            0x80: 0x10200000,
	            0x180: 0x10202008,
	            0x280: 0x8,
	            0x380: 0x200000,
	            0x480: 0x202008,
	            0x580: 0x10000008,
	            0x680: 0x10002000,
	            0x780: 0x2008,
	            0x880: 0x200008,
	            0x980: 0x2000,
	            0xa80: 0x10002008,
	            0xb80: 0x10200008,
	            0xc80: 0x0,
	            0xd80: 0x10202000,
	            0xe80: 0x202000,
	            0xf80: 0x10000000,
	            0x1000: 0x10002000,
	            0x1100: 0x10200008,
	            0x1200: 0x10202008,
	            0x1300: 0x2008,
	            0x1400: 0x200000,
	            0x1500: 0x10000000,
	            0x1600: 0x10000008,
	            0x1700: 0x202000,
	            0x1800: 0x202008,
	            0x1900: 0x0,
	            0x1a00: 0x8,
	            0x1b00: 0x10200000,
	            0x1c00: 0x2000,
	            0x1d00: 0x10002008,
	            0x1e00: 0x10202000,
	            0x1f00: 0x200008,
	            0x1080: 0x8,
	            0x1180: 0x202000,
	            0x1280: 0x200000,
	            0x1380: 0x10000008,
	            0x1480: 0x10002000,
	            0x1580: 0x2008,
	            0x1680: 0x10202008,
	            0x1780: 0x10200000,
	            0x1880: 0x10202000,
	            0x1980: 0x10200008,
	            0x1a80: 0x2000,
	            0x1b80: 0x202008,
	            0x1c80: 0x200008,
	            0x1d80: 0x0,
	            0x1e80: 0x10000000,
	            0x1f80: 0x10002008
	        },
	        {
	            0x0: 0x100000,
	            0x10: 0x2000401,
	            0x20: 0x400,
	            0x30: 0x100401,
	            0x40: 0x2100401,
	            0x50: 0x0,
	            0x60: 0x1,
	            0x70: 0x2100001,
	            0x80: 0x2000400,
	            0x90: 0x100001,
	            0xa0: 0x2000001,
	            0xb0: 0x2100400,
	            0xc0: 0x2100000,
	            0xd0: 0x401,
	            0xe0: 0x100400,
	            0xf0: 0x2000000,
	            0x8: 0x2100001,
	            0x18: 0x0,
	            0x28: 0x2000401,
	            0x38: 0x2100400,
	            0x48: 0x100000,
	            0x58: 0x2000001,
	            0x68: 0x2000000,
	            0x78: 0x401,
	            0x88: 0x100401,
	            0x98: 0x2000400,
	            0xa8: 0x2100000,
	            0xb8: 0x100001,
	            0xc8: 0x400,
	            0xd8: 0x2100401,
	            0xe8: 0x1,
	            0xf8: 0x100400,
	            0x100: 0x2000000,
	            0x110: 0x100000,
	            0x120: 0x2000401,
	            0x130: 0x2100001,
	            0x140: 0x100001,
	            0x150: 0x2000400,
	            0x160: 0x2100400,
	            0x170: 0x100401,
	            0x180: 0x401,
	            0x190: 0x2100401,
	            0x1a0: 0x100400,
	            0x1b0: 0x1,
	            0x1c0: 0x0,
	            0x1d0: 0x2100000,
	            0x1e0: 0x2000001,
	            0x1f0: 0x400,
	            0x108: 0x100400,
	            0x118: 0x2000401,
	            0x128: 0x2100001,
	            0x138: 0x1,
	            0x148: 0x2000000,
	            0x158: 0x100000,
	            0x168: 0x401,
	            0x178: 0x2100400,
	            0x188: 0x2000001,
	            0x198: 0x2100000,
	            0x1a8: 0x0,
	            0x1b8: 0x2100401,
	            0x1c8: 0x100401,
	            0x1d8: 0x400,
	            0x1e8: 0x2000400,
	            0x1f8: 0x100001
	        },
	        {
	            0x0: 0x8000820,
	            0x1: 0x20000,
	            0x2: 0x8000000,
	            0x3: 0x20,
	            0x4: 0x20020,
	            0x5: 0x8020820,
	            0x6: 0x8020800,
	            0x7: 0x800,
	            0x8: 0x8020000,
	            0x9: 0x8000800,
	            0xa: 0x20800,
	            0xb: 0x8020020,
	            0xc: 0x820,
	            0xd: 0x0,
	            0xe: 0x8000020,
	            0xf: 0x20820,
	            0x80000000: 0x800,
	            0x80000001: 0x8020820,
	            0x80000002: 0x8000820,
	            0x80000003: 0x8000000,
	            0x80000004: 0x8020000,
	            0x80000005: 0x20800,
	            0x80000006: 0x20820,
	            0x80000007: 0x20,
	            0x80000008: 0x8000020,
	            0x80000009: 0x820,
	            0x8000000a: 0x20020,
	            0x8000000b: 0x8020800,
	            0x8000000c: 0x0,
	            0x8000000d: 0x8020020,
	            0x8000000e: 0x8000800,
	            0x8000000f: 0x20000,
	            0x10: 0x20820,
	            0x11: 0x8020800,
	            0x12: 0x20,
	            0x13: 0x800,
	            0x14: 0x8000800,
	            0x15: 0x8000020,
	            0x16: 0x8020020,
	            0x17: 0x20000,
	            0x18: 0x0,
	            0x19: 0x20020,
	            0x1a: 0x8020000,
	            0x1b: 0x8000820,
	            0x1c: 0x8020820,
	            0x1d: 0x20800,
	            0x1e: 0x820,
	            0x1f: 0x8000000,
	            0x80000010: 0x20000,
	            0x80000011: 0x800,
	            0x80000012: 0x8020020,
	            0x80000013: 0x20820,
	            0x80000014: 0x20,
	            0x80000015: 0x8020000,
	            0x80000016: 0x8000000,
	            0x80000017: 0x8000820,
	            0x80000018: 0x8020820,
	            0x80000019: 0x8000020,
	            0x8000001a: 0x8000800,
	            0x8000001b: 0x0,
	            0x8000001c: 0x20800,
	            0x8000001d: 0x820,
	            0x8000001e: 0x20020,
	            0x8000001f: 0x8020800
	        }
	    ];

	    // Masks that select the SBOX input
	    var SBOX_MASK = [
	        0xf8000001, 0x1f800000, 0x01f80000, 0x001f8000,
	        0x0001f800, 0x00001f80, 0x000001f8, 0x8000001f
	    ];

	    /**
	     * DES block cipher algorithm.
	     */
	    var DES = C_algo.DES = BlockCipher.extend({
	        _doReset: function () {
	            // Shortcuts
	            var key = this._key;
	            var keyWords = key.words;

	            // Select 56 bits according to PC1
	            var keyBits = [];
	            for (var i = 0; i < 56; i++) {
	                var keyBitPos = PC1[i] - 1;
	                keyBits[i] = (keyWords[keyBitPos >>> 5] >>> (31 - keyBitPos % 32)) & 1;
	            }

	            // Assemble 16 subkeys
	            var subKeys = this._subKeys = [];
	            for (var nSubKey = 0; nSubKey < 16; nSubKey++) {
	                // Create subkey
	                var subKey = subKeys[nSubKey] = [];

	                // Shortcut
	                var bitShift = BIT_SHIFTS[nSubKey];

	                // Select 48 bits according to PC2
	                for (var i = 0; i < 24; i++) {
	                    // Select from the left 28 key bits
	                    subKey[(i / 6) | 0] |= keyBits[((PC2[i] - 1) + bitShift) % 28] << (31 - i % 6);

	                    // Select from the right 28 key bits
	                    subKey[4 + ((i / 6) | 0)] |= keyBits[28 + (((PC2[i + 24] - 1) + bitShift) % 28)] << (31 - i % 6);
	                }

	                // Since each subkey is applied to an expanded 32-bit input,
	                // the subkey can be broken into 8 values scaled to 32-bits,
	                // which allows the key to be used without expansion
	                subKey[0] = (subKey[0] << 1) | (subKey[0] >>> 31);
	                for (var i = 1; i < 7; i++) {
	                    subKey[i] = subKey[i] >>> ((i - 1) * 4 + 3);
	                }
	                subKey[7] = (subKey[7] << 5) | (subKey[7] >>> 27);
	            }

	            // Compute inverse subkeys
	            var invSubKeys = this._invSubKeys = [];
	            for (var i = 0; i < 16; i++) {
	                invSubKeys[i] = subKeys[15 - i];
	            }
	        },

	        encryptBlock: function (M, offset) {
	            this._doCryptBlock(M, offset, this._subKeys);
	        },

	        decryptBlock: function (M, offset) {
	            this._doCryptBlock(M, offset, this._invSubKeys);
	        },

	        _doCryptBlock: function (M, offset, subKeys) {
	            // Get input
	            this._lBlock = M[offset];
	            this._rBlock = M[offset + 1];

	            // Initial permutation
	            exchangeLR.call(this, 4,  0x0f0f0f0f);
	            exchangeLR.call(this, 16, 0x0000ffff);
	            exchangeRL.call(this, 2,  0x33333333);
	            exchangeRL.call(this, 8,  0x00ff00ff);
	            exchangeLR.call(this, 1,  0x55555555);

	            // Rounds
	            for (var round = 0; round < 16; round++) {
	                // Shortcuts
	                var subKey = subKeys[round];
	                var lBlock = this._lBlock;
	                var rBlock = this._rBlock;

	                // Feistel function
	                var f = 0;
	                for (var i = 0; i < 8; i++) {
	                    f |= SBOX_P[i][((rBlock ^ subKey[i]) & SBOX_MASK[i]) >>> 0];
	                }
	                this._lBlock = rBlock;
	                this._rBlock = lBlock ^ f;
	            }

	            // Undo swap from last round
	            var t = this._lBlock;
	            this._lBlock = this._rBlock;
	            this._rBlock = t;

	            // Final permutation
	            exchangeLR.call(this, 1,  0x55555555);
	            exchangeRL.call(this, 8,  0x00ff00ff);
	            exchangeRL.call(this, 2,  0x33333333);
	            exchangeLR.call(this, 16, 0x0000ffff);
	            exchangeLR.call(this, 4,  0x0f0f0f0f);

	            // Set output
	            M[offset] = this._lBlock;
	            M[offset + 1] = this._rBlock;
	        },

	        keySize: 64/32,

	        ivSize: 64/32,

	        blockSize: 64/32
	    });

	    // Swap bits across the left and right words
	    function exchangeLR(offset, mask) {
	        var t = ((this._lBlock >>> offset) ^ this._rBlock) & mask;
	        this._rBlock ^= t;
	        this._lBlock ^= t << offset;
	    }

	    function exchangeRL(offset, mask) {
	        var t = ((this._rBlock >>> offset) ^ this._lBlock) & mask;
	        this._lBlock ^= t;
	        this._rBlock ^= t << offset;
	    }

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.DES.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.DES.decrypt(ciphertext, key, cfg);
	     */
	    C.DES = BlockCipher._createHelper(DES);

	    /**
	     * Triple-DES block cipher algorithm.
	     */
	    var TripleDES = C_algo.TripleDES = BlockCipher.extend({
	        _doReset: function () {
	            // Shortcuts
	            var key = this._key;
	            var keyWords = key.words;

	            // Create DES instances
	            this._des1 = DES.createEncryptor(WordArray.create(keyWords.slice(0, 2)));
	            this._des2 = DES.createEncryptor(WordArray.create(keyWords.slice(2, 4)));
	            this._des3 = DES.createEncryptor(WordArray.create(keyWords.slice(4, 6)));
	        },

	        encryptBlock: function (M, offset) {
	            this._des1.encryptBlock(M, offset);
	            this._des2.decryptBlock(M, offset);
	            this._des3.encryptBlock(M, offset);
	        },

	        decryptBlock: function (M, offset) {
	            this._des3.decryptBlock(M, offset);
	            this._des2.encryptBlock(M, offset);
	            this._des1.decryptBlock(M, offset);
	        },

	        keySize: 192/32,

	        ivSize: 64/32,

	        blockSize: 64/32
	    });

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.TripleDES.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.TripleDES.decrypt(ciphertext, key, cfg);
	     */
	    C.TripleDES = BlockCipher._createHelper(TripleDES);
	}());


	return CryptoJS.TripleDES;

}));
});

var rc4 = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, encBase64, md5, evpkdf, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var StreamCipher = C_lib.StreamCipher;
	    var C_algo = C.algo;

	    /**
	     * RC4 stream cipher algorithm.
	     */
	    var RC4 = C_algo.RC4 = StreamCipher.extend({
	        _doReset: function () {
	            // Shortcuts
	            var key = this._key;
	            var keyWords = key.words;
	            var keySigBytes = key.sigBytes;

	            // Init sbox
	            var S = this._S = [];
	            for (var i = 0; i < 256; i++) {
	                S[i] = i;
	            }

	            // Key setup
	            for (var i = 0, j = 0; i < 256; i++) {
	                var keyByteIndex = i % keySigBytes;
	                var keyByte = (keyWords[keyByteIndex >>> 2] >>> (24 - (keyByteIndex % 4) * 8)) & 0xff;

	                j = (j + S[i] + keyByte) % 256;

	                // Swap
	                var t = S[i];
	                S[i] = S[j];
	                S[j] = t;
	            }

	            // Counters
	            this._i = this._j = 0;
	        },

	        _doProcessBlock: function (M, offset) {
	            M[offset] ^= generateKeystreamWord.call(this);
	        },

	        keySize: 256/32,

	        ivSize: 0
	    });

	    function generateKeystreamWord() {
	        // Shortcuts
	        var S = this._S;
	        var i = this._i;
	        var j = this._j;

	        // Generate keystream word
	        var keystreamWord = 0;
	        for (var n = 0; n < 4; n++) {
	            i = (i + 1) % 256;
	            j = (j + S[i]) % 256;

	            // Swap
	            var t = S[i];
	            S[i] = S[j];
	            S[j] = t;

	            keystreamWord |= S[(S[i] + S[j]) % 256] << (24 - n * 8);
	        }

	        // Update counters
	        this._i = i;
	        this._j = j;

	        return keystreamWord;
	    }

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.RC4.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.RC4.decrypt(ciphertext, key, cfg);
	     */
	    C.RC4 = StreamCipher._createHelper(RC4);

	    /**
	     * Modified RC4 stream cipher algorithm.
	     */
	    var RC4Drop = C_algo.RC4Drop = RC4.extend({
	        /**
	         * Configuration options.
	         *
	         * @property {number} drop The number of keystream words to drop. Default 192
	         */
	        cfg: RC4.cfg.extend({
	            drop: 192
	        }),

	        _doReset: function () {
	            RC4._doReset.call(this);

	            // Drop
	            for (var i = this.cfg.drop; i > 0; i--) {
	                generateKeystreamWord.call(this);
	            }
	        }
	    });

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.RC4Drop.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.RC4Drop.decrypt(ciphertext, key, cfg);
	     */
	    C.RC4Drop = StreamCipher._createHelper(RC4Drop);
	}());


	return CryptoJS.RC4;

}));
});

var rabbit = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, encBase64, md5, evpkdf, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var StreamCipher = C_lib.StreamCipher;
	    var C_algo = C.algo;

	    // Reusable objects
	    var S  = [];
	    var C_ = [];
	    var G  = [];

	    /**
	     * Rabbit stream cipher algorithm
	     */
	    var Rabbit = C_algo.Rabbit = StreamCipher.extend({
	        _doReset: function () {
	            // Shortcuts
	            var K = this._key.words;
	            var iv = this.cfg.iv;

	            // Swap endian
	            for (var i = 0; i < 4; i++) {
	                K[i] = (((K[i] << 8)  | (K[i] >>> 24)) & 0x00ff00ff) |
	                       (((K[i] << 24) | (K[i] >>> 8))  & 0xff00ff00);
	            }

	            // Generate initial state values
	            var X = this._X = [
	                K[0], (K[3] << 16) | (K[2] >>> 16),
	                K[1], (K[0] << 16) | (K[3] >>> 16),
	                K[2], (K[1] << 16) | (K[0] >>> 16),
	                K[3], (K[2] << 16) | (K[1] >>> 16)
	            ];

	            // Generate initial counter values
	            var C = this._C = [
	                (K[2] << 16) | (K[2] >>> 16), (K[0] & 0xffff0000) | (K[1] & 0x0000ffff),
	                (K[3] << 16) | (K[3] >>> 16), (K[1] & 0xffff0000) | (K[2] & 0x0000ffff),
	                (K[0] << 16) | (K[0] >>> 16), (K[2] & 0xffff0000) | (K[3] & 0x0000ffff),
	                (K[1] << 16) | (K[1] >>> 16), (K[3] & 0xffff0000) | (K[0] & 0x0000ffff)
	            ];

	            // Carry bit
	            this._b = 0;

	            // Iterate the system four times
	            for (var i = 0; i < 4; i++) {
	                nextState.call(this);
	            }

	            // Modify the counters
	            for (var i = 0; i < 8; i++) {
	                C[i] ^= X[(i + 4) & 7];
	            }

	            // IV setup
	            if (iv) {
	                // Shortcuts
	                var IV = iv.words;
	                var IV_0 = IV[0];
	                var IV_1 = IV[1];

	                // Generate four subvectors
	                var i0 = (((IV_0 << 8) | (IV_0 >>> 24)) & 0x00ff00ff) | (((IV_0 << 24) | (IV_0 >>> 8)) & 0xff00ff00);
	                var i2 = (((IV_1 << 8) | (IV_1 >>> 24)) & 0x00ff00ff) | (((IV_1 << 24) | (IV_1 >>> 8)) & 0xff00ff00);
	                var i1 = (i0 >>> 16) | (i2 & 0xffff0000);
	                var i3 = (i2 << 16)  | (i0 & 0x0000ffff);

	                // Modify counter values
	                C[0] ^= i0;
	                C[1] ^= i1;
	                C[2] ^= i2;
	                C[3] ^= i3;
	                C[4] ^= i0;
	                C[5] ^= i1;
	                C[6] ^= i2;
	                C[7] ^= i3;

	                // Iterate the system four times
	                for (var i = 0; i < 4; i++) {
	                    nextState.call(this);
	                }
	            }
	        },

	        _doProcessBlock: function (M, offset) {
	            // Shortcut
	            var X = this._X;

	            // Iterate the system
	            nextState.call(this);

	            // Generate four keystream words
	            S[0] = X[0] ^ (X[5] >>> 16) ^ (X[3] << 16);
	            S[1] = X[2] ^ (X[7] >>> 16) ^ (X[5] << 16);
	            S[2] = X[4] ^ (X[1] >>> 16) ^ (X[7] << 16);
	            S[3] = X[6] ^ (X[3] >>> 16) ^ (X[1] << 16);

	            for (var i = 0; i < 4; i++) {
	                // Swap endian
	                S[i] = (((S[i] << 8)  | (S[i] >>> 24)) & 0x00ff00ff) |
	                       (((S[i] << 24) | (S[i] >>> 8))  & 0xff00ff00);

	                // Encrypt
	                M[offset + i] ^= S[i];
	            }
	        },

	        blockSize: 128/32,

	        ivSize: 64/32
	    });

	    function nextState() {
	        // Shortcuts
	        var X = this._X;
	        var C = this._C;

	        // Save old counter values
	        for (var i = 0; i < 8; i++) {
	            C_[i] = C[i];
	        }

	        // Calculate new counter values
	        C[0] = (C[0] + 0x4d34d34d + this._b) | 0;
	        C[1] = (C[1] + 0xd34d34d3 + ((C[0] >>> 0) < (C_[0] >>> 0) ? 1 : 0)) | 0;
	        C[2] = (C[2] + 0x34d34d34 + ((C[1] >>> 0) < (C_[1] >>> 0) ? 1 : 0)) | 0;
	        C[3] = (C[3] + 0x4d34d34d + ((C[2] >>> 0) < (C_[2] >>> 0) ? 1 : 0)) | 0;
	        C[4] = (C[4] + 0xd34d34d3 + ((C[3] >>> 0) < (C_[3] >>> 0) ? 1 : 0)) | 0;
	        C[5] = (C[5] + 0x34d34d34 + ((C[4] >>> 0) < (C_[4] >>> 0) ? 1 : 0)) | 0;
	        C[6] = (C[6] + 0x4d34d34d + ((C[5] >>> 0) < (C_[5] >>> 0) ? 1 : 0)) | 0;
	        C[7] = (C[7] + 0xd34d34d3 + ((C[6] >>> 0) < (C_[6] >>> 0) ? 1 : 0)) | 0;
	        this._b = (C[7] >>> 0) < (C_[7] >>> 0) ? 1 : 0;

	        // Calculate the g-values
	        for (var i = 0; i < 8; i++) {
	            var gx = X[i] + C[i];

	            // Construct high and low argument for squaring
	            var ga = gx & 0xffff;
	            var gb = gx >>> 16;

	            // Calculate high and low result of squaring
	            var gh = ((((ga * ga) >>> 17) + ga * gb) >>> 15) + gb * gb;
	            var gl = (((gx & 0xffff0000) * gx) | 0) + (((gx & 0x0000ffff) * gx) | 0);

	            // High XOR low
	            G[i] = gh ^ gl;
	        }

	        // Calculate new state values
	        X[0] = (G[0] + ((G[7] << 16) | (G[7] >>> 16)) + ((G[6] << 16) | (G[6] >>> 16))) | 0;
	        X[1] = (G[1] + ((G[0] << 8)  | (G[0] >>> 24)) + G[7]) | 0;
	        X[2] = (G[2] + ((G[1] << 16) | (G[1] >>> 16)) + ((G[0] << 16) | (G[0] >>> 16))) | 0;
	        X[3] = (G[3] + ((G[2] << 8)  | (G[2] >>> 24)) + G[1]) | 0;
	        X[4] = (G[4] + ((G[3] << 16) | (G[3] >>> 16)) + ((G[2] << 16) | (G[2] >>> 16))) | 0;
	        X[5] = (G[5] + ((G[4] << 8)  | (G[4] >>> 24)) + G[3]) | 0;
	        X[6] = (G[6] + ((G[5] << 16) | (G[5] >>> 16)) + ((G[4] << 16) | (G[4] >>> 16))) | 0;
	        X[7] = (G[7] + ((G[6] << 8)  | (G[6] >>> 24)) + G[5]) | 0;
	    }

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.Rabbit.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.Rabbit.decrypt(ciphertext, key, cfg);
	     */
	    C.Rabbit = StreamCipher._createHelper(Rabbit);
	}());


	return CryptoJS.Rabbit;

}));
});

var rabbitLegacy = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, encBase64, md5, evpkdf, cipherCore);
	}
}(commonjsGlobal, function (CryptoJS) {

	(function () {
	    // Shortcuts
	    var C = CryptoJS;
	    var C_lib = C.lib;
	    var StreamCipher = C_lib.StreamCipher;
	    var C_algo = C.algo;

	    // Reusable objects
	    var S  = [];
	    var C_ = [];
	    var G  = [];

	    /**
	     * Rabbit stream cipher algorithm.
	     *
	     * This is a legacy version that neglected to convert the key to little-endian.
	     * This error doesn't affect the cipher's security,
	     * but it does affect its compatibility with other implementations.
	     */
	    var RabbitLegacy = C_algo.RabbitLegacy = StreamCipher.extend({
	        _doReset: function () {
	            // Shortcuts
	            var K = this._key.words;
	            var iv = this.cfg.iv;

	            // Generate initial state values
	            var X = this._X = [
	                K[0], (K[3] << 16) | (K[2] >>> 16),
	                K[1], (K[0] << 16) | (K[3] >>> 16),
	                K[2], (K[1] << 16) | (K[0] >>> 16),
	                K[3], (K[2] << 16) | (K[1] >>> 16)
	            ];

	            // Generate initial counter values
	            var C = this._C = [
	                (K[2] << 16) | (K[2] >>> 16), (K[0] & 0xffff0000) | (K[1] & 0x0000ffff),
	                (K[3] << 16) | (K[3] >>> 16), (K[1] & 0xffff0000) | (K[2] & 0x0000ffff),
	                (K[0] << 16) | (K[0] >>> 16), (K[2] & 0xffff0000) | (K[3] & 0x0000ffff),
	                (K[1] << 16) | (K[1] >>> 16), (K[3] & 0xffff0000) | (K[0] & 0x0000ffff)
	            ];

	            // Carry bit
	            this._b = 0;

	            // Iterate the system four times
	            for (var i = 0; i < 4; i++) {
	                nextState.call(this);
	            }

	            // Modify the counters
	            for (var i = 0; i < 8; i++) {
	                C[i] ^= X[(i + 4) & 7];
	            }

	            // IV setup
	            if (iv) {
	                // Shortcuts
	                var IV = iv.words;
	                var IV_0 = IV[0];
	                var IV_1 = IV[1];

	                // Generate four subvectors
	                var i0 = (((IV_0 << 8) | (IV_0 >>> 24)) & 0x00ff00ff) | (((IV_0 << 24) | (IV_0 >>> 8)) & 0xff00ff00);
	                var i2 = (((IV_1 << 8) | (IV_1 >>> 24)) & 0x00ff00ff) | (((IV_1 << 24) | (IV_1 >>> 8)) & 0xff00ff00);
	                var i1 = (i0 >>> 16) | (i2 & 0xffff0000);
	                var i3 = (i2 << 16)  | (i0 & 0x0000ffff);

	                // Modify counter values
	                C[0] ^= i0;
	                C[1] ^= i1;
	                C[2] ^= i2;
	                C[3] ^= i3;
	                C[4] ^= i0;
	                C[5] ^= i1;
	                C[6] ^= i2;
	                C[7] ^= i3;

	                // Iterate the system four times
	                for (var i = 0; i < 4; i++) {
	                    nextState.call(this);
	                }
	            }
	        },

	        _doProcessBlock: function (M, offset) {
	            // Shortcut
	            var X = this._X;

	            // Iterate the system
	            nextState.call(this);

	            // Generate four keystream words
	            S[0] = X[0] ^ (X[5] >>> 16) ^ (X[3] << 16);
	            S[1] = X[2] ^ (X[7] >>> 16) ^ (X[5] << 16);
	            S[2] = X[4] ^ (X[1] >>> 16) ^ (X[7] << 16);
	            S[3] = X[6] ^ (X[3] >>> 16) ^ (X[1] << 16);

	            for (var i = 0; i < 4; i++) {
	                // Swap endian
	                S[i] = (((S[i] << 8)  | (S[i] >>> 24)) & 0x00ff00ff) |
	                       (((S[i] << 24) | (S[i] >>> 8))  & 0xff00ff00);

	                // Encrypt
	                M[offset + i] ^= S[i];
	            }
	        },

	        blockSize: 128/32,

	        ivSize: 64/32
	    });

	    function nextState() {
	        // Shortcuts
	        var X = this._X;
	        var C = this._C;

	        // Save old counter values
	        for (var i = 0; i < 8; i++) {
	            C_[i] = C[i];
	        }

	        // Calculate new counter values
	        C[0] = (C[0] + 0x4d34d34d + this._b) | 0;
	        C[1] = (C[1] + 0xd34d34d3 + ((C[0] >>> 0) < (C_[0] >>> 0) ? 1 : 0)) | 0;
	        C[2] = (C[2] + 0x34d34d34 + ((C[1] >>> 0) < (C_[1] >>> 0) ? 1 : 0)) | 0;
	        C[3] = (C[3] + 0x4d34d34d + ((C[2] >>> 0) < (C_[2] >>> 0) ? 1 : 0)) | 0;
	        C[4] = (C[4] + 0xd34d34d3 + ((C[3] >>> 0) < (C_[3] >>> 0) ? 1 : 0)) | 0;
	        C[5] = (C[5] + 0x34d34d34 + ((C[4] >>> 0) < (C_[4] >>> 0) ? 1 : 0)) | 0;
	        C[6] = (C[6] + 0x4d34d34d + ((C[5] >>> 0) < (C_[5] >>> 0) ? 1 : 0)) | 0;
	        C[7] = (C[7] + 0xd34d34d3 + ((C[6] >>> 0) < (C_[6] >>> 0) ? 1 : 0)) | 0;
	        this._b = (C[7] >>> 0) < (C_[7] >>> 0) ? 1 : 0;

	        // Calculate the g-values
	        for (var i = 0; i < 8; i++) {
	            var gx = X[i] + C[i];

	            // Construct high and low argument for squaring
	            var ga = gx & 0xffff;
	            var gb = gx >>> 16;

	            // Calculate high and low result of squaring
	            var gh = ((((ga * ga) >>> 17) + ga * gb) >>> 15) + gb * gb;
	            var gl = (((gx & 0xffff0000) * gx) | 0) + (((gx & 0x0000ffff) * gx) | 0);

	            // High XOR low
	            G[i] = gh ^ gl;
	        }

	        // Calculate new state values
	        X[0] = (G[0] + ((G[7] << 16) | (G[7] >>> 16)) + ((G[6] << 16) | (G[6] >>> 16))) | 0;
	        X[1] = (G[1] + ((G[0] << 8)  | (G[0] >>> 24)) + G[7]) | 0;
	        X[2] = (G[2] + ((G[1] << 16) | (G[1] >>> 16)) + ((G[0] << 16) | (G[0] >>> 16))) | 0;
	        X[3] = (G[3] + ((G[2] << 8)  | (G[2] >>> 24)) + G[1]) | 0;
	        X[4] = (G[4] + ((G[3] << 16) | (G[3] >>> 16)) + ((G[2] << 16) | (G[2] >>> 16))) | 0;
	        X[5] = (G[5] + ((G[4] << 8)  | (G[4] >>> 24)) + G[3]) | 0;
	        X[6] = (G[6] + ((G[5] << 16) | (G[5] >>> 16)) + ((G[4] << 16) | (G[4] >>> 16))) | 0;
	        X[7] = (G[7] + ((G[6] << 8)  | (G[6] >>> 24)) + G[5]) | 0;
	    }

	    /**
	     * Shortcut functions to the cipher's object interface.
	     *
	     * @example
	     *
	     *     var ciphertext = CryptoJS.RabbitLegacy.encrypt(message, key, cfg);
	     *     var plaintext  = CryptoJS.RabbitLegacy.decrypt(ciphertext, key, cfg);
	     */
	    C.RabbitLegacy = StreamCipher._createHelper(RabbitLegacy);
	}());


	return CryptoJS.RabbitLegacy;

}));
});

var cryptoJs = createCommonjsModule(function (module, exports) {
(function (root, factory, undef) {
	{
		// CommonJS
		module.exports = exports = factory(core, x64Core, libTypedarrays, encUtf16, encBase64, md5, sha1, sha256, sha224, sha512, sha384, sha3, ripemd160, hmac, pbkdf2, evpkdf, cipherCore, modeCfb, modeCtr, modeCtrGladman, modeOfb, modeEcb, padAnsix923, padIso10126, padIso97971, padZeropadding, padNopadding, formatHex, aes, tripledes, rc4, rabbit, rabbitLegacy);
	}
}(commonjsGlobal, function (CryptoJS) {

	return CryptoJS;

}));
});

var cryptoJs_1 = cryptoJs.lib;
var cryptoJs_2 = cryptoJs.SHA256;
var cryptoJs_3 = cryptoJs.enc;

/**
 * @ngdoc object
 * @name IOTileAppModule.type:BlockingEvent
 *
 * @description
 * A concurrent event that allows waiting until a condition is met.  Anyone who
 * calls wait() will yield and block until set() is called, at which point all
 * waiters will be released in parallel.
 *
 * @property {boolean} isSet Whether the event is set
 */
var BlockingEvent = /** @class */ (function () {
    function BlockingEvent() {
        this._set = false;
        var that = this;
        this.event = new Promise(function (resolve, reject) {
            that.resolve = resolve;
        });
    }
    BlockingEvent.prototype.wait = function () {
        return this.event;
    };
    BlockingEvent.prototype.set = function () {
        this._set = true;
        if (this.resolve) {
            this.resolve();
        }
    };
    Object.defineProperty(BlockingEvent.prototype, "isSet", {
        get: function () {
            return this._set;
        },
        enumerable: true,
        configurable: true
    });
    return BlockingEvent;
}());

var DeltaStatus;
(function (DeltaStatus) {
    DeltaStatus[DeltaStatus["Applies"] = 0] = "Applies";
    DeltaStatus[DeltaStatus["Outdated"] = 1] = "Outdated";
    DeltaStatus[DeltaStatus["Conflicted"] = 2] = "Conflicted";
})(DeltaStatus || (DeltaStatus = {}));

var ModelDelta = /** @class */ (function () {
    function ModelDelta(name, slug, guidString) {
        if (guidString == null) {
            this.id = guid();
        }
        else {
            this.id = guidString;
        }
        this.slug = slug;
        this.classname = name;
    }
    ModelDelta.prototype.serialize = function () {
        return {
            classname: this.classname,
            guid: this.id,
            slug: this.slug,
            args: this.serializeArguments()
        };
    };
    return ModelDelta;
}());

var Device = /** @class */ (function () {
    function Device(data) {
        if (data === void 0) { data = {}; }
        this.busy = false;
        this.id = data.id;
        this.slug = data.slug;
        this.gid = data.gid;
        this.label = data.label || data.slug;
        this.template = data.template || "";
        this.rawData = data;
        this.project = data.project;
        this.drifterMode = data.drifter_mode || false;
        this.isModified = false;
        this.active = data.active || true;
        this.state = data.state || undefined;
        this.externalId = data.external_id || undefined;
        this.sensorGraphSlug = data.sg;
        this.properties = [];
        this.propertyMap = {};
        if ('busy' in data) {
            this.busy = data.busy;
        }
        if ('org' in data) {
            this.org = data.org;
        }
        if ('lat' in data && data.lat !== null) {
            this.lat = parseFloat(data.lat);
        }
        if ('lon' in data && data.lon !== null) {
            this.lon = parseFloat(data.lon);
        }
    }
    Device.prototype.toJson = function () {
        var result = this.rawData;
        result.label = this.label;
        result.drifter_mode = this.drifterMode;
        result.lat = this.lat;
        result.lon = this.lon;
        return result;
    };
    Device.prototype.getPatchPayload = function () {
        var payload = {
            label: this.label
        };
        if (this.lat) {
            payload.lat = this.lat;
        }
        if (this.lon) {
            payload.lon = this.lon;
        }
        payload.active = this.active;
        if (this.state) {
            payload.state = this.state;
        }
        return payload;
    };
    Device.prototype.addProperties = function (properties) {
        var _this = this;
        this.properties = properties;
        this.properties.forEach(function (property) {
            _this.propertyMap[property.name] = property;
        });
    };
    Device.prototype.getProperty = function (name) {
        return this.propertyMap[name];
    };
    Device.prototype.isDataBlock = function () {
        return (this.dataBlock != null);
    };
    Device.prototype.getStateDisplay = function () {
        if (this.state) {
            var factory = {
                'N0': 'Available',
                'N1': 'Active',
                'B0': 'Resetting',
                'B1': 'Archiving'
            };
            return factory[this.state];
        }
        else {
            return "";
        }
    };
    return Device;
}());
var DeviceDelta = /** @class */ (function (_super) {
    __extends(DeviceDelta, _super);
    function DeviceDelta() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return DeviceDelta;
}(ModelDelta));
var DeviceLocationDelta = /** @class */ (function (_super) {
    __extends(DeviceLocationDelta, _super);
    function DeviceLocationDelta(oldLat, oldLng, newLat, newLng, slug, guid) {
        var _this = _super.call(this, DeviceLocationDelta.ClassName, slug, guid) || this;
        _this.oldLat = oldLat;
        _this.oldLng = oldLng;
        _this.newLat = newLat;
        _this.newLng = newLng;
        return _this;
    }
    DeviceLocationDelta.prototype.check = function (device) {
        if (device.lat === this.newLat && device.lon === this.newLng) {
            return DeltaStatus.Outdated;
        }
        else if (device.lat === this.oldLat && device.lon === this.oldLng) {
            return DeltaStatus.Applies;
        }
        else {
            return DeltaStatus.Conflicted;
        }
    };
    DeviceLocationDelta.prototype.apply = function (device) {
        device.lat = this.newLat;
        device.lon = this.newLng;
    };
    DeviceLocationDelta.prototype.getPatch = function () {
        return {
            lat: this.newLat,
            lon: this.newLng
        };
    };
    DeviceLocationDelta.prototype.serializeArguments = function () {
        return {
            oldLat: this.oldLat,
            oldLng: this.oldLng,
            newLat: this.newLat,
            newLng: this.newLng
        };
    };
    DeviceLocationDelta.Deserialize = function (guid, slug, serializedArgs) {
        return new DeviceLocationDelta(serializedArgs.oldLat, serializedArgs.oldLng, serializedArgs.newLat, serializedArgs.newLng, slug, guid);
    };
    DeviceLocationDelta.ClassName = "DeviceLocationDelta";
    return DeviceLocationDelta;
}(DeviceDelta));
var DeviceDrifterDelta = /** @class */ (function (_super) {
    __extends(DeviceDrifterDelta, _super);
    function DeviceDrifterDelta(oldDrifter, newDrifter, slug, guid) {
        var _this = _super.call(this, DeviceDrifterDelta.ClassName, slug, guid) || this;
        _this.oldDrifter = oldDrifter;
        _this.newDrifter = newDrifter;
        return _this;
    }
    DeviceDrifterDelta.prototype.check = function (device) {
        if (device.drifterMode === this.newDrifter) {
            return DeltaStatus.Outdated;
        }
        else {
            return DeltaStatus.Applies;
        }
    };
    DeviceDrifterDelta.prototype.apply = function (device) {
        device.drifterMode = this.newDrifter;
    };
    DeviceDrifterDelta.prototype.getPatch = function () {
        return {};
    };
    DeviceDrifterDelta.prototype.serializeArguments = function () {
        return {
            oldDrifter: this.oldDrifter,
            newDrifter: this.newDrifter
        };
    };
    DeviceDrifterDelta.Deserialize = function (guid, slug, serializedArgs) {
        return new DeviceDrifterDelta(serializedArgs.oldDrifter, serializedArgs.newDrifter, slug, guid);
    };
    DeviceDrifterDelta.ClassName = "DeviceDrifterDelta";
    return DeviceDrifterDelta;
}(DeviceDelta));
var DeviceLabelDelta = /** @class */ (function (_super) {
    __extends(DeviceLabelDelta, _super);
    function DeviceLabelDelta(oldLabel, newLabel, slug, guid) {
        var _this = _super.call(this, DeviceLabelDelta.ClassName, slug, guid) || this;
        _this.oldLabel = oldLabel;
        _this.newLabel = newLabel;
        return _this;
    }
    DeviceLabelDelta.prototype.check = function (device) {
        if (device.label == this.newLabel) {
            return DeltaStatus.Outdated;
        }
        else if (device.label !== this.oldLabel) {
            return DeltaStatus.Conflicted;
        }
        return DeltaStatus.Applies;
    };
    DeviceLabelDelta.prototype.apply = function (device) {
        device.label = this.newLabel;
    };
    DeviceLabelDelta.prototype.getPatch = function () {
        return {
            label: this.newLabel
        };
    };
    DeviceLabelDelta.prototype.serializeArguments = function () {
        return {
            oldLabel: this.oldLabel,
            newLabel: this.newLabel
        };
    };
    DeviceLabelDelta.Deserialize = function (guid, slug, serializedArgs) {
        return new DeviceLabelDelta(serializedArgs.oldLabel, serializedArgs.newLabel, slug, guid);
    };
    DeviceLabelDelta.ClassName = "DeviceLabelDelta";
    return DeviceLabelDelta;
}(DeviceDelta));

var RPCArgs = /** @class */ (function () {
    function RPCArgs(data) {
        if (data === void 0) { data = {}; }
        if (data) {
            this.addr = data.addr || null;
            this.rpcId = Number(data.rpc_id) || null;
            this.callFmt = data.call_fmt || "";
            this.respFmt = data.resp_fmt || "";
            this.args = data.args || [];
            this.timeout = data.timeout || null;
        }
    }
    return RPCArgs;
}());
var StatefulRPCArgs = /** @class */ (function (_super) {
    __extends(StatefulRPCArgs, _super);
    function StatefulRPCArgs(data) {
        if (data === void 0) { data = {}; }
        var _this = _super.call(this, data) || this;
        _this.currentState = data.cur_state || false;
        _this.transitionStates = data.trans_states || [];
        _this.auto = data.auto || false;
        return _this;
    }
    return StatefulRPCArgs;
}(RPCArgs));
var StatefulSwitchArgs = /** @class */ (function () {
    function StatefulSwitchArgs(data) {
        if (data === void 0) { data = {}; }
        this.currentState = false;
        this.transitionStates = [];
        this.rpcs = [];
        if (data) {
            for (var rpc in data.rpcs) {
                this.rpcs.push(new StatefulRPCArgs(rpc));
            }
            this.currentState = data.cur_state || false;
            this.transitionStates = data.trans_states || [];
        }
    }
    return StatefulSwitchArgs;
}());
// export class WebArgs {
//   public options: WebOptions | any;
//   constructor(data: any = {}){
//     this.options = new WebOptions(data.options) || data.options;
//   }
// }
// export class WebOptions {
//   public tabViewId: string;
//   public ngComponent: string;
//   public seriesGroup: string;
//   public downloadable: boolean;
//   public chart?: any;
//   public ngComponentInputs?: any;
//   constructor(data: any = {}){
//     this.tabViewId = data.tabViewId;
//     this.ngComponent = data.ngComponent;
//     this.seriesGroup = data.seriesGroup;
//     this.downloadable = data.downloadable || false;
//     if ('chart' in data){
//       this.chart = data.chart;
//     }
//     if ('ngComponentInputs' in data){
//       this.ngComponentInputs = data.ngComponentInputs;
//     }
//   }
// }
var DisplayWidget = /** @class */ (function () {
    function DisplayWidget(data) {
        if (data === void 0) { data = {}; }
        this.label = data.label;
        this.lid = data.lid_hex;
        this.type = data.type;
        this.varType = data.var_type;
        this.derivedType = data.derived_unit_type;
        this.showInApp = data.show_in_app || false;
        this.showInWeb = data.show_in_web || false;
        if (!data.args) {
            this.args = null;
        }
        else if ('auto' in data.args) {
            this.args = new StatefulRPCArgs(data.args);
        }
        else if ('rpcs' in data.args) {
            this.args = new StatefulSwitchArgs(data.args);
        }
        else if (this.showInWeb) {
            this.args = data.args;
        }
        else {
            this.args = new RPCArgs(data.args);
        }
    }
    return DisplayWidget;
}());

var EventPage = /** @class */ (function (_super) {
    __extends(EventPage, _super);
    function EventPage(url, thisPage, pageCount) {
        var _this = _super.call(this, url, thisPage, pageCount) || this;
        _this.data = [];
        return _this;
    }
    return EventPage;
}(Page));
var EventPoint = /** @class */ (function () {
    function EventPoint(data) {
        if (data === void 0) { data = {}; }
        this.id = data.id;
        this.timestamp = new Date(data.timestamp);
        this.ext = data.ext;
        if ('stream' in data) {
            // Only getData returns a stream slug
            this.stream = data.stream;
        }
        if ('streamer_local_id' in data) {
            this.incrementalId = data.streamer_local_id;
        }
        if ('dirty_ts' in data) {
            this.dirtyTimestamp = data.dirty_ts;
        }
        if ('extra_data' in data) {
            this.summaryData = data.extra_data;
        }
    }
    return EventPoint;
}());

var FleetDevice = /** @class */ (function () {
    function FleetDevice(data) {
        this.device = data.device;
        this.alwaysOn = data.always_on;
        this.isAccessPoint = data.is_access_point;
    }
    return FleetDevice;
}());
var Fleet = /** @class */ (function () {
    function Fleet(data) {
        this.id = data.id;
        this.name = data.name;
        this.slug = data.slug;
        this.description = data.description;
        this.isNetwork = data.is_network;
        this.memberDictionary = {};
        this.members = [];
    }
    Fleet.prototype.addDevice = function (item) {
        this.members.push(item);
        this.memberDictionary[item.device] = item;
    };
    Fleet.prototype.getPostPayload = function () {
        var payload = {};
        payload['name'] = this.name;
        payload['description'] = this.description;
        payload['is_network'] = this.isNetwork;
        return payload;
    };
    return Fleet;
}());

var IndexFile = /** @class */ (function () {
    function IndexFile(data) {
        if (data === void 0) { data = {}; }
        this.id = data['id'] || '';
        this.title = data['title'] || '';
        this.url = data['url'] || '';
        this.fileType = data['file_type'] || '';
        this.createdOn = new Date(data['created_on']) || '';
        this.createdBy = data['created_by'] || '';
    }
    return IndexFile;
}());

var User = /** @class */ (function () {
    function User(data, token) {
        if (data === void 0) { data = {}; }
        this.slug = '';
        this.isStaff = false;
        this.tagline = data.tagline || '';
        this.username = data.username || "";
        this.name = data.name || "";
        this.email = data.email || "";
        this.isStaff = data.is_staff || false;
        this.id = data.id || "";
        this.orgRoles = data.orgRoles || {};
        if ('slug' in data) {
            this.slug = data.slug;
        }
        if (data.avatar) {
            this.avatarUrl = data.avatar.thumbnail;
        }
        if (data.created_at) {
            this.creationDate = new Date(data.created_at);
        }
        else {
            this.creationDate = new Date();
        }
        this.token = data.token || token || null;
    }
    User.prototype.toJson = function () {
        var rawData = {
            "username": this.username,
            "name": this.name,
            "email": this.email,
            "created_at": this.creationDate,
            "is_staff": this.isStaff,
            "id": this.id,
            "token": this.token,
            "avatar": {},
            "orgRoles": this.orgRoles
        };
        if (this.avatarUrl) {
            rawData.avatar["thumbnail"] = this.avatarUrl;
        }
        return rawData;
    };
    User.Unserialize = function (obj) {
        var user = new User(obj);
        var server = undefined;
        if (obj['server']) {
            server = obj['server'];
        }
        return { user: user, server: server };
    };
    User.prototype.getFullName = function () {
        var name = "";
        if (this.name) {
            name = this.name;
        }
        else {
            name = this.username;
        }
        return name;
    };
    User.prototype.getUsername = function () {
        return "@" + this.username;
    };
    User.prototype.getAvatar = function () {
        if (this.avatarUrl) {
            return this.avatarUrl;
        }
        else {
            return "";
        }
    };
    User.prototype.setOrgRoles = function (roles) {
        this.orgRoles = roles;
    };
    User.prototype.canReadProperties = function (orgSlug) {
        if (orgSlug in this.orgRoles) {
            return this.isStaff || this.orgRoles[orgSlug].permissions['can_read_device_properties'] || false;
        }
        return this.isStaff;
    };
    User.prototype.canModifyDevice = function (orgSlug) {
        if (orgSlug in this.orgRoles) {
            return this.isStaff || this.orgRoles[orgSlug].permissions['can_modify_device'] || false;
        }
        return this.isStaff;
    };
    User.prototype.canModifyStreamVariables = function (orgSlug) {
        if (orgSlug in this.orgRoles) {
            return this.isStaff || this.orgRoles[orgSlug].permissions['can_modify_stream_variables'] || false;
        }
        return this.isStaff;
    };
    return User;
}());

var GeneratedReport = /** @class */ (function () {
    function GeneratedReport(data) {
        if (data === void 0) { data = {}; }
        this.userInfo = new User();
        this.id = data['id'] || '';
        this.label = data['label'] || '';
        this.sourceRef = data['source_ref'] || '';
        this.createdOn = new Date(data['created_on']) || new Date();
        this.createdBy = data['created_by'] || '';
        this.org = data['org'] || '';
        this.status = data['status'] || '';
        this.template = data['template'] || '';
        this.groupSlug = data['group_slug'] || '';
        this.token = data['token'] || '';
        this.userInfo.email = data['user'] || '';
        if ('index_file' in data && data['index_file'] != null) {
            this.indexFile = new IndexFile(data['index_file']);
        }
        else {
            delete this.indexFile;
        }
        if ('user_info' in data && data['user_info'] != null) {
            this.userInfo.username = data['user_info']['username'];
            this.userInfo.slug = data['user_info']['slug'];
            this.userInfo.avatarUrl = data['user_info']['tiny_avatar'];
        }
        if ('args' in data && data['args'] != null) {
            this.args = data['args'];
        }
        else {
            delete this.args;
        }
    }
    GeneratedReport.prototype.getSchedulPostPayload = function () {
        var payload = {
            slug: this.sourceRef,
            template: this.template
        };
        if (this.args) {
            payload.args = this.args;
        }
        if (!payload.slug || !payload.template) {
            throw new Error("Payload cannot be returned because of missing fields: " + JSON.stringify(payload, null, 2) + ".");
        }
        return payload;
    };
    GeneratedReport.prototype.getStatusDisplay = function () {
        var factory = {
            'G0': 'In Progress...',
            'G1': 'Completed',
            'GE': 'Error'
        };
        return factory[this.status];
    };
    return GeneratedReport;
}());

var DeviceGlobalId = /** @class */ (function () {
    function DeviceGlobalId(id) {
        this.id = id;
    }
    /**
     *
     * This class represents a Device ID
     * It helps converts a device id like 0x20 to a string slug of
     * the form:
     * d--XXXX-XXXX-XXXX-XXXX
     *
     * The slug always has the hex string in lowercase.
     *
     */
    DeviceGlobalId.prototype.toString = function () {
        var hexString = Number(this.id).toString(16);
        while (hexString.length < 16) {
            hexString = '0' + hexString;
        }
        hexString = hexString.toLowerCase();
        return 'd--' + hexString.substr(0, 4) + '-' + hexString.substr(4, 4) + '-' + hexString.substr(8, 4) + '-' + hexString.substr(12, 4);
    };
    return DeviceGlobalId;
}());

var HttpError = /** @class */ (function () {
    function HttpError(resp) {
        var _this = this;
        this.raw = resp;
        var data = resp.response || resp;
        this.status = data.status || -1;
        this.statusText = data.statusText || 'Unknown Issue';
        this.nonFieldErrors = [];
        this.fieldErrors = {};
        if (data.data && (typeof data.data === "object")) {
            var fieldNames = Object.keys(data.data);
            fieldNames.forEach(function (name) {
                if (name === 'status') {
                    // Ignore
                }
                else if (name === 'message' || name === 'detail') {
                    _this.nonFieldErrors.push(data.data[name]);
                }
                else if (name === 'non_field_errors') {
                    var that_1 = _this;
                    data.data[name].forEach(function (err) {
                        if (!that_1.nonFieldErrors) {
                            that_1.nonFieldErrors = [];
                        }
                        that_1.nonFieldErrors.push(err);
                    });
                }
                else {
                    var msg_1 = '';
                    if (data.data[name] instanceof Array) {
                        data.data[name].forEach(function (err) {
                            msg_1 += err;
                        });
                    }
                    else {
                        // It seems like in some cases, data.response shows arrays and in some cases, strings
                        msg_1 += data.data[name];
                    }
                    _this.fieldErrors[name] = msg_1;
                }
            });
        }
        else if ((typeof data.data === "string") && data.data !== '') {
            this.heuristicallyParseErrorData(data.data);
        }
        else if (this.status == -1) {
            this.nonFieldErrors.push("Could not reach iotile.cloud.  Check your internet connection.");
        }
        if (resp.config) {
            if (resp.config.method) {
                this.method = resp.config.method.toUpperCase();
            }
            if (resp.config.url) {
                this.url = resp.config.url;
            }
        }
    }
    /*
      * Do our best to extract a meaningful error message from a string message thrown
      * by some deep part of the network stack.
      */
    HttpError.prototype.heuristicallyParseErrorData = function (data) {
        if (data.indexOf('ENOTFOUND') !== -1) {
            this.nonFieldErrors.push("Could not reach iotile.cloud.  Check your internet connection.");
        }
        else {
            this.nonFieldErrors.push(data);
        }
    };
    HttpError.prototype._formatFieldErrors = function () {
        var _this = this;
        var msg = '';
        if (this.nonFieldErrors && this.nonFieldErrors.length) {
            this.nonFieldErrors.forEach(function (err) {
                msg += ' ' + err;
            });
        }
        else {
            if (Object.keys(this.fieldErrors).length > 0) {
                msg += ' (';
                var fieldNames = Object.keys(this.fieldErrors);
                fieldNames.forEach(function (name) {
                    msg += ' ' + name + ': ' + _this.fieldErrors[name];
                });
                msg += ' )';
            }
        }
        return msg;
    };
    HttpError.prototype.shortUserErrorMsg = function () {
        var msg = 'Error!';
        var fieldErrors = this._formatFieldErrors();
        if (fieldErrors) {
            msg += fieldErrors;
        }
        else {
            // If no field or non-field errors were found, still give generic error
            msg += ' ' + this.statusText;
        }
        return msg;
    };
    HttpError.prototype.longUserErrorMsg = function () {
        var msg = 'Error ' + this.status + '! ';
        msg += this.statusText;
        var fieldErrors = this._formatFieldErrors();
        if (fieldErrors) {
            msg += ':' + fieldErrors;
        }
        return msg;
    };
    HttpError.prototype.extraInfo = function () {
        var msg = this.longUserErrorMsg();
        if (this.method && this.url) {
            msg += ' -> ' + this.method + ':' + this.url;
        }
        else {
            if (this.status === -1) {
                msg += ' -> ' + JSON.stringify(this.raw);
            }
        }
        return msg;
    };
    Object.defineProperty(HttpError.prototype, "message", {
        get: function () {
            return this.shortUserErrorMsg();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HttpError.prototype, "userMessage", {
        get: function () {
            return this.shortUserErrorMsg();
        },
        enumerable: true,
        configurable: true
    });
    return HttpError;
}());

var Invitation = /** @class */ (function () {
    function Invitation(data) {
        if (data === void 0) { data = {}; }
        this.email = "";
        if ('email' in data) {
            this.email = data.email;
        }
        if ('sent_on' in data) {
            this.sentOn = new Date(data.sent_on);
        }
        if ('sent_by' in data) {
            this.sentBy = data.sent_by;
        }
    }
    Invitation.prototype.postPayload = function () {
        var payload = {
            email: this.email
        };
        return payload;
    };
    return Invitation;
}());

var IOTileSysVar = /** @class */ (function () {
    function IOTileSysVar() {
        this.battery = '5800';
        this.gatewayScanBegin = '5a00';
        this.gatewayScanEnd = '5a01';
        this.gatewayScanFailure = '5a03';
        this.endOfTripSummary = '5a07';
        this.middleOfTripSummary = '5a08';
        this.reboot = '5c00';
        this.tripStarted = '0e00';
        this.tripEnded = '0e01';
        this.tripRecording = '0e02';
    }
    return IOTileSysVar;
}());

var MAX_INT32 = 2147483647;
var Mdo = /** @class */ (function () {
    function Mdo(data) {
        if (data === void 0) { data = {}; }
        this.m = data.multiplication_factor || data.m || 1;
        this.d = data.division_factor || data.d || 1;
        this.o = data.offset || data.o || 0;
        if (data.mdo_label) {
            this.label = data.mdo_label;
        }
    }
    Mdo.prototype.equal = function (other) {
        if (this.m !== other.m || this.d !== other.d || this.o !== other.o || this.label !== other.label) {
            return false;
        }
        return true;
    };
    Mdo.prototype.addToObject = function (obj, longNames) {
        if (longNames) {
            obj['offset'] = this.o;
            obj['multiplication_factor'] = this.m;
            obj['division_factor'] = this.d;
            obj['mdo_label'] = this.label;
        }
        else {
            obj['m'] = this.m;
            obj['d'] = this.d;
            obj['o'] = this.o;
        }
    };
    Mdo.prototype.toJson = function (longNames) {
        var obj = {};
        this.addToObject(obj, longNames);
        return obj;
    };
    /*
    private _round(value, decimals) {
      // See http://www.jacklmoore.com/notes/rounding-in-javascript/
      return Number(Math.round(value+'e'+decimals)+'e-'+decimals);
    }
    */
    Mdo.prototype._retr_dec = function (num) {
        // let numberFixedDecimal = num.toFixed(10);
        var numberString = num.toString();
        var decimalLength = (numberString.split(".")[1] || []).length;
        if (decimalLength > 8) {
            // Limit number of decimals to 8
            decimalLength = 8;
        }
        return decimalLength;
    };
    Mdo.prototype.computeValue = function (value) {
        var result = value;
        if (this.m) {
            result = result * this.m;
        }
        if (this.d) {
            result = result / this.d;
        }
        if (this.o) {
            result += this.o;
        }
        return result;
    };
    Mdo.prototype.setFromMdo = function (src) {
        if (src.m) {
            this.m = src.m;
        }
        if (src.d) {
            this.d = src.d;
        }
        if (src.o) {
            this.o = src.o;
        }
        if (src.label) {
            this.label = src.label;
        }
    };
    Mdo.prototype.setFromFactor = function (factor, invert) {
        var multiplication_factor = 1;
        var newFactor;
        if (factor < MAX_INT32) {
            // console.debug('factor is ' + factor);
            var decimals = this._retr_dec(factor);
            // console.debug('Decimals is ' + decimals);
            multiplication_factor = Math.pow(10, decimals);
            // console.debug('multiplication_factor is ' + multiplication_factor);
            newFactor = Math.round(factor * multiplication_factor);
            while (newFactor >= MAX_INT32) {
                // console.debug('factor is too large: ' + newFactor);
                newFactor = Math.round(newFactor / 10);
                multiplication_factor = Math.round(multiplication_factor / 10);
            }
        }
        else {
            newFactor = MAX_INT32;
        }
        this.o = 0.0;
        if (invert) {
            this.d = newFactor;
            this.m = multiplication_factor;
        }
        else {
            this.m = newFactor;
            this.d = multiplication_factor;
        }
    };
    Mdo.prototype.eq = function () {
        var eqStr = 'V * ' + this.m + '/' + this.d;
        if (this.o) {
            eqStr += ' + ' + this.o;
        }
        return eqStr;
    };
    Mdo.prototype.getPatchPayload = function () {
        var payload = {
            multiplication_factor: this.m,
            division_factor: this.d,
            offset: this.o
        };
        if (this.label) {
            payload['mdo_label'] = this.label;
        }
        return payload;
    };
    return Mdo;
}());

var Permissions = /** @class */ (function () {
    function Permissions(data) {
        if (data === void 0) { data = {}; }
        this.canDeleteOrg = data['can_delete_org'];
        this.canManageUsers = data['can_manage_users'];
        this.canManageOta = data['can_manage_ota'];
        this.canManageOrgAndProjects = data['can_manage_org_and_projects'];
        this.canClaimDevices = data['can_claim_devices'];
        this.canModifyDevice = data['can_modify_device'];
        this.canReadDeviceProperties = data['can_read_device_roperties'];
        this.canModifyDeviceProperties = data['can_modify_device_properties'];
        this.canReadNotes = data['can_read_notes'];
        this.canReadDeviceLocations = data['can_read_device_locations'];
        this.canReadStreamData = data['can_read_stream_data'];
        this.canCreateStreamData = data['can_create_stream_data'];
        this.canCreateDatablock = data['can_create_datablock'];
        this.canAccessDatablock = data['can_access_datablock'];
        this.canAccessWebapp = data['can_access_webapp'];
        this.canAccessReports = data['can_access_reports'];
        this.canCreateReports = data['can_create_reports'];
    }
    return Permissions;
}());

var Member = /** @class */ (function () {
    function Member(data) {
        if (data === void 0) { data = {}; }
        if ('user_details' in data) {
            this.user = new User(data['user_details']);
        }
        if ('created_on' in data) {
            this.createdOn = new Date(data['created_on']);
        }
        if ('is_active' in data) {
            this.isActive = data['is_active'];
        }
        if ('role' in data) {
            this.role = data['role'];
        }
        if ('permissions' in data) {
            this.permissions = new Permissions(data['permissions']);
        }
        if ('role_name' in data) {
            this.roleName = data['role_name'];
        }
    }
    return Member;
}());

var Membership = /** @class */ (function () {
    function Membership(data) {
        if (data === void 0) { data = {}; }
        this.user = data.user;
        this.isActive = data.is_active;
        this.permissions = data.permissions;
        this.role = data.role;
    }
    Membership.prototype.toJson = function () {
        var rawData = {
            "user": this.user,
            "is_active": this.isActive,
            "permissions": this.permissions,
            "role": this.role
        };
        return rawData;
    };
    Membership.Unserialize = function (obj) {
        var membership = new Membership(obj);
        return membership;
    };
    return Membership;
}());

var Note = /** @class */ (function () {
    function Note(data) {
        if (data === void 0) { data = {}; }
        this.id = 0;
        this.type = 'ui';
        this.target = data.target;
        this.timestamp = data.timestamp || new Date().toISOString();
        this.note = data.note;
        this.type = data.type;
        if ('id' in data) {
            this.id = data.id;
        }
        if ('user_info' in data) {
            this.userInfo = {
                username: data.user_info.username,
                slug: data.user_info.slug,
                tinyAvatar: data.user_info.tiny_avatar
            };
        }
        if ('attachment' in data && data.attachment != null) {
            this.attachment = {
                title: data.attachment.title,
                url: data.attachment.url,
                fileType: data.attachment.file_type
            };
        }
    }
    Note.prototype.postPayload = function () {
        var payload = {
            target: this.target,
            timestamp: this.timestamp,
            note: this.note,
            type: this.type
        };
        return payload;
    };
    return Note;
}());

var OrgTemplate = /** @class */ (function () {
    function OrgTemplate(data) {
        if (data === void 0) { data = {}; }
        this.id = data.id || '';
        this.name = data.name || '';
        this.slug = data.slug || '';
        this.createdOn = new Date(data.created_on);
        if ('version' in data) {
            this.version = data.version;
        }
        if ('extra_data' in data) {
            this.extraData = data['extra_data'];
        }
    }
    OrgTemplate.prototype.getExtraData = function () {
        if (this.extraData && 'web' in this.extraData) {
            return this.extraData['web'];
        }
    };
    return OrgTemplate;
}());

var Org = /** @class */ (function () {
    function Org(data) {
        if (data === void 0) { data = {}; }
        this.about = '';
        this.members = [];
        this.memberMap = {};
        this.pendingInvites = [];
        this.pendingInviteMap = {};
        this.slug = data.slug;
        this.name = data.name;
        this.createdBy = data.created_by;
        this.createdOn = new Date(data.created_on);
        this.rawData = data;
        if (data.about) {
            this.about = data.about;
        }
        if (data.avatar) {
            this.thumbnailUrl = data.avatar.thumbnail;
            this.tinyUrl = data.avatar.tiny;
        }
        if (data.current_member) {
            this.currentMember = new Member(data.current_member);
        }
        if (data.counts) {
            this.counts = data.counts;
        }
        if (data.ot) {
            this.orgTemplate = data.ot;
        }
    }
    Org.prototype.toJson = function () {
        return this.rawData;
    };
    Org.prototype.getPatchPayload = function () {
        var payload = {
            name: this.name
        };
        if (this.about) {
            payload.about = this.about;
        }
        return payload;
    };
    Org.prototype.addMembers = function (members) {
        var _this = this;
        this.members = members;
        this.memberMap = {};
        this.members.forEach(function (m) {
            if (m.user) {
                _this.memberMap[m.user.email] = m;
            }
        });
    };
    Org.prototype.getMember = function (slug) {
        return this.memberMap[slug];
    };
    Org.prototype.addPendingInvites = function (pendingInvites) {
        var _this = this;
        this.pendingInvites = pendingInvites;
        this.pendingInviteMap = {};
        this.pendingInvites.forEach(function (pv) {
            if (pv.email) {
                _this.pendingInviteMap[pv.email] = pv;
            }
        });
    };
    Org.prototype.getPendingInvite = function (email) {
        return this.pendingInviteMap[email];
    };
    return Org;
}());

var Unit = /** @class */ (function () {
    function Unit(data) {
        if (data === void 0) { data = {}; }
        this.mdo = new Mdo(data);
        this.fullName = data.unit_full;
        this.shortName = data.unit_short;
        this.slug = data.slug;
        if ('decimal_places' in data) {
            this.decimalPlaces = data.decimal_places;
        }
        if ('derived_units' in data) {
            this.derivedUnits = {};
            for (var key in data['derived_units']) {
                this.derivedUnits[key] = {};
                for (var name_1 in data['derived_units'][key]) {
                    this.derivedUnits[key][name_1] = new Mdo(data['derived_units'][key][name_1]);
                }
            }
        }
    }
    Unit.prototype.initFromJSON = function (data) {
        this.mdo = new Mdo(data);
        this.fullName = data.unit_full;
        this.shortName = data.unit_short;
        this.slug = data.slug;
        if ('decimal_places' in data) {
            this.decimalPlaces = data.decimal_places;
        }
        if ('derived_units' in data) {
            this.derivedUnits = {};
            for (var key in data['derived_units']) {
                this.derivedUnits[key] = {};
                for (var name_2 in data['derived_units'][key]) {
                    this.derivedUnits[key][name_2] = new Mdo(data['derived_units'][key][name_2]);
                }
            }
        }
    };
    Unit.prototype.toJson = function () {
        var obj = {
            slug: this.slug,
            unit_full: this.fullName,
            unit_short: this.shortName,
            m: this.mdo.m,
            d: this.mdo.d,
            o: this.mdo.o,
        };
        if (this.decimalPlaces !== undefined) {
            obj.decimal_places = this.decimalPlaces;
        }
        if (this.derivedUnits !== undefined) {
            obj.derived_units = {};
            for (var key in this.derivedUnits) {
                obj.derived_units[key] = {};
                for (var name_3 in this.derivedUnits[key]) {
                    obj.derived_units[key][name_3] = this.derivedUnits[key][name_3].toJson(false);
                }
            }
        }
        return obj;
    };
    Unit.prototype.setFromUnit = function (src) {
        this.initFromJSON(src.toJson());
    };
    Unit.prototype.deriveUnitTypes = function () {
        var keySet = [];
        if (this.derivedUnits) {
            for (var prop in this.derivedUnits) {
                if (this.derivedUnits.hasOwnProperty(prop)) {
                    keySet.push(prop);
                }
            }
        }
        return keySet;
    };
    Unit.prototype.deriveUnitsByType = function (type) {
        var keySet = [];
        if (this.derivedUnits) {
            for (var prop in this.derivedUnits[type]) {
                if (this.derivedUnits[type].hasOwnProperty(prop)) {
                    keySet.push(prop);
                }
            }
        }
        return keySet;
    };
    return Unit;
}());

var Variable = /** @class */ (function () {
    function Variable(data) {
        if (data === void 0) { data = {}; }
        this.inputUnit = null;
        this.outputUnit = null;
        this.id = data.id;
        this.slug = data.slug;
        this.lid = data.lid;
        this.name = data.name || data.slug;
        this.units = data.units;
        this.appOnly = data.app_only || false;
        this.webOnly = data.web_only || false;
        this.sysVar = data.project === null;
        this.about = data.about || "";
        this.mdo = new Mdo(data);
        this.type = data.var_type;
        this.rawData = data;
        this.project = data.project;
        this.decimalPlaces = data.decimal_places || 0;
        if (data.input_unit) {
            this.inputUnit = new Unit(data.input_unit);
        }
        if (data.output_unit) {
            this.outputUnit = new Unit(data.output_unit);
        }
    }
    Variable.prototype.toJson = function () {
        return this.rawData;
    };
    Variable.prototype.getHexLid = function () {
        if (this.slug) {
            var elements = this.slug.split("--");
            if (elements.length === 3) {
                return elements[2];
            }
        }
        return "";
    };
    Variable.prototype.getPatchPayload = function () {
        var basic = {
            name: this.name
        };
        var payload = Object.assign(basic, this.mdo.getPatchPayload());
        if (this.units) {
            payload['units'] = this.units;
        }
        if (this.inputUnit) {
            payload['input_unit'] = this.inputUnit.slug;
        }
        if (this.outputUnit) {
            payload['output_unit'] = this.outputUnit.slug;
        }
        if (this.about) {
            payload['about'] = this.about;
        }
        return payload;
    };
    return Variable;
}());

var PADDING = "000000";
var Stats = /** @class */ (function () {
    function Stats(data) {
        if (data === void 0) { data = {}; }
        this.count = 0;
        this.min = data.min;
        this.max = data.max;
        this.count = data.count;
        this.sum = data.sum;
        this.avg = data.avg;
        this.intervalDays = data.interval_days;
    }
    Stats.prototype._formatNumber = function (value, decimals) {
        var decimalDeparator = ".";
        var result;
        var _a = value.toString().split(decimalDeparator), integer = _a[0], _b = _a[1], fraction = _b === void 0 ? "" : _b;
        fraction = decimals > 0
            ? decimalDeparator + (fraction + PADDING).substring(0, decimals)
            : "";
        result = integer + fraction;
        return result;
    };
    Stats.prototype.getFormattedAvg = function () {
        if (this.avg) {
            return this._formatNumber(this.avg, 3);
        }
        return "";
    };
    return Stats;
}());

var Stream = /** @class */ (function () {
    function Stream(data) {
        if (data === void 0) { data = {}; }
        this.enabled = true;
        this.inputUnit = null;
        this.outputUnit = null;
        this.slug = data.slug;
        this.id = data.id;
        this.variable = data.variable;
        this.device = data.device;
        this.project = data.project;
        this.mdoType = data.mdo_type || null;
        this.mdo = new Mdo(data);
        this.stats = new Stats();
        this.rawValueFormat = data.raw_value_format || '<L';
        this._rawData = data;
        this.projectId = data.project_id;
        this.createdOn = data.created_on;
        this.type = data.data_type;
        this.enabled = data.enabled || true;
        //We always clear isModified since it will be set by the ProjectOverlay on an already built object
        this.isModified = false;
        this.data = [];
        this.dataLabel = data.data_label;
        if (data.block) {
            this.block = data.block;
        }
        if (data.var_name) {
            this.variableName = data.var_name;
        }
        if (data.var_type) {
            this.variableType = data.var_type;
        }
        this.variableLocalId = data.var_lid;
        if (data.input_unit) {
            this.inputUnit = new Unit(data.input_unit);
        }
        if (data.output_unit) {
            this.outputUnit = new Unit(data.output_unit);
        }
    }
    Stream.prototype.loadData = function (data) {
        this.slug = data.slug;
        this.id = data.id;
        this.variable = data.variable;
        this.device = data.device;
        this.project = data.project;
        this.mdoType = data.mdo_type || null;
        this.mdo = new Mdo(data);
        this.stats = new Stats();
        this.rawValueFormat = data.raw_value_format || '<L';
        this._rawData = data;
        this.projectId = data.project_id;
        this.createdOn = data.created_on;
        this.type = data.data_type;
        this.enabled = data.enabled || true;
        //We always clear isModified since it will be set by the ProjectOverlay on an already built object
        this.isModified = false;
        this.data = [];
        this.dataLabel = data.data_label;
        if (data.block) {
            this.block = data.block;
        }
        if (data.var_name) {
            this.variableName = data.var_name;
        }
        if (data.var_type) {
            this.variableType = data.var_type;
        }
        this.variableLocalId = data.var_lid;
        if (data.input_unit) {
            this.inputUnit = new Unit(data.input_unit);
        }
        if (data.output_unit) {
            this.outputUnit = new Unit(data.output_unit);
        }
    };
    Stream.prototype.toJson = function () {
        var obj = {
            id: this.id,
            project_id: this.projectId,
            project: this.project,
            device: this.device,
            variable: this.variable,
            data_label: this.dataLabel,
            raw_value_format: this.rawValueFormat,
            mdo_type: this.mdoType,
            slug: this.slug,
            type: this.type,
            created_on: this.createdOn,
            enabled: this.enabled,
            input_unit: null,
            output_unit: null
        };
        if (this.inputUnit) {
            obj['input_unit'] = this.inputUnit.toJson();
        }
        if (this.outputUnit) {
            obj['output_unit'] = this.outputUnit.toJson();
        }
        this.mdo.addToObject(obj, true);
        return obj;
    };
    Stream.prototype.addStats = function (stats) {
        this.stats = stats;
    };
    Stream.prototype.addData = function (data) {
        this.data = data;
    };
    Stream.prototype.getLocalVarId = function () {
        if (this.variable) {
            var elements = this.variable.split("--");
            if (elements.length === 3) {
                return elements[2];
            }
        }
        return "";
    };
    Stream.prototype.resetData = function () {
        this.data = [];
    };
    Stream.prototype.getPatchPayload = function () {
        var basic = {
            mdo_type: this.mdoType,
            enabled: this.enabled
        };
        var payload = Object.assign(basic, this.mdo.getPatchPayload());
        if (this.inputUnit) {
            payload['input_unit'] = this.inputUnit.slug;
        }
        if (this.outputUnit) {
            payload['output_unit'] = this.outputUnit.slug;
        }
        if (this.dataLabel) {
            payload['data_label'] = this.dataLabel;
        }
        return payload;
    };
    return Stream;
}());
var StreamDelta = /** @class */ (function (_super) {
    __extends(StreamDelta, _super);
    function StreamDelta() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return StreamDelta;
}(ModelDelta));
var StreamLabelDelta = /** @class */ (function (_super) {
    __extends(StreamLabelDelta, _super);
    function StreamLabelDelta(oldLabel, newLabel, slug, guid$$1) {
        var _this = _super.call(this, StreamLabelDelta.ClassName, slug, guid$$1) || this;
        _this.oldLabel = oldLabel;
        _this.newLabel = newLabel;
        return _this;
    }
    StreamLabelDelta.prototype.check = function (stream) {
        if (stream.dataLabel == this.newLabel) {
            return DeltaStatus.Outdated;
        }
        else if (stream.dataLabel !== this.oldLabel) {
            return DeltaStatus.Conflicted;
        }
        return DeltaStatus.Applies;
    };
    StreamLabelDelta.prototype.apply = function (stream) {
        stream.dataLabel = this.newLabel;
    };
    StreamLabelDelta.prototype.getPatch = function () {
        return {
            data_label: this.newLabel
        };
    };
    StreamLabelDelta.prototype.serializeArguments = function () {
        return {
            oldLabel: this.oldLabel,
            newLabel: this.newLabel
        };
    };
    StreamLabelDelta.Deserialize = function (guid$$1, slug, serializedArgs) {
        return new StreamLabelDelta(serializedArgs.oldLabel, serializedArgs.newLabel, slug, guid$$1);
    };
    StreamLabelDelta.ClassName = "StreamLabelDelta";
    return StreamLabelDelta;
}(StreamDelta));
var StreamMDODelta = /** @class */ (function (_super) {
    __extends(StreamMDODelta, _super);
    function StreamMDODelta(oldMDO, oldType, newMDO, newType, slug, guid$$1) {
        var _this = _super.call(this, StreamMDODelta.ClassName, slug, guid$$1) || this;
        _this.oldMDO = oldMDO;
        _this.oldType = oldType;
        _this.newMDO = newMDO;
        _this.newType = newType;
        return _this;
    }
    StreamMDODelta.prototype.check = function (stream) {
        if (stream.mdo.equal(this.newMDO) && stream.mdoType == this.newType) {
            return DeltaStatus.Outdated;
        }
        else if (!stream.mdo.equal(this.oldMDO) || stream.mdoType !== this.oldType) {
            return DeltaStatus.Conflicted;
        }
        return DeltaStatus.Applies;
    };
    StreamMDODelta.prototype.apply = function (stream) {
        stream.mdo.setFromMdo(this.newMDO);
        stream.mdoType = this.newType;
    };
    StreamMDODelta.prototype.getPatch = function () {
        return {
            mdo_type: this.newType,
            mdo_label: this.newMDO.label,
            multiplication_factor: this.newMDO.m,
            division_factor: this.newMDO.d,
            offset: this.newMDO.o
        };
    };
    StreamMDODelta.prototype.serializeArguments = function () {
        return {
            oldMDO: this.oldMDO.toJson(false),
            oldType: this.oldType,
            newMDO: this.newMDO.toJson(false),
            newType: this.newType
        };
    };
    StreamMDODelta.Deserialize = function (guid$$1, slug, serializedArgs) {
        var oldMDO = new Mdo(serializedArgs.oldMDO);
        var oldType = serializedArgs.oldType;
        var newMDO = new Mdo(serializedArgs.newMDO);
        var newType = serializedArgs.newType;
        return new StreamMDODelta(oldMDO, oldType, newMDO, newType, slug, guid$$1);
    };
    StreamMDODelta.ClassName = "StreamMDODelta";
    return StreamMDODelta;
}(StreamDelta));
var UnitType;
(function (UnitType) {
    UnitType[UnitType["Input"] = 0] = "Input";
    UnitType[UnitType["Output"] = 1] = "Output";
})(UnitType || (UnitType = {}));
/*
 * A delta representing a change in units for a stream.
 * This class has a slight complication in that the old units for a stream
 * may be null if they were never initialized.
 */
var StreamUnitsDelta = /** @class */ (function (_super) {
    __extends(StreamUnitsDelta, _super);
    function StreamUnitsDelta(oldUnits, newUnits, type, slug, classname, guid$$1) {
        var _this = _super.call(this, classname, slug, guid$$1) || this;
        _this.oldUnit = oldUnits;
        _this.newUnit = newUnits;
        _this.type = type;
        if (_this.newUnit == null) {
            throw new ArgumentError("You must always set a valid new unit in StreamUnitsDelta");
        }
        return _this;
    }
    StreamUnitsDelta.prototype.getSlug = function (unit) {
        if (unit == null) {
            return null;
        }
        return unit.slug;
    };
    StreamUnitsDelta.prototype.check = function (stream) {
        var unitSlug = this.getSlug(stream.inputUnit);
        if (this.type == UnitType.Output) {
            unitSlug = this.getSlug(stream.outputUnit);
        }
        var oldSlug = this.getSlug(this.oldUnit);
        var newSlug = this.getSlug(this.newUnit);
        if (unitSlug === newSlug) {
            return DeltaStatus.Outdated;
        }
        else if (unitSlug === oldSlug) {
            return DeltaStatus.Applies;
        }
        else {
            return DeltaStatus.Conflicted;
        }
    };
    /*
     * If the old units are null we need to create them from scratch
     * otherwise we can just update them with our new data.
     */
    StreamUnitsDelta.prototype.apply = function (stream) {
        if (this.type == UnitType.Input && stream.inputUnit == null) {
            stream.inputUnit = new Unit(this.newUnit.toJson());
        }
        else if (this.type == UnitType.Output && stream.outputUnit == null) {
            stream.outputUnit = new Unit(this.newUnit.toJson());
        }
        else {
            var unit = stream.outputUnit;
            if (this.type == UnitType.Input) {
                unit = stream.inputUnit;
            }
            if (unit) {
                unit.setFromUnit(this.newUnit);
            }
        }
    };
    StreamUnitsDelta.prototype.getPatch = function () {
        var paramName = 'output_unit';
        if (this.type == UnitType.Input) {
            paramName = 'input_unit';
        }
        var patch = {};
        patch[paramName] = this.newUnit.slug;
        return patch;
    };
    StreamUnitsDelta.prototype.serializeArguments = function () {
        return {
            oldUnit: this.oldUnit ? this.oldUnit.toJson() : null,
            newUnit: this.newUnit.toJson(),
            type: this.type
        };
    };
    return StreamUnitsDelta;
}(StreamDelta));
var StreamInputUnitsDelta = /** @class */ (function (_super) {
    __extends(StreamInputUnitsDelta, _super);
    function StreamInputUnitsDelta(oldUnits, newUnits, slug, guid$$1) {
        return _super.call(this, oldUnits, newUnits, UnitType.Input, slug, StreamInputUnitsDelta.ClassName, guid$$1) || this;
    }
    StreamInputUnitsDelta.Deserialize = function (guid$$1, slug, serializedArgs) {
        var oldUnit = null;
        if (serializedArgs.oldUnit) {
            oldUnit = new Unit(serializedArgs.oldUnit);
        }
        var newUnit = new Unit(serializedArgs.newUnit);
        return new StreamInputUnitsDelta(oldUnit, newUnit, slug, guid$$1);
    };
    StreamInputUnitsDelta.ClassName = "StreamInputUnitsDelta";
    return StreamInputUnitsDelta;
}(StreamUnitsDelta));
var StreamOutputUnitsDelta = /** @class */ (function (_super) {
    __extends(StreamOutputUnitsDelta, _super);
    function StreamOutputUnitsDelta(oldUnits, newUnits, slug, guid$$1) {
        return _super.call(this, oldUnits, newUnits, UnitType.Output, slug, StreamOutputUnitsDelta.ClassName, guid$$1) || this;
    }
    StreamOutputUnitsDelta.Deserialize = function (guid$$1, slug, serializedArgs) {
        var oldUnit = null;
        if (serializedArgs.oldUnit) {
            oldUnit = new Unit(serializedArgs.oldUnit);
        }
        var newUnit = new Unit(serializedArgs.newUnit);
        return new StreamOutputUnitsDelta(oldUnit, newUnit, slug, guid$$1);
    };
    StreamOutputUnitsDelta.ClassName = "StreamOutputUnitsDelta";
    return StreamOutputUnitsDelta;
}(StreamUnitsDelta));

var SensorGraph = /** @class */ (function () {
    function SensorGraph(data) {
        if (data === void 0) { data = {}; }
        this.id = data.id;
        this.name = data.name;
        this.slug = data.slug;
        this.org = data.org;
        this.projectTemplate = data.project_template;
        this.variableTemplates = data.variable_templates;
        this.uiExtra = data.ui_extra;
        this.version = data.version;
        this.majorVersion = data.major_version;
        this.minorVersion = data.minor_version;
        this.patchVersion = data.patch_version;
        this.createdOn = data.created_on;
        this.rawData = data;
        this.displayWidgetTemplates = [];
        if (!this.uiExtra) {
            this.uiExtra = {
                mobile: {
                    controller: 'defaultCtrl',
                    directory: null,
                    settingsController: 'defaultSettingsCtrl',
                    settingsTemplate: 'default-settings',
                    template: 'default',
                    settings: {
                        template: "device-settings",
                        controller: "DeviceSettingsCtrl"
                    },
                    ioInfo: null
                },
            };
        }
        if ("display_widget_templates" in data) {
            var that_1 = this;
            data["display_widget_templates"].forEach(function (d) {
                var widget = new DisplayWidget(d);
                that_1.displayWidgetTemplates.push(widget);
            });
        }
    }
    SensorGraph.prototype.getVersion = function () {
        return 'v' + [this.majorVersion, this.minorVersion, this.patchVersion].join('.');
    };
    SensorGraph.prototype.getUiExtra = function (type) {
        if (this.uiExtra && this.uiExtra[type]) {
            return this.uiExtra[type];
        }
        return null;
    };
    SensorGraph.prototype.getIoInfo = function (type) {
        if (this.getUiExtra(type)) {
            var uiExtra = this.getUiExtra(type);
            if (uiExtra.ioInfo && uiExtra.ioInfo.order && uiExtra.ioInfo.map) {
                return uiExtra.ioInfo;
            }
        }
        return null;
    };
    // Mobile method
    SensorGraph.prototype.getStreamLids = function () {
        var ioInfo = this.getIoInfo('mobile');
        if (ioInfo == null) {
            return [];
        }
        var streams = [];
        for (var lid in ioInfo.map) {
            streams.push(lid);
            if (ioInfo.map[lid].derived) {
                var derivedStreams = ioInfo.map[lid].derived;
                for (var derivedType in derivedStreams) {
                    if (derivedStreams[derivedType].lid) {
                        streams.push(derivedStreams[derivedType].lid);
                    }
                }
            }
        }
        return streams;
    };
    // Mobile method
    SensorGraph.prototype.getIoInfoParameter = function (lid, name) {
        var ioInfo = this.getIoInfo('mobile');
        // 1. Check if there is an ioInfo.map and if so, if there is
        //    data for the given LID
        if (ioInfo) {
            if (ioInfo.map[lid][name]) {
                return ioInfo.map[lid][name];
            }
        }
        else {
            // 2. Look for a global value for that parameter name
            var uiExtra = this.getUiExtra('mobile');
            if (uiExtra[name]) {
                return uiExtra[name];
            }
        }
        return '';
    };
    SensorGraph.prototype.getSettingsController = function (lid) {
        var controller = this.getIoInfoParameter(lid, 'settingsController');
        if (controller !== '') {
            return controller;
        }
        return 'defaultSettingsCtrl';
    };
    SensorGraph.prototype.getSettingsTemplate = function (lid) {
        var template = this.getIoInfoParameter(lid, 'settingsTemplate');
        if (template !== '') {
            return template;
        }
        return 'default-settings';
    };
    SensorGraph.prototype.toJson = function () {
        return this.rawData;
    };
    return SensorGraph;
}());

function streamInDevice(streamSlug, deviceSlug) {
    if (deviceSlug.length < 3) {
        return false;
    }
    var deviceGID = deviceSlug.substr(3);
    var streamParts = streamSlug.split('--');
    if (streamParts.length != 4) {
        return false;
    }
    return (streamParts[2] === deviceGID);
}
var DataConflictError = /** @class */ (function () {
    function DataConflictError(userMessage, technicalMessage) {
        if (technicalMessage === void 0) { technicalMessage = ""; }
        this.userMessage = userMessage;
        this.message = technicalMessage;
    }
    return DataConflictError;
}());

var merge = require('lodash.merge');
var ProjectOverlay = /** @class */ (function () {
    function ProjectOverlay(deltas) {
        if (deltas === void 0) { deltas = []; }
        this.deltaMap = { stream: {}, device: {} };
        this.deserializerMap = {};
        for (var _i = 0, deltas_1 = deltas; _i < deltas_1.length; _i++) {
            var delta = deltas_1[_i];
            this.addDelta(delta);
        }
        this.loadDeserializers();
    }
    ProjectOverlay.prototype.isEmpty = function () {
        var streamKeys = Object.keys(this.deltaMap.stream);
        var deviceKeys = Object.keys(this.deltaMap.device);
        return (streamKeys.length === 0 && deviceKeys.length === 0);
    };
    ProjectOverlay.prototype.toList = function () {
        var deltas = [];
        for (var slug in this.deltaMap.device) {
            for (var id in this.deltaMap.device[slug]) {
                deltas.push(this.deltaMap.device[slug][id]);
            }
        }
        for (var slug in this.deltaMap.stream) {
            for (var id in this.deltaMap.stream[slug]) {
                deltas.push(this.deltaMap.stream[slug][id]);
            }
        }
        return deltas;
    };
    ProjectOverlay.prototype.merge = function (overlay) {
        this.addDeltas(overlay.toList());
    };
    ProjectOverlay.prototype.affectedStreamModels = function () {
        return Object.keys(this.deltaMap.stream);
    };
    ProjectOverlay.prototype.affectedDeviceModels = function () {
        return Object.keys(this.deltaMap.device);
    };
    ProjectOverlay.prototype.patchForDevice = function (device) {
        if (!(device.slug in this.deltaMap.device)) {
            return {};
        }
        var patch = {};
        for (var deltaSlug in this.deltaMap.device[device.slug]) {
            var delta = this.deltaMap.device[device.slug][deltaSlug];
            if (delta.check(device) === DeltaStatus.Conflicted) {
                throw new DataConflictError("The same setting has also been modified in the cloud, please resync before trying to update.", "Conflict in slug: " + delta.slug + " guid: " + delta.id);
            }
            merge(patch, delta.getPatch(device));
        }
        return patch;
    };
    ProjectOverlay.prototype.patchForStream = function (stream) {
        if (stream.slug) {
            if (!(stream.slug in this.deltaMap.stream)) {
                return {};
            }
            var patch = {};
            for (var deltaSlug in this.deltaMap.stream[stream.slug]) {
                var delta = this.deltaMap.stream[stream.slug][deltaSlug];
                if (delta.check(stream) === DeltaStatus.Conflicted) {
                    throw new DataConflictError("The same setting has also been modified in the cloud, please resync before trying to update.", "Conflict in slug: " + delta.slug + " guid: " + delta.id);
                }
                merge(patch, delta.getPatch(stream));
            }
            return patch;
        }
        else {
            throw new UnknownKeyError("Cannot patch stream with unknown slug");
        }
    };
    /*
        * Return true if a device is directly modified or if one of its streams is modified
        */
    ProjectOverlay.prototype.deviceModified = function (deviceSlug) {
        if (deviceSlug in this.deltaMap.device) {
            return true;
        }
        for (var streamSlug in this.deltaMap.stream) {
            var delta = this.deltaMap.stream[streamSlug];
            if (streamInDevice(streamSlug, deviceSlug)) {
                return true;
            }
        }
        return false;
    };
    ProjectOverlay.prototype.deviceHasDelta = function (deviceSlug, deltaName) {
        if (!(deviceSlug in this.deltaMap.device)) {
            return false;
        }
        return deltaName in this.deltaMap.device[deviceSlug];
    };
    ProjectOverlay.prototype.variableModified = function (variableLid) {
        for (var slug in this.deltaMap.stream) {
            if (endsWith(slug, variableLid)) {
                return true;
            }
        }
        return false;
    };
    ProjectOverlay.prototype.loadDeserializers = function () {
        this.deserializerMap = {};
        //Stream Deserializers
        this.deserializerMap[StreamOutputUnitsDelta.ClassName] = StreamOutputUnitsDelta.Deserialize;
        this.deserializerMap[StreamInputUnitsDelta.ClassName] = StreamInputUnitsDelta.Deserialize;
        this.deserializerMap[StreamLabelDelta.ClassName] = StreamLabelDelta.Deserialize;
        this.deserializerMap[StreamMDODelta.ClassName] = StreamMDODelta.Deserialize;
        //Device Deserializers
        this.deserializerMap[DeviceLabelDelta.ClassName] = DeviceLabelDelta.Deserialize;
        this.deserializerMap[DeviceLocationDelta.ClassName] = DeviceLocationDelta.Deserialize;
        this.deserializerMap[DeviceDrifterDelta.ClassName] = DeviceDrifterDelta.Deserialize;
    };
    ProjectOverlay.prototype.prune = function (project) {
        for (var slug in this.deltaMap.stream) {
            var deltas = this.deltaMap.stream[slug];
            var stream = project.getStream(slug, true);
            //If the stream doesn't exist, all deltas are obsolete
            if (stream == null) {
                delete this.deltaMap.stream[slug];
                continue;
            }
            for (var guid$$1 in deltas) {
                var delta = deltas[guid$$1];
                if (delta.check(stream) !== DeltaStatus.Applies) {
                    delete deltas[guid$$1];
                }
            }
            //If we have removed all of the stream deltas, also remove the stream
            if (Object.keys(deltas).length == 0) {
                delete this.deltaMap.stream[slug];
            }
        }
        for (var slug in this.deltaMap.device) {
            var deltas = this.deltaMap.device[slug];
            var device = project.getDevice(slug, true);
            //If the device doesn't exist, all deltas are obsolete
            if (device == null) {
                delete this.deltaMap.device[slug];
                continue;
            }
            for (var guid$$1 in deltas) {
                var delta = deltas[guid$$1];
                if (delta.check(device) !== DeltaStatus.Applies) {
                    delete deltas[guid$$1];
                }
            }
            //If we have removed all of the device deltas, also remove the device
            if (Object.keys(deltas).length == 0) {
                delete this.deltaMap.device[slug];
            }
        }
    };
    ProjectOverlay.prototype.applyDevice = function (device, markModified) {
        var deltas = this.deltaMap.device[device.slug];
        if (deltas == null) {
            return;
        }
        for (var guid$$1 in deltas) {
            var delta = deltas[guid$$1];
            if (delta.check(device) === DeltaStatus.Applies) {
                delta.apply(device);
                if (markModified) {
                    device.isModified = true;
                }
            }
        }
    };
    ProjectOverlay.prototype.applyStream = function (stream, markModified) {
        if (stream.slug) {
            var deltas = this.deltaMap.stream[stream.slug];
            if (deltas == null) {
                return;
            }
            for (var guid$$1 in deltas) {
                var delta = deltas[guid$$1];
                if (delta.check(stream) === DeltaStatus.Applies) {
                    delta.apply(stream);
                    if (markModified) {
                        stream.isModified = true;
                    }
                }
            }
        }
    };
    ProjectOverlay.prototype.addDelta = function (delta) {
        var subMap = this.deltaMap.device;
        var slug = delta.slug;
        if (delta instanceof StreamDelta) {
            subMap = this.deltaMap.stream;
        }
        if (!(slug in subMap)) {
            subMap[slug] = {};
        }
        subMap[slug][delta.classname] = delta;
    };
    ProjectOverlay.prototype.addDeltas = function (deltas) {
        for (var _i = 0, deltas_2 = deltas; _i < deltas_2.length; _i++) {
            var delta = deltas_2[_i];
            this.addDelta(delta);
        }
    };
    ProjectOverlay.prototype.serialize = function () {
        var obj = {};
        for (var slug in this.deltaMap.stream) {
            var streamDeltas = this.deltaMap.stream[slug];
            obj[slug] = {};
            for (var id in streamDeltas) {
                obj[slug][id] = streamDeltas[id].serialize();
            }
        }
        for (var slug in this.deltaMap.device) {
            var deviceDeltas = this.deltaMap.device[slug];
            obj[slug] = {};
            for (var id in deviceDeltas) {
                obj[slug][id] = deviceDeltas[id].serialize();
            }
        }
        return obj;
    };
    ProjectOverlay.prototype.deserialize = function (obj, log) {
        for (var slug in obj) {
            var deltas = obj[slug];
            for (var className in deltas) {
                var serializedDelta = deltas[className];
                var guid$$1 = serializedDelta.guid;
                var slug_1 = serializedDelta.slug;
                if (!(className in this.deserializerMap)) {
                    if (log) {
                        log.warn("[ProjectOverlay] Skipping unknown delta type in overlay, type: " + className + ' slug: ' + slug_1);
                    }
                    continue;
                }
                var delta = this.deserializerMap[className](guid$$1, slug_1, serializedDelta.args);
                this.addDelta(delta);
            }
        }
    };
    ProjectOverlay.Deserialize = function (obj, log) {
        var overlay = new ProjectOverlay();
        overlay.deserialize(obj, log);
        return overlay;
    };
    return ProjectOverlay;
}());

var Project = /** @class */ (function () {
    function Project(data) {
        if (data === void 0) { data = {}; }
        this.id = data.id;
        this.gid = data.gid;
        this.name = data.name;
        this.orgSlug = data.org;
        this.template = data.project_template;
        this.slug = data.slug;
        this.rawData = data;
        this.devices = [];
        this.variables = [];
        this.streams = [];
        this.sensorGraphs = [];
        this.deviceMap = {};
        this.variableMap = {};
        this.projTemplateMap = {};
        this.streamMap = {};
        this.sensorGraphMap = {};
        this.overlay = new ProjectOverlay();
        this.properties = [];
        this.createdBy = data.created_by;
        this.createdOn = new Date(data.created_on);
        if ('project_template' in data) {
            this.projectTemplate = data.project_template;
        }
        if (data.counts) {
            this.counts = data.counts;
        }
        else {
            this.counts = {};
        }
        this.deviceMap = {};
        this.streamMap = {};
        this.variableMap = {};
        this.propertyMap = {};
    }
    Project.prototype.toJson = function () {
        return this.rawData;
    };
    Project.prototype.serialize = function () {
        var proj = this.toJson();
        //Now add in any added linked objects
        proj.devices = this.devices.map(function (dev) { return dev.toJson(); });
        proj.variables = this.variables.map(function (variable) { return variable.toJson(); });
        proj.streams = this.streams.map(function (stream) { return stream.toJson(); });
        proj.sensorGraphs = this.sensorGraphs.map(function (sg) { return sg.toJson(); });
        return proj;
    };
    Project.Unserialize = function (obj) {
        //Extract the org first since the slug is used above 
        var org = obj['org'];
        obj['orgSlug'] = org.slug;
        var proj = new Project(obj);
        if (obj['devices'] && obj['devices'].length > 0) {
            proj.addDevices(obj['devices'].map(function (data) { return new Device(data); }));
        }
        if (obj['variables'] && obj['variables'].length > 0) {
            proj.addVariables(obj['variables'].map(function (variable) { return new Variable(variable); }));
        }
        if (obj['streams'] && obj['streams'].length > 0) {
            proj.addStreams(obj['streams'].map(function (stream) { return new Stream(stream); }));
        }
        if (obj['sensorGraphs'] && obj['sensorGraphs'].length > 0) {
            proj.addSensorGraphs(obj['sensorGraphs'].map(function (sg) { return new SensorGraph(sg); }));
        }
        return proj;
    };
    Project.prototype.addDevices = function (devices) {
        var _this = this;
        this.devices = devices;
        this.deviceMap = {};
        this.devices.forEach(function (d) {
            _this.deviceMap[d.slug] = d;
        });
    };
    Project.prototype.addStreams = function (streams) {
        var _this = this;
        this.streams = streams;
        this.streamMap = {};
        this.streams.forEach(function (s) {
            _this.streamMap[s.slug] = s;
        });
    };
    Project.prototype.addStream = function (stream) {
        this.streams.push(stream);
        this.streamMap[stream.slug] = stream;
    };
    Project.prototype.addSensorGraphs = function (sg) {
        var _this = this;
        this.sensorGraphs = sg;
        this.sensorGraphs.forEach(function (sg) {
            _this.sensorGraphMap[sg.slug] = sg;
        });
    };
    Project.prototype.addSensorGraph = function (sg) {
        this.sensorGraphs.push(sg);
        this.sensorGraphMap[sg.slug] = sg;
    };
    Project.prototype.getSensorGraph = function (slug) {
        return this.sensorGraphMap[slug];
    };
    Project.prototype.addProjectTemplates = function (templates) {
        var _this = this;
        this.projTemplateMap = {};
        templates.forEach(function (pt) {
            _this.projTemplateMap[pt.slug] = pt;
        });
    };
    Project.prototype.getProjectTemplate = function () {
        if (this.projTemplateMap[this.template]) {
            return this.projTemplateMap[this.template];
        }
        else {
            throw new ArgumentError("Can't find Project Template for slug " + this.template);
        }
    };
    Project.prototype.addVariables = function (variables) {
        var _this = this;
        this.variables = variables;
        this.variableMap = {};
        this.variables.forEach(function (v) {
            _this.variableMap[v.slug] = v;
        });
    };
    Project.prototype.addVariable = function (variable) {
        this.variables.push(variable);
        this.variableMap[variable.slug] = variable;
    };
    Project.prototype.getVariable = function (slug) {
        return this.variableMap[slug];
    };
    Project.prototype.getVariableForStream = function (slug) {
        if (slug) {
            var elements = slug.split("--");
            if (elements.length === 4) {
                var varSlug = "v--" + elements[1] + "--" + elements[3];
                return this.getVariable(varSlug);
            }
        }
        return;
    };
    Project.prototype.getDevice = function (slug, unmodified) {
        var device = this.deviceMap[slug];
        if (!device) {
            return null;
        }
        device = new Device(device.toJson());
        if (unmodified || !this.overlay) {
            return device;
        }
        this.overlay.applyDevice(device, true);
        return device;
    };
    Project.prototype.deviceModified = function (slug) {
        return this.overlay.deviceModified(slug);
    };
    Project.prototype.hasDevice = function (slug) {
        return (slug in this.deviceMap);
    };
    Project.prototype.getStream = function (slug, unmodified) {
        var stream = this.streamMap[slug];
        if (!stream) {
            return null;
        }
        stream = new Stream(stream.toJson());
        if (unmodified || !this.overlay) {
            return stream;
        }
        this.overlay.applyStream(stream, true);
        return stream;
    };
    Project.prototype.streamsForDevice = function (deviceSlug, filterByIOInfo) {
        if (filterByIOInfo === void 0) { filterByIOInfo = false; }
        var streams = {};
        if (filterByIOInfo) {
            var device = this.getDevice(deviceSlug);
            if (device) {
                var sg = this.getSensorGraph(device.sensorGraphSlug);
                var lids = sg.getStreamLids();
                var streamIDBase = ['s', this.gid, device.gid].join('--');
                for (var _i = 0, lids_1 = lids; _i < lids_1.length; _i++) {
                    var lid = lids_1[_i];
                    var streamSlug = streamIDBase + '--' + lid;
                    var stream = this.getStream(streamSlug);
                    if (stream == null) {
                        throw new ArgumentError("Could not find stream specified in sensorgraph ioInfo: " + streamSlug);
                    }
                    streams[streamSlug] = stream;
                }
            }
        }
        else {
            for (var _a = 0, _b = this.streams; _a < _b.length; _a++) {
                var stream = _b[_a];
                if (stream.device == deviceSlug) {
                    var stream_obj = this.getStream(stream.slug);
                    if (stream_obj) {
                        streams[stream_obj.slug];
                    }
                }
            }
        }
        return streams;
    };
    Project.prototype.getSensorGraphSlugs = function () {
        return this.devices.map(function (device) { return device.sensorGraphSlug; });
    };
    /*
      * Apply an overlay permanently to the devices and streams in this project.
      * This is distinct from updating our separate overlay object that is just
      * used on demand when streams and devices are requested rather than flattened
      * into the objects themselves.  This function is useful as an optimization for
      * simulating the effects of pulling cloud data after the contents of this overlay
      * were successfully patched to iotile.cloud.
      *
      * We do not mark the device and stream modified here since this function is used
      * to reproduce synced data from the cloud, so the device is not modified with
      * respect to what is stored in the cloud.
      */
    Project.prototype.applyOverlay = function (overlay) {
        for (var _i = 0, _a = this.devices; _i < _a.length; _i++) {
            var device = _a[_i];
            overlay.applyDevice(device, false);
        }
        for (var _b = 0, _c = this.streams; _b < _c.length; _b++) {
            var stream = _c[_b];
            overlay.applyStream(stream, false);
        }
        //If these changes cause any of our internal overlay deltas to not longer apply, remove them
        this.overlay.prune(this);
    };
    Project.prototype.addProperties = function (properties) {
        var _this = this;
        this.properties = properties;
        this.propertyMap = {};
        this.properties.forEach(function (property) {
            _this.propertyMap[property.name] = property;
        });
    };
    Project.prototype.getProperty = function (name) {
        return this.propertyMap[name];
    };
    Project.prototype.computeInputValue = function (stream, rawValue, mdo) {
        var result;
        var varSlug = stream.variable;
        var varObj = this.variableMap[varSlug];
        // 1.- Compute Factor
        if (!mdo) {
            mdo = stream.mdo || varObj.mdo;
        }
        result = mdo.computeValue(rawValue);
        // 2.- Modify to internal storage units
        var inputUnit = stream.inputUnit;
        if (!inputUnit && varObj) {
            inputUnit = varObj.inputUnit;
        }
        if (inputUnit && inputUnit.mdo) {
            result = inputUnit.mdo.computeValue(result);
        }
        return result;
    };
    Project.prototype.getInputUnits = function (stream) {
        if (stream.inputUnit) {
            return stream.inputUnit;
        }
        var variable = this.variableMap[stream.variable];
        if (!variable) {
            return null;
        }
        return variable.inputUnit;
    };
    Project.prototype.getOutputUnits = function (stream) {
        if (stream.outputUnit) {
            return stream.outputUnit;
        }
        var variable = this.variableMap[stream.variable];
        if (!variable) {
            return null;
        }
        return variable.outputUnit;
    };
    Project.prototype.computeValue = function (stream, data) {
        var result = undefined;
        var mdo;
        if (data.value) {
            if (!stream) {
                return result;
            }
            if (stream.outputUnit) {
                mdo = stream.outputUnit.mdo;
                if (mdo) {
                    result = mdo.computeValue(data.value);
                }
            }
            else {
                result = data.outValue ? data.outValue : data.value;
            }
            return result;
        }
    };
    Project.prototype.computeOutputValue = function (stream, value) {
        var result;
        var varSlug = stream.variable;
        var varObj = this.variableMap[varSlug];
        // Modify from internal storage units
        var outputUnit = stream.outputUnit;
        if (!outputUnit && varObj) {
            outputUnit = varObj.outputUnit;
        }
        if (outputUnit && outputUnit.mdo) {
            result = outputUnit.mdo.computeValue(value);
        }
        else {
            result = value;
        }
        return result;
    };
    /**
     *
     * @description
     * Given a DataPoint with a .rawValue, compute
     * value using the stream.mdo and stream.inputUnit
     * Then compute outValue using the stream.outputUnit
     * Finally, DisplayValue represents the string version of outValue
     *
     * @param {DataPoint} dataPoint should have rawValue defined
     * @param {Stream} stream is the stream to use to get input/output units
     *
     * @returns {DataPoint} Modified dataPoint
     */
    Project.prototype.processDataPoint = function (stream, dataPoint) {
        if (dataPoint.rawValue) {
            dataPoint.value = this.computeInputValue(stream, dataPoint.rawValue, undefined);
        }
        if (dataPoint.value) {
            dataPoint.outValue = this.computeOutputValue(stream, dataPoint.value);
        }
        // Figure out units for displayValue field
        var outUnit = stream.outputUnit;
        var variable;
        if (!outUnit) {
            // If stream has no OutputUnit, default to the Variable one.
            variable = this.getVariable(stream.variable);
            if (variable) {
                outUnit = variable.outputUnit;
            }
        }
        if (dataPoint.outValue && dataPoint.value) {
            if (outUnit) {
                dataPoint.displayValue = dataPoint.outValue.toFixed(outUnit.decimalPlaces);
            }
            else {
                if (variable) {
                    dataPoint.displayValue = dataPoint.outValue.toFixed(variable.decimalPlaces);
                }
                else {
                    dataPoint.displayValue = dataPoint.value.toString();
                }
            }
            return dataPoint;
        }
        else {
            throw new InvalidDataError('Error processing data point', 'Data point is missing value');
        }
    };
    
    return Project;
}());

var ProjectTemplate = /** @class */ (function () {
    function ProjectTemplate(data) {
        if (data === void 0) { data = {}; }
        this.id = data.id;
        this.name = data.name;
        this.slug = data.slug;
        this.version = data.version;
        this.extraData = data.extra_data;
        this.org = data.org;
        this.rawData = data;
        if (!this.extraData) {
            this.extraData = {
                mobile: {
                    projectTemplateSlug: "default",
                    waveform: false
                }
            };
        }
    }
    ProjectTemplate.prototype.toJson = function () {
        return this.rawData;
    };
    return ProjectTemplate;
}());

var Property = /** @class */ (function () {
    function Property(data) {
        this.name = data.name;
        this.value = data.value;
        this.type = data.type;
        this.isSystem = data.is_system;
        this.rawData = data;
        if ('id' in data) {
            this.id = data.id;
        }
        else {
            delete this.id;
        }
        if ('target' in data) {
            this.target = data.target;
        }
    }
    Property.prototype.toJson = function () {
        return this.rawData;
    };
    Property.prototype.getPostPayload = function () {
        var payload = {};
        var type = this.type.toLowerCase() + '_value';
        if ('id' in this) {
            payload['id'] = this.id;
        }
        payload['name'] = this.name;
        payload[type] = this.value;
        return payload;
    };
    return Property;
}());

var PropertyTemplate = /** @class */ (function () {
    function PropertyTemplate(data) {
        this.enums = [];
        this.name = data.name;
        this.type = data.type;
        this.default = data.default;
        this.enums = data.enums;
        this.rawData = data;
        if ('id' in data) {
            this.id = data.id;
        }
        if ('org' in data) {
            this.org = data.org;
        }
        if ('extra' in data) {
            this.extra = data.extra;
        }
    }
    PropertyTemplate.prototype.toJson = function () {
        return this.rawData;
    };
    return PropertyTemplate;
}());

var Streamer = /** @class */ (function () {
    function Streamer(data) {
        if (data === void 0) { data = {}; }
        this.id = data.id;
        this.slug = data.slug;
        this.device = data.device;
        this.index = data.index;
        this.lastID = data.last_id;
    }
    return Streamer;
}());

var VarType = /** @class */ (function () {
    function VarType(data) {
        if (data === void 0) { data = {}; }
        this.availableInputUnits = [];
        this.availableOutputUnits = [];
        this.schema = {};
        this.name = data.name;
        this.slug = data.slug;
        this.unitFullName = data.storage_units_full;
        this.rawData = data;
        if ("available_input_units" in data) {
            var that_1 = this;
            data["available_input_units"].forEach(function (u) {
                var unit = new Unit(u);
                that_1.availableInputUnits.push(unit);
            });
        }
        if ("available_output_units" in data) {
            var that_2 = this;
            data["available_output_units"].forEach(function (u) {
                var unit = new Unit(u);
                that_2.availableOutputUnits.push(unit);
            });
        }
        if ('schema' in data) {
            var schema = data['schema'];
            if (schema && 'keys' in schema) {
                this.schema = schema.keys;
            }
        }
    }
    VarType.prototype.toJson = function () {
        return this.rawData;
    };
    VarType.prototype.getInputUnitForSlug = function (slug) {
        var resultingUnit = null;
        this.availableInputUnits.forEach(function (u) {
            if (u.slug === slug) {
                resultingUnit = u;
            }
        });
        return resultingUnit;
    };
    VarType.prototype.getOutputUnitForSlug = function (slug) {
        var resultingUnit = null;
        this.availableOutputUnits.forEach(function (u) {
            if (u.slug === slug) {
                resultingUnit = u;
            }
        });
        return resultingUnit;
    };
    VarType.prototype.getASchemaObj = function (schemaKey) {
        return this.schema && schemaKey in this.schema ? this.schema[schemaKey] : null;
    };
    VarType.prototype.getOutputUnitsForSchema = function (schemaKey) {
        var schemaObj = this.getASchemaObj(schemaKey);
        if (schemaObj && 'output_units' in schemaObj) {
            return schemaObj['output_units'];
        }
    };
    return VarType;
}());

var commonjsGlobal$1 = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};



function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule$1(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var LoggerOptions = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Log level for a logger.
 */
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["Trace"] = 0] = "Trace";
    LogLevel[LogLevel["Debug"] = 1] = "Debug";
    LogLevel[LogLevel["Info"] = 2] = "Info";
    LogLevel[LogLevel["Warn"] = 3] = "Warn";
    LogLevel[LogLevel["Error"] = 4] = "Error";
    LogLevel[LogLevel["Fatal"] = 5] = "Fatal";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
/* tslint:disable:no-namespace */
(function (LogLevel) {
    /**
     * Returns LogLevel based on string representation
     * @param val Value
     * @returns {LogLevel}, Error is thrown if invalid.
     */
    function fromString(val) {
        if (val == null) {
            throw new Error("Argument must be set");
        }
        switch (val.toLowerCase()) {
            case "trace":
                return LogLevel.Trace;
            case "debug":
                return LogLevel.Debug;
            case "info":
                return LogLevel.Info;
            case "warn":
                return LogLevel.Warn;
            case "error":
                return LogLevel.Error;
            case "fatal":
                return LogLevel.Fatal;
            default:
                throw new Error("Unsupported value for conversion: " + val);
        }
    }
    LogLevel.fromString = fromString;
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
/* tslint:disable:enable-namespace */
/**
 * Where to log to? Pick one of the constants. Custom requires a callback to be present, see LFService.createLoggerFactory(...)
 * where this comes into play.
 */
var LoggerType;
(function (LoggerType) {
    LoggerType[LoggerType["Console"] = 0] = "Console";
    LoggerType[LoggerType["MessageBuffer"] = 1] = "MessageBuffer";
    LoggerType[LoggerType["Custom"] = 2] = "Custom";
})(LoggerType = exports.LoggerType || (exports.LoggerType = {}));
/**
 * Defines several date enums used for formatting a date.
 */
var DateFormatEnum;
(function (DateFormatEnum) {
    /**
     * Displays as: year-month-day hour:minute:second,millis -> 1999-02-12 23:59:59,123
     * Note the date separator can be set separately.
     */
    DateFormatEnum[DateFormatEnum["Default"] = 0] = "Default";
    /**
     * Displays as: year-month-day hour:minute:second -> 1999-02-12 23:59:59
     * Note the date separator can be set separately.
     */
    DateFormatEnum[DateFormatEnum["YearMonthDayTime"] = 1] = "YearMonthDayTime";
    /**
     * Displays as: year-day-month hour:minute:second,millis -> 1999-12-02 23:59:59,123
     * Note the date separator can be set separately.
     */
    DateFormatEnum[DateFormatEnum["YearDayMonthWithFullTime"] = 2] = "YearDayMonthWithFullTime";
    /**
     * Displays as: year-day-month hour:minute:second -> 1999-12-02 23:59:59
     * Note the date separator can be set separately.
     */
    DateFormatEnum[DateFormatEnum["YearDayMonthTime"] = 3] = "YearDayMonthTime";
})(DateFormatEnum = exports.DateFormatEnum || (exports.DateFormatEnum = {}));
/* tslint:disable:no-namespace */
(function (DateFormatEnum) {
    /**
     * Returns LogLevel based on string representation
     * @param val Value
     * @returns {LogLevel}, Error is thrown if invalid.
     */
    function fromString(val) {
        if (val == null) {
            throw new Error("Argument must be set");
        }
        switch (val.toLowerCase()) {
            case "default":
                return DateFormatEnum.Default;
            case "yearmonthdayTime":
                return DateFormatEnum.YearMonthDayTime;
            case "yeardaymonthwithfulltime":
                return DateFormatEnum.YearDayMonthWithFullTime;
            case "yeardaymonthtime":
                return DateFormatEnum.YearDayMonthTime;
            default:
                throw new Error("Unsupported value for conversion: " + val);
        }
    }
    DateFormatEnum.fromString = fromString;
})(DateFormatEnum = exports.DateFormatEnum || (exports.DateFormatEnum = {}));
/* tslint:disable:enable-namespace */
/**
 * DateFormat class, stores data on how to format a date.
 */
var DateFormat = (function () {
    /**
     * Constructor to define the dateformat used for logging, can be called empty as it uses defaults.
     * @param formatEnum DateFormatEnum, use one of the constants from the enum. Defaults to DateFormatEnum.Default
     * @param dateSeparator Separator used between dates, defaults to -
     */
    function DateFormat(formatEnum, dateSeparator) {
        if (formatEnum === void 0) { formatEnum = DateFormatEnum.Default; }
        if (dateSeparator === void 0) { dateSeparator = "-"; }
        this._formatEnum = formatEnum;
        this._dateSeparator = dateSeparator;
    }
    Object.defineProperty(DateFormat.prototype, "formatEnum", {
        get: function () {
            return this._formatEnum;
        },
        set: function (value) {
            this._formatEnum = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateFormat.prototype, "dateSeparator", {
        get: function () {
            return this._dateSeparator;
        },
        set: function (value) {
            this._dateSeparator = value;
        },
        enumerable: true,
        configurable: true
    });
    DateFormat.prototype.copy = function () {
        return new DateFormat(this._formatEnum, this._dateSeparator);
    };
    return DateFormat;
}());
exports.DateFormat = DateFormat;
/**
 * Information about the log format, what will a log line look like?
 */
var LogFormat = (function () {
    /**
     * Constructor to create a LogFormat. Can be created without parameters where it will use sane defaults.
     * @param dateFormat DateFormat (what needs the date look like in the log line)
     * @param showTimeStamp Show date timestamp at all?
     * @param showLoggerName Show the logger name?
     */
    function LogFormat(dateFormat, showTimeStamp, showLoggerName) {
        if (dateFormat === void 0) { dateFormat = new DateFormat(); }
        if (showTimeStamp === void 0) { showTimeStamp = true; }
        if (showLoggerName === void 0) { showLoggerName = true; }
        this._showTimeStamp = true;
        this._showLoggerName = true;
        this._dateFormat = dateFormat;
        this._showTimeStamp = showTimeStamp;
        this._showLoggerName = showLoggerName;
    }
    Object.defineProperty(LogFormat.prototype, "dateFormat", {
        get: function () {
            return this._dateFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogFormat.prototype, "showTimeStamp", {
        get: function () {
            return this._showTimeStamp;
        },
        set: function (value) {
            this._showTimeStamp = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogFormat.prototype, "showLoggerName", {
        get: function () {
            return this._showLoggerName;
        },
        set: function (value) {
            this._showLoggerName = value;
        },
        enumerable: true,
        configurable: true
    });
    return LogFormat;
}());
exports.LogFormat = LogFormat;
/**
 * Information about the log format, what will a log line look like?
 */
var CategoryLogFormat = (function () {
    /**
     * Create an instance defining the category log format used.
     * @param dateFormat Date format (uses default), for details see DateFormat class.
     * @param showTimeStamp True to show timestamp in the logging, defaults to true.
     * @param showCategoryName True to show category name in the logging, defaults to true.
     */
    function CategoryLogFormat(dateFormat, showTimeStamp, showCategoryName) {
        if (dateFormat === void 0) { dateFormat = new DateFormat(); }
        if (showTimeStamp === void 0) { showTimeStamp = true; }
        if (showCategoryName === void 0) { showCategoryName = true; }
        this._dateFormat = dateFormat;
        this._showTimeStamp = showTimeStamp;
        this._showCategoryName = showCategoryName;
    }
    Object.defineProperty(CategoryLogFormat.prototype, "dateFormat", {
        get: function () {
            return this._dateFormat;
        },
        set: function (value) {
            this._dateFormat = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogFormat.prototype, "showTimeStamp", {
        get: function () {
            return this._showTimeStamp;
        },
        set: function (value) {
            this._showTimeStamp = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogFormat.prototype, "showCategoryName", {
        get: function () {
            return this._showCategoryName;
        },
        set: function (value) {
            this._showCategoryName = value;
        },
        enumerable: true,
        configurable: true
    });
    CategoryLogFormat.prototype.copy = function () {
        return new CategoryLogFormat(this._dateFormat.copy(), this._showTimeStamp, this._showCategoryName);
    };
    return CategoryLogFormat;
}());
exports.CategoryLogFormat = CategoryLogFormat;

});

unwrapExports(LoggerOptions);
var LoggerOptions_1 = LoggerOptions.LogLevel;
var LoggerOptions_2 = LoggerOptions.LoggerType;
var LoggerOptions_3 = LoggerOptions.DateFormatEnum;
var LoggerOptions_4 = LoggerOptions.DateFormat;
var LoggerOptions_5 = LoggerOptions.LogFormat;
var LoggerOptions_6 = LoggerOptions.CategoryLogFormat;

var DataStructures = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
var LinkedNode = (function () {
    function LinkedNode(value) {
        this._previous = null;
        this._next = null;
        this._value = value;
    }
    Object.defineProperty(LinkedNode.prototype, "previous", {
        get: function () {
            return this._previous;
        },
        set: function (value) {
            this._previous = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LinkedNode.prototype, "next", {
        get: function () {
            return this._next;
        },
        set: function (value) {
            this._next = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LinkedNode.prototype, "value", {
        get: function () {
            return this._value;
        },
        enumerable: true,
        configurable: true
    });
    return LinkedNode;
}());
/**
 * Double linkedlist implementation.
 */
var LinkedList = (function () {
    function LinkedList() {
        this.head = null;
        this.size = 0;
    }
    LinkedList.prototype.addHead = function (value) {
        if (!this.createHeadIfNeeded(value)) {
            if (this.head != null) {
                var nextNode = this.head.next;
                var newHeadNode = new LinkedNode(value);
                if (nextNode != null) {
                    nextNode.previous = newHeadNode;
                    newHeadNode.next = nextNode;
                }
                this.head = newHeadNode;
            }
            else {
                throw new Error("This should never happen, list implementation broken");
            }
        }
        this.size++;
    };
    LinkedList.prototype.addTail = function (value) {
        if (!this.createHeadIfNeeded(value)) {
            var oldTailNode = this.getTailNode();
            if (oldTailNode != null) {
                var newTailNode = new LinkedNode(value);
                oldTailNode.next = newTailNode;
                newTailNode.previous = oldTailNode;
            }
            else {
                throw new Error("List implementation broken");
            }
        }
        this.size++;
    };
    LinkedList.prototype.clear = function () {
        this.head = null;
        this.size = 0;
    };
    LinkedList.prototype.getHead = function () {
        if (this.head != null) {
            return this.head.value;
        }
        return null;
    };
    LinkedList.prototype.removeHead = function () {
        if (this.head != null) {
            var oldHead = this.head;
            var value = oldHead.value;
            this.head = oldHead.next;
            this.size--;
            return value;
        }
        return null;
    };
    LinkedList.prototype.getTail = function () {
        var node = this.getTailNode();
        if (node != null) {
            return node.value;
        }
        return null;
    };
    LinkedList.prototype.removeTail = function () {
        var node = this.getTailNode();
        if (node != null) {
            if (node === this.head) {
                this.head = null;
            }
            else {
                var previousNode = node.previous;
                if (previousNode != null) {
                    previousNode.next = null;
                }
                else {
                    throw new Error("List implementation is broken");
                }
            }
            this.size--;
            return node.value;
        }
        return null;
    };
    LinkedList.prototype.getSize = function () {
        return this.size;
    };
    LinkedList.prototype.filter = function (f) {
        var recurse = function (fn, node, values) {
            if (fn(node.value)) {
                values.push(node.value);
            }
            var nextNode = node.next;
            if (nextNode != null) {
                recurse(fn, nextNode, values);
            }
        };
        var result = [];
        var currentNode = this.head;
        if (currentNode != null) {
            recurse(f, currentNode, result);
        }
        return result;
    };
    LinkedList.prototype.createHeadIfNeeded = function (value) {
        if (this.head == null) {
            this.head = new LinkedNode(value);
            return true;
        }
        return false;
    };
    LinkedList.prototype.getTailNode = function () {
        if (this.head == null) {
            return null;
        }
        var node = this.head;
        while (node.next != null) {
            node = node.next;
        }
        return node;
    };
    return LinkedList;
}());
exports.LinkedList = LinkedList;
/**
 * Map implementation keyed by string (always).
 */
var SimpleMap = (function () {
    function SimpleMap() {
        this.array = {};
    }
    SimpleMap.prototype.put = function (key, value) {
        this.array[key] = value;
    };
    SimpleMap.prototype.get = function (key) {
        return this.array[key];
    };
    SimpleMap.prototype.exists = function (key) {
        var value = this.array[key];
        return (typeof value !== "undefined");
    };
    SimpleMap.prototype.remove = function (key) {
        var value = this.array[key];
        if (typeof value !== "undefined") {
            delete this.array[key];
        }
        return value;
    };
    SimpleMap.prototype.keys = function () {
        var keys = [];
        for (var key in this.array) {
            // To prevent random stuff to appear
            if (this.array.hasOwnProperty(key)) {
                keys.push(key);
            }
        }
        return keys;
    };
    SimpleMap.prototype.values = function () {
        var values = [];
        for (var key in this.array) {
            // To prevent random stuff to appear
            if (this.array.hasOwnProperty(key)) {
                values.push(this.get(key));
            }
        }
        return values;
    };
    SimpleMap.prototype.size = function () {
        return this.keys().length;
    };
    SimpleMap.prototype.isEmpty = function () {
        return this.size() === 0;
    };
    SimpleMap.prototype.clear = function () {
        this.array = {};
    };
    SimpleMap.prototype.forEach = function (cbFunction) {
        var count = 0;
        for (var key in this.array) {
            // To prevent random stuff to appear
            if (this.array.hasOwnProperty(key)) {
                var value = this.array[key];
                cbFunction(key, value, count);
                count++;
            }
        }
    };
    SimpleMap.prototype.forEachValue = function (cbFunction) {
        var count = 0;
        for (var key in this.array) {
            // To prevent random stuff to appear
            if (this.array.hasOwnProperty(key)) {
                var value = this.array[key];
                cbFunction(value, count);
                count++;
            }
        }
    };
    return SimpleMap;
}());
exports.SimpleMap = SimpleMap;
/**
 * Tuple to hold two values.
 */
var TuplePair = (function () {
    function TuplePair(x, y) {
        this._x = x;
        this._y = y;
    }
    Object.defineProperty(TuplePair.prototype, "x", {
        get: function () {
            return this._x;
        },
        set: function (value) {
            this._x = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TuplePair.prototype, "y", {
        get: function () {
            return this._y;
        },
        set: function (value) {
            this._y = value;
        },
        enumerable: true,
        configurable: true
    });
    return TuplePair;
}());
exports.TuplePair = TuplePair;
/**
 * Utility class to build up a string.
 */
var StringBuilder = (function () {
    function StringBuilder() {
        this.data = [];
    }
    StringBuilder.prototype.append = function (line) {
        if (line === undefined || line == null) {
            throw new Error("String must be set, cannot append null or undefined");
        }
        this.data.push(line);
        return this;
    };
    StringBuilder.prototype.appendLine = function (line) {
        this.data.push(line + "\n");
        return this;
    };
    StringBuilder.prototype.isEmpty = function () {
        return this.data.length === 0;
    };
    StringBuilder.prototype.clear = function () {
        this.data = [];
    };
    StringBuilder.prototype.toString = function (separator) {
        if (separator === void 0) { separator = ""; }
        return this.data.join(separator);
    };
    return StringBuilder;
}());
exports.StringBuilder = StringBuilder;

});

unwrapExports(DataStructures);
var DataStructures_1 = DataStructures.LinkedList;
var DataStructures_2 = DataStructures.SimpleMap;
var DataStructures_3 = DataStructures.TuplePair;
var DataStructures_4 = DataStructures.StringBuilder;

var stackframe = createCommonjsModule$1(function (module, exports) {
(function (root, factory) {
    if (typeof undefined === 'function' && undefined.amd) {
        undefined('stackframe', [], factory);
    } else {
        module.exports = factory();
    }
}(commonjsGlobal$1, function () {
    function _isNumber(n) {
        return !isNaN(parseFloat(n)) && isFinite(n);
    }

    function StackFrame(functionName, args, fileName, lineNumber, columnNumber, source) {
        if (functionName !== undefined) {
            this.setFunctionName(functionName);
        }
        if (args !== undefined) {
            this.setArgs(args);
        }
        if (fileName !== undefined) {
            this.setFileName(fileName);
        }
        if (lineNumber !== undefined) {
            this.setLineNumber(lineNumber);
        }
        if (columnNumber !== undefined) {
            this.setColumnNumber(columnNumber);
        }
        if (source !== undefined) {
            this.setSource(source);
        }
    }

    StackFrame.prototype = {
        getFunctionName: function () {
            return this.functionName;
        },
        setFunctionName: function (v) {
            this.functionName = String(v);
        },

        getArgs: function () {
            return this.args;
        },
        setArgs: function (v) {
            if (Object.prototype.toString.call(v) !== '[object Array]') {
                throw new TypeError('Args must be an Array');
            }
            this.args = v;
        },

        // NOTE: Property name may be misleading as it includes the path,
        // but it somewhat mirrors V8's JavaScriptStackTraceApi
        // https://code.google.com/p/v8/wiki/JavaScriptStackTraceApi and Gecko's
        // http://mxr.mozilla.org/mozilla-central/source/xpcom/base/nsIException.idl#14
        getFileName: function () {
            return this.fileName;
        },
        setFileName: function (v) {
            this.fileName = String(v);
        },

        getLineNumber: function () {
            return this.lineNumber;
        },
        setLineNumber: function (v) {
            if (!_isNumber(v)) {
                throw new TypeError('Line Number must be a Number');
            }
            this.lineNumber = Number(v);
        },

        getColumnNumber: function () {
            return this.columnNumber;
        },
        setColumnNumber: function (v) {
            if (!_isNumber(v)) {
                throw new TypeError('Column Number must be a Number');
            }
            this.columnNumber = Number(v);
        },

        getSource: function () {
            return this.source;
        },
        setSource: function (v) {
            this.source = String(v);
        },

        toString: function() {
            var functionName = this.getFunctionName() || '{anonymous}';
            var args = '(' + (this.getArgs() || []).join(',') + ')';
            var fileName = this.getFileName() ? ('@' + this.getFileName()) : '';
            var lineNumber = _isNumber(this.getLineNumber()) ? (':' + this.getLineNumber()) : '';
            var columnNumber = _isNumber(this.getColumnNumber()) ? (':' + this.getColumnNumber()) : '';
            return functionName + args + fileName + lineNumber + columnNumber;
        }
    };

    return StackFrame;
}));
});

var errorStackParser = createCommonjsModule$1(function (module, exports) {
(function(root, factory) {
    if (typeof undefined === 'function' && undefined.amd) {
        undefined('error-stack-parser', ['stackframe'], factory);
    } else {
        module.exports = factory(stackframe);
    }
}(commonjsGlobal$1, function ErrorStackParser(StackFrame) {
    var FIREFOX_SAFARI_STACK_REGEXP = /(^|@)\S+\:\d+/;
    var CHROME_IE_STACK_REGEXP = /^\s*at .*(\S+\:\d+|\(native\))/m;
    var SAFARI_NATIVE_CODE_REGEXP = /^(eval@)?(\[native code\])?$/;

    function _map(array, fn, thisArg) {
        if (typeof Array.prototype.map === 'function') {
            return array.map(fn, thisArg);
        } else {
            var output = new Array(array.length);
            for (var i = 0; i < array.length; i++) {
                output[i] = fn.call(thisArg, array[i]);
            }
            return output;
        }
    }

    function _filter(array, fn, thisArg) {
        if (typeof Array.prototype.filter === 'function') {
            return array.filter(fn, thisArg);
        } else {
            var output = [];
            for (var i = 0; i < array.length; i++) {
                if (fn.call(thisArg, array[i])) {
                    output.push(array[i]);
                }
            }
            return output;
        }
    }

    function _indexOf(array, target) {
        if (typeof Array.prototype.indexOf === 'function') {
            return array.indexOf(target);
        } else {
            for (var i = 0; i < array.length; i++) {
                if (array[i] === target) {
                    return i;
                }
            }
            return -1;
        }
    }

    return {
        /**
         * Given an Error object, extract the most information from it.
         *
         * @param {Error} error object
         * @return {Array} of StackFrames
         */
        parse: function ErrorStackParser$$parse(error) {
            if (typeof error.stacktrace !== 'undefined' || typeof error['opera#sourceloc'] !== 'undefined') {
                return this.parseOpera(error);
            } else if (error.stack && error.stack.match(CHROME_IE_STACK_REGEXP)) {
                return this.parseV8OrIE(error);
            } else if (error.stack) {
                return this.parseFFOrSafari(error);
            } else {
                throw new Error('Cannot parse given Error object');
            }
        },

        // Separate line and column numbers from a string of the form: (URI:Line:Column)
        extractLocation: function ErrorStackParser$$extractLocation(urlLike) {
            // Fail-fast but return locations like "(native)"
            if (urlLike.indexOf(':') === -1) {
                return [urlLike];
            }

            var regExp = /(.+?)(?:\:(\d+))?(?:\:(\d+))?$/;
            var parts = regExp.exec(urlLike.replace(/[\(\)]/g, ''));
            return [parts[1], parts[2] || undefined, parts[3] || undefined];
        },

        parseV8OrIE: function ErrorStackParser$$parseV8OrIE(error) {
            var filtered = _filter(error.stack.split('\n'), function(line) {
                return !!line.match(CHROME_IE_STACK_REGEXP);
            }, this);

            return _map(filtered, function(line) {
                if (line.indexOf('(eval ') > -1) {
                    // Throw away eval information until we implement stacktrace.js/stackframe#8
                    line = line.replace(/eval code/g, 'eval').replace(/(\(eval at [^\()]*)|(\)\,.*$)/g, '');
                }
                var tokens = line.replace(/^\s+/, '').replace(/\(eval code/g, '(').split(/\s+/).slice(1);
                var locationParts = this.extractLocation(tokens.pop());
                var functionName = tokens.join(' ') || undefined;
                var fileName = _indexOf(['eval', '<anonymous>'], locationParts[0]) > -1 ? undefined : locationParts[0];

                return new StackFrame(functionName, undefined, fileName, locationParts[1], locationParts[2], line);
            }, this);
        },

        parseFFOrSafari: function ErrorStackParser$$parseFFOrSafari(error) {
            var filtered = _filter(error.stack.split('\n'), function(line) {
                return !line.match(SAFARI_NATIVE_CODE_REGEXP);
            }, this);

            return _map(filtered, function(line) {
                // Throw away eval information until we implement stacktrace.js/stackframe#8
                if (line.indexOf(' > eval') > -1) {
                    line = line.replace(/ line (\d+)(?: > eval line \d+)* > eval\:\d+\:\d+/g, ':$1');
                }

                if (line.indexOf('@') === -1 && line.indexOf(':') === -1) {
                    // Safari eval frames only have function names and nothing else
                    return new StackFrame(line);
                } else {
                    var tokens = line.split('@');
                    var locationParts = this.extractLocation(tokens.pop());
                    var functionName = tokens.join('@') || undefined;
                    return new StackFrame(functionName,
                        undefined,
                        locationParts[0],
                        locationParts[1],
                        locationParts[2],
                        line);
                }
            }, this);
        },

        parseOpera: function ErrorStackParser$$parseOpera(e) {
            if (!e.stacktrace || (e.message.indexOf('\n') > -1 &&
                e.message.split('\n').length > e.stacktrace.split('\n').length)) {
                return this.parseOpera9(e);
            } else if (!e.stack) {
                return this.parseOpera10(e);
            } else {
                return this.parseOpera11(e);
            }
        },

        parseOpera9: function ErrorStackParser$$parseOpera9(e) {
            var lineRE = /Line (\d+).*script (?:in )?(\S+)/i;
            var lines = e.message.split('\n');
            var result = [];

            for (var i = 2, len = lines.length; i < len; i += 2) {
                var match = lineRE.exec(lines[i]);
                if (match) {
                    result.push(new StackFrame(undefined, undefined, match[2], match[1], undefined, lines[i]));
                }
            }

            return result;
        },

        parseOpera10: function ErrorStackParser$$parseOpera10(e) {
            var lineRE = /Line (\d+).*script (?:in )?(\S+)(?:: In function (\S+))?$/i;
            var lines = e.stacktrace.split('\n');
            var result = [];

            for (var i = 0, len = lines.length; i < len; i += 2) {
                var match = lineRE.exec(lines[i]);
                if (match) {
                    result.push(
                        new StackFrame(
                            match[3] || undefined,
                            undefined,
                            match[2],
                            match[1],
                            undefined,
                            lines[i]
                        )
                    );
                }
            }

            return result;
        },

        // Opera 10.65+ Error.stack very similar to FF/Safari
        parseOpera11: function ErrorStackParser$$parseOpera11(error) {
            var filtered = _filter(error.stack.split('\n'), function(line) {
                return !!line.match(FIREFOX_SAFARI_STACK_REGEXP) && !line.match(/^Error created at/);
            }, this);

            return _map(filtered, function(line) {
                var tokens = line.split('@');
                var locationParts = this.extractLocation(tokens.pop());
                var functionCall = (tokens.shift() || '');
                var functionName = functionCall
                        .replace(/<anonymous function(: (\w+))?>/, '$2')
                        .replace(/\([^\)]*\)/g, '') || undefined;
                var argsRaw;
                if (functionCall.match(/\(([^\)]*)\)/)) {
                    argsRaw = functionCall.replace(/^[^\(]+\(([^\)]*)\)$/, '$1');
                }
                var args = (argsRaw === undefined || argsRaw === '[arguments not available]') ?
                    undefined : argsRaw.split(',');
                return new StackFrame(
                    functionName,
                    args,
                    locationParts[0],
                    locationParts[1],
                    locationParts[2],
                    line);
            }, this);
        }
    };
}));
});

var stackframe$2 = createCommonjsModule$1(function (module, exports) {
(function(root, factory) {
    if (typeof undefined === 'function' && undefined.amd) {
        undefined('stackframe', [], factory);
    } else {
        module.exports = factory();
    }
}(commonjsGlobal$1, function() {
    function _isNumber(n) {
        return !isNaN(parseFloat(n)) && isFinite(n);
    }

    function _capitalize(str) {
        return str.charAt(0).toUpperCase() + str.substring(1);
    }

    function _getter(p) {
        return function() {
            return this[p];
        };
    }

    var booleanProps = ['isConstructor', 'isEval', 'isNative', 'isToplevel'];
    var numericProps = ['columnNumber', 'lineNumber'];
    var stringProps = ['fileName', 'functionName', 'source'];
    var arrayProps = ['args'];

    var props = booleanProps.concat(numericProps, stringProps, arrayProps);

    function StackFrame(obj) {
        if (obj instanceof Object) {
            for (var i = 0; i < props.length; i++) {
                if (obj.hasOwnProperty(props[i]) && obj[props[i]] !== undefined) {
                    this['set' + _capitalize(props[i])](obj[props[i]]);
                }
            }
        }
    }

    StackFrame.prototype = {
        getArgs: function() {
            return this.args;
        },
        setArgs: function(v) {
            if (Object.prototype.toString.call(v) !== '[object Array]') {
                throw new TypeError('Args must be an Array');
            }
            this.args = v;
        },

        getEvalOrigin: function() {
            return this.evalOrigin;
        },
        setEvalOrigin: function(v) {
            if (v instanceof StackFrame) {
                this.evalOrigin = v;
            } else if (v instanceof Object) {
                this.evalOrigin = new StackFrame(v);
            } else {
                throw new TypeError('Eval Origin must be an Object or StackFrame');
            }
        },

        toString: function() {
            var functionName = this.getFunctionName() || '{anonymous}';
            var args = '(' + (this.getArgs() || []).join(',') + ')';
            var fileName = this.getFileName() ? ('@' + this.getFileName()) : '';
            var lineNumber = _isNumber(this.getLineNumber()) ? (':' + this.getLineNumber()) : '';
            var columnNumber = _isNumber(this.getColumnNumber()) ? (':' + this.getColumnNumber()) : '';
            return functionName + args + fileName + lineNumber + columnNumber;
        }
    };

    for (var i = 0; i < booleanProps.length; i++) {
        StackFrame.prototype['get' + _capitalize(booleanProps[i])] = _getter(booleanProps[i]);
        StackFrame.prototype['set' + _capitalize(booleanProps[i])] = (function(p) {
            return function(v) {
                this[p] = Boolean(v);
            };
        })(booleanProps[i]);
    }

    for (var j = 0; j < numericProps.length; j++) {
        StackFrame.prototype['get' + _capitalize(numericProps[j])] = _getter(numericProps[j]);
        StackFrame.prototype['set' + _capitalize(numericProps[j])] = (function(p) {
            return function(v) {
                if (!_isNumber(v)) {
                    throw new TypeError(p + ' must be a Number');
                }
                this[p] = Number(v);
            };
        })(numericProps[j]);
    }

    for (var k = 0; k < stringProps.length; k++) {
        StackFrame.prototype['get' + _capitalize(stringProps[k])] = _getter(stringProps[k]);
        StackFrame.prototype['set' + _capitalize(stringProps[k])] = (function(p) {
            return function(v) {
                this[p] = String(v);
            };
        })(stringProps[k]);
    }

    return StackFrame;
}));
});

var stackGenerator = createCommonjsModule$1(function (module, exports) {
(function (root, factory) {
    if (typeof undefined === 'function' && undefined.amd) {
        undefined('stack-generator', ['stackframe'], factory);
    } else {
        module.exports = factory(stackframe$2);
    }
}(commonjsGlobal$1, function (StackFrame) {
    return {
        backtrace: function StackGenerator$$backtrace(opts) {
            var stack = [];
            var maxStackSize = 10;

            if (typeof opts === 'object' && typeof opts.maxStackSize === 'number') {
                maxStackSize = opts.maxStackSize;
            }

            var curr = arguments.callee;
            while (curr && stack.length < maxStackSize) {
                // Allow V8 optimizations
                var args = new Array(curr['arguments'].length);
                for(var i = 0; i < args.length; ++i) {
                    args[i] = curr['arguments'][i];
                }
                if (/function(?:\s+([\w$]+))+\s*\(/.test(curr.toString())) {
                    stack.push(new StackFrame({functionName: RegExp.$1 || undefined, args: args}));
                } else {
                    stack.push(new StackFrame({args: args}));
                }

                try {
                    curr = curr.caller;
                } catch (e) {
                    break;
                }
            }
            return stack;
        }
    };
}));
});

var util = createCommonjsModule$1(function (module, exports) {
/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 */

/**
 * This is a helper function for getting values from parameter/options
 * objects.
 *
 * @param args The object we are extracting values from
 * @param name The name of the property we are getting.
 * @param defaultValue An optional value to return if the property is missing
 * from the object. If this is not specified and the property is missing, an
 * error will be thrown.
 */
function getArg(aArgs, aName, aDefaultValue) {
  if (aName in aArgs) {
    return aArgs[aName];
  } else if (arguments.length === 3) {
    return aDefaultValue;
  } else {
    throw new Error('"' + aName + '" is a required argument.');
  }
}
exports.getArg = getArg;

var urlRegexp = /^(?:([\w+\-.]+):)?\/\/(?:(\w+:\w+)@)?([\w.]*)(?::(\d+))?(\S*)$/;
var dataUrlRegexp = /^data:.+\,.+$/;

function urlParse(aUrl) {
  var match = aUrl.match(urlRegexp);
  if (!match) {
    return null;
  }
  return {
    scheme: match[1],
    auth: match[2],
    host: match[3],
    port: match[4],
    path: match[5]
  };
}
exports.urlParse = urlParse;

function urlGenerate(aParsedUrl) {
  var url = '';
  if (aParsedUrl.scheme) {
    url += aParsedUrl.scheme + ':';
  }
  url += '//';
  if (aParsedUrl.auth) {
    url += aParsedUrl.auth + '@';
  }
  if (aParsedUrl.host) {
    url += aParsedUrl.host;
  }
  if (aParsedUrl.port) {
    url += ":" + aParsedUrl.port;
  }
  if (aParsedUrl.path) {
    url += aParsedUrl.path;
  }
  return url;
}
exports.urlGenerate = urlGenerate;

/**
 * Normalizes a path, or the path portion of a URL:
 *
 * - Replaces consecutive slashes with one slash.
 * - Removes unnecessary '.' parts.
 * - Removes unnecessary '<dir>/..' parts.
 *
 * Based on code in the Node.js 'path' core module.
 *
 * @param aPath The path or url to normalize.
 */
function normalize(aPath) {
  var path = aPath;
  var url = urlParse(aPath);
  if (url) {
    if (!url.path) {
      return aPath;
    }
    path = url.path;
  }
  var isAbsolute = exports.isAbsolute(path);

  var parts = path.split(/\/+/);
  for (var part, up = 0, i = parts.length - 1; i >= 0; i--) {
    part = parts[i];
    if (part === '.') {
      parts.splice(i, 1);
    } else if (part === '..') {
      up++;
    } else if (up > 0) {
      if (part === '') {
        // The first part is blank if the path is absolute. Trying to go
        // above the root is a no-op. Therefore we can remove all '..' parts
        // directly after the root.
        parts.splice(i + 1, up);
        up = 0;
      } else {
        parts.splice(i, 2);
        up--;
      }
    }
  }
  path = parts.join('/');

  if (path === '') {
    path = isAbsolute ? '/' : '.';
  }

  if (url) {
    url.path = path;
    return urlGenerate(url);
  }
  return path;
}
exports.normalize = normalize;

/**
 * Joins two paths/URLs.
 *
 * @param aRoot The root path or URL.
 * @param aPath The path or URL to be joined with the root.
 *
 * - If aPath is a URL or a data URI, aPath is returned, unless aPath is a
 *   scheme-relative URL: Then the scheme of aRoot, if any, is prepended
 *   first.
 * - Otherwise aPath is a path. If aRoot is a URL, then its path portion
 *   is updated with the result and aRoot is returned. Otherwise the result
 *   is returned.
 *   - If aPath is absolute, the result is aPath.
 *   - Otherwise the two paths are joined with a slash.
 * - Joining for example 'http://' and 'www.example.com' is also supported.
 */
function join(aRoot, aPath) {
  if (aRoot === "") {
    aRoot = ".";
  }
  if (aPath === "") {
    aPath = ".";
  }
  var aPathUrl = urlParse(aPath);
  var aRootUrl = urlParse(aRoot);
  if (aRootUrl) {
    aRoot = aRootUrl.path || '/';
  }

  // `join(foo, '//www.example.org')`
  if (aPathUrl && !aPathUrl.scheme) {
    if (aRootUrl) {
      aPathUrl.scheme = aRootUrl.scheme;
    }
    return urlGenerate(aPathUrl);
  }

  if (aPathUrl || aPath.match(dataUrlRegexp)) {
    return aPath;
  }

  // `join('http://', 'www.example.com')`
  if (aRootUrl && !aRootUrl.host && !aRootUrl.path) {
    aRootUrl.host = aPath;
    return urlGenerate(aRootUrl);
  }

  var joined = aPath.charAt(0) === '/'
    ? aPath
    : normalize(aRoot.replace(/\/+$/, '') + '/' + aPath);

  if (aRootUrl) {
    aRootUrl.path = joined;
    return urlGenerate(aRootUrl);
  }
  return joined;
}
exports.join = join;

exports.isAbsolute = function (aPath) {
  return aPath.charAt(0) === '/' || !!aPath.match(urlRegexp);
};

/**
 * Make a path relative to a URL or another path.
 *
 * @param aRoot The root path or URL.
 * @param aPath The path or URL to be made relative to aRoot.
 */
function relative(aRoot, aPath) {
  if (aRoot === "") {
    aRoot = ".";
  }

  aRoot = aRoot.replace(/\/$/, '');

  // It is possible for the path to be above the root. In this case, simply
  // checking whether the root is a prefix of the path won't work. Instead, we
  // need to remove components from the root one by one, until either we find
  // a prefix that fits, or we run out of components to remove.
  var level = 0;
  while (aPath.indexOf(aRoot + '/') !== 0) {
    var index = aRoot.lastIndexOf("/");
    if (index < 0) {
      return aPath;
    }

    // If the only part of the root that is left is the scheme (i.e. http://,
    // file:///, etc.), one or more slashes (/), or simply nothing at all, we
    // have exhausted all components, so the path is not relative to the root.
    aRoot = aRoot.slice(0, index);
    if (aRoot.match(/^([^\/]+:\/)?\/*$/)) {
      return aPath;
    }

    ++level;
  }

  // Make sure we add a "../" for each component we removed from the root.
  return Array(level + 1).join("../") + aPath.substr(aRoot.length + 1);
}
exports.relative = relative;

var supportsNullProto = (function () {
  var obj = Object.create(null);
  return !('__proto__' in obj);
}());

function identity (s) {
  return s;
}

/**
 * Because behavior goes wacky when you set `__proto__` on objects, we
 * have to prefix all the strings in our set with an arbitrary character.
 *
 * See https://github.com/mozilla/source-map/pull/31 and
 * https://github.com/mozilla/source-map/issues/30
 *
 * @param String aStr
 */
function toSetString(aStr) {
  if (isProtoString(aStr)) {
    return '$' + aStr;
  }

  return aStr;
}
exports.toSetString = supportsNullProto ? identity : toSetString;

function fromSetString(aStr) {
  if (isProtoString(aStr)) {
    return aStr.slice(1);
  }

  return aStr;
}
exports.fromSetString = supportsNullProto ? identity : fromSetString;

function isProtoString(s) {
  if (!s) {
    return false;
  }

  var length = s.length;

  if (length < 9 /* "__proto__".length */) {
    return false;
  }

  if (s.charCodeAt(length - 1) !== 95  /* '_' */ ||
      s.charCodeAt(length - 2) !== 95  /* '_' */ ||
      s.charCodeAt(length - 3) !== 111 /* 'o' */ ||
      s.charCodeAt(length - 4) !== 116 /* 't' */ ||
      s.charCodeAt(length - 5) !== 111 /* 'o' */ ||
      s.charCodeAt(length - 6) !== 114 /* 'r' */ ||
      s.charCodeAt(length - 7) !== 112 /* 'p' */ ||
      s.charCodeAt(length - 8) !== 95  /* '_' */ ||
      s.charCodeAt(length - 9) !== 95  /* '_' */) {
    return false;
  }

  for (var i = length - 10; i >= 0; i--) {
    if (s.charCodeAt(i) !== 36 /* '$' */) {
      return false;
    }
  }

  return true;
}

/**
 * Comparator between two mappings where the original positions are compared.
 *
 * Optionally pass in `true` as `onlyCompareGenerated` to consider two
 * mappings with the same original source/line/column, but different generated
 * line and column the same. Useful when searching for a mapping with a
 * stubbed out mapping.
 */
function compareByOriginalPositions(mappingA, mappingB, onlyCompareOriginal) {
  var cmp = mappingA.source - mappingB.source;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.originalLine - mappingB.originalLine;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.originalColumn - mappingB.originalColumn;
  if (cmp !== 0 || onlyCompareOriginal) {
    return cmp;
  }

  cmp = mappingA.generatedColumn - mappingB.generatedColumn;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.generatedLine - mappingB.generatedLine;
  if (cmp !== 0) {
    return cmp;
  }

  return mappingA.name - mappingB.name;
}
exports.compareByOriginalPositions = compareByOriginalPositions;

/**
 * Comparator between two mappings with deflated source and name indices where
 * the generated positions are compared.
 *
 * Optionally pass in `true` as `onlyCompareGenerated` to consider two
 * mappings with the same generated line and column, but different
 * source/name/original line and column the same. Useful when searching for a
 * mapping with a stubbed out mapping.
 */
function compareByGeneratedPositionsDeflated(mappingA, mappingB, onlyCompareGenerated) {
  var cmp = mappingA.generatedLine - mappingB.generatedLine;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.generatedColumn - mappingB.generatedColumn;
  if (cmp !== 0 || onlyCompareGenerated) {
    return cmp;
  }

  cmp = mappingA.source - mappingB.source;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.originalLine - mappingB.originalLine;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.originalColumn - mappingB.originalColumn;
  if (cmp !== 0) {
    return cmp;
  }

  return mappingA.name - mappingB.name;
}
exports.compareByGeneratedPositionsDeflated = compareByGeneratedPositionsDeflated;

function strcmp(aStr1, aStr2) {
  if (aStr1 === aStr2) {
    return 0;
  }

  if (aStr1 > aStr2) {
    return 1;
  }

  return -1;
}

/**
 * Comparator between two mappings with inflated source and name strings where
 * the generated positions are compared.
 */
function compareByGeneratedPositionsInflated(mappingA, mappingB) {
  var cmp = mappingA.generatedLine - mappingB.generatedLine;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.generatedColumn - mappingB.generatedColumn;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = strcmp(mappingA.source, mappingB.source);
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.originalLine - mappingB.originalLine;
  if (cmp !== 0) {
    return cmp;
  }

  cmp = mappingA.originalColumn - mappingB.originalColumn;
  if (cmp !== 0) {
    return cmp;
  }

  return strcmp(mappingA.name, mappingB.name);
}
exports.compareByGeneratedPositionsInflated = compareByGeneratedPositionsInflated;
});

var util_1 = util.getArg;
var util_2 = util.urlParse;
var util_3 = util.urlGenerate;
var util_4 = util.normalize;
var util_5 = util.join;
var util_6 = util.isAbsolute;
var util_7 = util.relative;
var util_8 = util.toSetString;
var util_9 = util.fromSetString;
var util_10 = util.compareByOriginalPositions;
var util_11 = util.compareByGeneratedPositionsDeflated;
var util_12 = util.compareByGeneratedPositionsInflated;

var binarySearch = createCommonjsModule$1(function (module, exports) {
/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 */

exports.GREATEST_LOWER_BOUND = 1;
exports.LEAST_UPPER_BOUND = 2;

/**
 * Recursive implementation of binary search.
 *
 * @param aLow Indices here and lower do not contain the needle.
 * @param aHigh Indices here and higher do not contain the needle.
 * @param aNeedle The element being searched for.
 * @param aHaystack The non-empty array being searched.
 * @param aCompare Function which takes two elements and returns -1, 0, or 1.
 * @param aBias Either 'binarySearch.GREATEST_LOWER_BOUND' or
 *     'binarySearch.LEAST_UPPER_BOUND'. Specifies whether to return the
 *     closest element that is smaller than or greater than the one we are
 *     searching for, respectively, if the exact element cannot be found.
 */
function recursiveSearch(aLow, aHigh, aNeedle, aHaystack, aCompare, aBias) {
  // This function terminates when one of the following is true:
  //
  //   1. We find the exact element we are looking for.
  //
  //   2. We did not find the exact element, but we can return the index of
  //      the next-closest element.
  //
  //   3. We did not find the exact element, and there is no next-closest
  //      element than the one we are searching for, so we return -1.
  var mid = Math.floor((aHigh - aLow) / 2) + aLow;
  var cmp = aCompare(aNeedle, aHaystack[mid], true);
  if (cmp === 0) {
    // Found the element we are looking for.
    return mid;
  }
  else if (cmp > 0) {
    // Our needle is greater than aHaystack[mid].
    if (aHigh - mid > 1) {
      // The element is in the upper half.
      return recursiveSearch(mid, aHigh, aNeedle, aHaystack, aCompare, aBias);
    }

    // The exact needle element was not found in this haystack. Determine if
    // we are in termination case (3) or (2) and return the appropriate thing.
    if (aBias == exports.LEAST_UPPER_BOUND) {
      return aHigh < aHaystack.length ? aHigh : -1;
    } else {
      return mid;
    }
  }
  else {
    // Our needle is less than aHaystack[mid].
    if (mid - aLow > 1) {
      // The element is in the lower half.
      return recursiveSearch(aLow, mid, aNeedle, aHaystack, aCompare, aBias);
    }

    // we are in termination case (3) or (2) and return the appropriate thing.
    if (aBias == exports.LEAST_UPPER_BOUND) {
      return mid;
    } else {
      return aLow < 0 ? -1 : aLow;
    }
  }
}

/**
 * This is an implementation of binary search which will always try and return
 * the index of the closest element if there is no exact hit. This is because
 * mappings between original and generated line/col pairs are single points,
 * and there is an implicit region between each of them, so a miss just means
 * that you aren't on the very start of a region.
 *
 * @param aNeedle The element you are looking for.
 * @param aHaystack The array that is being searched.
 * @param aCompare A function which takes the needle and an element in the
 *     array and returns -1, 0, or 1 depending on whether the needle is less
 *     than, equal to, or greater than the element, respectively.
 * @param aBias Either 'binarySearch.GREATEST_LOWER_BOUND' or
 *     'binarySearch.LEAST_UPPER_BOUND'. Specifies whether to return the
 *     closest element that is smaller than or greater than the one we are
 *     searching for, respectively, if the exact element cannot be found.
 *     Defaults to 'binarySearch.GREATEST_LOWER_BOUND'.
 */
exports.search = function search(aNeedle, aHaystack, aCompare, aBias) {
  if (aHaystack.length === 0) {
    return -1;
  }

  var index = recursiveSearch(-1, aHaystack.length, aNeedle, aHaystack,
                              aCompare, aBias || exports.GREATEST_LOWER_BOUND);
  if (index < 0) {
    return -1;
  }

  // We have found either the exact element, or the next-closest element than
  // the one we are searching for. However, there may be more than one such
  // element. Make sure we always return the smallest of these.
  while (index - 1 >= 0) {
    if (aCompare(aHaystack[index], aHaystack[index - 1], true) !== 0) {
      break;
    }
    --index;
  }

  return index;
};
});

var binarySearch_1 = binarySearch.GREATEST_LOWER_BOUND;
var binarySearch_2 = binarySearch.LEAST_UPPER_BOUND;
var binarySearch_3 = binarySearch.search;

/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 */


var has = Object.prototype.hasOwnProperty;

/**
 * A data structure which is a combination of an array and a set. Adding a new
 * member is O(1), testing for membership is O(1), and finding the index of an
 * element is O(1). Removing elements from the set is not supported. Only
 * strings are supported for membership.
 */
function ArraySet() {
  this._array = [];
  this._set = Object.create(null);
}

/**
 * Static method for creating ArraySet instances from an existing array.
 */
ArraySet.fromArray = function ArraySet_fromArray(aArray, aAllowDuplicates) {
  var set = new ArraySet();
  for (var i = 0, len = aArray.length; i < len; i++) {
    set.add(aArray[i], aAllowDuplicates);
  }
  return set;
};

/**
 * Return how many unique items are in this ArraySet. If duplicates have been
 * added, than those do not count towards the size.
 *
 * @returns Number
 */
ArraySet.prototype.size = function ArraySet_size() {
  return Object.getOwnPropertyNames(this._set).length;
};

/**
 * Add the given string to this set.
 *
 * @param String aStr
 */
ArraySet.prototype.add = function ArraySet_add(aStr, aAllowDuplicates) {
  var sStr = util.toSetString(aStr);
  var isDuplicate = has.call(this._set, sStr);
  var idx = this._array.length;
  if (!isDuplicate || aAllowDuplicates) {
    this._array.push(aStr);
  }
  if (!isDuplicate) {
    this._set[sStr] = idx;
  }
};

/**
 * Is the given string a member of this set?
 *
 * @param String aStr
 */
ArraySet.prototype.has = function ArraySet_has(aStr) {
  var sStr = util.toSetString(aStr);
  return has.call(this._set, sStr);
};

/**
 * What is the index of the given string in the array?
 *
 * @param String aStr
 */
ArraySet.prototype.indexOf = function ArraySet_indexOf(aStr) {
  var sStr = util.toSetString(aStr);
  if (has.call(this._set, sStr)) {
    return this._set[sStr];
  }
  throw new Error('"' + aStr + '" is not in the set.');
};

/**
 * What is the element at the given index?
 *
 * @param Number aIdx
 */
ArraySet.prototype.at = function ArraySet_at(aIdx) {
  if (aIdx >= 0 && aIdx < this._array.length) {
    return this._array[aIdx];
  }
  throw new Error('No element indexed by ' + aIdx);
};

/**
 * Returns the array representation of this set (which has the proper indices
 * indicated by indexOf). Note that this is a copy of the internal array used
 * for storing the members so that no one can mess with internal state.
 */
ArraySet.prototype.toArray = function ArraySet_toArray() {
  return this._array.slice();
};

var ArraySet_1 = ArraySet;

var arraySet = {
	ArraySet: ArraySet_1
};

/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 */

var intToCharMap = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.split('');

/**
 * Encode an integer in the range of 0 to 63 to a single base 64 digit.
 */
var encode = function (number) {
  if (0 <= number && number < intToCharMap.length) {
    return intToCharMap[number];
  }
  throw new TypeError("Must be between 0 and 63: " + number);
};

/**
 * Decode a single base 64 character code digit to an integer. Returns -1 on
 * failure.
 */
var decode = function (charCode) {
  var bigA = 65;     // 'A'
  var bigZ = 90;     // 'Z'

  var littleA = 97;  // 'a'
  var littleZ = 122; // 'z'

  var zero = 48;     // '0'
  var nine = 57;     // '9'

  var plus = 43;     // '+'
  var slash = 47;    // '/'

  var littleOffset = 26;
  var numberOffset = 52;

  // 0 - 25: ABCDEFGHIJKLMNOPQRSTUVWXYZ
  if (bigA <= charCode && charCode <= bigZ) {
    return (charCode - bigA);
  }

  // 26 - 51: abcdefghijklmnopqrstuvwxyz
  if (littleA <= charCode && charCode <= littleZ) {
    return (charCode - littleA + littleOffset);
  }

  // 52 - 61: 0123456789
  if (zero <= charCode && charCode <= nine) {
    return (charCode - zero + numberOffset);
  }

  // 62: +
  if (charCode == plus) {
    return 62;
  }

  // 63: /
  if (charCode == slash) {
    return 63;
  }

  // Invalid base64 digit.
  return -1;
};

var base64 = {
	encode: encode,
	decode: decode
};

/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 *
 * Based on the Base 64 VLQ implementation in Closure Compiler:
 * https://code.google.com/p/closure-compiler/source/browse/trunk/src/com/google/debugging/sourcemap/Base64VLQ.java
 *
 * Copyright 2011 The Closure Compiler Authors. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 *  * Neither the name of Google Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */



// A single base 64 digit can contain 6 bits of data. For the base 64 variable
// length quantities we use in the source map spec, the first bit is the sign,
// the next four bits are the actual value, and the 6th bit is the
// continuation bit. The continuation bit tells us whether there are more
// digits in this value following this digit.
//
//   Continuation
//   |    Sign
//   |    |
//   V    V
//   101011

var VLQ_BASE_SHIFT = 5;

// binary: 100000
var VLQ_BASE = 1 << VLQ_BASE_SHIFT;

// binary: 011111
var VLQ_BASE_MASK = VLQ_BASE - 1;

// binary: 100000
var VLQ_CONTINUATION_BIT = VLQ_BASE;

/**
 * Converts from a two-complement value to a value where the sign bit is
 * placed in the least significant bit.  For example, as decimals:
 *   1 becomes 2 (10 binary), -1 becomes 3 (11 binary)
 *   2 becomes 4 (100 binary), -2 becomes 5 (101 binary)
 */
function toVLQSigned(aValue) {
  return aValue < 0
    ? ((-aValue) << 1) + 1
    : (aValue << 1) + 0;
}

/**
 * Converts to a two-complement value from a value where the sign bit is
 * placed in the least significant bit.  For example, as decimals:
 *   2 (10 binary) becomes 1, 3 (11 binary) becomes -1
 *   4 (100 binary) becomes 2, 5 (101 binary) becomes -2
 */
function fromVLQSigned(aValue) {
  var isNegative = (aValue & 1) === 1;
  var shifted = aValue >> 1;
  return isNegative
    ? -shifted
    : shifted;
}

/**
 * Returns the base 64 VLQ encoded value.
 */
var encode$1 = function base64VLQ_encode(aValue) {
  var encoded = "";
  var digit;

  var vlq = toVLQSigned(aValue);

  do {
    digit = vlq & VLQ_BASE_MASK;
    vlq >>>= VLQ_BASE_SHIFT;
    if (vlq > 0) {
      // There are still more digits in this value, so we must make sure the
      // continuation bit is marked.
      digit |= VLQ_CONTINUATION_BIT;
    }
    encoded += base64.encode(digit);
  } while (vlq > 0);

  return encoded;
};

/**
 * Decodes the next base 64 VLQ value from the given string and returns the
 * value and the rest of the string via the out parameter.
 */
var decode$1 = function base64VLQ_decode(aStr, aIndex, aOutParam) {
  var strLen = aStr.length;
  var result = 0;
  var shift = 0;
  var continuation, digit;

  do {
    if (aIndex >= strLen) {
      throw new Error("Expected more digits in base 64 VLQ value.");
    }

    digit = base64.decode(aStr.charCodeAt(aIndex++));
    if (digit === -1) {
      throw new Error("Invalid base64 digit: " + aStr.charAt(aIndex - 1));
    }

    continuation = !!(digit & VLQ_CONTINUATION_BIT);
    digit &= VLQ_BASE_MASK;
    result = result + (digit << shift);
    shift += VLQ_BASE_SHIFT;
  } while (continuation);

  aOutParam.value = fromVLQSigned(result);
  aOutParam.rest = aIndex;
};

var base64Vlq = {
	encode: encode$1,
	decode: decode$1
};

/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 */

// It turns out that some (most?) JavaScript engines don't self-host
// `Array.prototype.sort`. This makes sense because C++ will likely remain
// faster than JS when doing raw CPU-intensive sorting. However, when using a
// custom comparator function, calling back and forth between the VM's C++ and
// JIT'd JS is rather slow *and* loses JIT type information, resulting in
// worse generated code for the comparator function than would be optimal. In
// fact, when sorting with a comparator, these costs outweigh the benefits of
// sorting in C++. By using our own JS-implemented Quick Sort (below), we get
// a ~3500ms mean speed-up in `bench/bench.html`.

/**
 * Swap the elements indexed by `x` and `y` in the array `ary`.
 *
 * @param {Array} ary
 *        The array.
 * @param {Number} x
 *        The index of the first item.
 * @param {Number} y
 *        The index of the second item.
 */
function swap(ary, x, y) {
  var temp = ary[x];
  ary[x] = ary[y];
  ary[y] = temp;
}

/**
 * Returns a random integer within the range `low .. high` inclusive.
 *
 * @param {Number} low
 *        The lower bound on the range.
 * @param {Number} high
 *        The upper bound on the range.
 */
function randomIntInRange(low, high) {
  return Math.round(low + (Math.random() * (high - low)));
}

/**
 * The Quick Sort algorithm.
 *
 * @param {Array} ary
 *        An array to sort.
 * @param {function} comparator
 *        Function to use to compare two items.
 * @param {Number} p
 *        Start index of the array
 * @param {Number} r
 *        End index of the array
 */
function doQuickSort(ary, comparator, p, r) {
  // If our lower bound is less than our upper bound, we (1) partition the
  // array into two pieces and (2) recurse on each half. If it is not, this is
  // the empty array and our base case.

  if (p < r) {
    // (1) Partitioning.
    //
    // The partitioning chooses a pivot between `p` and `r` and moves all
    // elements that are less than or equal to the pivot to the before it, and
    // all the elements that are greater than it after it. The effect is that
    // once partition is done, the pivot is in the exact place it will be when
    // the array is put in sorted order, and it will not need to be moved
    // again. This runs in O(n) time.

    // Always choose a random pivot so that an input array which is reverse
    // sorted does not cause O(n^2) running time.
    var pivotIndex = randomIntInRange(p, r);
    var i = p - 1;

    swap(ary, pivotIndex, r);
    var pivot = ary[r];

    // Immediately after `j` is incremented in this loop, the following hold
    // true:
    //
    //   * Every element in `ary[p .. i]` is less than or equal to the pivot.
    //
    //   * Every element in `ary[i+1 .. j-1]` is greater than the pivot.
    for (var j = p; j < r; j++) {
      if (comparator(ary[j], pivot) <= 0) {
        i += 1;
        swap(ary, i, j);
      }
    }

    swap(ary, i + 1, j);
    var q = i + 1;

    // (2) Recurse on each half.

    doQuickSort(ary, comparator, p, q - 1);
    doQuickSort(ary, comparator, q + 1, r);
  }
}

/**
 * Sort the given array in-place with the given comparator function.
 *
 * @param {Array} ary
 *        An array to sort.
 * @param {function} comparator
 *        Function to use to compare two items.
 */
var quickSort_1 = function (ary, comparator) {
  doQuickSort(ary, comparator, 0, ary.length - 1);
};

var quickSort = {
	quickSort: quickSort_1
};

/* -*- Mode: js; js-indent-level: 2; -*- */
/*
 * Copyright 2011 Mozilla Foundation and contributors
 * Licensed under the New BSD license. See LICENSE or:
 * http://opensource.org/licenses/BSD-3-Clause
 */



var ArraySet$1 = arraySet.ArraySet;

var quickSort$2 = quickSort.quickSort;

function SourceMapConsumer(aSourceMap) {
  var sourceMap = aSourceMap;
  if (typeof aSourceMap === 'string') {
    sourceMap = JSON.parse(aSourceMap.replace(/^\)\]\}'/, ''));
  }

  return sourceMap.sections != null
    ? new IndexedSourceMapConsumer(sourceMap)
    : new BasicSourceMapConsumer(sourceMap);
}

SourceMapConsumer.fromSourceMap = function(aSourceMap) {
  return BasicSourceMapConsumer.fromSourceMap(aSourceMap);
};

/**
 * The version of the source mapping spec that we are consuming.
 */
SourceMapConsumer.prototype._version = 3;

// `__generatedMappings` and `__originalMappings` are arrays that hold the
// parsed mapping coordinates from the source map's "mappings" attribute. They
// are lazily instantiated, accessed via the `_generatedMappings` and
// `_originalMappings` getters respectively, and we only parse the mappings
// and create these arrays once queried for a source location. We jump through
// these hoops because there can be many thousands of mappings, and parsing
// them is expensive, so we only want to do it if we must.
//
// Each object in the arrays is of the form:
//
//     {
//       generatedLine: The line number in the generated code,
//       generatedColumn: The column number in the generated code,
//       source: The path to the original source file that generated this
//               chunk of code,
//       originalLine: The line number in the original source that
//                     corresponds to this chunk of generated code,
//       originalColumn: The column number in the original source that
//                       corresponds to this chunk of generated code,
//       name: The name of the original symbol which generated this chunk of
//             code.
//     }
//
// All properties except for `generatedLine` and `generatedColumn` can be
// `null`.
//
// `_generatedMappings` is ordered by the generated positions.
//
// `_originalMappings` is ordered by the original positions.

SourceMapConsumer.prototype.__generatedMappings = null;
Object.defineProperty(SourceMapConsumer.prototype, '_generatedMappings', {
  get: function () {
    if (!this.__generatedMappings) {
      this._parseMappings(this._mappings, this.sourceRoot);
    }

    return this.__generatedMappings;
  }
});

SourceMapConsumer.prototype.__originalMappings = null;
Object.defineProperty(SourceMapConsumer.prototype, '_originalMappings', {
  get: function () {
    if (!this.__originalMappings) {
      this._parseMappings(this._mappings, this.sourceRoot);
    }

    return this.__originalMappings;
  }
});

SourceMapConsumer.prototype._charIsMappingSeparator =
  function SourceMapConsumer_charIsMappingSeparator(aStr, index) {
    var c = aStr.charAt(index);
    return c === ";" || c === ",";
  };

/**
 * Parse the mappings in a string in to a data structure which we can easily
 * query (the ordered arrays in the `this.__generatedMappings` and
 * `this.__originalMappings` properties).
 */
SourceMapConsumer.prototype._parseMappings =
  function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
    throw new Error("Subclasses must implement _parseMappings");
  };

SourceMapConsumer.GENERATED_ORDER = 1;
SourceMapConsumer.ORIGINAL_ORDER = 2;

SourceMapConsumer.GREATEST_LOWER_BOUND = 1;
SourceMapConsumer.LEAST_UPPER_BOUND = 2;

/**
 * Iterate over each mapping between an original source/line/column and a
 * generated line/column in this source map.
 *
 * @param Function aCallback
 *        The function that is called with each mapping.
 * @param Object aContext
 *        Optional. If specified, this object will be the value of `this` every
 *        time that `aCallback` is called.
 * @param aOrder
 *        Either `SourceMapConsumer.GENERATED_ORDER` or
 *        `SourceMapConsumer.ORIGINAL_ORDER`. Specifies whether you want to
 *        iterate over the mappings sorted by the generated file's line/column
 *        order or the original's source/line/column order, respectively. Defaults to
 *        `SourceMapConsumer.GENERATED_ORDER`.
 */
SourceMapConsumer.prototype.eachMapping =
  function SourceMapConsumer_eachMapping(aCallback, aContext, aOrder) {
    var context = aContext || null;
    var order = aOrder || SourceMapConsumer.GENERATED_ORDER;

    var mappings;
    switch (order) {
    case SourceMapConsumer.GENERATED_ORDER:
      mappings = this._generatedMappings;
      break;
    case SourceMapConsumer.ORIGINAL_ORDER:
      mappings = this._originalMappings;
      break;
    default:
      throw new Error("Unknown order of iteration.");
    }

    var sourceRoot = this.sourceRoot;
    mappings.map(function (mapping) {
      var source = mapping.source === null ? null : this._sources.at(mapping.source);
      if (source != null && sourceRoot != null) {
        source = util.join(sourceRoot, source);
      }
      return {
        source: source,
        generatedLine: mapping.generatedLine,
        generatedColumn: mapping.generatedColumn,
        originalLine: mapping.originalLine,
        originalColumn: mapping.originalColumn,
        name: mapping.name === null ? null : this._names.at(mapping.name)
      };
    }, this).forEach(aCallback, context);
  };

/**
 * Returns all generated line and column information for the original source,
 * line, and column provided. If no column is provided, returns all mappings
 * corresponding to a either the line we are searching for or the next
 * closest line that has any mappings. Otherwise, returns all mappings
 * corresponding to the given line and either the column we are searching for
 * or the next closest column that has any offsets.
 *
 * The only argument is an object with the following properties:
 *
 *   - source: The filename of the original source.
 *   - line: The line number in the original source.
 *   - column: Optional. the column number in the original source.
 *
 * and an array of objects is returned, each with the following properties:
 *
 *   - line: The line number in the generated source, or null.
 *   - column: The column number in the generated source, or null.
 */
SourceMapConsumer.prototype.allGeneratedPositionsFor =
  function SourceMapConsumer_allGeneratedPositionsFor(aArgs) {
    var line = util.getArg(aArgs, 'line');

    // When there is no exact match, BasicSourceMapConsumer.prototype._findMapping
    // returns the index of the closest mapping less than the needle. By
    // setting needle.originalColumn to 0, we thus find the last mapping for
    // the given line, provided such a mapping exists.
    var needle = {
      source: util.getArg(aArgs, 'source'),
      originalLine: line,
      originalColumn: util.getArg(aArgs, 'column', 0)
    };

    if (this.sourceRoot != null) {
      needle.source = util.relative(this.sourceRoot, needle.source);
    }
    if (!this._sources.has(needle.source)) {
      return [];
    }
    needle.source = this._sources.indexOf(needle.source);

    var mappings = [];

    var index = this._findMapping(needle,
                                  this._originalMappings,
                                  "originalLine",
                                  "originalColumn",
                                  util.compareByOriginalPositions,
                                  binarySearch.LEAST_UPPER_BOUND);
    if (index >= 0) {
      var mapping = this._originalMappings[index];

      if (aArgs.column === undefined) {
        var originalLine = mapping.originalLine;

        // Iterate until either we run out of mappings, or we run into
        // a mapping for a different line than the one we found. Since
        // mappings are sorted, this is guaranteed to find all mappings for
        // the line we found.
        while (mapping && mapping.originalLine === originalLine) {
          mappings.push({
            line: util.getArg(mapping, 'generatedLine', null),
            column: util.getArg(mapping, 'generatedColumn', null),
            lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
          });

          mapping = this._originalMappings[++index];
        }
      } else {
        var originalColumn = mapping.originalColumn;

        // Iterate until either we run out of mappings, or we run into
        // a mapping for a different line than the one we were searching for.
        // Since mappings are sorted, this is guaranteed to find all mappings for
        // the line we are searching for.
        while (mapping &&
               mapping.originalLine === line &&
               mapping.originalColumn == originalColumn) {
          mappings.push({
            line: util.getArg(mapping, 'generatedLine', null),
            column: util.getArg(mapping, 'generatedColumn', null),
            lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
          });

          mapping = this._originalMappings[++index];
        }
      }
    }

    return mappings;
  };

var SourceMapConsumer_1 = SourceMapConsumer;

/**
 * A BasicSourceMapConsumer instance represents a parsed source map which we can
 * query for information about the original file positions by giving it a file
 * position in the generated source.
 *
 * The only parameter is the raw source map (either as a JSON string, or
 * already parsed to an object). According to the spec, source maps have the
 * following attributes:
 *
 *   - version: Which version of the source map spec this map is following.
 *   - sources: An array of URLs to the original source files.
 *   - names: An array of identifiers which can be referrenced by individual mappings.
 *   - sourceRoot: Optional. The URL root from which all sources are relative.
 *   - sourcesContent: Optional. An array of contents of the original source files.
 *   - mappings: A string of base64 VLQs which contain the actual mappings.
 *   - file: Optional. The generated file this source map is associated with.
 *
 * Here is an example source map, taken from the source map spec[0]:
 *
 *     {
 *       version : 3,
 *       file: "out.js",
 *       sourceRoot : "",
 *       sources: ["foo.js", "bar.js"],
 *       names: ["src", "maps", "are", "fun"],
 *       mappings: "AA,AB;;ABCDE;"
 *     }
 *
 * [0]: https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit?pli=1#
 */
function BasicSourceMapConsumer(aSourceMap) {
  var sourceMap = aSourceMap;
  if (typeof aSourceMap === 'string') {
    sourceMap = JSON.parse(aSourceMap.replace(/^\)\]\}'/, ''));
  }

  var version = util.getArg(sourceMap, 'version');
  var sources = util.getArg(sourceMap, 'sources');
  // Sass 3.3 leaves out the 'names' array, so we deviate from the spec (which
  // requires the array) to play nice here.
  var names = util.getArg(sourceMap, 'names', []);
  var sourceRoot = util.getArg(sourceMap, 'sourceRoot', null);
  var sourcesContent = util.getArg(sourceMap, 'sourcesContent', null);
  var mappings = util.getArg(sourceMap, 'mappings');
  var file = util.getArg(sourceMap, 'file', null);

  // Once again, Sass deviates from the spec and supplies the version as a
  // string rather than a number, so we use loose equality checking here.
  if (version != this._version) {
    throw new Error('Unsupported version: ' + version);
  }

  sources = sources
    .map(String)
    // Some source maps produce relative source paths like "./foo.js" instead of
    // "foo.js".  Normalize these first so that future comparisons will succeed.
    // See bugzil.la/1090768.
    .map(util.normalize)
    // Always ensure that absolute sources are internally stored relative to
    // the source root, if the source root is absolute. Not doing this would
    // be particularly problematic when the source root is a prefix of the
    // source (valid, but why??). See github issue #199 and bugzil.la/1188982.
    .map(function (source) {
      return sourceRoot && util.isAbsolute(sourceRoot) && util.isAbsolute(source)
        ? util.relative(sourceRoot, source)
        : source;
    });

  // Pass `true` below to allow duplicate names and sources. While source maps
  // are intended to be compressed and deduplicated, the TypeScript compiler
  // sometimes generates source maps with duplicates in them. See Github issue
  // #72 and bugzil.la/889492.
  this._names = ArraySet$1.fromArray(names.map(String), true);
  this._sources = ArraySet$1.fromArray(sources, true);

  this.sourceRoot = sourceRoot;
  this.sourcesContent = sourcesContent;
  this._mappings = mappings;
  this.file = file;
}

BasicSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
BasicSourceMapConsumer.prototype.consumer = SourceMapConsumer;

/**
 * Create a BasicSourceMapConsumer from a SourceMapGenerator.
 *
 * @param SourceMapGenerator aSourceMap
 *        The source map that will be consumed.
 * @returns BasicSourceMapConsumer
 */
BasicSourceMapConsumer.fromSourceMap =
  function SourceMapConsumer_fromSourceMap(aSourceMap) {
    var smc = Object.create(BasicSourceMapConsumer.prototype);

    var names = smc._names = ArraySet$1.fromArray(aSourceMap._names.toArray(), true);
    var sources = smc._sources = ArraySet$1.fromArray(aSourceMap._sources.toArray(), true);
    smc.sourceRoot = aSourceMap._sourceRoot;
    smc.sourcesContent = aSourceMap._generateSourcesContent(smc._sources.toArray(),
                                                            smc.sourceRoot);
    smc.file = aSourceMap._file;

    // Because we are modifying the entries (by converting string sources and
    // names to indices into the sources and names ArraySets), we have to make
    // a copy of the entry or else bad things happen. Shared mutable state
    // strikes again! See github issue #191.

    var generatedMappings = aSourceMap._mappings.toArray().slice();
    var destGeneratedMappings = smc.__generatedMappings = [];
    var destOriginalMappings = smc.__originalMappings = [];

    for (var i = 0, length = generatedMappings.length; i < length; i++) {
      var srcMapping = generatedMappings[i];
      var destMapping = new Mapping;
      destMapping.generatedLine = srcMapping.generatedLine;
      destMapping.generatedColumn = srcMapping.generatedColumn;

      if (srcMapping.source) {
        destMapping.source = sources.indexOf(srcMapping.source);
        destMapping.originalLine = srcMapping.originalLine;
        destMapping.originalColumn = srcMapping.originalColumn;

        if (srcMapping.name) {
          destMapping.name = names.indexOf(srcMapping.name);
        }

        destOriginalMappings.push(destMapping);
      }

      destGeneratedMappings.push(destMapping);
    }

    quickSort$2(smc.__originalMappings, util.compareByOriginalPositions);

    return smc;
  };

/**
 * The version of the source mapping spec that we are consuming.
 */
BasicSourceMapConsumer.prototype._version = 3;

/**
 * The list of original sources.
 */
Object.defineProperty(BasicSourceMapConsumer.prototype, 'sources', {
  get: function () {
    return this._sources.toArray().map(function (s) {
      return this.sourceRoot != null ? util.join(this.sourceRoot, s) : s;
    }, this);
  }
});

/**
 * Provide the JIT with a nice shape / hidden class.
 */
function Mapping() {
  this.generatedLine = 0;
  this.generatedColumn = 0;
  this.source = null;
  this.originalLine = null;
  this.originalColumn = null;
  this.name = null;
}

/**
 * Parse the mappings in a string in to a data structure which we can easily
 * query (the ordered arrays in the `this.__generatedMappings` and
 * `this.__originalMappings` properties).
 */
BasicSourceMapConsumer.prototype._parseMappings =
  function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
    var generatedLine = 1;
    var previousGeneratedColumn = 0;
    var previousOriginalLine = 0;
    var previousOriginalColumn = 0;
    var previousSource = 0;
    var previousName = 0;
    var length = aStr.length;
    var index = 0;
    var cachedSegments = {};
    var temp = {};
    var originalMappings = [];
    var generatedMappings = [];
    var mapping, str, segment, end, value;

    while (index < length) {
      if (aStr.charAt(index) === ';') {
        generatedLine++;
        index++;
        previousGeneratedColumn = 0;
      }
      else if (aStr.charAt(index) === ',') {
        index++;
      }
      else {
        mapping = new Mapping();
        mapping.generatedLine = generatedLine;

        // Because each offset is encoded relative to the previous one,
        // many segments often have the same encoding. We can exploit this
        // fact by caching the parsed variable length fields of each segment,
        // allowing us to avoid a second parse if we encounter the same
        // segment again.
        for (end = index; end < length; end++) {
          if (this._charIsMappingSeparator(aStr, end)) {
            break;
          }
        }
        str = aStr.slice(index, end);

        segment = cachedSegments[str];
        if (segment) {
          index += str.length;
        } else {
          segment = [];
          while (index < end) {
            base64Vlq.decode(aStr, index, temp);
            value = temp.value;
            index = temp.rest;
            segment.push(value);
          }

          if (segment.length === 2) {
            throw new Error('Found a source, but no line and column');
          }

          if (segment.length === 3) {
            throw new Error('Found a source and line, but no column');
          }

          cachedSegments[str] = segment;
        }

        // Generated column.
        mapping.generatedColumn = previousGeneratedColumn + segment[0];
        previousGeneratedColumn = mapping.generatedColumn;

        if (segment.length > 1) {
          // Original source.
          mapping.source = previousSource + segment[1];
          previousSource += segment[1];

          // Original line.
          mapping.originalLine = previousOriginalLine + segment[2];
          previousOriginalLine = mapping.originalLine;
          // Lines are stored 0-based
          mapping.originalLine += 1;

          // Original column.
          mapping.originalColumn = previousOriginalColumn + segment[3];
          previousOriginalColumn = mapping.originalColumn;

          if (segment.length > 4) {
            // Original name.
            mapping.name = previousName + segment[4];
            previousName += segment[4];
          }
        }

        generatedMappings.push(mapping);
        if (typeof mapping.originalLine === 'number') {
          originalMappings.push(mapping);
        }
      }
    }

    quickSort$2(generatedMappings, util.compareByGeneratedPositionsDeflated);
    this.__generatedMappings = generatedMappings;

    quickSort$2(originalMappings, util.compareByOriginalPositions);
    this.__originalMappings = originalMappings;
  };

/**
 * Find the mapping that best matches the hypothetical "needle" mapping that
 * we are searching for in the given "haystack" of mappings.
 */
BasicSourceMapConsumer.prototype._findMapping =
  function SourceMapConsumer_findMapping(aNeedle, aMappings, aLineName,
                                         aColumnName, aComparator, aBias) {
    // To return the position we are searching for, we must first find the
    // mapping for the given position and then return the opposite position it
    // points to. Because the mappings are sorted, we can use binary search to
    // find the best mapping.

    if (aNeedle[aLineName] <= 0) {
      throw new TypeError('Line must be greater than or equal to 1, got '
                          + aNeedle[aLineName]);
    }
    if (aNeedle[aColumnName] < 0) {
      throw new TypeError('Column must be greater than or equal to 0, got '
                          + aNeedle[aColumnName]);
    }

    return binarySearch.search(aNeedle, aMappings, aComparator, aBias);
  };

/**
 * Compute the last column for each generated mapping. The last column is
 * inclusive.
 */
BasicSourceMapConsumer.prototype.computeColumnSpans =
  function SourceMapConsumer_computeColumnSpans() {
    for (var index = 0; index < this._generatedMappings.length; ++index) {
      var mapping = this._generatedMappings[index];

      // Mappings do not contain a field for the last generated columnt. We
      // can come up with an optimistic estimate, however, by assuming that
      // mappings are contiguous (i.e. given two consecutive mappings, the
      // first mapping ends where the second one starts).
      if (index + 1 < this._generatedMappings.length) {
        var nextMapping = this._generatedMappings[index + 1];

        if (mapping.generatedLine === nextMapping.generatedLine) {
          mapping.lastGeneratedColumn = nextMapping.generatedColumn - 1;
          continue;
        }
      }

      // The last mapping for each line spans the entire line.
      mapping.lastGeneratedColumn = Infinity;
    }
  };

/**
 * Returns the original source, line, and column information for the generated
 * source's line and column positions provided. The only argument is an object
 * with the following properties:
 *
 *   - line: The line number in the generated source.
 *   - column: The column number in the generated source.
 *   - bias: Either 'SourceMapConsumer.GREATEST_LOWER_BOUND' or
 *     'SourceMapConsumer.LEAST_UPPER_BOUND'. Specifies whether to return the
 *     closest element that is smaller than or greater than the one we are
 *     searching for, respectively, if the exact element cannot be found.
 *     Defaults to 'SourceMapConsumer.GREATEST_LOWER_BOUND'.
 *
 * and an object is returned with the following properties:
 *
 *   - source: The original source file, or null.
 *   - line: The line number in the original source, or null.
 *   - column: The column number in the original source, or null.
 *   - name: The original identifier, or null.
 */
BasicSourceMapConsumer.prototype.originalPositionFor =
  function SourceMapConsumer_originalPositionFor(aArgs) {
    var needle = {
      generatedLine: util.getArg(aArgs, 'line'),
      generatedColumn: util.getArg(aArgs, 'column')
    };

    var index = this._findMapping(
      needle,
      this._generatedMappings,
      "generatedLine",
      "generatedColumn",
      util.compareByGeneratedPositionsDeflated,
      util.getArg(aArgs, 'bias', SourceMapConsumer.GREATEST_LOWER_BOUND)
    );

    if (index >= 0) {
      var mapping = this._generatedMappings[index];

      if (mapping.generatedLine === needle.generatedLine) {
        var source = util.getArg(mapping, 'source', null);
        if (source !== null) {
          source = this._sources.at(source);
          if (this.sourceRoot != null) {
            source = util.join(this.sourceRoot, source);
          }
        }
        var name = util.getArg(mapping, 'name', null);
        if (name !== null) {
          name = this._names.at(name);
        }
        return {
          source: source,
          line: util.getArg(mapping, 'originalLine', null),
          column: util.getArg(mapping, 'originalColumn', null),
          name: name
        };
      }
    }

    return {
      source: null,
      line: null,
      column: null,
      name: null
    };
  };

/**
 * Return true if we have the source content for every source in the source
 * map, false otherwise.
 */
BasicSourceMapConsumer.prototype.hasContentsOfAllSources =
  function BasicSourceMapConsumer_hasContentsOfAllSources() {
    if (!this.sourcesContent) {
      return false;
    }
    return this.sourcesContent.length >= this._sources.size() &&
      !this.sourcesContent.some(function (sc) { return sc == null; });
  };

/**
 * Returns the original source content. The only argument is the url of the
 * original source file. Returns null if no original source content is
 * available.
 */
BasicSourceMapConsumer.prototype.sourceContentFor =
  function SourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
    if (!this.sourcesContent) {
      return null;
    }

    if (this.sourceRoot != null) {
      aSource = util.relative(this.sourceRoot, aSource);
    }

    if (this._sources.has(aSource)) {
      return this.sourcesContent[this._sources.indexOf(aSource)];
    }

    var url;
    if (this.sourceRoot != null
        && (url = util.urlParse(this.sourceRoot))) {
      // XXX: file:// URIs and absolute paths lead to unexpected behavior for
      // many users. We can help them out when they expect file:// URIs to
      // behave like it would if they were running a local HTTP server. See
      // https://bugzilla.mozilla.org/show_bug.cgi?id=885597.
      var fileUriAbsPath = aSource.replace(/^file:\/\//, "");
      if (url.scheme == "file"
          && this._sources.has(fileUriAbsPath)) {
        return this.sourcesContent[this._sources.indexOf(fileUriAbsPath)]
      }

      if ((!url.path || url.path == "/")
          && this._sources.has("/" + aSource)) {
        return this.sourcesContent[this._sources.indexOf("/" + aSource)];
      }
    }

    // This function is used recursively from
    // IndexedSourceMapConsumer.prototype.sourceContentFor. In that case, we
    // don't want to throw if we can't find the source - we just want to
    // return null, so we provide a flag to exit gracefully.
    if (nullOnMissing) {
      return null;
    }
    else {
      throw new Error('"' + aSource + '" is not in the SourceMap.');
    }
  };

/**
 * Returns the generated line and column information for the original source,
 * line, and column positions provided. The only argument is an object with
 * the following properties:
 *
 *   - source: The filename of the original source.
 *   - line: The line number in the original source.
 *   - column: The column number in the original source.
 *   - bias: Either 'SourceMapConsumer.GREATEST_LOWER_BOUND' or
 *     'SourceMapConsumer.LEAST_UPPER_BOUND'. Specifies whether to return the
 *     closest element that is smaller than or greater than the one we are
 *     searching for, respectively, if the exact element cannot be found.
 *     Defaults to 'SourceMapConsumer.GREATEST_LOWER_BOUND'.
 *
 * and an object is returned with the following properties:
 *
 *   - line: The line number in the generated source, or null.
 *   - column: The column number in the generated source, or null.
 */
BasicSourceMapConsumer.prototype.generatedPositionFor =
  function SourceMapConsumer_generatedPositionFor(aArgs) {
    var source = util.getArg(aArgs, 'source');
    if (this.sourceRoot != null) {
      source = util.relative(this.sourceRoot, source);
    }
    if (!this._sources.has(source)) {
      return {
        line: null,
        column: null,
        lastColumn: null
      };
    }
    source = this._sources.indexOf(source);

    var needle = {
      source: source,
      originalLine: util.getArg(aArgs, 'line'),
      originalColumn: util.getArg(aArgs, 'column')
    };

    var index = this._findMapping(
      needle,
      this._originalMappings,
      "originalLine",
      "originalColumn",
      util.compareByOriginalPositions,
      util.getArg(aArgs, 'bias', SourceMapConsumer.GREATEST_LOWER_BOUND)
    );

    if (index >= 0) {
      var mapping = this._originalMappings[index];

      if (mapping.source === needle.source) {
        return {
          line: util.getArg(mapping, 'generatedLine', null),
          column: util.getArg(mapping, 'generatedColumn', null),
          lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
        };
      }
    }

    return {
      line: null,
      column: null,
      lastColumn: null
    };
  };

var BasicSourceMapConsumer_1 = BasicSourceMapConsumer;

/**
 * An IndexedSourceMapConsumer instance represents a parsed source map which
 * we can query for information. It differs from BasicSourceMapConsumer in
 * that it takes "indexed" source maps (i.e. ones with a "sections" field) as
 * input.
 *
 * The only parameter is a raw source map (either as a JSON string, or already
 * parsed to an object). According to the spec for indexed source maps, they
 * have the following attributes:
 *
 *   - version: Which version of the source map spec this map is following.
 *   - file: Optional. The generated file this source map is associated with.
 *   - sections: A list of section definitions.
 *
 * Each value under the "sections" field has two fields:
 *   - offset: The offset into the original specified at which this section
 *       begins to apply, defined as an object with a "line" and "column"
 *       field.
 *   - map: A source map definition. This source map could also be indexed,
 *       but doesn't have to be.
 *
 * Instead of the "map" field, it's also possible to have a "url" field
 * specifying a URL to retrieve a source map from, but that's currently
 * unsupported.
 *
 * Here's an example source map, taken from the source map spec[0], but
 * modified to omit a section which uses the "url" field.
 *
 *  {
 *    version : 3,
 *    file: "app.js",
 *    sections: [{
 *      offset: {line:100, column:10},
 *      map: {
 *        version : 3,
 *        file: "section.js",
 *        sources: ["foo.js", "bar.js"],
 *        names: ["src", "maps", "are", "fun"],
 *        mappings: "AAAA,E;;ABCDE;"
 *      }
 *    }],
 *  }
 *
 * [0]: https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit#heading=h.535es3xeprgt
 */
function IndexedSourceMapConsumer(aSourceMap) {
  var sourceMap = aSourceMap;
  if (typeof aSourceMap === 'string') {
    sourceMap = JSON.parse(aSourceMap.replace(/^\)\]\}'/, ''));
  }

  var version = util.getArg(sourceMap, 'version');
  var sections = util.getArg(sourceMap, 'sections');

  if (version != this._version) {
    throw new Error('Unsupported version: ' + version);
  }

  this._sources = new ArraySet$1();
  this._names = new ArraySet$1();

  var lastOffset = {
    line: -1,
    column: 0
  };
  this._sections = sections.map(function (s) {
    if (s.url) {
      // The url field will require support for asynchronicity.
      // See https://github.com/mozilla/source-map/issues/16
      throw new Error('Support for url field in sections not implemented.');
    }
    var offset = util.getArg(s, 'offset');
    var offsetLine = util.getArg(offset, 'line');
    var offsetColumn = util.getArg(offset, 'column');

    if (offsetLine < lastOffset.line ||
        (offsetLine === lastOffset.line && offsetColumn < lastOffset.column)) {
      throw new Error('Section offsets must be ordered and non-overlapping.');
    }
    lastOffset = offset;

    return {
      generatedOffset: {
        // The offset fields are 0-based, but we use 1-based indices when
        // encoding/decoding from VLQ.
        generatedLine: offsetLine + 1,
        generatedColumn: offsetColumn + 1
      },
      consumer: new SourceMapConsumer(util.getArg(s, 'map'))
    }
  });
}

IndexedSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
IndexedSourceMapConsumer.prototype.constructor = SourceMapConsumer;

/**
 * The version of the source mapping spec that we are consuming.
 */
IndexedSourceMapConsumer.prototype._version = 3;

/**
 * The list of original sources.
 */
Object.defineProperty(IndexedSourceMapConsumer.prototype, 'sources', {
  get: function () {
    var sources = [];
    for (var i = 0; i < this._sections.length; i++) {
      for (var j = 0; j < this._sections[i].consumer.sources.length; j++) {
        sources.push(this._sections[i].consumer.sources[j]);
      }
    }
    return sources;
  }
});

/**
 * Returns the original source, line, and column information for the generated
 * source's line and column positions provided. The only argument is an object
 * with the following properties:
 *
 *   - line: The line number in the generated source.
 *   - column: The column number in the generated source.
 *
 * and an object is returned with the following properties:
 *
 *   - source: The original source file, or null.
 *   - line: The line number in the original source, or null.
 *   - column: The column number in the original source, or null.
 *   - name: The original identifier, or null.
 */
IndexedSourceMapConsumer.prototype.originalPositionFor =
  function IndexedSourceMapConsumer_originalPositionFor(aArgs) {
    var needle = {
      generatedLine: util.getArg(aArgs, 'line'),
      generatedColumn: util.getArg(aArgs, 'column')
    };

    // Find the section containing the generated position we're trying to map
    // to an original position.
    var sectionIndex = binarySearch.search(needle, this._sections,
      function(needle, section) {
        var cmp = needle.generatedLine - section.generatedOffset.generatedLine;
        if (cmp) {
          return cmp;
        }

        return (needle.generatedColumn -
                section.generatedOffset.generatedColumn);
      });
    var section = this._sections[sectionIndex];

    if (!section) {
      return {
        source: null,
        line: null,
        column: null,
        name: null
      };
    }

    return section.consumer.originalPositionFor({
      line: needle.generatedLine -
        (section.generatedOffset.generatedLine - 1),
      column: needle.generatedColumn -
        (section.generatedOffset.generatedLine === needle.generatedLine
         ? section.generatedOffset.generatedColumn - 1
         : 0),
      bias: aArgs.bias
    });
  };

/**
 * Return true if we have the source content for every source in the source
 * map, false otherwise.
 */
IndexedSourceMapConsumer.prototype.hasContentsOfAllSources =
  function IndexedSourceMapConsumer_hasContentsOfAllSources() {
    return this._sections.every(function (s) {
      return s.consumer.hasContentsOfAllSources();
    });
  };

/**
 * Returns the original source content. The only argument is the url of the
 * original source file. Returns null if no original source content is
 * available.
 */
IndexedSourceMapConsumer.prototype.sourceContentFor =
  function IndexedSourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
    for (var i = 0; i < this._sections.length; i++) {
      var section = this._sections[i];

      var content = section.consumer.sourceContentFor(aSource, true);
      if (content) {
        return content;
      }
    }
    if (nullOnMissing) {
      return null;
    }
    else {
      throw new Error('"' + aSource + '" is not in the SourceMap.');
    }
  };

/**
 * Returns the generated line and column information for the original source,
 * line, and column positions provided. The only argument is an object with
 * the following properties:
 *
 *   - source: The filename of the original source.
 *   - line: The line number in the original source.
 *   - column: The column number in the original source.
 *
 * and an object is returned with the following properties:
 *
 *   - line: The line number in the generated source, or null.
 *   - column: The column number in the generated source, or null.
 */
IndexedSourceMapConsumer.prototype.generatedPositionFor =
  function IndexedSourceMapConsumer_generatedPositionFor(aArgs) {
    for (var i = 0; i < this._sections.length; i++) {
      var section = this._sections[i];

      // Only consider this section if the requested source is in the list of
      // sources of the consumer.
      if (section.consumer.sources.indexOf(util.getArg(aArgs, 'source')) === -1) {
        continue;
      }
      var generatedPosition = section.consumer.generatedPositionFor(aArgs);
      if (generatedPosition) {
        var ret = {
          line: generatedPosition.line +
            (section.generatedOffset.generatedLine - 1),
          column: generatedPosition.column +
            (section.generatedOffset.generatedLine === generatedPosition.line
             ? section.generatedOffset.generatedColumn - 1
             : 0)
        };
        return ret;
      }
    }

    return {
      line: null,
      column: null
    };
  };

/**
 * Parse the mappings in a string in to a data structure which we can easily
 * query (the ordered arrays in the `this.__generatedMappings` and
 * `this.__originalMappings` properties).
 */
IndexedSourceMapConsumer.prototype._parseMappings =
  function IndexedSourceMapConsumer_parseMappings(aStr, aSourceRoot) {
    this.__generatedMappings = [];
    this.__originalMappings = [];
    for (var i = 0; i < this._sections.length; i++) {
      var section = this._sections[i];
      var sectionMappings = section.consumer._generatedMappings;
      for (var j = 0; j < sectionMappings.length; j++) {
        var mapping = sectionMappings[j];

        var source = section.consumer._sources.at(mapping.source);
        if (section.consumer.sourceRoot !== null) {
          source = util.join(section.consumer.sourceRoot, source);
        }
        this._sources.add(source);
        source = this._sources.indexOf(source);

        var name = section.consumer._names.at(mapping.name);
        this._names.add(name);
        name = this._names.indexOf(name);

        // The mappings coming from the consumer for the section have
        // generated positions relative to the start of the section, so we
        // need to offset them to be relative to the start of the concatenated
        // generated file.
        var adjustedMapping = {
          source: source,
          generatedLine: mapping.generatedLine +
            (section.generatedOffset.generatedLine - 1),
          generatedColumn: mapping.generatedColumn +
            (section.generatedOffset.generatedLine === mapping.generatedLine
            ? section.generatedOffset.generatedColumn - 1
            : 0),
          originalLine: mapping.originalLine,
          originalColumn: mapping.originalColumn,
          name: name
        };

        this.__generatedMappings.push(adjustedMapping);
        if (typeof adjustedMapping.originalLine === 'number') {
          this.__originalMappings.push(adjustedMapping);
        }
      }
    }

    quickSort$2(this.__generatedMappings, util.compareByGeneratedPositionsDeflated);
    quickSort$2(this.__originalMappings, util.compareByOriginalPositions);
  };

var IndexedSourceMapConsumer_1 = IndexedSourceMapConsumer;

var sourceMapConsumer = {
	SourceMapConsumer: SourceMapConsumer_1,
	BasicSourceMapConsumer: BasicSourceMapConsumer_1,
	IndexedSourceMapConsumer: IndexedSourceMapConsumer_1
};

var stacktraceGps = createCommonjsModule$1(function (module, exports) {
(function(root, factory) {
    if (typeof undefined === 'function' && undefined.amd) {
        undefined('stacktrace-gps', ['source-map', 'stackframe'], factory);
    } else {
        module.exports = factory(sourceMapConsumer, stackframe);
    }
}(commonjsGlobal$1, function(SourceMap, StackFrame) {
    function _xdr(url) {
        return new Promise(function(resolve, reject) {
            var req = new XMLHttpRequest();
            req.open('get', url);
            req.onerror = reject;
            req.onreadystatechange = function onreadystatechange() {
                if (req.readyState === 4) {
                    if (req.status >= 200 && req.status < 300) {
                        resolve(req.responseText);
                    } else {
                        reject(new Error('HTTP status: ' + req.status + ' retrieving ' + url));
                    }
                }
            };
            req.send();
        });

    }

    /**
     * Convert a Base64-encoded string into its original representation.
     * Used for inline sourcemaps.
     *
     * @param {String} b64str Base-64 encoded string
     * @returns {String} original representation of the base64-encoded string.
     */
    function _atob(b64str) {
        if (typeof window !== 'undefined' && window.atob) {
            return window.atob(b64str);
        } else {
            throw new Error('You must supply a polyfill for window.atob in this environment');
        }
    }

    function _parseJson(string) {
        if (typeof JSON !== 'undefined' && JSON.parse) {
            return JSON.parse(string);
        } else {
            throw new Error('You must supply a polyfill for JSON.parse in this environment');
        }
    }

    function _findFunctionName(source, lineNumber/*, columnNumber*/) {
        // function {name}({args}) m[1]=name m[2]=args
        var reFunctionDeclaration = /function\s+([^(]*?)\s*\(([^)]*)\)/;
        // {name} = function ({args}) TODO args capture
        var reFunctionExpression = /['"]?([$_A-Za-z][$_A-Za-z0-9]*)['"]?\s*[:=]\s*function\b/;
        // {name} = eval()
        var reFunctionEvaluation = /['"]?([$_A-Za-z][$_A-Za-z0-9]*)['"]?\s*[:=]\s*(?:eval|new Function)\b/;
        var lines = source.split('\n');

        // Walk backwards in the source lines until we find the line which matches one of the patterns above
        var code = '';
        var maxLines = Math.min(lineNumber, 20);
        var m;
        for (var i = 0; i < maxLines; ++i) {
            // lineNo is 1-based, source[] is 0-based
            var line = lines[lineNumber - i - 1];
            var commentPos = line.indexOf('//');
            if (commentPos >= 0) {
                line = line.substr(0, commentPos);
            }

            if (line) {
                code = line + code;
                m = reFunctionExpression.exec(code);
                if (m && m[1]) {
                    return m[1];
                }
                m = reFunctionDeclaration.exec(code);
                if (m && m[1]) {
                    return m[1];
                }
                m = reFunctionEvaluation.exec(code);
                if (m && m[1]) {
                    return m[1];
                }
            }
        }
        return undefined;
    }

    function _ensureSupportedEnvironment() {
        if (typeof Object.defineProperty !== 'function' || typeof Object.create !== 'function') {
            throw new Error('Unable to consume source maps in older browsers');
        }
    }

    function _ensureStackFrameIsLegit(stackframe$$2) {
        if (typeof stackframe$$2 !== 'object') {
            throw new TypeError('Given StackFrame is not an object');
        } else if (typeof stackframe$$2.fileName !== 'string') {
            throw new TypeError('Given file name is not a String');
        } else if (typeof stackframe$$2.lineNumber !== 'number' ||
            stackframe$$2.lineNumber % 1 !== 0 ||
            stackframe$$2.lineNumber < 1) {
            throw new TypeError('Given line number must be a positive integer');
        } else if (typeof stackframe$$2.columnNumber !== 'number' ||
            stackframe$$2.columnNumber % 1 !== 0 ||
            stackframe$$2.columnNumber < 0) {
            throw new TypeError('Given column number must be a non-negative integer');
        }
        return true;
    }

    function _findSourceMappingURL(source) {
        var m = /\/\/[#@] ?sourceMappingURL=([^\s'"]+)\s*$/.exec(source);
        if (m && m[1]) {
            return m[1];
        } else {
            throw new Error('sourceMappingURL not found');
        }
    }

    function _extractLocationInfoFromSourceMap(stackframe$$2, rawSourceMap, sourceCache) {
        return new Promise(function(resolve, reject) {
            var mapConsumer = new SourceMap.SourceMapConsumer(rawSourceMap);

            var loc = mapConsumer.originalPositionFor({
                line: stackframe$$2.lineNumber,
                column: stackframe$$2.columnNumber
            });

            if (loc.source) {
                var mappedSource = mapConsumer.sourceContentFor(loc.source);
                if (mappedSource) {
                    sourceCache[loc.source] = mappedSource;
                }
                resolve(
                    new StackFrame(
                        loc.name || stackframe$$2.functionName,
                        stackframe$$2.args,
                        loc.source,
                        loc.line,
                        loc.column));
            } else {
                reject(new Error('Could not get original source for given stackframe and source map'));
            }
        });
    }

    /**
     * @constructor
     * @param {Object} opts
     *      opts.sourceCache = {url: "Source String"} => preload source cache
     *      opts.offline = True to prevent network requests.
     *              Best effort without sources or source maps.
     *      opts.ajax = Promise returning function to make X-Domain requests
     */
    return function StackTraceGPS(opts) {
        if (!(this instanceof StackTraceGPS)) {
            return new StackTraceGPS(opts);
        }
        opts = opts || {};

        this.sourceCache = opts.sourceCache || {};

        this.ajax = opts.ajax || _xdr;

        this._atob = opts.atob || _atob;

        this._get = function _get(location) {
            return new Promise(function(resolve, reject) {
                var isDataUrl = location.substr(0, 5) === 'data:';
                if (this.sourceCache[location]) {
                    resolve(this.sourceCache[location]);
                } else if (opts.offline && !isDataUrl) {
                    reject(new Error('Cannot make network requests in offline mode'));
                } else {
                    if (isDataUrl) {
                        // data URLs can have parameters.
                        // see http://tools.ietf.org/html/rfc2397
                        var supportedEncodingRegexp =
                            /^data:application\/json;([\w=:"-]+;)*base64,/;
                        var match = location.match(supportedEncodingRegexp);
                        if (match) {
                            var sourceMapStart = match[0].length;
                            var encodedSource = location.substr(sourceMapStart);
                            var source = this._atob(encodedSource);
                            this.sourceCache[location] = source;
                            resolve(source);
                        } else {
                            reject(new Error('The encoding of the inline sourcemap is not supported'));
                        }
                    } else {
                        var xhrPromise = this.ajax(location, {method: 'get'});
                        // Cache the Promise to prevent duplicate in-flight requests
                        this.sourceCache[location] = xhrPromise;
                        xhrPromise.then(resolve, reject);
                    }
                }
            }.bind(this));
        };

        /**
         * Given a StackFrame, enhance function name and use source maps for a
         * better StackFrame.
         *
         * @param {StackFrame} stackframe object
         * @returns {Promise} that resolves with with source-mapped StackFrame
         */
        this.pinpoint = function StackTraceGPS$$pinpoint(stackframe$$2) {
            return new Promise(function(resolve, reject) {
                this.getMappedLocation(stackframe$$2).then(function(mappedStackFrame) {
                    function resolveMappedStackFrame() {
                        resolve(mappedStackFrame);
                    }

                    this.findFunctionName(mappedStackFrame)
                        .then(resolve, resolveMappedStackFrame)
                        ['catch'](resolveMappedStackFrame);
                }.bind(this), reject);
            }.bind(this));
        };

        /**
         * Given a StackFrame, guess function name from location information.
         *
         * @param {StackFrame} stackframe
         * @returns {Promise} that resolves with enhanced StackFrame.
         */
        this.findFunctionName = function StackTraceGPS$$findFunctionName(stackframe$$2) {
            return new Promise(function(resolve, reject) {
                _ensureStackFrameIsLegit(stackframe$$2);
                this._get(stackframe$$2.fileName).then(function getSourceCallback(source) {
                    var lineNumber = stackframe$$2.lineNumber;
                    var columnNumber = stackframe$$2.columnNumber;
                    var guessedFunctionName = _findFunctionName(source, lineNumber, columnNumber);
                    // Only replace functionName if we found something
                    if (guessedFunctionName) {
                        resolve(new StackFrame(guessedFunctionName,
                            stackframe$$2.args,
                            stackframe$$2.fileName,
                            lineNumber,
                            columnNumber));
                    } else {
                        resolve(stackframe$$2);
                    }
                }, reject)['catch'](reject);
            }.bind(this));
        };

        /**
         * Given a StackFrame, seek source-mapped location and return new enhanced StackFrame.
         *
         * @param {StackFrame} stackframe
         * @returns {Promise} that resolves with enhanced StackFrame.
         */
        this.getMappedLocation = function StackTraceGPS$$getMappedLocation(stackframe$$2) {
            return new Promise(function(resolve, reject) {
                _ensureSupportedEnvironment();
                _ensureStackFrameIsLegit(stackframe$$2);

                var sourceCache = this.sourceCache;
                var fileName = stackframe$$2.fileName;
                this._get(fileName).then(function(source) {
                    var sourceMappingURL = _findSourceMappingURL(source);
                    var isDataUrl = sourceMappingURL.substr(0, 5) === 'data:';
                    var base = fileName.substring(0, fileName.lastIndexOf('/') + 1);

                    if (sourceMappingURL[0] !== '/' && !isDataUrl && !(/^https?:\/\/|^\/\//i).test(sourceMappingURL)) {
                        sourceMappingURL = base + sourceMappingURL;
                    }

                    this._get(sourceMappingURL).then(function(sourceMap) {
                        if (typeof sourceMap === 'string') {
                            sourceMap = _parseJson(sourceMap.replace(/^\)\]\}'/, ''));
                        }
                        if (typeof sourceMap.sourceRoot === 'undefined') {
                            sourceMap.sourceRoot = base;
                        }

                        _extractLocationInfoFromSourceMap(stackframe$$2, sourceMap, sourceCache)
                            .then(resolve)['catch'](function() {
                            resolve(stackframe$$2);
                        });
                    }, reject)['catch'](reject);
                }.bind(this), reject)['catch'](reject);
            }.bind(this));
        };
    };
}));
});

var stacktrace = createCommonjsModule$1(function (module, exports) {
(function(root, factory) {
    if (typeof undefined === 'function' && undefined.amd) {
        undefined('stacktrace', ['error-stack-parser', 'stack-generator', 'stacktrace-gps'], factory);
    } else {
        module.exports = factory(errorStackParser, stackGenerator, stacktraceGps);
    }
}(commonjsGlobal$1, function StackTrace(ErrorStackParser, StackGenerator, StackTraceGPS) {
    var _options = {
        filter: function(stackframe) {
            // Filter out stackframes for this library by default
            return (stackframe.functionName || '').indexOf('StackTrace$$') === -1 &&
                (stackframe.functionName || '').indexOf('ErrorStackParser$$') === -1 &&
                (stackframe.functionName || '').indexOf('StackTraceGPS$$') === -1 &&
                (stackframe.functionName || '').indexOf('StackGenerator$$') === -1;
        },
        sourceCache: {}
    };

    var _generateError = function StackTrace$$GenerateError() {
        try {
            // Error must be thrown to get stack in IE
            throw new Error();
        } catch (err) {
            return err;
        }
    };

    /**
     * Merge 2 given Objects. If a conflict occurs the second object wins.
     * Does not do deep merges.
     *
     * @param {Object} first base object
     * @param {Object} second overrides
     * @returns {Object} merged first and second
     * @private
     */
    function _merge(first, second) {
        var target = {};

        [first, second].forEach(function(obj) {
            for (var prop in obj) {
                if (obj.hasOwnProperty(prop)) {
                    target[prop] = obj[prop];
                }
            }
            return target;
        });

        return target;
    }

    function _isShapedLikeParsableError(err) {
        return err.stack || err['opera#sourceloc'];
    }

    function _filtered(stackframes, filter) {
        if (typeof filter === 'function') {
            return stackframes.filter(filter);
        }
        return stackframes;
    }

    return {
        /**
         * Get a backtrace from invocation point.
         *
         * @param {Object} opts
         * @returns {Array} of StackFrame
         */
        get: function StackTrace$$get(opts) {
            var err = _generateError();
            return _isShapedLikeParsableError(err) ? this.fromError(err, opts) : this.generateArtificially(opts);
        },

        /**
         * Get a backtrace from invocation point.
         * IMPORTANT: Does not handle source maps or guess function names!
         *
         * @param {Object} opts
         * @returns {Array} of StackFrame
         */
        getSync: function StackTrace$$getSync(opts) {
            opts = _merge(_options, opts);
            var err = _generateError();
            var stack = _isShapedLikeParsableError(err) ? ErrorStackParser.parse(err) : StackGenerator.backtrace(opts);
            return _filtered(stack, opts.filter);
        },

        /**
         * Given an error object, parse it.
         *
         * @param {Error} error object
         * @param {Object} opts
         * @returns {Promise} for Array[StackFrame}
         */
        fromError: function StackTrace$$fromError(error, opts) {
            opts = _merge(_options, opts);
            var gps = new StackTraceGPS(opts);
            return new Promise(function(resolve) {
                var stackframes = _filtered(ErrorStackParser.parse(error), opts.filter);
                resolve(Promise.all(stackframes.map(function(sf) {
                    return new Promise(function(resolve) {
                        function resolveOriginal() {
                            resolve(sf);
                        }

                        gps.pinpoint(sf).then(resolve, resolveOriginal)['catch'](resolveOriginal);
                    });
                })));
            }.bind(this));
        },

        /**
         * Use StackGenerator to generate a backtrace.
         *
         * @param {Object} opts
         * @returns {Promise} of Array[StackFrame]
         */
        generateArtificially: function StackTrace$$generateArtificially(opts) {
            opts = _merge(_options, opts);
            var stackFrames = StackGenerator.backtrace(opts);
            if (typeof opts.filter === 'function') {
                stackFrames = stackFrames.filter(opts.filter);
            }
            return Promise.resolve(stackFrames);
        },

        /**
         * Given a function, wrap it such that invocations trigger a callback that
         * is called with a stack trace.
         *
         * @param {Function} fn to be instrumented
         * @param {Function} callback function to call with a stack trace on invocation
         * @param {Function} errback optional function to call with error if unable to get stack trace.
         * @param {Object} thisArg optional context object (e.g. window)
         */
        instrument: function StackTrace$$instrument(fn, callback, errback, thisArg) {
            if (typeof fn !== 'function') {
                throw new Error('Cannot instrument non-function object');
            } else if (typeof fn.__stacktraceOriginalFn === 'function') {
                // Already instrumented, return given Function
                return fn;
            }

            var instrumented = function StackTrace$$instrumented() {
                try {
                    this.get().then(callback, errback)['catch'](errback);
                    return fn.apply(thisArg || this, arguments);
                } catch (e) {
                    if (_isShapedLikeParsableError(e)) {
                        this.fromError(e).then(callback, errback)['catch'](errback);
                    }
                    throw e;
                }
            }.bind(this);
            instrumented.__stacktraceOriginalFn = fn;

            return instrumented;
        },

        /**
         * Given a function that has been instrumented,
         * revert the function to it's original (non-instrumented) state.
         *
         * @param {Function} fn to de-instrument
         */
        deinstrument: function StackTrace$$deinstrument(fn) {
            if (typeof fn !== 'function') {
                throw new Error('Cannot de-instrument non-function object');
            } else if (typeof fn.__stacktraceOriginalFn === 'function') {
                return fn.__stacktraceOriginalFn;
            } else {
                // Function not instrumented, return original
                return fn;
            }
        },

        /**
         * Given an error message and Array of StackFrames, serialize and POST to given URL.
         *
         * @param {Array} stackframes
         * @param {String} url
         * @param {String} errorMsg
         */
        report: function StackTrace$$report(stackframes, url, errorMsg) {
            return new Promise(function(resolve, reject) {
                var req = new XMLHttpRequest();
                req.onerror = reject;
                req.onreadystatechange = function onreadystatechange() {
                    if (req.readyState === 4) {
                        if (req.status >= 200 && req.status < 400) {
                            resolve(req.responseText);
                        } else {
                            reject(new Error('POST to ' + url + ' failed with status: ' + req.status));
                        }
                    }
                };
                req.open('post', url);
                req.setRequestHeader('Content-Type', 'application/json');

                var reportPayload = {stack: stackframes};
                if (errorMsg !== undefined) {
                    reportPayload.message = errorMsg;
                }

                req.send(JSON.stringify(reportPayload));
            });
        }
    };
}));
});

var MessageUtils = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });


/**
 * Some utilities to format messages.
 */
var MessageFormatUtils = (function () {
    function MessageFormatUtils() {
    }
    /**
     * Render given date in given DateFormat and return as String.
     * @param date Date
     * @param dateFormat Format
     * @returns {string} Formatted date
     */
    MessageFormatUtils.renderDate = function (date, dateFormat) {
        var lpad = function (value, chars, padWith) {
            var howMany = chars - value.length;
            if (howMany > 0) {
                var res = "";
                for (var i = 0; i < howMany; i++) {
                    res += padWith;
                }
                res += value;
                return res;
            }
            return value;
        };
        var fullYear = function (d) {
            return lpad(d.getFullYear().toString(), 4, "0");
        };
        var month = function (d) {
            return lpad((d.getMonth() + 1).toString(), 2, "0");
        };
        var day = function (d) {
            return lpad(d.getDate().toString(), 2, "0");
        };
        var hours = function (d) {
            return lpad(d.getHours().toString(), 2, "0");
        };
        var minutes = function (d) {
            return lpad(d.getMinutes().toString(), 2, "0");
        };
        var seconds = function (d) {
            return lpad(d.getSeconds().toString(), 2, "0");
        };
        var millis = function (d) {
            return lpad(d.getMilliseconds().toString(), 3, "0");
        };
        var dateSeparator = dateFormat.dateSeparator;
        var ds = "";
        switch (dateFormat.formatEnum) {
            case LoggerOptions.DateFormatEnum.Default:
                // yyyy-mm-dd hh:mm:ss,m
                ds = fullYear(date) + dateSeparator + month(date) + dateSeparator + day(date) + " " +
                    hours(date) + ":" + minutes(date) + ":" + seconds(date) + "," + millis(date);
                break;
            case LoggerOptions.DateFormatEnum.YearMonthDayTime:
                ds = fullYear(date) + dateSeparator + month(date) + dateSeparator + day(date) + " " +
                    hours(date) + ":" + minutes(date) + ":" + seconds(date);
                break;
            case LoggerOptions.DateFormatEnum.YearDayMonthWithFullTime:
                ds = fullYear(date) + dateSeparator + day(date) + dateSeparator + month(date) + " " +
                    hours(date) + ":" + minutes(date) + ":" + seconds(date) + "," + millis(date);
                break;
            case LoggerOptions.DateFormatEnum.YearDayMonthTime:
                ds = fullYear(date) + dateSeparator + day(date) + dateSeparator + month(date) + " " +
                    hours(date) + ":" + minutes(date) + ":" + seconds(date);
                break;
            default:
                throw new Error("Unsupported date format enum: " + dateFormat.formatEnum);
        }
        return ds;
    };
    /**
     * Renders given category log message in default format.
     * @param msg Message to format
     * @param addStack If true adds the stack to the output, otherwise skips it
     * @returns {string} Formatted message
     */
    MessageFormatUtils.renderDefaultMessage = function (msg, addStack) {
        var result = "";
        var logFormat = msg.logFormat;
        if (logFormat.showTimeStamp) {
            result += MessageFormatUtils.renderDate(msg.date, logFormat.dateFormat) + " ";
        }
        result += LoggerOptions.LogLevel[msg.level].toUpperCase();
        if (msg.isResolvedErrorMessage) {
            result += " (resolved)";
        }
        result += " ";
        if (logFormat.showCategoryName) {
            result += "[";
            msg.categories.forEach(function (value, idx) {
                if (idx > 0) {
                    result += ", ";
                }
                result += value.name;
            });
            result += "]";
        }
        // Get the normal string message first
        var actualStringMsg = "";
        var dataString = "";
        var messageOrLogData = msg.message;
        if (typeof messageOrLogData === "string") {
            actualStringMsg = messageOrLogData;
        }
        else {
            var logData = messageOrLogData;
            actualStringMsg = logData.msg;
            // We do have data?
            if (logData.data) {
                dataString = " [data]: " + (logData.ds ? logData.ds(logData.data) : JSON.stringify(logData.data));
            }
        }
        result += " " + actualStringMsg + "" + dataString;
        if (addStack && msg.errorAsStack !== null) {
            result += "\n" + msg.errorAsStack;
        }
        return result;
    };
    /**
     * Renders given log4j log message in default format.
     * @param msg Message to format
     * @param addStack If true adds the stack to the output, otherwise skips it
     * @returns {string} Formatted message
     */
    MessageFormatUtils.renderDefaultLog4jMessage = function (msg, addStack) {
        var format = msg.logGroupRule.logFormat;
        var result = "";
        if (format.showTimeStamp) {
            result += MessageFormatUtils.renderDate(msg.date, format.dateFormat) + " ";
        }
        result += LoggerOptions.LogLevel[msg.level].toUpperCase() + " ";
        if (format.showLoggerName) {
            result += "[" + msg.loggerName + "]";
        }
        // Get the normal string message first
        var actualStringMsg = "";
        var dataString = "";
        if (typeof msg.message === "string") {
            actualStringMsg = msg.message;
        }
        else {
            var logData = msg.message;
            actualStringMsg = logData.msg;
            // We do have data?
            if (logData.data) {
                dataString = " [data]: " + (logData.ds ? logData.ds(logData.data) : JSON.stringify(logData.data));
            }
        }
        result += " " + actualStringMsg + "" + dataString;
        if (addStack && msg.errorAsStack !== null) {
            result += "\n" + msg.errorAsStack;
        }
        return result;
    };
    /**
     * Render error as stack
     * @param error Return error as Promise
     * @returns {Promise<string>|Promise} Promise for stack
     */
    MessageFormatUtils.renderError = function (error) {
        var result = error.name + ": " + error.message + "\n@";
        return new Promise(function (resolve) {
            // This one has a promise too
            stacktrace.fromError(error, { offline: true }).then(function (frames) {
                var stackStr = (frames.map(function (frame) {
                    return frame.toString();
                })).join("\n  ");
                result += "\n" + stackStr;
                // This resolves our returned promise
                resolve(result);
            }).catch(function () {
                result = "Unexpected error object was passed in. ";
                try {
                    result += "Could not resolve it, stringified object: " + JSON.stringify(error);
                }
                catch (e) {
                    // Cannot stringify can only tell something was wrong.
                    result += "Could not resolve it or stringify it.";
                }
                resolve(result);
            });
        });
    };
    return MessageFormatUtils;
}());
exports.MessageFormatUtils = MessageFormatUtils;

});

unwrapExports(MessageUtils);
var MessageUtils_1 = MessageUtils.MessageFormatUtils;

var AbstractLogger_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });



var LogMessageInternalImpl = (function () {
    function LogMessageInternalImpl(loggerName, message, errorAsStack, error, logGroupRule, date, level, ready) {
        this._errorAsStack = null;
        this._error = null;
        this._loggerName = loggerName;
        this._message = message;
        this._errorAsStack = errorAsStack;
        this._error = error;
        this._logGroupRule = logGroupRule;
        this._date = date;
        this._level = level;
        this._ready = ready;
    }
    Object.defineProperty(LogMessageInternalImpl.prototype, "loggerName", {
        get: function () {
            return this._loggerName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "message", {
        get: function () {
            return this._message;
        },
        set: function (value) {
            this._message = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "errorAsStack", {
        get: function () {
            return this._errorAsStack;
        },
        set: function (value) {
            this._errorAsStack = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "error", {
        get: function () {
            return this._error;
        },
        set: function (value) {
            this._error = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "logGroupRule", {
        get: function () {
            return this._logGroupRule;
        },
        set: function (value) {
            this._logGroupRule = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "date", {
        get: function () {
            return this._date;
        },
        set: function (value) {
            this._date = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "level", {
        get: function () {
            return this._level;
        },
        set: function (value) {
            this._level = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "isMessageLogData", {
        get: function () {
            return typeof (this._message) !== "string";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "ready", {
        get: function () {
            return this._ready;
        },
        set: function (value) {
            this._ready = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "messageAsString", {
        get: function () {
            if (typeof (this._message) === "string") {
                return this._message;
            }
            return this._message.msg;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogMessageInternalImpl.prototype, "logData", {
        get: function () {
            var result = null;
            if (typeof (this._message) !== "string") {
                result = this.message;
            }
            return result;
        },
        enumerable: true,
        configurable: true
    });
    return LogMessageInternalImpl;
}());
/**
 * Abstract base logger, extend to easily implement a custom logger that
 * logs wherever you want. You only need to implement doLog(msg: LogMessage) and
 * log that somewhere (it will contain format and everything else).
 */
var AbstractLogger = (function () {
    function AbstractLogger(name, logGroupRuntimeSettings) {
        this._allMessages = new DataStructures.LinkedList();
        this._open = true;
        this._name = name;
        this._logGroupRuntimeSettings = logGroupRuntimeSettings;
    }
    Object.defineProperty(AbstractLogger.prototype, "name", {
        get: function () {
            return this._name;
        },
        enumerable: true,
        configurable: true
    });
    AbstractLogger.prototype.trace = function (msg, error) {
        if (error === void 0) { error = null; }
        this._log(LoggerOptions.LogLevel.Trace, msg, error);
    };
    AbstractLogger.prototype.debug = function (msg, error) {
        if (error === void 0) { error = null; }
        this._log(LoggerOptions.LogLevel.Debug, msg, error);
    };
    AbstractLogger.prototype.info = function (msg, error) {
        if (error === void 0) { error = null; }
        this._log(LoggerOptions.LogLevel.Info, msg, error);
    };
    AbstractLogger.prototype.warn = function (msg, error) {
        if (error === void 0) { error = null; }
        this._log(LoggerOptions.LogLevel.Warn, msg, error);
    };
    AbstractLogger.prototype.error = function (msg, error) {
        if (error === void 0) { error = null; }
        this._log(LoggerOptions.LogLevel.Error, msg, error);
    };
    AbstractLogger.prototype.fatal = function (msg, error) {
        if (error === void 0) { error = null; }
        this._log(LoggerOptions.LogLevel.Fatal, msg, error);
    };
    AbstractLogger.prototype.isTraceEnabled = function () {
        return this._logGroupRuntimeSettings.level === LoggerOptions.LogLevel.Trace;
    };
    AbstractLogger.prototype.isDebugEnabled = function () {
        return this._logGroupRuntimeSettings.level <= LoggerOptions.LogLevel.Debug;
    };
    AbstractLogger.prototype.isInfoEnabled = function () {
        return this._logGroupRuntimeSettings.level <= LoggerOptions.LogLevel.Info;
    };
    AbstractLogger.prototype.isWarnEnabled = function () {
        return this._logGroupRuntimeSettings.level <= LoggerOptions.LogLevel.Warn;
    };
    AbstractLogger.prototype.isErrorEnabled = function () {
        return this._logGroupRuntimeSettings.level <= LoggerOptions.LogLevel.Error;
    };
    AbstractLogger.prototype.isFatalEnabled = function () {
        return this._logGroupRuntimeSettings.level <= LoggerOptions.LogLevel.Fatal;
    };
    AbstractLogger.prototype.getLogLevel = function () {
        return this._logGroupRuntimeSettings.level;
    };
    AbstractLogger.prototype.isOpen = function () {
        return this._open;
    };
    AbstractLogger.prototype.close = function () {
        this._open = false;
        this._allMessages.clear();
    };
    AbstractLogger.prototype.createDefaultLogMessage = function (msg) {
        return MessageUtils.MessageFormatUtils.renderDefaultLog4jMessage(msg, true);
    };
    /**
     * Return optional message formatter. All LoggerTypes (except custom) will see if
     * they have this, and if so use it to log.
     * @returns {((message:LogMessage)=>string)|null}
     */
    AbstractLogger.prototype._getMessageFormatter = function () {
        return this._logGroupRuntimeSettings.formatterLogMessage;
    };
    AbstractLogger.prototype._log = function (level, msg, error) {
        if (error === void 0) { error = null; }
        if (this._open && this._logGroupRuntimeSettings.level <= level) {
            var functionMessage = function () {
                if (typeof msg === "function") {
                    return msg();
                }
                return msg;
            };
            var functionError = function () {
                if (typeof error === "function") {
                    return error();
                }
                return error;
            };
            this._allMessages.addTail(this.createMessage(level, functionMessage, functionError, new Date()));
            this.processMessages();
        }
    };
    AbstractLogger.prototype.createMessage = function (level, msg, error, date) {
        var _this = this;
        var errorResult = error();
        if (errorResult !== null) {
            var message_1 = new LogMessageInternalImpl(this._name, msg(), null, errorResult, this._logGroupRuntimeSettings.logGroupRule, date, level, false);
            MessageUtils.MessageFormatUtils.renderError(errorResult).then(function (stack) {
                message_1.errorAsStack = stack;
                message_1.ready = true;
                _this.processMessages();
            }).catch(function () {
                message_1.errorAsStack = "<UNKNOWN> unable to get stack.";
                message_1.ready = true;
                _this.processMessages();
            });
            return message_1;
        }
        return new LogMessageInternalImpl(this._name, msg(), null, errorResult, this._logGroupRuntimeSettings.logGroupRule, date, level, true);
    };
    AbstractLogger.prototype.processMessages = function () {
        // Basically we wait until errors are resolved (those messages
        // may not be ready).
        var msgs = this._allMessages;
        if (msgs.getSize() > 0) {
            do {
                var msg = msgs.getHead();
                if (msg != null) {
                    if (!msg.ready) {
                        break;
                    }
                    msgs.removeHead();
                    // This can never be null normally, but strict null checking ...
                    if (msg.message !== null) {
                        this.doLog(msg);
                    }
                }
            } while (msgs.getSize() > 0);
        }
    };
    return AbstractLogger;
}());
exports.AbstractLogger = AbstractLogger;

});

unwrapExports(AbstractLogger_1);
var AbstractLogger_2 = AbstractLogger_1.AbstractLogger;

var ConsoleLoggerImpl_1 = createCommonjsModule$1(function (module, exports) {
var __extends = (commonjsGlobal$1 && commonjsGlobal$1.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });


/**
 * Simple logger, that logs to the console. If the console is unavailable will throw exception.
 */
var ConsoleLoggerImpl = (function (_super) {
    __extends(ConsoleLoggerImpl, _super);
    function ConsoleLoggerImpl(name, logGroupRuntimeSettings) {
        return _super.call(this, name, logGroupRuntimeSettings) || this;
    }
    ConsoleLoggerImpl.prototype.doLog = function (message) {
        if (console !== undefined) {
            var logged = false;
            var logLevel = message.level;
            var messageFormatter = this._getMessageFormatter();
            var msg = void 0;
            if (messageFormatter === null) {
                msg = this.createDefaultLogMessage(message);
            }
            else {
                msg = messageFormatter(message);
            }
            /* tslint:disable:no-console */
            switch (logLevel) {
                case LoggerOptions.LogLevel.Trace:
                    // Do not try trace we don't want a stack
                    break;
                case LoggerOptions.LogLevel.Debug:
                    // Don't try, too much differences of consoles.
                    break;
                case LoggerOptions.LogLevel.Info:
                    if (console.info) {
                        console.info(msg);
                        logged = true;
                    }
                    break;
                case LoggerOptions.LogLevel.Warn:
                    if (console.warn) {
                        console.warn(msg);
                        logged = true;
                    }
                    break;
                case LoggerOptions.LogLevel.Error:
                case LoggerOptions.LogLevel.Fatal:
                    if (console.error) {
                        console.error(msg);
                        logged = true;
                    }
                    break;
                default:
                    throw new Error("Log level not supported: " + logLevel);
            }
            if (!logged) {
                console.log(msg);
            }
            /* tslint:enable:no-console */
        }
        else {
            throw new Error("Console is not defined, cannot log msg: " + message.message);
        }
    };
    return ConsoleLoggerImpl;
}(AbstractLogger_1.AbstractLogger));
exports.ConsoleLoggerImpl = ConsoleLoggerImpl;

});

unwrapExports(ConsoleLoggerImpl_1);
var ConsoleLoggerImpl_2 = ConsoleLoggerImpl_1.ConsoleLoggerImpl;

var MessageBufferLoggerImpl_1 = createCommonjsModule$1(function (module, exports) {
var __extends = (commonjsGlobal$1 && commonjsGlobal$1.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * Logger which buffers all messages, use with care due to possible high memory footprint.
 * Can be convenient in some cases. Call toString() for full output, or cast to this class
 * and call getMessages() to do something with it yourself.
 */
var MessageBufferLoggerImpl = (function (_super) {
    __extends(MessageBufferLoggerImpl, _super);
    function MessageBufferLoggerImpl(name, logGroupRuntimeSettings) {
        var _this = _super.call(this, name, logGroupRuntimeSettings) || this;
        _this.messages = [];
        return _this;
    }
    MessageBufferLoggerImpl.prototype.close = function () {
        this.messages = [];
        _super.prototype.close.call(this);
    };
    MessageBufferLoggerImpl.prototype.getMessages = function () {
        return this.messages;
    };
    MessageBufferLoggerImpl.prototype.toString = function () {
        return this.messages.map(function (msg) {
            return msg;
        }).join("\n");
    };
    MessageBufferLoggerImpl.prototype.doLog = function (message) {
        var messageFormatter = this._getMessageFormatter();
        var fullMsg;
        if (messageFormatter === null) {
            fullMsg = this.createDefaultLogMessage(message);
        }
        else {
            fullMsg = messageFormatter(message);
        }
        this.messages.push(fullMsg);
    };
    return MessageBufferLoggerImpl;
}(AbstractLogger_1.AbstractLogger));
exports.MessageBufferLoggerImpl = MessageBufferLoggerImpl;

});

unwrapExports(MessageBufferLoggerImpl_1);
var MessageBufferLoggerImpl_2 = MessageBufferLoggerImpl_1.MessageBufferLoggerImpl;

var LogGroupRuntimeSettings_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * Represents the runtime settings for a LogGroup (LogGroupRule).
 */
var LogGroupRuntimeSettings = (function () {
    function LogGroupRuntimeSettings(logGroupRule) {
        this._formatterLogMessage = null;
        this._logGroupRule = logGroupRule;
        this._level = logGroupRule.level;
        this._loggerType = logGroupRule.loggerType;
        this._logFormat = new LoggerOptions.LogFormat(new LoggerOptions.DateFormat(logGroupRule.logFormat.dateFormat.formatEnum, logGroupRule.logFormat.dateFormat.dateSeparator), logGroupRule.logFormat.showTimeStamp, logGroupRule.logFormat.showLoggerName);
        this._callBackLogger = logGroupRule.callBackLogger;
        this._formatterLogMessage = logGroupRule.formatterLogMessage;
    }
    Object.defineProperty(LogGroupRuntimeSettings.prototype, "logGroupRule", {
        /**
         * Returns original LogGroupRule (so not runtime settings!)
         * @return {LogGroupRule}
         */
        get: function () {
            return this._logGroupRule;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRuntimeSettings.prototype, "level", {
        get: function () {
            return this._level;
        },
        set: function (value) {
            this._level = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRuntimeSettings.prototype, "loggerType", {
        get: function () {
            return this._loggerType;
        },
        set: function (value) {
            this._loggerType = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRuntimeSettings.prototype, "logFormat", {
        get: function () {
            return this._logFormat;
        },
        set: function (value) {
            this._logFormat = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRuntimeSettings.prototype, "callBackLogger", {
        get: function () {
            return this._callBackLogger;
        },
        set: function (value) {
            this._callBackLogger = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRuntimeSettings.prototype, "formatterLogMessage", {
        get: function () {
            return this._formatterLogMessage;
        },
        set: function (value) {
            this._formatterLogMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    return LogGroupRuntimeSettings;
}());
exports.LogGroupRuntimeSettings = LogGroupRuntimeSettings;

});

unwrapExports(LogGroupRuntimeSettings_1);
var LogGroupRuntimeSettings_2 = LogGroupRuntimeSettings_1.LogGroupRuntimeSettings;

var LoggerFactoryImpl_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });






var LoggerFactoryImpl = (function () {
    function LoggerFactoryImpl(name, options) {
        this._loggers = new DataStructures.SimpleMap();
        this._logGroupRuntimeSettingsIndexed = [];
        this._loggerToLogGroupSettings = new DataStructures.SimpleMap();
        this._name = name;
        this.configure(options);
    }
    LoggerFactoryImpl.prototype.configure = function (options) {
        this._options = options;
        // Close any current open loggers.
        this.closeLoggers();
        this._loggerToLogGroupSettings.clear();
        this._logGroupRuntimeSettingsIndexed = [];
        var logGroupRules = this._options.logGroupRules;
        /* tslint:disable:prefer-for-of */
        for (var i = 0; i < logGroupRules.length; i++) {
            this._logGroupRuntimeSettingsIndexed.push(new LogGroupRuntimeSettings_1.LogGroupRuntimeSettings(logGroupRules[i]));
        }
        /* tslint:enable:prefer-for-of */
    };
    LoggerFactoryImpl.prototype.getLogger = function (named) {
        if (!this._options.enabled) {
            throw new Error("LoggerFactory is not enabled, please check your options passed in");
        }
        var logger = this._loggers.get(named);
        if (typeof logger !== "undefined") {
            return logger;
        }
        // Initialize logger with appropriate level
        logger = this.loadLogger(named);
        this._loggers.put(named, logger);
        return logger;
    };
    LoggerFactoryImpl.prototype.isEnabled = function () {
        return this._options.enabled;
    };
    LoggerFactoryImpl.prototype.closeLoggers = function () {
        this._loggers.forEachValue(function (logger) {
            // We can only close if AbstractLogger is used (our loggers, but user loggers may not extend it, even though unlikely).
            if (logger instanceof AbstractLogger_1.AbstractLogger) {
                logger.close();
            }
        });
        this._loggers.clear();
    };
    LoggerFactoryImpl.prototype.getName = function () {
        return this._name;
    };
    LoggerFactoryImpl.prototype.getLogGroupRuntimeSettingsByIndex = function (idx) {
        if (idx >= 0 && idx < this._logGroupRuntimeSettingsIndexed.length) {
            return this._logGroupRuntimeSettingsIndexed[idx];
        }
        return null;
    };
    LoggerFactoryImpl.prototype.getLogGroupRuntimeSettingsByLoggerName = function (nameLogger) {
        var result = this._loggerToLogGroupSettings.get(nameLogger);
        if (typeof result === "undefined") {
            return null;
        }
        return result;
    };
    LoggerFactoryImpl.prototype.getLogGroupRuntimeSettings = function () {
        return this._logGroupRuntimeSettingsIndexed.slice(0);
    };
    LoggerFactoryImpl.prototype.loadLogger = function (named) {
        var logGroupRules = this._options.logGroupRules;
        for (var i = 0; i < logGroupRules.length; i++) {
            var logGroupRule = logGroupRules[i];
            if (logGroupRule.regExp.test(named)) {
                var logGroupRuntimeSettings = this._logGroupRuntimeSettingsIndexed[i];
                var logger = void 0;
                switch (logGroupRule.loggerType) {
                    case LoggerOptions.LoggerType.Console:
                        logger = new ConsoleLoggerImpl_1.ConsoleLoggerImpl(named, logGroupRuntimeSettings);
                        break;
                    case LoggerOptions.LoggerType.MessageBuffer:
                        logger = new MessageBufferLoggerImpl_1.MessageBufferLoggerImpl(named, logGroupRuntimeSettings);
                        break;
                    case LoggerOptions.LoggerType.Custom:
                        if (logGroupRule.callBackLogger != null) {
                            logger = logGroupRule.callBackLogger(named, logGroupRuntimeSettings);
                        }
                        else {
                            throw new Error("Cannot create a custom logger, custom callback is null");
                        }
                        break;
                    default:
                        throw new Error("Cannot create a Logger for LoggerType: " + logGroupRule.loggerType);
                }
                // For a new logger map it by its name
                this._loggerToLogGroupSettings.put(named, logGroupRuntimeSettings);
                return logger;
            }
        }
        throw new Error("Failed to find a match to create a Logger for: " + named);
    };
    return LoggerFactoryImpl;
}());
exports.LoggerFactoryImpl = LoggerFactoryImpl;

});

unwrapExports(LoggerFactoryImpl_1);
var LoggerFactoryImpl_2 = LoggerFactoryImpl_1.LoggerFactoryImpl;

var AbstractCategoryLogger_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });



var CategoryLogMessageImpl = (function () {
    function CategoryLogMessageImpl(message, error, categories, date, level, logFormat, ready) {
        this._resolvedErrorMessage = false;
        this._errorAsStack = null;
        this._message = message;
        this._error = error;
        this._categories = categories;
        this._date = date;
        this._level = level;
        this._logFormat = logFormat;
        this._ready = ready;
    }
    Object.defineProperty(CategoryLogMessageImpl.prototype, "message", {
        get: function () {
            return this._message;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "error", {
        get: function () {
            return this._error;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "categories", {
        get: function () {
            return this._categories;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "date", {
        get: function () {
            return this._date;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "level", {
        get: function () {
            return this._level;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "logFormat", {
        get: function () {
            return this._logFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "isMessageLogData", {
        get: function () {
            return typeof (this._message) !== "string";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "messageAsString", {
        get: function () {
            if (typeof (this._message) === "string") {
                return this._message;
            }
            return this._message.msg;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "logData", {
        get: function () {
            var result = null;
            if (typeof (this._message) !== "string") {
                result = this.message;
            }
            return result;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "isResolvedErrorMessage", {
        get: function () {
            return this._resolvedErrorMessage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryLogMessageImpl.prototype, "errorAsStack", {
        get: function () {
            return this._errorAsStack;
        },
        set: function (stack) {
            this._errorAsStack = stack;
        },
        enumerable: true,
        configurable: true
    });
    CategoryLogMessageImpl.prototype.isReady = function () {
        return this._ready;
    };
    CategoryLogMessageImpl.prototype.setReady = function (value) {
        this._ready = value;
    };
    Object.defineProperty(CategoryLogMessageImpl.prototype, "resolvedErrorMessage", {
        get: function () {
            return this._resolvedErrorMessage;
        },
        set: function (value) {
            this._resolvedErrorMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    return CategoryLogMessageImpl;
}());
/**
 * Abstract category logger, use as your base class for new type of loggers (it
 * saves you a lot of work) and override doLog(CategoryLogMessage). The message argument
 * provides full access to anything related to the logging event.
 * If you just want the standard line of logging, call: this.createDefaultLogMessage(msg) on
 * this class which will return you the formatted log message as string (e.g. the
 * default loggers all use this).
 */
var AbstractCategoryLogger = (function () {
    function AbstractCategoryLogger(rootCategory, runtimeSettings) {
        this.allMessages = new DataStructures.LinkedList();
        this.rootCategory = rootCategory;
        this.runtimeSettings = runtimeSettings;
    }
    AbstractCategoryLogger.prototype.trace = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Trace, msg, null, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.debug = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Debug, msg, null, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.info = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Info, msg, null, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.warn = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Warn, msg, null, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.error = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Error, msg, error, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.fatal = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Fatal, msg, error, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.resolved = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        this._log.apply(this, [LoggerOptions.LogLevel.Error, msg, error, true].concat(categories));
    };
    AbstractCategoryLogger.prototype.log = function (level, msg, error) {
        var categories = [];
        for (var _i = 3; _i < arguments.length; _i++) {
            categories[_i - 3] = arguments[_i];
        }
        this._log.apply(this, [level, msg, error, false].concat(categories));
    };
    AbstractCategoryLogger.prototype.getRootCategory = function () {
        return this.rootCategory;
    };
    AbstractCategoryLogger.prototype.createDefaultLogMessage = function (msg) {
        return MessageUtils.MessageFormatUtils.renderDefaultMessage(msg, true);
    };
    /**
     * Return optional message formatter. All LoggerTypes (except custom) will see if
     * they have this, and if so use it to log.
     * @returns {((message:CategoryLogMessage)=>string)|null}
     */
    AbstractCategoryLogger.prototype._getMessageFormatter = function () {
        var categorySettings = this.runtimeSettings.getCategorySettings(this.rootCategory);
        // Should not happen but make ts happy
        if (categorySettings === null) {
            throw new Error("Did not find CategorySettings for rootCategory: " + this.rootCategory.name);
        }
        return categorySettings.formatterLogMessage;
    };
    AbstractCategoryLogger.prototype._log = function (level, msg, error, resolved) {
        if (error === void 0) { error = null; }
        if (resolved === void 0) { resolved = false; }
        var categories = [];
        for (var _i = 4; _i < arguments.length; _i++) {
            categories[_i - 4] = arguments[_i];
        }
        // this._logInternal(level, () => msg, () => error, resolved, ...categories);
        var functionMessage = function () {
            if (typeof msg === "function") {
                return msg();
            }
            return msg;
        };
        var functionError = function () {
            if (typeof error === "function") {
                return error();
            }
            return error;
        };
        this._logInternal.apply(this, [level, functionMessage, functionError, resolved].concat(categories));
    };
    AbstractCategoryLogger.prototype._logInternal = function (level, msg, error, resolved) {
        var _this = this;
        var categories = [];
        for (var _i = 4; _i < arguments.length; _i++) {
            categories[_i - 4] = arguments[_i];
        }
        var logCategories = [this.rootCategory];
        // Log root category by default if none present
        if (typeof categories !== "undefined" && categories.length > 0) {
            logCategories = logCategories.concat(categories.filter(function (c) { return c !== _this.rootCategory; }));
        }
        var _loop_1 = function (i) {
            var category = logCategories[i];
            if (category === null) {
                throw new Error("Cannot have a null element within categories, at index=" + i);
            }
            var settings = this_1.runtimeSettings.getCategorySettings(category);
            if (settings === null) {
                throw new Error("Category with path: " + category.getCategoryPath() + " is not registered with this logger, maybe " +
                    "you registered it with a different root logger?");
            }
            if (settings.logLevel <= level) {
                var actualError = error !== null ? error() : null;
                if (actualError === null) {
                    var logMessage = new CategoryLogMessageImpl(msg(), actualError, logCategories, new Date(), level, settings.logFormat, true);
                    logMessage.resolvedErrorMessage = resolved;
                    this_1.allMessages.addTail(logMessage);
                    this_1.processMessages();
                }
                else {
                    var logMessage_1 = new CategoryLogMessageImpl(msg(), actualError, logCategories, new Date(), level, settings.logFormat, false);
                    logMessage_1.resolvedErrorMessage = resolved;
                    this_1.allMessages.addTail(logMessage_1);
                    MessageUtils.MessageFormatUtils.renderError(actualError).then(function (stack) {
                        logMessage_1.errorAsStack = stack;
                        logMessage_1.setReady(true);
                        _this.processMessages();
                    }).catch(function () {
                        logMessage_1.errorAsStack = "<UNKNOWN> unable to get stack.";
                        logMessage_1.setReady(true);
                        _this.processMessages();
                    });
                }
                return "break";
            }
        };
        var this_1 = this;
        // Get the runtime levels for given categories. If their level is lower than given level, we log.
        // In addition we pass along which category/categories we log this statement for.
        for (var i = 0; i < logCategories.length; i++) {
            var state_1 = _loop_1(i);
            if (state_1 === "break")
                break;
        }
    };
    AbstractCategoryLogger.prototype.processMessages = function () {
        // Basically we wait until errors are resolved (those messages
        // may not be ready).
        var msgs = this.allMessages;
        if (msgs.getSize() > 0) {
            do {
                var msg = msgs.getHead();
                if (msg != null) {
                    if (!msg.isReady()) {
                        break;
                    }
                    msgs.removeHead();
                    this.doLog(msg);
                }
            } while (msgs.getSize() > 0);
        }
    };
    return AbstractCategoryLogger;
}());
exports.AbstractCategoryLogger = AbstractCategoryLogger;

});

unwrapExports(AbstractCategoryLogger_1);
var AbstractCategoryLogger_2 = AbstractCategoryLogger_1.AbstractCategoryLogger;

var CategoryConsoleLoggerImpl_1 = createCommonjsModule$1(function (module, exports) {
var __extends = (commonjsGlobal$1 && commonjsGlobal$1.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });


/**
 * Simple logger, that logs to the console. If the console is unavailable will throw an exception.
 */
var CategoryConsoleLoggerImpl = (function (_super) {
    __extends(CategoryConsoleLoggerImpl, _super);
    function CategoryConsoleLoggerImpl(rootCategory, runtimeSettings) {
        return _super.call(this, rootCategory, runtimeSettings) || this;
    }
    CategoryConsoleLoggerImpl.prototype.doLog = function (msg) {
        if (console !== undefined) {
            var messageFormatter = this._getMessageFormatter();
            var fullMsg = void 0;
            if (messageFormatter === null) {
                fullMsg = this.createDefaultLogMessage(msg);
            }
            else {
                fullMsg = messageFormatter(msg);
            }
            var logged = false;
            /* tslint:disable:no-console */
            switch (msg.level) {
                case LoggerOptions.LogLevel.Trace:
                    // Don't try trace we don't want stacks
                    break;
                case LoggerOptions.LogLevel.Debug:
                    // Don't try, too much differences of consoles.
                    break;
                case LoggerOptions.LogLevel.Info:
                    if (console.info) {
                        console.info(fullMsg);
                        logged = true;
                    }
                    break;
                case LoggerOptions.LogLevel.Warn:
                    if (console.warn) {
                        console.warn(fullMsg);
                        logged = true;
                    }
                    break;
                case LoggerOptions.LogLevel.Error:
                case LoggerOptions.LogLevel.Fatal:
                    if (console.error) {
                        console.error(fullMsg);
                        logged = true;
                    }
                    break;
                default:
                    throw new Error("Unsupported level: " + msg.level);
            }
            if (!logged) {
                console.log(fullMsg);
            }
            /* tslint:enable:no-console */
        }
        else {
            throw new Error("Console is not defined, cannot log msg: " + msg.messageAsString);
        }
    };
    return CategoryConsoleLoggerImpl;
}(AbstractCategoryLogger_1.AbstractCategoryLogger));
exports.CategoryConsoleLoggerImpl = CategoryConsoleLoggerImpl;

});

unwrapExports(CategoryConsoleLoggerImpl_1);
var CategoryConsoleLoggerImpl_2 = CategoryConsoleLoggerImpl_1.CategoryConsoleLoggerImpl;

var CategoryDelegateLoggerImpl_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Delegate logger, delegates logging to given logger (constructor).
 */
var CategoryDelegateLoggerImpl = (function () {
    function CategoryDelegateLoggerImpl(delegate) {
        this._delegate = delegate;
    }
    Object.defineProperty(CategoryDelegateLoggerImpl.prototype, "delegate", {
        get: function () {
            return this._delegate;
        },
        set: function (value) {
            this._delegate = value;
        },
        enumerable: true,
        configurable: true
    });
    CategoryDelegateLoggerImpl.prototype.trace = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        (_a = this._delegate).trace.apply(_a, [msg].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.debug = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        (_a = this._delegate).debug.apply(_a, [msg].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.info = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        (_a = this._delegate).info.apply(_a, [msg].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.warn = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        (_a = this._delegate).warn.apply(_a, [msg].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.error = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        (_a = this._delegate).error.apply(_a, [msg, error].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.fatal = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        (_a = this._delegate).fatal.apply(_a, [msg, error].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.resolved = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        (_a = this._delegate).resolved.apply(_a, [msg, error].concat(categories));
        var _a;
    };
    CategoryDelegateLoggerImpl.prototype.log = function (level, msg, error) {
        var categories = [];
        for (var _i = 3; _i < arguments.length; _i++) {
            categories[_i - 3] = arguments[_i];
        }
        (_a = this._delegate).log.apply(_a, [level, msg, error].concat(categories));
        var _a;
    };
    return CategoryDelegateLoggerImpl;
}());
exports.CategoryDelegateLoggerImpl = CategoryDelegateLoggerImpl;

});

unwrapExports(CategoryDelegateLoggerImpl_1);
var CategoryDelegateLoggerImpl_2 = CategoryDelegateLoggerImpl_1.CategoryDelegateLoggerImpl;

var CategoryExtensionLoggerImpl_1 = createCommonjsModule$1(function (module, exports) {
var __extends = (commonjsGlobal$1 && commonjsGlobal$1.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });


/**
 * This class should not be used directly, it is used for communication with the extension only.
 */
var CategoryExtensionLoggerImpl = (function (_super) {
    __extends(CategoryExtensionLoggerImpl, _super);
    function CategoryExtensionLoggerImpl(rootCategory, runtimeSettings) {
        return _super.call(this, rootCategory, runtimeSettings) || this;
    }
    CategoryExtensionLoggerImpl.prototype.doLog = function (msg) {
        if (typeof window !== "undefined") {
            ExtensionHelper_1$1.ExtensionHelper.sendCategoryLogMessage(msg);
        }
        else {
            /* tslint:disable:no-console */
            console.log("window is not available, you must be running in a browser for this. Dropped message.");
            /* tslint:enable:no-console */
        }
    };
    return CategoryExtensionLoggerImpl;
}(AbstractCategoryLogger_1.AbstractCategoryLogger));
exports.CategoryExtensionLoggerImpl = CategoryExtensionLoggerImpl;

});

unwrapExports(CategoryExtensionLoggerImpl_1);
var CategoryExtensionLoggerImpl_2 = CategoryExtensionLoggerImpl_1.CategoryExtensionLoggerImpl;

var CategoryMessageBufferImpl = createCommonjsModule$1(function (module, exports) {
var __extends = (commonjsGlobal$1 && commonjsGlobal$1.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * Logger which buffers all messages, use with care due to possible high memory footprint.
 * Can be convenient in some cases. Call toString() for full output, or cast to this class
 * and call getMessages() to do something with it yourself.
 */
var CategoryMessageBufferLoggerImpl = (function (_super) {
    __extends(CategoryMessageBufferLoggerImpl, _super);
    function CategoryMessageBufferLoggerImpl() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.messages = [];
        return _this;
    }
    CategoryMessageBufferLoggerImpl.prototype.getMessages = function () {
        return this.messages;
    };
    CategoryMessageBufferLoggerImpl.prototype.toString = function () {
        return this.messages.map(function (msg) {
            return msg;
        }).join("\n");
    };
    CategoryMessageBufferLoggerImpl.prototype.doLog = function (msg) {
        var messageFormatter = this._getMessageFormatter();
        var fullMsg;
        if (messageFormatter === null) {
            fullMsg = this.createDefaultLogMessage(msg);
        }
        else {
            fullMsg = messageFormatter(msg);
        }
        this.messages.push(fullMsg);
    };
    return CategoryMessageBufferLoggerImpl;
}(AbstractCategoryLogger_1.AbstractCategoryLogger));
exports.CategoryMessageBufferLoggerImpl = CategoryMessageBufferLoggerImpl;

});

unwrapExports(CategoryMessageBufferImpl);
var CategoryMessageBufferImpl_1 = CategoryMessageBufferImpl.CategoryMessageBufferLoggerImpl;

var CategoryRuntimeSettings_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * RuntimeSettings for a category, at runtime these are associated to a category.
 */
var CategoryRuntimeSettings = (function () {
    function CategoryRuntimeSettings(category, logLevel, loggerType, logFormat, callBackLogger, formatterLogMessage) {
        if (logLevel === void 0) { logLevel = LoggerOptions.LogLevel.Error; }
        if (loggerType === void 0) { loggerType = LoggerOptions.LoggerType.Console; }
        if (logFormat === void 0) { logFormat = new LoggerOptions.CategoryLogFormat(); }
        if (callBackLogger === void 0) { callBackLogger = null; }
        if (formatterLogMessage === void 0) { formatterLogMessage = null; }
        this._formatterLogMessage = null;
        this._category = category;
        this._logLevel = logLevel;
        this._loggerType = loggerType;
        this._logFormat = logFormat;
        this._callBackLogger = callBackLogger;
        this._formatterLogMessage = formatterLogMessage;
    }
    Object.defineProperty(CategoryRuntimeSettings.prototype, "category", {
        get: function () {
            return this._category;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryRuntimeSettings.prototype, "logLevel", {
        get: function () {
            return this._logLevel;
        },
        set: function (value) {
            this._logLevel = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryRuntimeSettings.prototype, "loggerType", {
        get: function () {
            return this._loggerType;
        },
        set: function (value) {
            this._loggerType = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryRuntimeSettings.prototype, "logFormat", {
        get: function () {
            return this._logFormat;
        },
        set: function (value) {
            this._logFormat = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryRuntimeSettings.prototype, "callBackLogger", {
        get: function () {
            return this._callBackLogger;
        },
        set: function (value) {
            this._callBackLogger = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryRuntimeSettings.prototype, "formatterLogMessage", {
        get: function () {
            return this._formatterLogMessage;
        },
        set: function (value) {
            this._formatterLogMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    return CategoryRuntimeSettings;
}());
exports.CategoryRuntimeSettings = CategoryRuntimeSettings;

});

unwrapExports(CategoryRuntimeSettings_1);
var CategoryRuntimeSettings_2 = CategoryRuntimeSettings_1.CategoryRuntimeSettings;

var CategoryConfiguration_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * Default configuration, can be used to initially set a different default configuration
 * on the CategoryServiceFactory. This will be applied to all categories already registered (or
 * registered in the future). Can also be applied to one Category (and childs).
 */
var CategoryConfiguration = (function () {
    /**
     * Create a new instance
     * @param logLevel Log level for all loggers, default is LogLevel.Error
     * @param loggerType Where to log, default is LoggerType.Console
     * @param logFormat What logging format to use, use default instance, for default values see CategoryLogFormat.
     * @param callBackLogger Optional callback, if LoggerType.Custom is used as loggerType. In that case must return a new Logger instance.
     *            It is recommended to extend AbstractCategoryLogger to make your custom logger.
     */
    function CategoryConfiguration(logLevel, loggerType, logFormat, callBackLogger) {
        if (logLevel === void 0) { logLevel = LoggerOptions.LogLevel.Error; }
        if (loggerType === void 0) { loggerType = LoggerOptions.LoggerType.Console; }
        if (logFormat === void 0) { logFormat = new LoggerOptions.CategoryLogFormat(); }
        if (callBackLogger === void 0) { callBackLogger = null; }
        this._formatterLogMessage = null;
        this._logLevel = logLevel;
        this._loggerType = loggerType;
        this._logFormat = logFormat;
        this._callBackLogger = callBackLogger;
        if (this._loggerType === LoggerOptions.LoggerType.Custom && this.callBackLogger === null) {
            throw new Error("If you specify loggerType to be Custom, you must provide the callBackLogger argument");
        }
    }
    Object.defineProperty(CategoryConfiguration.prototype, "logLevel", {
        get: function () {
            return this._logLevel;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryConfiguration.prototype, "loggerType", {
        get: function () {
            return this._loggerType;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryConfiguration.prototype, "logFormat", {
        get: function () {
            return this._logFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryConfiguration.prototype, "callBackLogger", {
        get: function () {
            return this._callBackLogger;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryConfiguration.prototype, "formatterLogMessage", {
        /**
         * Get the formatterLogMessage function, see comment on the setter.
         * @returns {((message:CategoryLogMessage)=>string)|null}
         */
        get: function () {
            return this._formatterLogMessage;
        },
        /**
         * Set the default formatterLogMessage function, if set it is applied to all type of loggers except for a custom logger.
         * By default this is null (not set). You can assign a function to allow custom formatting of a log message.
         * Each log message will call this function then and expects your function to format the message and return a string.
         * Will throw an error if you attempt to set a formatterLogMessage if the LoggerType is custom.
         * @param value The formatter function, or null to reset it.
         */
        set: function (value) {
            if (value !== null && this._loggerType === LoggerOptions.LoggerType.Custom) {
                throw new Error("You cannot specify a formatter for log messages if your loggerType is Custom");
            }
            this._formatterLogMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    CategoryConfiguration.prototype.copy = function () {
        var config = new CategoryConfiguration(this.logLevel, this.loggerType, this.logFormat.copy(), this.callBackLogger);
        config.formatterLogMessage = this.formatterLogMessage;
        return config;
    };
    return CategoryConfiguration;
}());
exports.CategoryConfiguration = CategoryConfiguration;

});

unwrapExports(CategoryConfiguration_1);
var CategoryConfiguration_2 = CategoryConfiguration_1.CategoryConfiguration;

var CategoryService = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });









/**
 * The service (only available as singleton) for all category related stuff as
 * retrieving, registering a logger. You should normally NOT use this,
 * instead use CategoryServiceFactory which is meant for end users.
 */
var CategoryServiceImpl = (function () {
    function CategoryServiceImpl() {
        this._defaultConfig = new CategoryConfiguration_1.CategoryConfiguration();
        this._mapState = new DataStructures.SimpleMap();
        // Private constructor
        ExtensionHelper_1$1.ExtensionHelper.register();
    }
    CategoryServiceImpl.getInstance = function () {
        // Load on-demand, to assure webpack ordering of module usage doesn't screw things over
        // for us when we accidentally change the order.
        if (CategoryServiceImpl._INSTANCE === null) {
            CategoryServiceImpl._INSTANCE = new CategoryServiceImpl();
        }
        return CategoryServiceImpl._INSTANCE;
    };
    CategoryServiceImpl.prototype.getLogger = function (category) {
        return this.createOrGetCategoryState(category).logger;
    };
    /**
     * Clears everything, including a default configuration you may have set.
     * After this you need to re-register your categories etc.
     */
    CategoryServiceImpl.prototype.clear = function () {
        this._mapState.clear();
        this.setDefaultConfiguration(new CategoryConfiguration_1.CategoryConfiguration());
    };
    CategoryServiceImpl.prototype.getCategorySettings = function (category) {
        return this.createOrGetCategoryState(category).currentRuntimeSettings;
    };
    CategoryServiceImpl.prototype.getOriginalCategorySettings = function (category) {
        return this.createOrGetCategoryState(category).originalRuntimeSettings;
    };
    /**
     * Set the default configuration. New root loggers created get this
     * applied. If you want to reset all current loggers to have this
     * applied as well, pass in reset=true (the default is false). All
     * categories will be reset then as well.
     * @param config New config
     * @param reset Defaults to true. Set to true to reset all loggers and current runtimesettings.
     */
    CategoryServiceImpl.prototype.setDefaultConfiguration = function (config, reset) {
        if (reset === void 0) { reset = true; }
        this._defaultConfig = config;
        if (reset) {
            this._mapState.forEachValue(function (state) {
                state.updateSettings(config);
            });
        }
    };
    /**
     * Set new configuration settings for a category (and possibly its child categories)
     * @param config Config
     * @param category Category
     * @param applyChildren True to apply to child categories, defaults to false.
     */
    CategoryServiceImpl.prototype.setConfigurationCategory = function (config, category, applyChildren) {
        var _this = this;
        if (applyChildren === void 0) { applyChildren = false; }
        this.createOrGetCategoryState(category).updateSettings(config);
        // Apply the settings to children recursive if requested
        if (applyChildren) {
            category.children.forEach(function (child) {
                // False flag, a child cannot reset a rootlogger
                _this.setConfigurationCategory(config, child, applyChildren);
            });
        }
    };
    CategoryServiceImpl.prototype.registerCategory = function (category) {
        if (category === null || typeof category === "undefined") {
            throw new Error("Category CANNOT be null/undefined");
        }
        if (this._mapState.exists(CategoryServiceImpl.getCategoryKey(category))) {
            throw new Error("Cannot add this root category with name: " + category.name + ", it already exists (same name in hierarchy).");
        }
        this.createOrGetCategoryState(category);
    };
    /**
     * Used to enable integration with chrome extension. Do not use manually, the
     * extension and the logger framework deal with this.
     */
    CategoryServiceImpl.prototype.enableExtensionIntegration = function () {
        var _this = this;
        this._mapState.forEachValue(function (state) { return state.enableForExtension(_this); });
    };
    /**
     * Return all root categories currently registered.
     */
    CategoryServiceImpl.prototype.getRootCategories = function () {
        return this._mapState.values().filter(function (state) { return state.category.parent == null; }).map(function (state) { return state.category; });
    };
    /**
     * Return Category by id
     * @param id The id of the category to find
     * @returns {Category} or null if not found
     */
    CategoryServiceImpl.prototype.getCategoryById = function (id) {
        var result = this._mapState.values().filter(function (state) { return state.category.id === id; }).map(function (state) { return state.category; });
        if (result.length === 1) {
            return result[0];
        }
        return null;
    };
    CategoryServiceImpl.prototype.createOrGetCategoryState = function (category) {
        var key = CategoryServiceImpl.getCategoryKey(category);
        var state = this._mapState.get(key);
        if (typeof state !== "undefined") {
            return state;
        }
        var newState = this.createState(category);
        this._mapState.put(key, newState);
        return newState;
    };
    CategoryServiceImpl.prototype.createState = function (category) {
        var _this = this;
        return new CategoryState(category, function () { return _this._defaultConfig; }, function (cat1) { return _this.createLogger(cat1); });
    };
    CategoryServiceImpl.prototype.createLogger = function (category) {
        // Default is always a console logger
        switch (this._defaultConfig.loggerType) {
            case LoggerOptions.LoggerType.Console:
                return new CategoryConsoleLoggerImpl_1.CategoryConsoleLoggerImpl(category, this);
            case LoggerOptions.LoggerType.MessageBuffer:
                return new CategoryMessageBufferImpl.CategoryMessageBufferLoggerImpl(category, this);
            case LoggerOptions.LoggerType.Custom:
                if (this._defaultConfig.callBackLogger === null) {
                    throw new Error("Cannot create custom logger, custom callback is null");
                }
                else {
                    return this._defaultConfig.callBackLogger(category, this);
                }
            default:
                throw new Error("Cannot create a Logger for LoggerType: " + this._defaultConfig.loggerType);
        }
    };
    CategoryServiceImpl.getCategoryKey = function (category) {
        return category.getCategoryPath();
    };
    // Singleton category service, used by CategoryServiceFactory as well as Categories.
    // Loaded on demand. Do NOT change as webpack may pack things in wrong order otherwise.
    CategoryServiceImpl._INSTANCE = null;
    return CategoryServiceImpl;
}());
exports.CategoryServiceImpl = CategoryServiceImpl;
var CategoryState = (function () {
    function CategoryState(category, defaultConfig, createLogger) {
        this._category = category;
        this._lazyState = new LazyState(category, defaultConfig, createLogger);
    }
    Object.defineProperty(CategoryState.prototype, "category", {
        get: function () {
            return this._category;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryState.prototype, "logger", {
        get: function () {
            return this._lazyState.getLogger();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryState.prototype, "originalRuntimeSettings", {
        get: function () {
            return this._lazyState.getOriginalRuntimeSettings();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CategoryState.prototype, "currentRuntimeSettings", {
        get: function () {
            return this._lazyState.getCurrentRuntimeSettings();
        },
        enumerable: true,
        configurable: true
    });
    CategoryState.prototype.enableForExtension = function (runtimeSettings) {
        this._lazyState.enableForExtension(runtimeSettings);
    };
    CategoryState.prototype.updateSettings = function (config) {
        this._lazyState.updateSettings(config);
    };
    return CategoryState;
}());
var LazyState = (function () {
    function LazyState(category, defaultConfig, createLogger) {
        this._category = category;
        this._defaultConfig = defaultConfig;
        this._createLogger = createLogger;
    }
    LazyState.prototype.isLoaded = function () {
        return (typeof this._logger !== "undefined");
    };
    LazyState.prototype.getLogger = function () {
        this.loadLoggerOnDemand();
        return this._delegateLogger;
    };
    LazyState.prototype.getOriginalRuntimeSettings = function () {
        this.loadLoggerOnDemand();
        return this._originalRuntimeSettings;
    };
    LazyState.prototype.getCurrentRuntimeSettings = function () {
        this.loadLoggerOnDemand();
        return this._currentRuntimeSettings;
    };
    LazyState.prototype.enableForExtension = function (runtimeSettings) {
        this.loadLoggerOnDemand();
        if (!(this._wrappedLogger instanceof CategoryExtensionLoggerImpl_1.CategoryExtensionLoggerImpl)) {
            /* tslint:disable no-console */
            console.log("Reconfiguring logger for extension for category: " + this._category.name);
            /* tslint:enable no-console */
            this._wrappedLogger = new CategoryExtensionLoggerImpl_1.CategoryExtensionLoggerImpl(this._category, runtimeSettings);
            this._delegateLogger.delegate = this._wrappedLogger;
        }
    };
    LazyState.prototype.updateSettings = function (config) {
        if (this.isLoaded()) {
            this._currentRuntimeSettings.logLevel = config.logLevel;
            this._currentRuntimeSettings.loggerType = config.loggerType;
            this._currentRuntimeSettings.logFormat = config.logFormat;
            this._currentRuntimeSettings.callBackLogger = config.callBackLogger;
            this._currentRuntimeSettings.formatterLogMessage = config.formatterLogMessage;
            // Replace the real logger, it may have changed.
            this._logger = this._createLogger(this._category);
            if (!(this._wrappedLogger instanceof CategoryExtensionLoggerImpl_1.CategoryExtensionLoggerImpl)) {
                this._wrappedLogger = this._logger;
            }
            this._delegateLogger.delegate = this._wrappedLogger;
        }
        else {
            // Set this config, it may be for the category specific, the default is therefore not good enough.
            this._defaultConfig = function () { return config; };
        }
    };
    LazyState.prototype.loadLoggerOnDemand = function () {
        if (!this.isLoaded()) {
            this._logger = this._createLogger(this._category);
            this._wrappedLogger = this._logger;
            this._delegateLogger = new CategoryDelegateLoggerImpl_1.CategoryDelegateLoggerImpl(this._wrappedLogger);
            this._originalRuntimeSettings = this.initNewSettings();
            this._currentRuntimeSettings = this.initNewSettings();
        }
    };
    LazyState.prototype.initNewSettings = function () {
        var defSettings = this._defaultConfig().copy();
        return new CategoryRuntimeSettings_1.CategoryRuntimeSettings(this._category, defSettings.logLevel, defSettings.loggerType, defSettings.logFormat, defSettings.callBackLogger, defSettings.formatterLogMessage);
    };
    return LazyState;
}());

});

unwrapExports(CategoryService);
var CategoryService_1 = CategoryService.CategoryServiceImpl;

var ExtensionHelper_1$1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });



var ExtensionHelper = (function () {
    function ExtensionHelper() {
        // Private constructor
    }
    /**
     * Enables the window event listener to listen to messages (from extensions).
     * Can be registered/enabled only once.
     */
    ExtensionHelper.register = function () {
        if (!ExtensionHelper.registered) {
            ExtensionHelper.registered = true;
            var listener = function (evt) {
                var msg = evt.data;
                if (msg !== null) {
                    ExtensionHelper.processMessageFromExtension(msg);
                }
            };
            if (typeof window !== "undefined") {
                window.removeEventListener("message", listener);
                window.addEventListener("message", listener);
            }
        }
    };
    ExtensionHelper.processMessageFromExtension = function (msg) {
        if (!ExtensionHelper.registered) {
            return;
        }
        /* tslint:disable:no-console */
        if (msg.from === "tsl-extension") {
            var data = msg.data;
            switch (data.type) {
                case "register":
                    ExtensionHelper.enableExtensionIntegration();
                    break;
                case "request-change-loglevel":
                    var valueRequest = data.value;
                    var catsApplied = ExtensionHelper.applyLogLevel(valueRequest.categoryId, valueRequest.logLevel, valueRequest.recursive);
                    if (catsApplied.length > 0) {
                        // Send changes back
                        ExtensionHelper.sendCategoriesRuntimeUpdateMessage(catsApplied);
                    }
                    break;
                default:
                    console.log("Unknown command to process message from extension, command was: " + data.type);
                    break;
            }
        }
        /* tslint:enable:no-console */
    };
    ExtensionHelper.sendCategoryLogMessage = function (msg) {
        if (!ExtensionHelper.registered) {
            return;
        }
        var categoryIds = msg.categories.map(function (cat) {
            return cat.id;
        });
        var content = {
            type: "log-message",
            value: {
                categories: categoryIds,
                errorAsStack: msg.errorAsStack,
                formattedMessage: MessageUtils.MessageFormatUtils.renderDefaultMessage(msg, false),
                logLevel: LoggerOptions.LogLevel[msg.level].toString(),
                message: msg.messageAsString,
                resolvedErrorMessage: msg.isResolvedErrorMessage
            }
        };
        var message = {
            data: content,
            from: "tsl-logging",
        };
        ExtensionHelper.sendMessage(message);
    };
    ExtensionHelper.sendCategoriesRuntimeUpdateMessage = function (categories) {
        if (!ExtensionHelper.registered) {
            return;
        }
        var service = CategoryService.CategoryServiceImpl.getInstance();
        var catLevels = { categories: Array() };
        categories.forEach(function (cat) {
            var catSettings = service.getCategorySettings(cat);
            if (catSettings != null) {
                catLevels.categories.push({ id: cat.id, logLevel: LoggerOptions.LogLevel[catSettings.logLevel].toString() });
            }
        });
        var content = {
            type: "categories-rt-update",
            value: catLevels,
        };
        var message = {
            data: content,
            from: "tsl-logging"
        };
        ExtensionHelper.sendMessage(message);
    };
    ExtensionHelper.sendRootCategoriesToExtension = function () {
        if (!ExtensionHelper.registered) {
            return;
        }
        var categories = CategoryService.CategoryServiceImpl.getInstance().getRootCategories().map(function (cat) {
            return ExtensionHelper.getCategoryAsJSON(cat);
        });
        var content = {
            type: "root-categories-tree",
            value: categories
        };
        var message = {
            data: content,
            from: "tsl-logging"
        };
        ExtensionHelper.sendMessage(message);
    };
    /**
     * If extension integration is enabled, will send the root categories over to the extension.
     * Otherwise does nothing.
     */
    ExtensionHelper.getCategoryAsJSON = function (cat) {
        var childCategories = cat.children.map(function (child) {
            return ExtensionHelper.getCategoryAsJSON(child);
        });
        return {
            children: childCategories,
            id: cat.id,
            logLevel: LoggerOptions.LogLevel[cat.logLevel].toString(),
            name: cat.name,
            parentId: (cat.parent != null ? cat.parent.id : null),
        };
    };
    ExtensionHelper.applyLogLevel = function (categoryId, logLevel, recursive) {
        var cats = [];
        var category = CategoryService.CategoryServiceImpl.getInstance().getCategoryById(categoryId);
        if (category != null) {
            ExtensionHelper._applyLogLevelRecursive(category, LoggerOptions.LogLevel.fromString(logLevel), recursive, cats);
        }
        else {
            /* tslint:disable:no-console */
            console.log("Could not change log level, failed to find category with id: " + categoryId);
            /* tslint:enable:no-console */
        }
        return cats;
    };
    ExtensionHelper._applyLogLevelRecursive = function (category, logLevel, recursive, cats) {
        var categorySettings = CategoryService.CategoryServiceImpl.getInstance().getCategorySettings(category);
        if (categorySettings != null) {
            categorySettings.logLevel = logLevel;
            cats.push(category);
            if (recursive) {
                category.children.forEach(function (child) {
                    ExtensionHelper._applyLogLevelRecursive(child, logLevel, recursive, cats);
                });
            }
        }
    };
    ExtensionHelper.getAllCategories = function () {
        var cats = [];
        var addCats = function (cat, allCats) {
            allCats.push(cat);
            cat.children.forEach(function (catChild) {
                addCats(catChild, allCats);
            });
        };
        CategoryService.CategoryServiceImpl.getInstance().getRootCategories().forEach(function (cat) {
            addCats(cat, cats);
        });
        return cats;
    };
    ExtensionHelper.sendMessage = function (msg) {
        if (!ExtensionHelper.registered) {
            return;
        }
        if (typeof window !== "undefined") {
            window.postMessage(msg, "*");
        }
    };
    /**
     *  Extension framework will call this to enable the integration between two,
     *  after this call the framework will respond with postMessage() messages.
     */
    ExtensionHelper.enableExtensionIntegration = function () {
        if (!ExtensionHelper.registered) {
            return;
        }
        var instance = CategoryService.CategoryServiceImpl.getInstance();
        instance.enableExtensionIntegration();
        // Send over all categories
        ExtensionHelper.sendRootCategoriesToExtension();
        // Send over the current runtime levels
        var cats = ExtensionHelper.getAllCategories();
        ExtensionHelper.sendCategoriesRuntimeUpdateMessage(cats);
    };
    ExtensionHelper.registered = false;
    return ExtensionHelper;
}());
exports.ExtensionHelper = ExtensionHelper;

});

unwrapExports(ExtensionHelper_1$1);
var ExtensionHelper_2 = ExtensionHelper_1$1.ExtensionHelper;

var LogGroupRule_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * Defines a LogGroupRule, this allows you to either have everything configured the same way
 * or for example loggers that start with name model. It allows you to group loggers together
 * to have a certain loglevel and other settings. You can configure this when creating the
 * LoggerFactory (which accepts multiple LogGroupRules).
 */
var LogGroupRule = (function () {
    /**
     * Create a LogGroupRule. Basically you define what logger name(s) match for this group, what level should be used what logger type (where to log)
     * and what format to write in. If the loggerType is custom, then the callBackLogger must be supplied as callback function to return a custom logger.
     * @param regExp Regular expression, what matches for your logger names for this group
     * @param level LogLevel
     * @param logFormat LogFormat
     * @param loggerType Type of logger, if Custom, make sure to implement callBackLogger and pass in, this will be called so you can return your own logger.
     * @param callBackLogger Callback function to return a new clean custom logger (yours!)
     */
    function LogGroupRule(regExp, level, logFormat, loggerType, callBackLogger) {
        if (logFormat === void 0) { logFormat = new LoggerOptions.LogFormat(); }
        if (loggerType === void 0) { loggerType = LoggerOptions.LoggerType.Console; }
        if (callBackLogger === void 0) { callBackLogger = null; }
        this._formatterLogMessage = null;
        this._regExp = regExp;
        this._level = level;
        this._logFormat = logFormat;
        this._loggerType = loggerType;
        this._callBackLogger = callBackLogger;
    }
    Object.defineProperty(LogGroupRule.prototype, "regExp", {
        get: function () {
            return this._regExp;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRule.prototype, "level", {
        get: function () {
            return this._level;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRule.prototype, "loggerType", {
        get: function () {
            return this._loggerType;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRule.prototype, "logFormat", {
        get: function () {
            return this._logFormat;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRule.prototype, "callBackLogger", {
        get: function () {
            return this._callBackLogger;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LogGroupRule.prototype, "formatterLogMessage", {
        /**
         * Get the formatterLogMessage function, see comment on the setter.
         * @returns {((message:LogMessage)=>string)|null}
         */
        get: function () {
            return this._formatterLogMessage;
        },
        /**
         * Set the default formatterLogMessage function, if set it is applied to all type of loggers except for a custom logger.
         * By default this is null (not set). You can assign a function to allow custom formatting of a log message.
         * Each log message will call this function then and expects your function to format the message and return a string.
         * Will throw an error if you attempt to set a formatterLogMessage if the LoggerType is custom.
         * @param value The formatter function, or null to reset it.
         */
        set: function (value) {
            if (value !== null && this._loggerType === LoggerOptions.LoggerType.Custom) {
                throw new Error("You cannot specify a formatter for log messages if your loggerType is Custom");
            }
            this._formatterLogMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    return LogGroupRule;
}());
exports.LogGroupRule = LogGroupRule;

});

unwrapExports(LogGroupRule_1);
var LogGroupRule_2 = LogGroupRule_1.LogGroupRule;

var LoggerFactoryOptions_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Options object you can use to configure the LoggerFactory you create at LFService.
 */
var LoggerFactoryOptions = (function () {
    function LoggerFactoryOptions() {
        this._logGroupRules = [];
        this._enabled = true;
    }
    /**
     * Add LogGroupRule, see {LogGroupRule) for details
     * @param rule Rule to add
     * @returns {LoggerFactoryOptions} returns itself
     */
    LoggerFactoryOptions.prototype.addLogGroupRule = function (rule) {
        this._logGroupRules.push(rule);
        return this;
    };
    /**
     * Enable or disable logging completely for the LoggerFactory.
     * @param enabled True for enabled (default)
     * @returns {LoggerFactoryOptions} returns itself
     */
    LoggerFactoryOptions.prototype.setEnabled = function (enabled) {
        this._enabled = enabled;
        return this;
    };
    Object.defineProperty(LoggerFactoryOptions.prototype, "logGroupRules", {
        get: function () {
            return this._logGroupRules;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoggerFactoryOptions.prototype, "enabled", {
        get: function () {
            return this._enabled;
        },
        enumerable: true,
        configurable: true
    });
    return LoggerFactoryOptions;
}());
exports.LoggerFactoryOptions = LoggerFactoryOptions;

});

unwrapExports(LoggerFactoryOptions_1);
var LoggerFactoryOptions_2 = LoggerFactoryOptions_1.LoggerFactoryOptions;

var LFService_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });






var LFServiceImpl = (function () {
    function LFServiceImpl() {
        // Private constructor.
        this._nameCounter = 1;
        this._mapFactories = new DataStructures.SimpleMap();
        ExtensionHelper_1$1.ExtensionHelper.register();
    }
    LFServiceImpl.getInstance = function () {
        // Loaded on demand. Do NOT change as webpack may pack things in wrong order otherwise.
        if (LFServiceImpl._INSTANCE === null) {
            LFServiceImpl._INSTANCE = new LFServiceImpl();
        }
        return LFServiceImpl._INSTANCE;
    };
    /**
     * Create a new LoggerFactory with given options (if any). If no options
     * are specified, the LoggerFactory, will accept any named logger and will
     * log on info level by default for, to the console.
     * @param options Options, optional.
     * @returns {LoggerFactory}
     */
    LFServiceImpl.prototype.createLoggerFactory = function (options) {
        if (options === void 0) { options = null; }
        var name = "LoggerFactory" + this._nameCounter++;
        return this.createNamedLoggerFactory(name, options);
    };
    /**
     * Create a new LoggerFactory using given name (used for console api/extension).
     * @param name Name Pick something short but distinguishable.
     * @param options Options, optional
     * @return {LoggerFactory}
     */
    LFServiceImpl.prototype.createNamedLoggerFactory = function (name, options) {
        if (options === void 0) { options = null; }
        if (this._mapFactories.exists(name)) {
            throw new Error("LoggerFactory with name " + name + " already exists.");
        }
        var factory;
        if (options !== null) {
            factory = new LoggerFactoryImpl_1.LoggerFactoryImpl(name, options);
        }
        else {
            factory = new LoggerFactoryImpl_1.LoggerFactoryImpl(name, LFServiceImpl.createDefaultOptions());
        }
        this._mapFactories.put(name, factory);
        return factory;
    };
    /**
     * Closes all Loggers for LoggerFactories that were created.
     * After this call, all previously fetched Loggers (from their
     * factories) are unusable. The factories remain as they were.
     */
    LFServiceImpl.prototype.closeLoggers = function () {
        this._mapFactories.values().forEach(function (factory) {
            factory.closeLoggers();
        });
        this._mapFactories.clear();
        this._nameCounter = 1;
    };
    LFServiceImpl.prototype.getRuntimeSettingsForLoggerFactories = function () {
        var result = [];
        this._mapFactories.forEachValue(function (factory) { return result.push(factory); });
        return result;
    };
    LFServiceImpl.prototype.getLogGroupSettings = function (nameLoggerFactory, idLogGroupRule) {
        var factory = this._mapFactories.get(nameLoggerFactory);
        if (typeof factory === "undefined") {
            return null;
        }
        return factory.getLogGroupRuntimeSettingsByIndex(idLogGroupRule);
    };
    LFServiceImpl.prototype.getLoggerFactoryRuntimeSettingsByName = function (nameLoggerFactory) {
        var result = this._mapFactories.get(nameLoggerFactory);
        if (typeof result === "undefined") {
            return null;
        }
        return result;
    };
    LFServiceImpl.createDefaultOptions = function () {
        return new LoggerFactoryOptions_1.LoggerFactoryOptions().addLogGroupRule(new LogGroupRule_1.LogGroupRule(new RegExp(".+"), LoggerOptions.LogLevel.Info));
    };
    // Loaded on demand. Do NOT change as webpack may pack things in wrong order otherwise.
    LFServiceImpl._INSTANCE = null;
    return LFServiceImpl;
}());
/**
 * Create and configure your LoggerFactory from here.
 */
var LFService = (function () {
    function LFService() {
    }
    /**
     * Create a new LoggerFactory with given options (if any). If no options
     * are specified, the LoggerFactory, will accept any named logger and will
     * log on info level by default for, to the console.
     * @param options Options, optional.
     * @returns {LoggerFactory}
     */
    LFService.createLoggerFactory = function (options) {
        if (options === void 0) { options = null; }
        return LFService.INSTANCE_SERVICE.createLoggerFactory(options);
    };
    /**
     * Create a new LoggerFactory using given name (used for console api/extension).
     * @param name Name Pick something short but distinguishable. The word "DEFAULT" is reserved and cannot be taken, it is used
     * for the default LoggerFactory.
     * @param options Options, optional
     * @return {LoggerFactory}
     */
    LFService.createNamedLoggerFactory = function (name, options) {
        if (options === void 0) { options = null; }
        if (name === LFService.DEFAULT_LOGGER_FACTORY_NAME) {
            throw new Error("LoggerFactory name: " + LFService.DEFAULT_LOGGER_FACTORY_NAME + " is reserved and cannot be used.");
        }
        return LFService.INSTANCE_SERVICE.createNamedLoggerFactory(name, options);
    };
    /**
     * Closes all Loggers for LoggerFactories that were created.
     * After this call, all previously fetched Loggers (from their
     * factories) are unusable. The factories remain as they were.
     */
    LFService.closeLoggers = function () {
        return LFService.INSTANCE_SERVICE.closeLoggers();
    };
    /**
     * Return LFServiceRuntimeSettings to retrieve information loggerfactories
     * and their runtime settings.
     * @returns {LFServiceRuntimeSettings}
     */
    LFService.getRuntimeSettings = function () {
        return LFService.INSTANCE_SERVICE;
    };
    Object.defineProperty(LFService, "DEFAULT", {
        /**
         * This property returns the default LoggerFactory (if not yet initialized it is initialized).
         * This LoggerFactory can be used to share among multiple
         * applications/libraries - that way you can enable/change logging over everything from
         * your own application when required.
         * It is recommended to be used by library developers to make logging easily available for the
         * consumers of their libraries.
         * It is highly recommended to use Loggers from the LoggerFactory with unique grouping/names to prevent
         * clashes of Loggers between multiple projects.
         * @returns {LoggerFactory} Returns the default LoggerFactory
         */
        get: function () {
            return LFService.getDefault();
        },
        enumerable: true,
        configurable: true
    });
    LFService.getDefault = function () {
        if (LFService.DEFAULT_LOGGER_FACTORY === null) {
            LFService.DEFAULT_LOGGER_FACTORY = LFService.DEFAULT_LOGGER_FACTORY = LFService.INSTANCE_SERVICE.createNamedLoggerFactory(LFService.DEFAULT_LOGGER_FACTORY_NAME, new LoggerFactoryOptions_1.LoggerFactoryOptions().addLogGroupRule(new LogGroupRule_1.LogGroupRule(new RegExp(".+"), LoggerOptions.LogLevel.Error)));
        }
        return LFService.DEFAULT_LOGGER_FACTORY;
    };
    LFService.DEFAULT_LOGGER_FACTORY_NAME = "DEFAULT";
    LFService.INSTANCE_SERVICE = LFServiceImpl.getInstance();
    LFService.DEFAULT_LOGGER_FACTORY = null;
    return LFService;
}());
exports.LFService = LFService;

});

unwrapExports(LFService_1);
var LFService_2 = LFService_1.LFService;

var LogGroupControl = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });



var LoggerControlImpl = (function () {
    function LoggerControlImpl() {
    }
    LoggerControlImpl.prototype.help = function () {
        /* tslint:disable:no-console */
        console.log(LoggerControlImpl._help);
        /* tslint:enable:no-console */
    };
    LoggerControlImpl.prototype.listFactories = function () {
        var rtSettingsFactories = LoggerControlImpl._getRuntimeSettingsLoggerFactories();
        var result = new DataStructures.StringBuilder();
        result.appendLine("Registered LoggerFactories (index / name)");
        for (var i = 0; i < rtSettingsFactories.length; i++) {
            var rtSettingsFactory = rtSettingsFactories[i];
            result.append("  " + i).append(": " + rtSettingsFactory.getName() + "\n");
        }
        /* tslint:disable:no-console */
        console.log(result.toString());
        /* tslint:enable:no-console */
    };
    LoggerControlImpl.prototype.showSettings = function (id) {
        if (id === void 0) { id = "all"; }
        var result = [];
        if (id === "all") {
            var idx_1 = 0;
            LoggerControlImpl._getRuntimeSettingsLoggerFactories().forEach(function (item) {
                result.push(new DataStructures.TuplePair(idx_1++, item));
            });
        }
        else {
            var settings = LoggerControlImpl._getRuntimeSettingsLoggerFactories();
            if (id >= 0 && id < settings.length) {
                result.push(new DataStructures.TuplePair(id, settings[id]));
            }
            else {
                throw new Error("Requested number: " + id + " was not found.");
            }
        }
        for (var _i = 0, result_1 = result; _i < result_1.length; _i++) {
            var setting = result_1[_i];
            /* tslint:disable:no-console */
            console.log("  LoggerFactory: " + setting.y.getName() + " (id=" + setting.x + ")");
            var logGroupRuntimeSettings = setting.y.getLogGroupRuntimeSettings();
            for (var g = 0; g < logGroupRuntimeSettings.length; g++) {
                var groupSetting = logGroupRuntimeSettings[g];
                console.log("     LogGroup: (id=" + g + ")");
                console.log("       RegExp: " + groupSetting.logGroupRule.regExp.source);
                console.log("       Level: " + LoggerOptions.LogLevel[groupSetting.level].toString());
                console.log("       LoggerType: " + LoggerOptions.LoggerType[groupSetting.loggerType].toString());
            }
            /* tslint:enable:no-console */
        }
    };
    LoggerControlImpl.prototype.reset = function (idFactory) {
        if (idFactory === void 0) { idFactory = "all"; }
        var loggerFactoriesSettings = LoggerControlImpl._getRuntimeSettingsLoggerFactories();
        var result = [];
        if (idFactory === "all") {
            result = loggerFactoriesSettings;
        }
        else {
            if (idFactory >= 0 && idFactory < loggerFactoriesSettings.length) {
                result.push(loggerFactoriesSettings[idFactory]);
            }
        }
        result.forEach(function (setting) {
            /* tslint:disable:no-console */
            console.log("Reset all settings for factory " + idFactory);
            /* tslint:enable:no-console */
            var control = new LoggerFactoryControlImpl(setting);
            control.reset();
        });
    };
    LoggerControlImpl.prototype.getLoggerFactoryControl = function (idFactory) {
        var loggerFactoriesSettings = LoggerControlImpl._getRuntimeSettingsLoggerFactories();
        if (idFactory >= 0 && idFactory < loggerFactoriesSettings.length) {
            return new LoggerFactoryControlImpl(loggerFactoriesSettings[idFactory]);
        }
        throw new Error("idFactory is invalid (less than 0) or non existing id.");
    };
    LoggerControlImpl._getRuntimeSettingsLoggerFactories = function () {
        return LoggerControlImpl._getSettings().getRuntimeSettingsForLoggerFactories();
    };
    LoggerControlImpl._getSettings = function () {
        return LFService_1.LFService.getRuntimeSettings();
    };
    LoggerControlImpl._help = "\n  help(): void\n    ** Shows this help.\n\n  listFactories(): void\n    ** List all registered LoggerFactories with associated log groups with respective ids (ids can be used to target a factory and/or group).\n\n  showSettings(idFactory: number | \"all\"): void\n    ** Show log group settings for idFactory (use listFactories to find id for a LoggerFactory). If idFactory is \"all\" shows all factories.\n\n  getLoggerFactoryControl(idFactory: number): LoggerFactoryControl\n    ** Return LoggerFactoryControl when found for given idFactory or throws Error if invalid or null, get the id by using listFactories()\n\n  reset(idFactory: number | \"all\"): void\n    ** Resets given factory or all factories back to original values.\n";
    return LoggerControlImpl;
}());
exports.LoggerControlImpl = LoggerControlImpl;
var LoggerFactoryControlImpl = (function () {
    function LoggerFactoryControlImpl(settings) {
        this._settings = settings;
    }
    LoggerFactoryControlImpl.prototype.help = function () {
        /* tslint:disable:no-console */
        console.log(LoggerFactoryControlImpl._help);
        /* tslint:enable:no-console */
    };
    LoggerFactoryControlImpl.prototype.example = function () {
        /* tslint:disable:no-console */
        console.log(LoggerFactoryControlImpl._example);
        /* tslint:enable:no-console */
    };
    LoggerFactoryControlImpl.prototype.showSettings = function (id) {
        if (id === void 0) { id = "all"; }
        var result = new DataStructures.StringBuilder();
        var logGroupRuntimeSettings = this._settings.getLogGroupRuntimeSettings();
        result.appendLine("Registered LogGroups (index / expression)");
        for (var i = 0; i < logGroupRuntimeSettings.length; i++) {
            var logGroupRuntimeSetting = logGroupRuntimeSettings[i];
            result.appendLine("  " + i + ": " + logGroupRuntimeSetting.logGroupRule.regExp.source + ", logLevel=" +
                LoggerOptions.LogLevel[logGroupRuntimeSetting.level].toString() + ", showTimestamp=" + logGroupRuntimeSetting.logFormat.showTimeStamp +
                ", showLoggerName=" + logGroupRuntimeSetting.logFormat.showLoggerName +
                ", format=" + LoggerOptions.DateFormatEnum[logGroupRuntimeSetting.logFormat.dateFormat.formatEnum].toString());
        }
        /* tslint:disable:no-console */
        console.log(result.toString());
        /* tslint:enable:no-console */
    };
    LoggerFactoryControlImpl.prototype.change = function (settings) {
        var logGroupRuntimeSettings = this._getLogGroupRunTimeSettingsFor(settings.group);
        var logLevel = null;
        var formatEnum = null;
        var showLoggerName = null;
        var showTimestamp = null;
        var result = null;
        var addResult = function (value) {
            if (result !== null) {
                result += ", ";
            }
            if (result === null) {
                result = value;
            }
            else {
                result += value;
            }
        };
        if (typeof settings.logLevel === "string") {
            logLevel = LoggerOptions.LogLevel.fromString(settings.logLevel);
            addResult("logLevel=" + settings.logLevel);
        }
        if (typeof settings.logFormat === "string") {
            formatEnum = LoggerOptions.DateFormatEnum.fromString(settings.logFormat);
            addResult("logFormat=" + settings.logFormat);
        }
        if (typeof settings.showLoggerName === "boolean") {
            showLoggerName = settings.showLoggerName;
            addResult("showLoggerName=" + settings.showLoggerName);
        }
        if (typeof settings.showTimestamp === "boolean") {
            showTimestamp = settings.showTimestamp;
            addResult("showTimestamp=" + settings.showTimestamp);
        }
        logGroupRuntimeSettings.forEach(function (s) {
            if (logLevel !== null) {
                s.level = logLevel;
            }
            if (formatEnum !== null) {
                s.logFormat.dateFormat.formatEnum = formatEnum;
            }
            if (showTimestamp !== null) {
                s.logFormat.showTimeStamp = showTimestamp;
            }
            if (showLoggerName !== null) {
                s.logFormat.showLoggerName = showLoggerName;
            }
        });
        /* tslint:disable:no-console */
        console.log("Applied changes: " + result + " to log groups '" + settings.group + "'.");
        /* tslint:enable:no-console */
    };
    LoggerFactoryControlImpl.prototype.reset = function (idGroup) {
        if (idGroup === void 0) { idGroup = "all"; }
        var settings = this._getLogGroupRunTimeSettingsFor(idGroup);
        for (var _i = 0, settings_1 = settings; _i < settings_1.length; _i++) {
            var setting = settings_1[_i];
            setting.level = setting.logGroupRule.level;
            setting.logFormat.showTimeStamp = setting.logGroupRule.logFormat.showTimeStamp;
            setting.logFormat.showLoggerName = setting.logGroupRule.logFormat.showLoggerName;
            setting.logFormat.dateFormat.formatEnum = setting.logGroupRule.logFormat.dateFormat.formatEnum;
        }
        /* tslint:disable:no-console */
        console.log("Reset all settings for group " + idGroup);
        /* tslint:enable:no-console */
    };
    LoggerFactoryControlImpl.prototype._getLogGroupRunTimeSettingsFor = function (idGroup) {
        var settings = [];
        if (idGroup === "all") {
            settings = this._settings.getLogGroupRuntimeSettings();
        }
        else {
            this._checkIndex(idGroup);
            settings.push(this._settings.getLogGroupRuntimeSettings()[idGroup]);
        }
        return settings;
    };
    LoggerFactoryControlImpl.prototype._checkIndex = function (index) {
        if (index < 0 || index >= this._settings.getLogGroupRuntimeSettings().length) {
            throw new Error("Invalid index, use listLogGroups to find out a valid one.");
        }
    };
    LoggerFactoryControlImpl._help = "\n  help(): void\n    ** Shows this help.\n\n  example(): void\n    ** Shows an example of usage.\n\n  showSettings(id: number | \"all\"): void\n    ** Prints settings for given group id, \"all\" for all group.\n\n  change(settings: LogGroupControlSettings): void\n    ** Changes the current settings for one or all log groups.\n    **\n       LogGroupControlSettings, properties of object:\n         group: number | \"all\"\n           ** Apply to specific group, or \"all\".\n           ** Required\n\n         logLevel: \"Fatal\" | \"Error\" | \"Warn\" | \"Info\" | \"Debug\" | \"Trace\" | undefined\n           ** Set log level, undefined will not change the setting.\n           ** Optional\n\n         logFormat: \"Default\" | \"YearMonthDayTime\" | \"YearDayMonthWithFullTime\" | \"YearDayMonthTime\" | undefined\n           ** Set the log format, undefined will not change the setting.\n           ** Optional\n\n         showTimestamp: boolean | undefined\n           ** Whether to show timestamp, undefined will not change the setting.\n           ** Optional\n\n         showLoggerName: boolean | undefined\n           ** Whether to show the logger name, undefined will not change the setting.\n           ** Optional\n\n  reset(id: number | \"all\"): void\n    ** Resets everything to original values, for one specific or for all groups.\n\n  help():\n    ** Shows this help.\n";
    LoggerFactoryControlImpl._example = "\n  Examples:\n    change({group: \"all\", logLevel: \"Info\"})\n      ** Change loglevel to Info for all groups.\n\n    change({group: 1, recursive:false, logLevel: \"Warn\"})\n      ** Change logLevel for group 1 to Warn.\n\n    change({group: \"all\", logLevel: \"Debug\", logFormat: \"YearDayMonthTime\", showTimestamp:false, showLoggerName:false})\n      ** Change loglevel to Debug for all groups, apply format, do not show timestamp and logger names.\n";
    return LoggerFactoryControlImpl;
}());

});

unwrapExports(LogGroupControl);
var LogGroupControl_1 = LogGroupControl.LoggerControlImpl;

var CategoryServiceControl = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });



/**
 * Implementation class for CategoryServiceControl.
 */
var CategoryServiceControlImpl = (function () {
    function CategoryServiceControlImpl() {
    }
    CategoryServiceControlImpl.prototype.help = function () {
        /* tslint:disable:no-console */
        console.log(CategoryServiceControlImpl._help);
        /* tslint:enable:no-console */
    };
    CategoryServiceControlImpl.prototype.example = function () {
        /* tslint:disable:no-console */
        console.log(CategoryServiceControlImpl._example);
        /* tslint:enable:no-console */
    };
    CategoryServiceControlImpl.prototype.showSettings = function (id) {
        if (id === void 0) { id = "all"; }
        var result = new DataStructures.StringBuilder();
        var service = CategoryServiceControlImpl._getCategoryService();
        var categories = CategoryServiceControlImpl._getCategories(id);
        categories.forEach(function (category) {
            CategoryServiceControlImpl._processCategory(service, category, result, 0);
        });
        /* tslint:disable:no-console */
        console.log(result.toString());
        /* tslint:enable:no-console */
    };
    CategoryServiceControlImpl.prototype.change = function (settings) {
        var service = CategoryServiceControlImpl._getCategoryService();
        var categories = CategoryServiceControlImpl._getCategories(settings.category);
        var logLevel = null;
        var formatEnum = null;
        var showCategoryName = null;
        var showTimestamp = null;
        var result = null;
        var addResult = function (value) {
            if (result !== null) {
                result += ", ";
            }
            if (result === null) {
                result = value;
            }
            else {
                result += value;
            }
        };
        addResult("recursive=" + settings.recursive);
        if (typeof settings.logLevel === "string") {
            logLevel = LoggerOptions.LogLevel.fromString(settings.logLevel);
            addResult("logLevel=" + settings.logLevel);
        }
        if (typeof settings.logFormat === "string") {
            formatEnum = LoggerOptions.DateFormatEnum.fromString(settings.logFormat);
            addResult("logFormat=" + settings.logFormat);
        }
        if (typeof settings.showCategoryName === "boolean") {
            showCategoryName = settings.showCategoryName;
            addResult("showCategoryName=" + settings.showCategoryName);
        }
        if (typeof settings.showTimestamp === "boolean") {
            showTimestamp = settings.showTimestamp;
            addResult("showTimestamp=" + settings.showTimestamp);
        }
        var applyChanges = function (cat) {
            var categorySettings = service.getCategorySettings(cat);
            // Should not happen but make tslint happy
            if (categorySettings !== null) {
                if (logLevel !== null) {
                    categorySettings.logLevel = logLevel;
                }
                if (formatEnum !== null) {
                    categorySettings.logFormat.dateFormat.formatEnum = formatEnum;
                }
                if (showTimestamp !== null) {
                    categorySettings.logFormat.showTimeStamp = showTimestamp;
                }
                if (showCategoryName !== null) {
                    categorySettings.logFormat.showCategoryName = showCategoryName;
                }
            }
        };
        categories.forEach(function (cat) { return CategoryServiceControlImpl._applyToCategory(cat, settings.recursive, applyChanges); });
        /* tslint:disable:no-console */
        console.log("Applied changes: " + result + " to categories '" + settings.category + "'.");
        /* tslint:enable:no-console */
    };
    CategoryServiceControlImpl.prototype.reset = function (id) {
        if (id === void 0) { id = "all"; }
        var service = CategoryServiceControlImpl._getCategoryService();
        var categories = CategoryServiceControlImpl._getCategories(id);
        var applyChanges = function (cat) {
            var categorySettings = service.getCategorySettings(cat);
            var original = service.getOriginalCategorySettings(cat);
            // Should not happen but make tslint happy
            if (categorySettings !== null && original !== null) {
                categorySettings.logLevel = original.logLevel;
                categorySettings.logFormat.dateFormat.formatEnum = original.logFormat.dateFormat.formatEnum;
                categorySettings.logFormat.showTimeStamp = original.logFormat.showTimeStamp;
                categorySettings.logFormat.showCategoryName = original.logFormat.showCategoryName;
            }
        };
        categories.forEach(function (cat) { return CategoryServiceControlImpl._applyToCategory(cat, true, applyChanges); });
        /* tslint:disable:no-console */
        console.log("Applied reset to category: " + id + ".");
        /* tslint:enable:no-console */
    };
    CategoryServiceControlImpl._processCategory = function (service, category, result, indent) {
        var settings = service.getCategorySettings(category);
        if (settings !== null) {
            result.append("  " + category.id + ": ");
            if (indent > 0) {
                for (var i = 0; i < indent; i++) {
                    result.append("  ");
                }
            }
            result.append(category.name + " (" + LoggerOptions.LogLevel[settings.logLevel].toString() + "@" + LoggerOptions.LoggerType[settings.loggerType].toString() + ")\n");
            if (category.children.length > 0) {
                category.children.forEach(function (child) {
                    CategoryServiceControlImpl._processCategory(service, child, result, indent + 1);
                });
            }
        }
    };
    CategoryServiceControlImpl._applyToCategory = function (category, recursive, apply) {
        apply(category);
        if (recursive) {
            category.children.forEach(function (child) {
                CategoryServiceControlImpl._applyToCategory(child, recursive, apply);
            });
        }
    };
    CategoryServiceControlImpl._getCategoryService = function () {
        return CategoryService.CategoryServiceImpl.getInstance();
    };
    CategoryServiceControlImpl._getCategories = function (idCategory) {
        var service = CategoryServiceControlImpl._getCategoryService();
        var categories = [];
        if (idCategory === "all") {
            categories = service.getRootCategories();
        }
        else {
            var category = service.getCategoryById(idCategory);
            if (category === null) {
                throw new Error("Failed to find category with id " + idCategory);
            }
            categories.push(category);
        }
        return categories;
    };
    CategoryServiceControlImpl._help = "\n  help(): void\n    ** Shows this help.\n\n  example(): void\n    ** Shows an example on how to use this.\n\n  showSettings(id: number | \"all\" = \"all\"): void\n    ** Shows settings for a specific category, or for all. The id of categories can be found by calling this method without parameter.\n\n  change(settings: CategoryServiceControlSettings): void\n    ** Changes the current settings for one or all categories.\n    **\n       CategoryServiceControlSettings, properties of object:\n         category: number | \"all\"\n           ** Apply to specific category, or \"all\".\n           ** Required\n\n         recursive: boolean\n           ** Apply to child categories (true) or not.\n           ** Required\n\n         logLevel: \"Fatal\" | \"Error\" | \"Warn\" | \"Info\" | \"Debug\" | \"Trace\" | undefined\n           ** Set log level, undefined will not change the setting.\n           ** Optional\n\n         logFormat: \"Default\" | \"YearMonthDayTime\" | \"YearDayMonthWithFullTime\" | \"YearDayMonthTime\" | undefined\n           ** Set the log format, undefined will not change the setting.\n           ** Optional\n\n         showTimestamp: boolean | undefined\n           ** Whether to show timestamp, undefined will not change the setting.\n           ** Optional\n\n         showCategoryName: boolean | undefined\n           ** Whether to show the category name, undefined will not change the setting.\n           ** Optional\n\n   reset(id: number | \"all\"): void\n     ** Resets everything to original values, for one specific or for all categories.\n";
    CategoryServiceControlImpl._example = "\n  Examples:\n    change({category: \"all\", recursive:true, logLevel: \"Info\"})\n      ** Change loglevel to Info for all categories, apply to child categories as well.\n\n    change({category: 1, recursive:false, logLevel: \"Warn\"})\n      ** Change logLevel for category 1, do not recurse.\n\n    change({category: \"all\", recursive:true, logLevel: \"Debug\", logFormat: \"YearDayMonthTime\", showTimestamp:false, showCategoryName:false})\n      ** Change loglevel to Debug for all categories, apply format, do not show timestamp and category names - recursively to child categories.\n\n";
    return CategoryServiceControlImpl;
}());
exports.CategoryServiceControlImpl = CategoryServiceControlImpl;

});

unwrapExports(CategoryServiceControl);
var CategoryServiceControl_1 = CategoryServiceControl.CategoryServiceControlImpl;

var Category_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });


/**
 * Category for use with categorized logging.
 * At minimum you need one category, which will serve as the root category.
 * You can create child categories (like a tree). You can have multiple root
 * categories.
 */
var Category = (function () {
    function Category(name, parent) {
        if (parent === void 0) { parent = null; }
        this._children = [];
        this._logLevel = LoggerOptions.LogLevel.Error;
        if (name.indexOf("#") !== -1) {
            throw new Error("Cannot use # in a name of a Category");
        }
        this._id = Category.nextId();
        this._name = name;
        this._parent = parent;
        if (this._parent !== null) {
            this._parent._children.push(this);
        }
        CategoryService.CategoryServiceImpl.getInstance().registerCategory(this);
    }
    Object.defineProperty(Category.prototype, "name", {
        get: function () {
            return this._name;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Category.prototype, "parent", {
        get: function () {
            return this._parent;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Category.prototype, "children", {
        get: function () {
            return this._children;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Category.prototype, "logLevel", {
        get: function () {
            return this._logLevel;
        },
        enumerable: true,
        configurable: true
    });
    Category.prototype.trace = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).trace.apply(_a, [msg].concat(categories));
        var _a;
    };
    Category.prototype.debug = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).debug.apply(_a, [msg].concat(categories));
        var _a;
    };
    Category.prototype.info = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).info.apply(_a, [msg].concat(categories));
        var _a;
    };
    Category.prototype.warn = function (msg) {
        var categories = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            categories[_i - 1] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).warn.apply(_a, [msg].concat(categories));
        var _a;
    };
    Category.prototype.error = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).error.apply(_a, [msg, error].concat(categories));
        var _a;
    };
    Category.prototype.fatal = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).fatal.apply(_a, [msg, error].concat(categories));
        var _a;
    };
    Category.prototype.resolved = function (msg, error) {
        var categories = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            categories[_i - 2] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).resolved.apply(_a, [msg, error].concat(categories));
        var _a;
    };
    Category.prototype.log = function (level, msg, error) {
        var categories = [];
        for (var _i = 3; _i < arguments.length; _i++) {
            categories[_i - 3] = arguments[_i];
        }
        this.loadCategoryLogger();
        (_a = this._logger).log.apply(_a, [level, msg, error].concat(categories));
        var _a;
    };
    Category.prototype.getCategoryPath = function () {
        var result = this.name;
        var cat = this.parent;
        while (cat != null) {
            result = cat.name + "#" + result;
            cat = cat.parent;
        }
        return result;
    };
    Object.defineProperty(Category.prototype, "id", {
        /**
         * Returns the id for this category (this
         * is for internal purposes only).
         * @returns {number} Id
         */
        get: function () {
            return this._id;
        },
        enumerable: true,
        configurable: true
    });
    Category.prototype.loadCategoryLogger = function () {
        if (!this._logger) {
            this._logger = CategoryService.CategoryServiceImpl.getInstance().getLogger(this);
        }
        if (typeof this._logger === "undefined" || this._logger === null) {
            throw new Error("Failed to load a logger for category (should not happen): " + this.name);
        }
    };
    Category.nextId = function () {
        return Category.currentId++;
    };
    Category.currentId = 1;
    return Category;
}());
exports.Category = Category;

});

unwrapExports(Category_1);
var Category_2 = Category_1.Category;

var CategoryServiceFactory_1 = createCommonjsModule$1(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * Categorized service for logging, where logging is bound to categories which
 * can log horizontally through specific application logic (services, group(s) of components etc).
 * For the standard way of logging like most frameworks do these days, use LFService instead.
 * If you want fine grained control to divide sections of your application in
 * logical units to enable/disable logging for, this is the service you want to use instead.
 * Also for this type a browser plugin will be available.
 */
var CategoryServiceFactory = (function () {
    function CategoryServiceFactory() {
        // Private constructor.
    }
    /**
     * Return a CategoryLogger for given ROOT category (thus has no parent).
     * You can only retrieve loggers for their root, when logging
     * you specify to log for what (child)categories.
     * @param root Category root (has no parent)
     * @returns {CategoryLogger}
     */
    CategoryServiceFactory.getLogger = function (root) {
        return CategoryService.CategoryServiceImpl.getInstance().getLogger(root);
    };
    /**
     * Clears everything, any registered (root)categories and loggers
     * are discarded. Resets to default configuration.
     */
    CategoryServiceFactory.clear = function () {
        return CategoryService.CategoryServiceImpl.getInstance().clear();
    };
    /**
     * Set the default configuration. New root loggers created get this
     * applied. If you want to reset all current loggers to have this
     * applied as well, pass in reset=true (the default is false). All
     * categories runtimesettings will be reset then as well.
     * @param config The new default configuration
     * @param reset If true, will reset *all* runtimesettings for all loggers/categories to these. Default is true.
     */
    CategoryServiceFactory.setDefaultConfiguration = function (config, reset) {
        if (reset === void 0) { reset = true; }
        CategoryService.CategoryServiceImpl.getInstance().setDefaultConfiguration(config, reset);
    };
    /**
     * Set new configuration settings for a category (and possibly its child categories)
     * @param config Config
     * @param category Category
     * @param applyChildren True to apply to child categories, defaults to false.
     */
    CategoryServiceFactory.setConfigurationCategory = function (config, category, applyChildren) {
        if (applyChildren === void 0) { applyChildren = false; }
        CategoryService.CategoryServiceImpl.getInstance().setConfigurationCategory(config, category, applyChildren);
    };
    return CategoryServiceFactory;
}());
exports.CategoryServiceFactory = CategoryServiceFactory;

});

unwrapExports(CategoryServiceFactory_1);
var CategoryServiceFactory_2 = CategoryServiceFactory_1.CategoryServiceFactory;

var JSONHelper_1 = createCommonjsModule$1(function (module, exports) {
var __extends = (commonjsGlobal$1 && commonjsGlobal$1.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Module containing bunch of JSON related stuff.
 */


var JSONTypeImpl = (function () {
    function JSONTypeImpl(value) {
        this._value = value;
    }
    JSONTypeImpl.prototype.getValue = function () {
        return this._value;
    };
    JSONTypeImpl.prototype.toString = function () {
        var value = this.getValue();
        if (value != null) {
            return value.toString();
        }
        return "null";
    };
    return JSONTypeImpl;
}());
var JSONBooleanType = (function (_super) {
    __extends(JSONBooleanType, _super);
    function JSONBooleanType(value) {
        return _super.call(this, value) || this;
    }
    return JSONBooleanType;
}(JSONTypeImpl));
var JSONNumberType = (function (_super) {
    __extends(JSONNumberType, _super);
    function JSONNumberType(value) {
        return _super.call(this, value) || this;
    }
    return JSONNumberType;
}(JSONTypeImpl));
var JSONStringType = (function (_super) {
    __extends(JSONStringType, _super);
    function JSONStringType(value) {
        return _super.call(this, value) || this;
    }
    JSONStringType.prototype.toString = function () {
        var value = this.getValue();
        if (value != null) {
            return JSON.stringify(value.toString());
        }
        return "null";
    };
    return JSONStringType;
}(JSONTypeImpl));
var JSONObjectType = (function (_super) {
    __extends(JSONObjectType, _super);
    function JSONObjectType(value) {
        return _super.call(this, value) || this;
    }
    return JSONObjectType;
}(JSONTypeImpl));
var JSONArrayType = (function (_super) {
    __extends(JSONArrayType, _super);
    function JSONArrayType(value) {
        return _super.call(this, value) || this;
    }
    JSONArrayType.prototype.toString = function () {
        var value = this.getValue();
        if (value != null) {
            return value.toString();
        }
        return "null";
    };
    return JSONArrayType;
}(JSONTypeImpl));
var JSONNullType = (function (_super) {
    __extends(JSONNullType, _super);
    function JSONNullType() {
        return _super.call(this, null) || this;
    }
    JSONNullType.prototype.toString = function () {
        return "null";
    };
    return JSONNullType;
}(JSONTypeImpl));
var JSONTypeConverter = (function () {
    function JSONTypeConverter() {
    }
    JSONTypeConverter.toJSONType = function (value) {
        if (value === null) {
            return new JSONNullType();
        }
        if (typeof value === "string") {
            return new JSONStringType(value);
        }
        if (typeof value === "number") {
            return new JSONNumberType(value);
        }
        if (typeof value === "boolean") {
            return new JSONBooleanType(value);
        }
        if (value instanceof JSONObject) {
            return new JSONObjectType(value);
        }
        throw new Error("Type not supported for value: " + value);
    };
    return JSONTypeConverter;
}());
var JSONObject = (function () {
    function JSONObject() {
        this.values = new DataStructures.SimpleMap();
    }
    JSONObject.prototype.addBoolean = function (name, value) {
        this.checkName(name);
        JSONObject.checkValue(value);
        this.values.put(name, new JSONBooleanType(value));
        return this;
    };
    JSONObject.prototype.addNumber = function (name, value) {
        this.checkName(name);
        JSONObject.checkValue(value);
        this.values.put(name, new JSONNumberType(value));
        return this;
    };
    JSONObject.prototype.addString = function (name, value) {
        this.checkName(name);
        JSONObject.checkValue(value);
        this.values.put(name, new JSONStringType(value));
        return this;
    };
    JSONObject.prototype.addNull = function (name) {
        this.checkName(name);
        this.values.put(name, new JSONNullType());
        return this;
    };
    JSONObject.prototype.addArray = function (name, array) {
        this.checkName(name);
        JSONObject.checkValue(array);
        if (array == null) {
            throw new Error("Cannot add array as null");
        }
        this.values.put(name, new JSONArrayType(array));
        return this;
    };
    JSONObject.prototype.addObject = function (name, object) {
        this.checkName(name);
        JSONObject.checkValue(object);
        if (object == null) {
            throw new Error("Cannot add object as null");
        }
        this.values.put(name, new JSONObjectType(object));
        return this;
    };
    JSONObject.prototype.toString = function (pretty) {
        var _this = this;
        if (pretty === void 0) { pretty = false; }
        var comma = false;
        var buffer = new DataStructures.StringBuilder();
        buffer.append("{");
        this.values.keys().forEach(function (key) {
            var value = _this.values.get(key);
            if (value != null) {
                if (comma) {
                    buffer.append(",");
                }
                buffer.append('"').append(key).append('":').append(value.toString());
                comma = true;
            }
        });
        buffer.append("}");
        return buffer.toString();
    };
    JSONObject.prototype.checkName = function (name) {
        if (name == null || name === undefined) {
            throw new Error("Name is null or undefined");
        }
        if (this.values.exists(name)) {
            throw new Error("Name " + name + " is already present for this object");
        }
    };
    JSONObject.checkValue = function (value) {
        if (value === undefined) {
            throw new Error("Value is undefined");
        }
    };
    return JSONObject;
}());
exports.JSONObject = JSONObject;
var JSONArray = (function () {
    function JSONArray() {
        this.objects = [];
    }
    JSONArray.prototype.add = function (object) {
        if (object === undefined) {
            throw new Error("Object is not allowed to be undefined");
        }
        this.objects.push(JSONTypeConverter.toJSONType(object));
        return this;
    };
    JSONArray.prototype.toString = function (pretty) {
        if (pretty === void 0) { pretty = false; }
        var buffer = new DataStructures.StringBuilder();
        buffer.append("[");
        this.objects.forEach(function (value, index) {
            if (index > 0) {
                buffer.append(",");
            }
            buffer.append(value.toString());
        });
        buffer.append("]");
        return buffer.toString();
    };
    return JSONArray;
}());
exports.JSONArray = JSONArray;
/**
 * Utility class that helps us convert things to and from json (not for normal usage).
 */
var JSONHelper = (function () {
    function JSONHelper() {
    }
    JSONHelper.categoryToJSON = function (cat, recursive) {
        /*
         {
         "categories":
         [
         { id=1,
         name: "x",
         parent: null,
         logLevel: "Error"
         },
         { id=2,
         name: "y",
         parent: 1,
         logLevel: "Error"
         }
         ]
         }
         */
        var arr = new JSONArray();
        JSONHelper._categoryToJSON(cat, arr, recursive);
        var object = new JSONObject();
        object.addArray("categories", arr);
        return object;
    };
    JSONHelper._categoryToJSON = function (cat, arr, recursive) {
        var object = new JSONObject();
        object.addNumber("id", cat.id);
        object.addString("name", cat.name);
        object.addString("logLevel", LoggerOptions.LogLevel[cat.logLevel].toString());
        if (cat.parent != null) {
            object.addNumber("parent", cat.parent.id);
        }
        else {
            object.addNull("parent");
        }
        arr.add(object);
        if (recursive) {
            cat.children.forEach(function (child) {
                JSONHelper._categoryToJSON(child, arr, recursive);
            });
        }
    };
    return JSONHelper;
}());
exports.JSONHelper = JSONHelper;

});

unwrapExports(JSONHelper_1);
var JSONHelper_2 = JSONHelper_1.JSONObject;
var JSONHelper_3 = JSONHelper_1.JSONArray;
var JSONHelper_4 = JSONHelper_1.JSONHelper;

var typescriptLogging = createCommonjsModule$1(function (module, exports) {
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });



exports.ExtensionHelper = ExtensionHelper_1$1.ExtensionHelper;
// Category related

exports.AbstractCategoryLogger = AbstractCategoryLogger_1.AbstractCategoryLogger;

exports.CategoryConsoleLoggerImpl = CategoryConsoleLoggerImpl_1.CategoryConsoleLoggerImpl;

exports.CategoryDelegateLoggerImpl = CategoryDelegateLoggerImpl_1.CategoryDelegateLoggerImpl;

exports.Category = Category_1.Category;

exports.CategoryRuntimeSettings = CategoryRuntimeSettings_1.CategoryRuntimeSettings;

exports.CategoryConfiguration = CategoryConfiguration_1.CategoryConfiguration;

exports.CategoryMessageBufferLoggerImpl = CategoryMessageBufferImpl.CategoryMessageBufferLoggerImpl;

exports.CategoryServiceFactory = CategoryServiceFactory_1.CategoryServiceFactory;

exports.LoggerFactoryOptions = LoggerFactoryOptions_1.LoggerFactoryOptions;

exports.LogGroupRule = LogGroupRule_1.LogGroupRule;

exports.LFService = LFService_1.LFService;

exports.AbstractLogger = AbstractLogger_1.AbstractLogger;

exports.ConsoleLoggerImpl = ConsoleLoggerImpl_1.ConsoleLoggerImpl;

exports.MessageBufferLoggerImpl = MessageBufferLoggerImpl_1.MessageBufferLoggerImpl;

exports.CategoryLogFormat = LoggerOptions.CategoryLogFormat;
exports.DateFormat = LoggerOptions.DateFormat;
exports.DateFormatEnum = LoggerOptions.DateFormatEnum;
exports.LogFormat = LoggerOptions.LogFormat;
exports.LoggerType = LoggerOptions.LoggerType;
exports.LogLevel = LoggerOptions.LogLevel;
// Utilities

exports.SimpleMap = DataStructures.SimpleMap;
exports.LinkedList = DataStructures.LinkedList;
__export(JSONHelper_1);

exports.MessageFormatUtils = MessageUtils.MessageFormatUtils;
/*
 Functions to export on TSL libarary var.
*/
// Export help function
function help() {
    /* tslint:disable:no-console */
    console.log("help()\n   ** Shows this help\n\n getLogControl(): LoggerControl\n   ** Returns LoggerControl Object, use to dynamically change loglevels for log4j logging.\n   ** Call .help() on LoggerControl object for available options.\n\n getCategoryControl(): CategoryServiceControl\n   ** Returns CategoryServiceControl Object, use to dynamically change loglevels for category logging.\n   ** Call .help() on CategoryServiceControl object for available options.\n");
    /* tslint:enable:no-console */
}
exports.help = help;
// Export LogControl function (log4j)
function getLogControl() {
    return new LogGroupControl.LoggerControlImpl();
}
exports.getLogControl = getLogControl;
// Export CategoryControl function
function getCategoryControl() {
    return new CategoryServiceControl.CategoryServiceControlImpl();
}
exports.getCategoryControl = getCategoryControl;

});

unwrapExports(typescriptLogging);
var typescriptLogging_1 = typescriptLogging.ExtensionHelper;
var typescriptLogging_2 = typescriptLogging.AbstractCategoryLogger;
var typescriptLogging_3 = typescriptLogging.CategoryConsoleLoggerImpl;
var typescriptLogging_4 = typescriptLogging.CategoryDelegateLoggerImpl;
var typescriptLogging_5 = typescriptLogging.Category;
var typescriptLogging_6 = typescriptLogging.CategoryRuntimeSettings;
var typescriptLogging_7 = typescriptLogging.CategoryConfiguration;
var typescriptLogging_8 = typescriptLogging.CategoryMessageBufferLoggerImpl;
var typescriptLogging_9 = typescriptLogging.CategoryServiceFactory;
var typescriptLogging_10 = typescriptLogging.LoggerFactoryOptions;
var typescriptLogging_11 = typescriptLogging.LogGroupRule;
var typescriptLogging_12 = typescriptLogging.LFService;
var typescriptLogging_13 = typescriptLogging.AbstractLogger;
var typescriptLogging_14 = typescriptLogging.ConsoleLoggerImpl;
var typescriptLogging_15 = typescriptLogging.MessageBufferLoggerImpl;
var typescriptLogging_16 = typescriptLogging.CategoryLogFormat;
var typescriptLogging_17 = typescriptLogging.DateFormat;
var typescriptLogging_18 = typescriptLogging.DateFormatEnum;
var typescriptLogging_19 = typescriptLogging.LogFormat;
var typescriptLogging_20 = typescriptLogging.LoggerType;
var typescriptLogging_21 = typescriptLogging.LogLevel;
var typescriptLogging_22 = typescriptLogging.SimpleMap;
var typescriptLogging_23 = typescriptLogging.LinkedList;
var typescriptLogging_24 = typescriptLogging.MessageFormatUtils;
var typescriptLogging_25 = typescriptLogging.help;
var typescriptLogging_26 = typescriptLogging.getLogControl;
var typescriptLogging_27 = typescriptLogging.getCategoryControl;

// Optionally change default settings, in this example set default logging to Info.
// Without changing configuration, categories will log to Error.
typescriptLogging_9.setDefaultConfiguration(new typescriptLogging_7(typescriptLogging_21.Info));
// Create categories, they will autoregister themselves, one category without parent (root) and a child category.
var catService = new typescriptLogging_5("iotile.cloud");
var catCloud = new typescriptLogging_5("IOTileCloud", catService);

var axios = require("axios");
var lodash = require('lodash');
var IOTileCloud = /** @class */ (function () {
    function IOTileCloud(Config) {
        this.Config = Config;
        this.inProgressConnections = 0;
        this.event = new BlockingEvent();
        this.initialized = this.event.wait();
    }
    IOTileCloud.prototype.serverList = function () {
        return this.Config.ENV.SERVER_URLS;
    };
    IOTileCloud.prototype.defaultServer = function () {
        for (var _i = 0, _a = this.serverList(); _i < _a.length; _i++) {
            var server = _a[_i];
            if ("default" in server) {
                return server;
            }
        }
        catCloud.info('No Default Server specified; targeting iotile.cloud');
        return {
            "shortName": "PRODUCTION",
            "longName": "Production Server",
            "url": "https://iotile.cloud/api/v1",
            "default": true
        };
    };
    IOTileCloud.prototype.isDefault = function () {
        var defServer = this.defaultServer();
        if (defServer) {
            return (this.server.url == defServer.url);
        }
        else {
            return false;
        }
    };
    Object.defineProperty(IOTileCloud.prototype, "server", {
        get: function () {
            if (this._server) {
                return this._server;
            }
            else {
                throw new ArgumentError("No Server has been set.");
            }
        },
        set: function (server) {
            this._server = server;
            this.event.set();
        },
        enumerable: true,
        configurable: true
    });
    IOTileCloud.prototype.Project = function (item) {
        return new Project(item);
    };
    
    IOTileCloud.prototype.Org = function (item) {
        return new Org(item);
    };
    
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProject
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a single project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Project object
     *
     * @example
     * <pre>
     * // Get an array of all projects available
     * var projects = await IOTileCloud.fetchProjects();
     * console.log("Found " + projects.length + " IOTile Projects!");
     * </pre>
     *
     * @returns {Project[]} A list of the IOTile projects.
     */
    IOTileCloud.prototype.fetchProject = function (projectID) {
        return __awaiter(this, void 0, void 0, function () {
            var that, projData;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        that = this;
                        return [4 /*yield*/, that.fetchFromServer('/project/' + projectID + '/')];
                    case 1:
                        projData = _a.sent();
                        return [2 /*return*/, new Project(projData)];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjects
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available projects from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Project objects with all projects retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all projects available
     * var projects = await IOTileCloud.fetchProjects();
     * console.log("Found " + projects.length + " IOTile Projects!");
     * </pre>
     *
     * @returns {Project[]} A list of the IOTile projects.
     */
    IOTileCloud.prototype.fetchProjects = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/project/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newProject = new Project(item);
                                list.push(newProject);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    //Create a new org
    IOTileCloud.prototype.createOrg = function (name, about) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'name': name,
                            'about': about
                        };
                        return [4 /*yield*/, this.postToServer('/org/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    //Create a new project in an org and return the project id
    IOTileCloud.prototype.createProject = function (orgSlug, name) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            name: name,
                            org: orgSlug
                        };
                        return [4 /*yield*/, this.postToServer('/project/new/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response['id']];
                }
            });
        });
    };
    IOTileCloud.prototype.checkClaimable = function (data) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.postToServer('/device/claimable/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    //FIXME: Verify that we use the project id here and not the slug
    IOTileCloud.prototype.claimDevice = function (deviceSlug, projectID) {
        return __awaiter(this, void 0, void 0, function () {
            var data;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            device: deviceSlug,
                            project: projectID
                        };
                        return [4 /*yield*/, this.postToServer('/device/claim/', data)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchOrgs
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available organizations from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Org objects with all organizations retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all orgs available
     * var orgs = await IOTileCloud.fetchOrgs();
     * console.log("Found " + orgs.length + " IOTile Orgs!");
     * </pre>
     *
     * @returns {Org[]} A list of the IOTile organizations.
     */
    IOTileCloud.prototype.fetchOrgs = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/org/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newOrg = new Org(item);
                                list.push(newOrg);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchOrgMembership
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches user membership information from a given Org
     *
     * **This is an async method!**
     *
     * Returns a Membership object: the user's membership information for the given Org
     *
     * @example
     * <pre>
     * // Get membership information for org
     * var membership = await IOTileCloud.fetchOrgMembership(org.slug);
     * </pre>
     *
     * @returns {Membership} The membership information of the User in the given Org
     */
    IOTileCloud.prototype.fetchOrgMembership = function (org) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/org/' + org.slug + '/membership/')
                            .then(function (result) {
                            var membership = new Membership(result);
                            resolve(membership);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchOrgList
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a list of OrgMetaData objects with the names and ids
     * of all projects in all orgs.
     *
     * **This is an async method!**
     *
     * Returns an array of OrgMetaData objects with all organizations retrieved.
     */
    IOTileCloud.prototype.fetchOrgMetaData = function () {
        return __awaiter(this, void 0, void 0, function () {
            var orgs, projects, projectMap, orgMap, _i, projects_1, project, _a, orgs_1, org, projectID, project, orgSlug, orgList, orgSlug;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, this.fetchOrgs()];
                    case 1:
                        orgs = _b.sent();
                        return [4 /*yield*/, this.fetchProjects()];
                    case 2:
                        projects = _b.sent();
                        projectMap = {};
                        orgMap = {};
                        for (_i = 0, projects_1 = projects; _i < projects_1.length; _i++) {
                            project = projects_1[_i];
                            projectMap[project.id] = project;
                        }
                        for (_a = 0, orgs_1 = orgs; _a < orgs_1.length; _a++) {
                            org = orgs_1[_a];
                            orgMap[org.slug] = {
                                name: org.name,
                                slug: org.slug,
                                projects: []
                            };
                        }
                        for (projectID in projectMap) {
                            project = projectMap[projectID];
                            orgSlug = project.orgSlug;
                            if (!(orgSlug in orgMap)) {
                                catCloud.debug("Received a project from IOTile.cloud that did not have an org: " + project + " " + orgSlug);
                                continue;
                            }
                            orgMap[orgSlug].projects.push({
                                name: project.name,
                                id: project.id
                            });
                        }
                        orgList = [];
                        for (orgSlug in orgMap) {
                            orgList.push(orgMap[orgSlug]);
                        }
                        return [2 /*return*/, orgList];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllDevices
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available devices from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Device objects with all devices retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all devices available
     * var devices = await IOTileCloud.fetchAllDevices();
     * console.log("Found " + devices.length + " IOTile Devices!");
     * </pre>
     *
     * @returns {Device[]} A list of the IOTile devices.
     */
    IOTileCloud.prototype.fetchAllDevices = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/device/?page_size=1000') //The default limit of devices returned per page is apparently 100
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newDevice = new Device(item);
                                list.push(newDevice);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjectDevices
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all devices for a given project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Device objects with all devices retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all devices available for project with ID: projId
     * var projDevices = await IOTileCloud.fetchProjectDevices(projId);
     * console.log("Found " + projDevices.length + " IOTile Devices!");
     * </pre>
     *
     * @param {string} projectId The id property of the project object that
     *                           devices will be fetched from.
     *
     * @returns {Device[]} A list of the IOTile devices.
     */
    IOTileCloud.prototype.fetchProjectDevices = function (projectId) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/device/?project=' + projectId + '&page_size=1000')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newDevice = new Device(item);
                                list.push(newDevice);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchDevice
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific device from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Device object with the device requested.
     *
     * @example
     * <pre>
     * // Get a device object for device with slug: devSlug
     * var device = await IOTileCloud.fetchDevice(devSlug);
     * console.log("Found device with label: " + device.label);
     * </pre>
     *
     * @param {string} deviceSlug The slug property of the device that will
     *                            be fetched.
     *
     * @returns {Device} An IOTile Device.
     */
    IOTileCloud.prototype.fetchDevice = function (deviceSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/device/' + deviceSlug + '/')
                            .then(function (item) {
                            var newDevice = new Device(item);
                            resolve(newDevice);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllStreams
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available streams from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Stream objects with all streams retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all streams available
     * var streams = await IOTileCloud.fetchAllStreams();
     * console.log("Found " + streams.length + " IOTile Streams!");
     * </pre>
     *
     * @returns {Stream[]} A list of the IOTile streams.
     */
    IOTileCloud.prototype.fetchAllStreams = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/stream/?page_size=3000')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newStream = new Stream(item);
                                list.push(newStream);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjectStreams
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all streams for a given project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Stream objects with all streams retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all streams available for project with ID: projId
     * var projStreams = await IOTileCloud.fetchProjectStreams(projId);
     * console.log("Found " + projStreams.length + " IOTile Streams!");
     * </pre>
     *
     * @param {string} projectId The id property of the project object that
     *                           streams will be fetched from.
     *
     * @returns {Stream[]} A list of the IOTile streams.
     */
    IOTileCloud.prototype.fetchProjectStreams = function (projectId, virtual) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var uri = '/stream/?project=' + projectId + '&page_size=3000';
                        if (virtual) {
                            uri += '&virtual=1';
                        }
                        that.fetchFromServer(uri)
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newStream = new Stream(item);
                                list.push(newStream);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchStream
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific stream from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Stream object with the stream requested.
     *
     * @example
     * <pre>
     * // Get a stream object for stream with slug: streamSlug
     * var stream = await IOTileCloud.fetchStream(streamSlug);
     * console.log("Found stream with slug: " + stream.slug);
     * </pre>
     *
     * @param {string} streamSlug The slug property of the stream that will
     *                            be fetched.
     *
     * @returns {Stream} An IOTile Stream.
     */
    IOTileCloud.prototype.fetchStream = function (streamSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/stream/' + streamSlug + '/')
                            .then(function (item) {
                            var newStream = new Stream(item);
                            resolve(newStream);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.deleteStream = function (streamSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.deleteFromServer('/stream/' + streamSlug + '/')
                            .then(function (resp) {
                            resolve(resp);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchStreamData
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific stream's datapoints from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a list of DataPoints from the stream requested.
     *
     * @example
     * <pre>
     * // Get an array of DataPoints for stream with slug: streamSlug
     * var datapoints = await IOTileCloud.fetchStreamData(streamSlug);
     * console.log(`Found ${datapoints.length} datapoints from stream with slug: ${stream.slug}`);
     * </pre>
     *
     * @param {string} streamSlug The slug property of the stream that will
     *                            be fetched.
     *
     * @returns {Array<DataPoint>} An array of DataPoints.
     */
    IOTileCloud.prototype.fetchStreamData = function (streamSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that, datapoints;
            return __generator(this, function (_a) {
                that = this;
                datapoints = [];
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/stream/' + streamSlug + '/')
                            .then(function (result) {
                            lodash.forEach(result, function (item) {
                                var newData = new DataPoint(item);
                                datapoints.push(newData);
                            });
                            resolve(datapoints);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.createStream = function (variable, dataLabel) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'variable': variable,
                            'data_label': dataLabel
                        };
                        return [4 /*yield*/, this.postToServer('/stream/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    IOTileCloud.prototype.createVariable = function (name, project, lid) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'name': name,
                            'project': project,
                            'lid': lid
                        };
                        return [4 /*yield*/, this.postToServer('/variable/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    IOTileCloud.prototype.postStreamData = function (streamSlug, type, value) {
        return __awaiter(this, void 0, void 0, function () {
            var data, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        data = {
                            'stream': streamSlug,
                            'type': type,
                            'timestamp': new Date(),
                            'int_value': value
                        };
                        return [4 /*yield*/, this.postToServer('/data/', data)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllVariables
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available variables from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Variable objects with all variables retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all variables available
     * var variables = await IOTileCloud.fetchAllVariables();
     * console.log("Found " + variables.length + " IOTile Variables!");
     * </pre>
     *
     * @returns {Variable[]} A list of the IOTile variables.
     */
    IOTileCloud.prototype.fetchAllVariables = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newVariable = new Variable(item);
                                list.push(newVariable);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchProjectVariables
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all variables for a given project from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of Variable objects with all variables retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all variables available for project with ID: projId
     * var projVariables = await IOTileCloud.fetchProjectVariables(projId);
     * console.log("Found " + projVariables.length + " IOTile Variables!");
     * </pre>
     *
     * @param {string} projectId The id property of the project object that
     *                           variables will be fetched from.
     *
     * @returns {Variable[]} A list of the IOTile variables.
     */
    IOTileCloud.prototype.fetchProjectVariables = function (projectId) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/?project=' + projectId)
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newVariable = new Variable(item);
                                list.push(newVariable);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchVariable
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific variable from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Variable object with the variable requested.
     *
     * @example
     * <pre>
     * // Get a Variable object for variable with slug: variableSlug
     * var variable = await IOTileCloud.fetchVariable(variableSlug);
     * console.log("Found variable with slug: " + variable.slug);
     * </pre>
     *
     * @param {string} variableSlug The slug property of the variable that will
     *                            be fetched.
     *
     * @returns {Variable} An IOTile Variable.
     */
    IOTileCloud.prototype.fetchVariable = function (variableSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/' + variableSlug + '/')
                            .then(function (item) {
                            var newVariable = new Variable(item);
                            resolve(newVariable);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllVarTypes
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available vartypes from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of VarType objects with all vartypes retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all vartypes available
     * var vartypes = await IOTileCloud.fetchAllVarTypes();
     * console.log("Found " + vartypes.length + " IOTile VarTypes!");
     * </pre>
     *
     * @returns {VarType[]} A list of the IOTile vartypes.
     */
    IOTileCloud.prototype.fetchAllVarTypes = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/vartype/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newVarType = new VarType(item);
                                list.push(newVarType);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchAllProjectTemplates
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches all available project templates from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns an array of ProjectTemplate objects with all project templates retrieved.
     *
     * @example
     * <pre>
     * // Get an array of all project templates available
     * var project_templates = await IOTileCloud.fetchAllProjectTemplates();
     * console.log("Found " + project_templates.length + " IOTile ProjectTemplates!");
     * </pre>
     *
     * @returns {ProjectTemplate[]} A list of the IOTile project templates.
     */
    IOTileCloud.prototype.fetchAllProjectTemplates = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/pt/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newProjectTemplate = new ProjectTemplate(item);
                                list.push(newProjectTemplate);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
   * @ngdoc method
   * @name iotile.cloud.service:IOTileCloud#fetchAllPropertyTemplates
   * @methodOf iotile.cloud.service:IOTileCloud
   *
   * @description
   * Fetches all available property templates from the IOTile Cloud.
   *
   * **This is an async method!**
   *
   * Returns an array of PropertyTemplate objects with all property templates retrieved.
   *
   * @example
   * <pre>
   * // Get an array of all property templates available
   * var property_templates = await IOTileCloud.fetchAllPropertyTemplates();
   * console.log("Found " + property_templates.length + " IOTile PropertyTemplates!");
   * </pre>
   *
   * @returns {PropertyTemplate[]} A list of the IOTile property templates.
   */
    IOTileCloud.prototype.fetchAllPropertyTemplates = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/propertytemplate/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newPropertyTemplate = new PropertyTemplate(item);
                                list.push(newPropertyTemplate);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
   * @ngdoc method
   * @name iotile.cloud.service:IOTileCloud#fetchProperties
   * @methodOf iotile.cloud.service:IOTileCloud
   *
   * @description
   * Fetches properties for a given target from the IOTile Cloud.
   *
   * **This is an async method!**
   *
   * Returns a Property object for the target requested.
   *
   * @example
   * <pre>
   * // Get the Properties for a target with slug: slug
   * var properties = await IOTileCloud.fetchProperties(slug);
   * </pre>
   *
   * @param {string} deviceSlug The slug property of the device for which
   *                              the property is associated.
   *
   * @returns {Property[]} An IOTile Property.
   */
    IOTileCloud.prototype.fetchProperties = function (deviceSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/property/?target=' + deviceSlug)
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newProperty = new Property(item);
                                list.push(newProperty);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchVarType
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific variable type from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a VarType object with the variable type requested.
     *
     * @example
     * <pre>
     * // Get a VarType object for variable with slug: variableSlug
     * var vartype = await IOTileCloud.fetchVarType(variableSlug);
     * console.log("Found vartype with slug: " + vartype.slug);
     * </pre>
     *
     * @param {string} variableSlug The slug property of the variable for which
     *                              the vartype is associated.
     *
     * @returns {Variable} An IOTile Variable.
     */
    IOTileCloud.prototype.fetchVarType = function (variableSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/variable/' + variableSlug + '/type/')
                            .then(function (item) {
                            var newVarType = new VarType(item);
                            resolve(newVarType);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.fetchSensorGraphs = function () {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/sg/')
                            .then(function (result) {
                            var list = [];
                            lodash.forEach(result, function (item) {
                                var newSG = new SensorGraph(item);
                                list.push(newSG);
                            });
                            resolve(list);
                        }).catch(function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.refreshToken = function (currentToken) {
        return __awaiter(this, void 0, void 0, function () {
            var response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.postToServer('/auth/api-jwt-refresh/', { token: currentToken })];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, response['token']];
                }
            });
        });
    };
    IOTileCloud.prototype.logout = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.postToServer('/auth/logout/', undefined)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.login = function (email, password) {
        return __awaiter(this, void 0, void 0, function () {
            var response, user, err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 3, , 4]);
                        return [4 /*yield*/, this.postToServer('/auth/api-jwt-auth/', { username: email, password: password })];
                    case 1:
                        response = _a.sent();
                        return [4 /*yield*/, this.fetchUserData(response['token'])];
                    case 2:
                        user = _a.sent();
                        return [2 /*return*/, user];
                    case 3:
                        err_1 = _a.sent();
                        if (!(err_1 instanceof HttpError)) {
                            err_1 = new HttpError(err_1);
                        }
                        throw err_1;
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.register = function (username, name, email, password1, password2) {
        try {
            return this.postToServer('/account/', {
                username: username,
                name: name,
                email: email,
                password: password1,
                confirm_password: password2
            });
        }
        catch (err) {
            if (!(err instanceof HttpError)) {
                err = new HttpError(err);
            }
            throw err;
        }
    };
    IOTileCloud.prototype.fetchUserData = function (token) {
        return __awaiter(this, void 0, void 0, function () {
            var response, info;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetchFromServer('/account/', { 'Authorization': "JWT " + token })];
                    case 1:
                        response = _a.sent();
                        if (!response['length']) {
                            throw new UserNotLoggedInError("No information for logged in user token");
                        }
                        info = response[0];
                        return [2 /*return*/, new User(info, token)];
                }
            });
        });
    };
    IOTileCloud.prototype.setToken = function (token) {
        axios.defaults.headers.common['Authorization'] = token;
    };
    IOTileCloud.prototype.deleteFromServer = function (uri, headers) {
        return __awaiter(this, void 0, void 0, function () {
            var request, that;
            return __generator(this, function (_a) {
                if (!this._server) {
                    throw new Error("Cannot delete " + uri + ": unknown server address");
                }
                request = {
                    method: 'DELETE',
                    url: this._server.url + uri,
                    timeout: this.Config.ENV.HTTP_TIMEOUT
                };
                if (headers) {
                    request['headers'] = headers;
                }
                catCloud.debug("[IOTileCloud] Delete request: " + request);
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(request).then(function (response) {
                            catCloud.debug("[IOTileCloud] Response: " + response);
                            that.inProgressConnections -= 1;
                            if (response.data['results'] !== undefined) {
                                resolve(response.data['results']);
                            }
                            else {
                                resolve(response.data);
                            }
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new HttpError(err));
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.fetchFromServer = function (uri, headers) {
        return __awaiter(this, void 0, void 0, function () {
            var request, that;
            return __generator(this, function (_a) {
                if (!this._server) {
                    throw new Error("Cannot fetch " + uri + ": unknown server address");
                }
                request = {
                    method: 'GET',
                    url: this._server.url + uri,
                    timeout: this.Config.ENV.HTTP_TIMEOUT
                };
                if (headers) {
                    request['headers'] = headers;
                }
                catCloud.debug("[IOTileCloud] Fetch request: " + request);
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(request).then(function (response) {
                            catCloud.debug("[IOTileCloud] Response: " + response);
                            that.inProgressConnections -= 1;
                            if (response.data['results'] !== undefined) {
                                resolve(response.data['results']);
                            }
                            else {
                                resolve(response.data);
                            }
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new HttpError(err));
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.postToServer = function (uri, data) {
        return __awaiter(this, void 0, void 0, function () {
            var request, that;
            return __generator(this, function (_a) {
                if (!this._server) {
                    throw new Error("Cannot post to " + uri + ": unknown server address");
                }
                
                request = { method: 'POST',
                    url: this._server.url + uri,
                    timeout: this.Config.ENV.HTTP_TIMEOUT };
                if (data !== null) {
                    request['data'] = data;
                }
                catCloud.debug("[IOTileCloud] Post request: " + request);
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(request).then(function (response) {
                            catCloud.debug("[IOTileCloud] Response: " + response);
                            that.inProgressConnections -= 1;
                            if (response.data['results'] !== undefined) {
                                resolve(response.data['results']);
                            }
                            else {
                                resolve(response.data);
                            }
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new HttpError(err));
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.postFirmwareUpgrade = function (slug, version) {
        return __awaiter(this, void 0, void 0, function () {
            var payload;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            firmware: version
                        };
                        return [4 /*yield*/, this.postToServer("/device/" + slug + "/upgrade/", payload)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.postEvent = function (stream, extra_data) {
        return __awaiter(this, void 0, void 0, function () {
            var payload;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            "stream": stream,
                            "timestamp": new Date(),
                            //"streamer_local_id": 0,
                            "extra_data": extra_data
                        };
                        return [4 /*yield*/, this.postToServer('/event/', payload)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.postFileToNote = function (note_id, file) {
        return __awaiter(this, void 0, void 0, function () {
            var url_payload, resp, formData, metaData, key, value, s3Response, err_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        url_payload = {
                            "name": file.name
                        };
                        return [4 /*yield*/, this.postToServer("/note/" + note_id + "/uploadurl/", url_payload)];
                    case 1:
                        resp = _a.sent();
                        if (!resp) return [3 /*break*/, 7];
                        formData = new FormData();
                        metaData = resp['fields'];
                        for (key in metaData) {
                            value = metaData[key];
                            formData.append(key, value);
                        }
                        formData.append('file', file, file.name);
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 6, , 7]);
                        return [4 /*yield*/, axios({
                                method: 'POST',
                                url: resp['url'],
                                data: formData,
                                transformRequest: [function (data, headers) {
                                        delete headers.common.Authorization;
                                        return data;
                                    }]
                            })];
                    case 3:
                        s3Response = _a.sent();
                        if (!(s3Response.status == 204)) return [3 /*break*/, 5];
                        return [4 /*yield*/, this.postToServer("/note/" + note_id + "/uploadsuccess/", { "name": file.name, "uuid": resp['uuid'] })];
                    case 4:
                        _a.sent();
                        _a.label = 5;
                    case 5: return [3 /*break*/, 7];
                    case 6:
                        err_2 = _a.sent();
                        catCloud.error("S3 Upload failed on " + file.name, err_2);
                        return [3 /*break*/, 7];
                    case 7: return [2 /*return*/];
                }
            });
        });
    };
    IOTileCloud.prototype.postNote = function (target, timestamp, note) {
        return __awaiter(this, void 0, void 0, function () {
            var payload, resp;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            "target": target,
                            "timestamp": timestamp || new Date(),
                            "note": note
                        };
                        return [4 /*yield*/, this.postToServer('/note/', payload)];
                    case 1:
                        resp = _a.sent();
                        return [2 /*return*/, resp];
                }
            });
        });
    };
    IOTileCloud.prototype.postLocation = function (target, timestamp, lat, lon) {
        return __awaiter(this, void 0, void 0, function () {
            var payload;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        payload = {
                            "target": target,
                            "timestamp": timestamp || new Date(),
                            "lat": lat,
                            "lon": lon
                        };
                        return [4 /*yield*/, this.postToServer('/location/', payload)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#fetchStreamer
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Fetches a specific variable type from the IOTile Cloud.
     *
     * **This is an async method!**
     *
     * Returns a Streamer object with the slug requested.
     *
     * @example
     * <pre>
     * // Get a Streamer object for variable with slug: streamerSlug
     * var streamer = await IOTileCloud.fetchStreamer(streamerSlug);
     * console.log("Found streamer with slug: " + streamer.slug);
     * </pre>
     *
     * @param {string} streamerSlug The slug property of the streamer we're requesting.
     *
     * @returns {Streamer} An IOTile Streamer.
     */
    IOTileCloud.prototype.fetchStreamer = function (streamerSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var that;
            return __generator(this, function (_a) {
                that = this;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.fetchFromServer('/streamer/' + streamerSlug + '/')
                            .then(function (item) {
                            var newStreamer = new Streamer(item);
                            resolve(newStreamer);
                        }, function (err) {
                            reject(err);
                        });
                    })];
            });
        });
    };
    IOTileCloud.prototype.fetchAcknowledgements = function (deviceSlug) {
        return __awaiter(this, void 0, void 0, function () {
            var filter, acks;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        filter = "?";
                        if (deviceSlug != null)
                            filter = "?device=" + deviceSlug + "&";
                        filter += 'page_size=1000';
                        return [4 /*yield*/, this.fetchFromServer('/streamer/' + filter)];
                    case 1:
                        acks = _a.sent();
                        return [2 /*return*/, acks.map(function (val) {
                                return {
                                    deviceSlug: val['device'],
                                    index: val['index'],
                                    highestAck: val['last_id']
                                };
                            })];
                }
            });
        });
    };
    /**
     * @ngdoc method
     * @name iotile.cloud.service:IOTileCloud#patchStream
     * @methodOf iotile.cloud.service:IOTileCloud
     *
     * @description
     * Updates the IOTile Cloud with any changes made to a Stream object.
     *
     * **This is an async method!**
     *
     * Returns a promise that will resolve with the status of the http call.
     *
     * @example
     * <pre>
     * // Patch our changed Stream object (streamObj) up to the cloud
     * var status = await IOTileCloud.patchStream(streamObj);
     * console.log("Patched stream with status: " + status.status);
     * </pre>
     *
     * @param {Stream} streamObj The stream object that has been updated.
     *
     * @returns {Promise} A promise that will resolve with the http status.
     */
    IOTileCloud.prototype.patchModel = function (slug, patchPayload) {
        return __awaiter(this, void 0, void 0, function () {
            var that, modelType, payload;
            return __generator(this, function (_a) {
                that = this;
                modelType = null;
                if (startsWith(slug, 's--')) {
                    modelType = '/stream/';
                }
                else if (startsWith(slug, 'd--')) {
                    modelType = '/device/';
                }
                else {
                    throw new ArgumentError("Unknown slug type in patchModel: " + slug);
                }
                if (!this._server) {
                    throw new Error("Cannot patch " + slug + ": unknown server address");
                }
                payload = {
                    url: this._server.url + modelType + slug + '/',
                    method: 'PATCH',
                    data: patchPayload,
                    timeout: this.Config.ENV.HTTP_TIMEOUT
                };
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        that.inProgressConnections += 1;
                        axios(payload).then(function (result) {
                            that.inProgressConnections -= 1;
                            resolve(result);
                        }, function (err) {
                            that.inProgressConnections -= 1;
                            reject(new HttpError(err));
                        });
                    })];
            });
        });
    };
    return IOTileCloud;
}());

/*
 * Mock data for two projects that can be used to test the IOTile Companion App.
 */
var clonedeep = require("lodash.clonedeep");
var MockAdapter = require("axios-mock-adapter");
var axios$1 = require("axios");
var Response;
(function (Response) {
    Response[Response["Success"] = 200] = "Success";
    Response[Response["Fail401"] = 401] = "Fail401";
    Response[Response["Fail402"] = 402] = "Fail402";
})(Response || (Response = {}));
var MockCloud = /** @class */ (function () {
    function MockCloud(cloud) {
        this.cloud = cloud;
        this.cloud['Config'].ENV.SERVER_URLS = [{
                "shortName": "PRODUCTION",
                "longName": "Production Server",
                "url": "https://iotile.cloud/api/v1",
                "default": true
            }];
        this.cloud.server = {
            "shortName": "PRODUCTION",
            "longName": "Production Server",
            "url": "https://iotile.cloud/api/v1",
            "default": true
        };
        this.projects = [new Project(soil_proj), new Project(water_proj)];
        var deviceList = [];
        devices.forEach(function (element) {
            deviceList.push(new Device(element));
        });
        this.devices = deviceList;
        var varList = [];
        variables.forEach(function (element) {
            varList.push(new Variable(element));
        });
        this.variables = varList;
        var streamList = [];
        streams.forEach(function (element) {
            streamList.push(new Stream(element));
        });
        this.streams = streamList;
        var sgList = [];
        sg.forEach(function (element) {
            sgList.push(new SensorGraph(element));
        });
        this.sensorGraphs = sgList;
        var vartypeList = [];
        vartypes.forEach(function (element) {
            vartypeList.push(new VarType(element));
        });
        this.varTypes = vartypeList;
        var pts = [];
        project_templates.forEach(function (element) {
            pts.push(new ProjectTemplate(element));
        });
        this.projTemplates = pts;
    }
    MockCloud.prototype.buildListResponse = function (objects) {
        var obj = {
            "count": objects.length,
            "next": null,
            "prev": null,
            "results": objects
        };
        return clonedeep(obj);
    };
    MockCloud.prototype.buildParamResponse = function (getType, paramType, param) {
        var retrieved = [];
        switch (getType) {
            case 'project':
                for (var _i = 0, _a = this.projects; _i < _a.length; _i++) {
                    var p = _a[_i];
                    if (p[paramType] == param) {
                        retrieved.push(p.serialize());
                    }
                }
                break;
            case 'device':
                for (var _b = 0, _c = this.devices; _b < _c.length; _b++) {
                    var d = _c[_b];
                    if (d[paramType] == param) {
                        retrieved.push(d.toJson());
                    }
                }
                break;
            case 'sensorgraph':
                for (var _d = 0, _e = this.sensorGraphs; _d < _e.length; _d++) {
                    var sg_1 = _e[_d];
                    if (sg_1[paramType] == param) {
                        retrieved.push(sg_1.toJson());
                    }
                }
                break;
            case 'variable':
                for (var _f = 0, _g = this.variables; _f < _g.length; _f++) {
                    var v = _g[_f];
                    if (v[paramType] == param) {
                        retrieved.push(v.toJson());
                    }
                }
                break;
            case 'stream':
                for (var _h = 0, _j = this.streams; _h < _j.length; _h++) {
                    var s = _j[_h];
                    if (s[paramType] == param) {
                        retrieved.push(s.toJson());
                    }
                }
                break;
            case 'vartype':
                for (var _k = 0, _l = this.varTypes; _k < _l.length; _k++) {
                    var vt = _l[_k];
                    if (vt[paramType] == param) {
                        retrieved.push(vt.toJson());
                    }
                }
                break;
            case 'pt':
                for (var _m = 0, _o = this.projTemplates; _m < _o.length; _m++) {
                    var pt = _o[_m];
                    if (pt[paramType] == param) {
                        retrieved.push(pt.toJson());
                    }
                }
                break;
        }
        var obj = this.buildListResponse(retrieved);
        return clonedeep(obj);
    };
    MockCloud.prototype.getStream = function (slug) {
        for (var _i = 0, streams_1 = streams; _i < streams_1.length; _i++) {
            var stream = streams_1[_i];
            if (stream.slug == slug) {
                return new Stream(stream);
            }
        }
        throw new ArgumentError("Unknown stream slug: " + slug);
    };
    MockCloud.prototype.getDevice = function (slug) {
        for (var _i = 0, devices_1 = devices; _i < devices_1.length; _i++) {
            var device = devices_1[_i];
            if (device.slug == slug) {
                return new Device(device);
            }
        }
        throw new ArgumentError("Unknown device slug: " + slug);
    };
    MockCloud.prototype.expectStreamPatch = function (slug, data, responseType, responseData) {
        if (responseData == null) {
            responseData = {};
        }
        var url = '/stream/' + slug + '/';
        this.MockAdapter.onPatch(url, data).reply(Response, responseData);
    };
    MockCloud.prototype.defaultSetup = function () {
        this.MockAdapter = new MockAdapter(axios$1);
        var that = this;
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/project/').reply(200, that.buildListResponse([water_proj, soil_proj]));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/org/').reply(200, that.buildListResponse([arch_internal_org, arch_systems_org]));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/device/?page_size=1000').reply(200, that.buildListResponse(devices));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/stream/?page_size=3000').reply(200, that.buildListResponse(streams));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/variable/').reply(200, that.buildListResponse(variables));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/vartype/').reply(200, that.buildListResponse(vartypes));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/sg/').reply(200, that.buildListResponse(sg));
        this.MockAdapter.onGet('https://iotile.cloud/api/v1/pt/').reply(200, that.buildListResponse(project_templates));
        this.MockAdapter.onGet("https://iotile.cloud/api/v1/org/" + arch_internal_org.slug + "/membership/").reply(200, arch_internal_membership);
        this.MockAdapter.onGet("https://iotile.cloud/api/v1/org/" + arch_systems_org.slug + "/membership/").reply(200, arch_systems_membership);
        // this.MockAdapter.onGet(`https://iotile.cloud/api/v1/project/(.+)/`, undefined, ['id']).reply(this.buildParamResponse('project', 'project', params['id']));
        // this.MockAdapter.onGet(`https://iotile.cloud/api/v1/device/?project=(.+)`, undefined, ['id']).reply(this.buildParamResponse('device', 'project', params['id']));
        // this.MockAdapter.onGet(`https://iotile.cloud/api/v1/stream/?project=(.+)`, undefined, ['id']).reply(this.buildParamResponse('stream', 'project', params['id']));
        // this.MockAdapter.onGet(`https://iotile.cloud/api/v1/variable/(.+)`, undefined, ['id']).reply(this.buildParamResponse('variable', 'project', params['id']));
    };
    return MockCloud;
}());
var project_templates = [
    {
        "id": 2,
        "name": "Default Template",
        "slug": "default-template-v1-0-0",
        "org": "arch-systems",
        "version": "v1.0.0",
        "extra_data": {
            "web": {
                "projectTemplateSlug": "default"
            }
        },
        "created_on": "2017-01-22T22:50:24.512275Z"
    },
    {
        "id": 8,
        "name": "Shipping Template",
        "slug": "shipping-template-v1-0-0",
        "org": "arch-systems",
        "version": "v1.0.0",
        "extra_data": {
            "web": {
                "projectTemplateSlug": "shipping"
            }
        },
        "created_on": "2017-08-31T01:52:39.851213Z"
    },
    {
        "id": 9,
        "name": "Simple Template",
        "slug": "simple-template-v1-0-0",
        "org": "arch-systems",
        "version": "v1.0.0",
        "extra_data": {
            "web": {
                "projectTemplateSlug": "simple"
            }
        },
        "created_on": "2017-09-04T23:45:16.642470Z"
    },
    {
        "id": 7,
        "name": "Water Meter",
        "slug": "water-meter-v1-1-0",
        "org": "arch-systems",
        "version": "v1.1.0",
        "extra_data": {
            "web": {
                "projectTemplateSlug": "default"
            }
        },
        "created_on": "2017-03-17T06:15:44.410131Z"
    }
];
var arch_internal_org = {
    "id": "564c54b5-19df-4fe0-9655-92542a2d0932",
    "name": "Arch - Internal",
    "slug": "arch-internal",
    "about": "Internal Projects for Testing",
    "created_on": "2016-11-04T00:48:13.033551Z",
    "created_by": "david",
    "avatar": {
        "thumbnail": "https://media.iotile.cloud/prod/images/3e5554ff-0e4d-4a10-b299-415e143c6931/thumbnail.jpg",
        "tiny": "https://media.iotile.cloud/prod/images/3e5554ff-0e4d-4a10-b299-415e143c6931/tiny.jpg"
    }
};
var arch_systems_org = {
    "id": "0e1031ba-b4b1-48e1-873c-73155b30c038",
    "name": "Arch Systems",
    "slug": "arch-systems",
    "about": "",
    "created_on": "2016-11-04T00:42:34.151136Z",
    "created_by": "david",
    "avatar": {
        "thumbnail": "https://media.iotile.cloud/prod/images/09592eb4-0a84-4394-bcc6-e2205235a8b8/thumbnail.jpg",
        "tiny": "https://media.iotile.cloud/prod/images/09592eb4-0a84-4394-bcc6-e2205235a8b8/tiny.jpg"
    }
};
var arch_internal_membership = {
    "user": "kaylie",
    "user_details": {
        "email": "kaylie@arch-iot.com",
        "username": "kaylie",
        "name": "Kaylie DeHart",
        "tagline": "Software Engineer [Mobile] @Arch",
        "avatar": {
            "tiny": "https://secure.gravatar.com/avatar/59dfdaa43783adc9adebdaa55a768c27?s=28&d=identicon",
            "thumbnail": "https://secure.gravatar.com/avatar/59dfdaa43783adc9adebdaa55a768c27?s=80&d=identicon"
        }
    },
    "created_on": "2017-04-17T23:00:06Z",
    "is_active": true,
    "is_org_admin": true
};
var arch_systems_membership = {
    "user": "kaylie",
    "user_details": {
        "email": "kaylie@arch-iot.com",
        "username": "kaylie",
        "name": "Kaylie DeHart",
        "tagline": "Software Engineer [Mobile] @Arch",
        "avatar": {
            "tiny": "https://secure.gravatar.com/avatar/59dfdaa43783adc9adebdaa55a768c27?s=28&d=identicon",
            "thumbnail": "https://secure.gravatar.com/avatar/59dfdaa43783adc9adebdaa55a768c27?s=80&d=identicon"
        }
    },
    "created_on": "2017-04-17T23:00:06Z",
    "is_active": true,
    "is_org_admin": false
};
var soil_proj = {
    "id": "5311e938-1150-4d40-bc66-e2319d112655",
    "name": "Mobile App Testing Project - Soil",
    "slug": "p--0000-006d",
    "gid": "0000-006d",
    "org": "arch-internal",
    "about": "",
    "project_template": null,
    "page": {
        "label": "Water Meter",
        "id": 2,
        "slug": "water-meter"
    },
    "created_on": "2017-03-20T01:02:56.295859Z",
    "created_by": "david"
};
var water_proj = {
    "id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
    "name": "Mobile App Testing Project - Water",
    "slug": "p--0000-006e",
    "gid": "0000-006e",
    "org": "arch-internal",
    "about": "",
    "project_template": null,
    "page": {
        "label": "Water Meter",
        "id": 2,
        "slug": "water-meter"
    },
    "created_on": "2017-03-20T01:02:56.314521Z",
    "created_by": "david"
};
var sg = [
    {
        "id": 18,
        "name": "4-420-1-flow ProtoPod",
        "slug": "4-420-1-flow-protopod-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 49,
                "label": "IO 1",
                "lid_hex": "5001",
                "derived_lid_hex": "",
                "var_type": "water-meter-volume",
                "default_input_unit": "in--water-meter-volume--gallons",
                "default_output_unit": "out--water-meter-volume--gallons",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 50,
                "label": "IO 2",
                "lid_hex": "5005",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 51,
                "label": "IO 3",
                "lid_hex": "500c",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 52,
                "label": "IO 4",
                "lid_hex": "500d",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 53,
                "label": "IO 5",
                "lid_hex": "500e",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 54,
                "label": "Pulse 1",
                "lid_hex": "100b",
                "derived_lid_hex": "",
                "var_type": "water-meter-flow",
                "default_input_unit": "in--water-meter-flow--gallons",
                "default_output_unit": "out--water-meter-flow--gallons-per-min",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 55,
                "label": "RT 2",
                "lid_hex": "1011",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 56,
                "label": "RT 3",
                "lid_hex": "1016",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 57,
                "label": "RT 4",
                "lid_hex": "1017",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 58,
                "label": "RT 5",
                "lid_hex": "1018",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 41,
                "label": "IO 1",
                "lid_hex": "5001",
                "var_type": "water-meter-volume",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 42,
                "label": "IO 2",
                "lid_hex": "5005",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 43,
                "label": "IO 3",
                "lid_hex": "500c",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 44,
                "label": "IO 4",
                "lid_hex": "500d",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 45,
                "label": "IO 5",
                "lid_hex": "500e",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 46,
                "label": "RT 1",
                "lid_hex": "100b",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 47,
                "label": "RT 2",
                "lid_hex": "1011",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 48,
                "label": "RT 3",
                "lid_hex": "1016",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 49,
                "label": "RT 4",
                "lid_hex": "1017",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 50,
                "label": "RT 5",
                "lid_hex": "1018",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Flow 1",
                                    "lid": "100b"
                                }
                            }
                        },
                        "500d": {
                            "label": "IO 4",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 4",
                                    "lid": "1017"
                                }
                            }
                        },
                        "500e": {
                            "label": "IO 5",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 5",
                                    "lid": "1018"
                                }
                            }
                        },
                        "5005": {
                            "label": "IO 2",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 2",
                                    "lid": "1011"
                                }
                            }
                        },
                        "500c": {
                            "label": "IO 3",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 3",
                                    "lid": "1016"
                                }
                            }
                        }
                    },
                    "order": [
                        "5001",
                        "5005",
                        "500c",
                        "500d",
                        "500e"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-06-15T22:16:25.050506Z"
    },
    {
        "id": 12,
        "name": "Accelerometer",
        "slug": "accelerometer-v0-1-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 32,
                "label": "RT X",
                "lid_hex": "1012",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 33,
                "label": "RT Y",
                "lid_hex": "1013",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 34,
                "label": "RT Z",
                "lid_hex": "1014",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 27,
                "label": "ACC ST",
                "lid_hex": "5006",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 28,
                "label": "ACC X",
                "lid_hex": "5007",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 29,
                "label": "ACC Y",
                "lid_hex": "5008",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 30,
                "label": "ACC Z",
                "lid_hex": "5009",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 31,
                "label": "ACC SLEEP",
                "lid_hex": "500a",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 19,
                "label": "Status",
                "lid_hex": "5006",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 20,
                "label": "X",
                "lid_hex": "5007",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 21,
                "label": "Y",
                "lid_hex": "5008",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 22,
                "label": "Z",
                "lid_hex": "5009",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 23,
                "label": "Sleep",
                "lid_hex": "500a",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 24,
                "label": "RT X",
                "lid_hex": "1012",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 25,
                "label": "RT Y",
                "lid_hex": "1013",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 26,
                "label": "RT Z",
                "lid_hex": "1014",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5008": {
                            "label": "Y",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "RT Y",
                                    "lid": "1013"
                                }
                            }
                        },
                        "5009": {
                            "label": "Z",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "RT Z",
                                    "lid": "1014"
                                }
                            }
                        },
                        "5007": {
                            "label": "X",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "RT X",
                                    "lid": "1012"
                                }
                            }
                        }
                    },
                    "order": [
                        "5007",
                        "5008",
                        "5009"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 0,
        "minor_version": 1,
        "patch_version": 0,
        "created_on": "2017-03-28T00:15:01.377573Z"
    },
    {
        "id": 19,
        "name": "Development",
        "slug": "development-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [],
        "display_widget_templates": [],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": null,
                "other": null
            },
            "web": {
                "pageTemplateSlug": "proto"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-06-23T05:40:38.385443Z"
    },
    {
        "id": 3,
        "name": "Double Soil Moisture",
        "slug": "double-soil-moisture-v1-0-0",
        "org": "arch-systems",
        "project_template": null,
        "variable_templates": [],
        "display_widget_templates": [],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings"
                        },
                        "5002": {
                            "label": "IO 2",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings"
                        }
                    },
                    "order": [
                        "5001",
                        "5002"
                    ]
                },
                "other": null
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-01-26T06:26:21.206491Z"
    },
    {
        "id": 7,
        "name": "Double Soil Moisture",
        "slug": "double-soil-moisture-v1-1-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 7,
                "label": "IO 1",
                "lid_hex": "5001",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 8,
                "label": "IO 2",
                "lid_hex": "5002",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 9,
                "label": "Sensor 1",
                "lid_hex": "100a",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 10,
                "label": "Sensor 2",
                "lid_hex": "100b",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 1,
                "label": "IO 1",
                "lid_hex": "5001",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 8,
                "label": "IO Realtime 1",
                "lid_hex": "100a",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 2,
                "label": "IO 2",
                "lid_hex": "5002",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 9,
                "label": "IO Realtime 2",
                "lid_hex": "100b",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Realtime IO 1",
                                    "lid": "100a"
                                }
                            }
                        },
                        "5002": {
                            "label": "IO 2",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Realtime IO 2",
                                    "lid": "100b"
                                }
                            }
                        }
                    },
                    "order": [
                        "5001",
                        "5002"
                    ]
                },
                "other": null
            }
        },
        "major_version": 1,
        "minor_version": 1,
        "patch_version": 0,
        "created_on": "2017-03-17T06:27:58.682673Z"
    },
    {
        "id": 10,
        "name": "Double Soil Moisture",
        "slug": "double-soil-moisture-v2-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 19,
                "label": "IO 1",
                "lid_hex": "5003",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 20,
                "label": "IO 2",
                "lid_hex": "5004",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 21,
                "label": "Sensor 1",
                "lid_hex": "100f",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 22,
                "label": "Sensor 2",
                "lid_hex": "1010",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 11,
                "label": "IO 1",
                "lid_hex": "5003",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 12,
                "label": "IO Realtime 1",
                "lid_hex": "100f",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 13,
                "label": "IO 2",
                "lid_hex": "5004",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 14,
                "label": "IO Realtime 2",
                "lid_hex": "1010",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5004": {
                            "label": "IO 2",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Realtime IO 2",
                                    "lid": "1010"
                                }
                            }
                        },
                        "5003": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Realtime IO 1",
                                    "lid": "100f"
                                }
                            }
                        }
                    },
                    "order": [
                        "5003",
                        "5004"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 2,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-03-22T02:36:28.932715Z"
    },
    {
        "id": 14,
        "name": "Dust Sensor",
        "slug": "dust-sensor-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 35,
                "label": "IO 1",
                "lid_hex": "500b",
                "derived_lid_hex": "",
                "var_type": "dust-density",
                "default_input_unit": "in--dust-density--mgm3",
                "default_output_unit": "out--dust-density--mgm3",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 36,
                "label": "Fast Density 1",
                "lid_hex": "1015",
                "derived_lid_hex": "",
                "var_type": "dust-density",
                "default_input_unit": "in--dust-density--mgm3",
                "default_output_unit": "out--dust-density--mgm3",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 27,
                "label": "IO 1",
                "lid_hex": "500b",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 28,
                "label": "Fast Density 1",
                "lid_hex": "1015",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "500b": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 1",
                                    "lid": "1015"
                                }
                            }
                        }
                    },
                    "order": [
                        "500b"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-04-14T06:07:18.184517Z"
    },
    {
        "id": 15,
        "name": "Dust Sensor",
        "slug": "dust-sensor-v1-1-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 37,
                "label": "IO 1",
                "lid_hex": "500b",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 38,
                "label": "Fast Density 1",
                "lid_hex": "1015",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 29,
                "label": "IO 1",
                "lid_hex": "500b",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 30,
                "label": "Fast Density 1",
                "lid_hex": "1015",
                "var_type": "default",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "500b": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 1",
                                    "lid": "1015"
                                }
                            }
                        }
                    },
                    "order": [
                        "500b"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 1,
        "minor_version": 1,
        "patch_version": 0,
        "created_on": "2017-04-30T04:55:44.092678Z"
    },
    {
        "id": 13,
        "name": "Gateway",
        "slug": "gateway-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [],
        "display_widget_templates": [],
        "ui_extra": {
            "mobile": {
                "controller": "gatewayCtrl",
                "template": "gateway",
                "ioInfo": null,
                "other": null
            },
            "web": {
                "pageTemplateSlug": "gateway"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-03-31T00:59:23.570953Z"
    },
    {
        "id": 16,
        "name": "RedTrac ProtoPod",
        "slug": "redtrac-protopod-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 39,
                "label": "IO 1",
                "lid_hex": "5001",
                "derived_lid_hex": "",
                "var_type": "water-meter-volume",
                "default_input_unit": "in--water-meter-volume--gallons",
                "default_output_unit": "out--water-meter-volume--gallons",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 40,
                "label": "IO 2",
                "lid_hex": "5005",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 41,
                "label": "IO 3",
                "lid_hex": "500c",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 42,
                "label": "IO 4",
                "lid_hex": "500d",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 43,
                "label": "IO 5",
                "lid_hex": "500e",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 44,
                "label": "Pulse 1",
                "lid_hex": "100b",
                "derived_lid_hex": "",
                "var_type": "water-meter-flow",
                "default_input_unit": "in--water-meter-flow--gallons",
                "default_output_unit": "out--water-meter-flow--gallons-per-min",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 45,
                "label": "RT 2",
                "lid_hex": "1011",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 46,
                "label": "RT 3",
                "lid_hex": "1016",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 47,
                "label": "RT 4",
                "lid_hex": "1017",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 48,
                "label": "RT 5",
                "lid_hex": "1018",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 31,
                "label": "IO 1",
                "lid_hex": "5001",
                "var_type": "water-meter-volume",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 32,
                "label": "IO 2",
                "lid_hex": "5005",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 33,
                "label": "IO 3",
                "lid_hex": "500c",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 34,
                "label": "IO 4",
                "lid_hex": "500d",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 35,
                "label": "IO 5",
                "lid_hex": "500e",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 36,
                "label": "RT 1",
                "lid_hex": "100b",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 37,
                "label": "RT 2",
                "lid_hex": "1011",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 38,
                "label": "RT 3",
                "lid_hex": "1016",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 39,
                "label": "RT 4",
                "lid_hex": "1017",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            },
            {
                "id": 40,
                "label": "RT 5",
                "lid_hex": "1018",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Flow 1",
                                    "lid": "100b"
                                }
                            }
                        },
                        "500d": {
                            "label": "IO 4",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 4",
                                    "lid": "1017"
                                }
                            }
                        },
                        "500e": {
                            "label": "IO 5",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 5",
                                    "lid": "1018"
                                }
                            }
                        },
                        "5005": {
                            "label": "IO 2",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 2",
                                    "lid": "1011"
                                }
                            }
                        },
                        "500c": {
                            "label": "IO 3",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 3",
                                    "lid": "1016"
                                }
                            }
                        }
                    },
                    "order": [
                        "5001",
                        "5005",
                        "500c",
                        "500d",
                        "500e"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-05-16T19:20:40.272561Z"
    },
    {
        "id": 21,
        "name": "Saver",
        "slug": "saver-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 65,
                "label": "Accelerometer",
                "lid_hex": "5020",
                "derived_lid_hex": "",
                "var_type": "default",
                "default_input_unit": "in--default--unit",
                "default_output_unit": "out--default--unit",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": true
            },
            {
                "id": 66,
                "label": "Pressure",
                "lid_hex": "5021",
                "derived_lid_hex": "",
                "var_type": "pressure",
                "default_input_unit": "in--pressure--lansmont-saver",
                "default_output_unit": "out--pressure--millibar",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": true
            },
            {
                "id": 67,
                "label": "Relative Humidity",
                "lid_hex": "5022",
                "derived_lid_hex": "",
                "var_type": "relative-humidity",
                "default_input_unit": "in--relative-humidity--lansmont-saver",
                "default_output_unit": "out--relative-humidity--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": true
            },
            {
                "id": 68,
                "label": "Temperature",
                "lid_hex": "5023",
                "derived_lid_hex": "",
                "var_type": "temp",
                "default_input_unit": "in--temp--lansmont-saver",
                "default_output_unit": "out--temp--celsius",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": true
            }
        ],
        "display_widget_templates": [
            {
                "id": 59,
                "label": "Pressure",
                "lid_hex": "5021",
                "var_type": "pressure",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 60,
                "label": "Relative Humidity",
                "lid_hex": "5022",
                "var_type": "relative-humidity",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 61,
                "label": "Temperature",
                "lid_hex": "5023",
                "var_type": "temp",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": null,
                "other": null
            },
            "web": {
                "pageTemplateSlug": "shipping"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-06-30T00:40:24.420694Z"
    },
    {
        "id": 5,
        "name": "Single 4-20 Sensor",
        "slug": "single-4-20-sensor-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 26,
                "label": "Sensor 1",
                "lid_hex": "1011",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 25,
                "label": "IO 1",
                "lid_hex": "5005",
                "derived_lid_hex": "",
                "var_type": "420-milliamps",
                "default_input_unit": "in--420-milliamps--milliamps",
                "default_output_unit": "out--420-milliamps--milliamps",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 17,
                "label": "IO 1",
                "lid_hex": "5005",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 18,
                "label": "IO Realtime 1",
                "lid_hex": "1011",
                "var_type": "420-milliamps",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5005": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "IO 1",
                                    "lid": "1011"
                                }
                            }
                        }
                    },
                    "order": [
                        "5005"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-03-10T22:55:14.045385Z"
    },
    {
        "id": 2,
        "name": "Single Soil Moisture",
        "slug": "single-soil-moisture-v1-0-0",
        "org": "arch-systems",
        "project_template": null,
        "variable_templates": [],
        "display_widget_templates": [],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings"
                        }
                    },
                    "order": [
                        "5001"
                    ]
                },
                "other": null
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-01-26T06:25:58.502281Z"
    },
    {
        "id": 8,
        "name": "Single Soil Moisture",
        "slug": "single-soil-moisture-v1-1-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 17,
                "label": "IO 1",
                "lid_hex": "5001",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 18,
                "label": "Sensor 1",
                "lid_hex": "100a",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 7,
                "label": "IO 1",
                "lid_hex": "5001",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 10,
                "label": "IO Realtime 1",
                "lid_hex": "100a",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Realtime IO 1",
                                    "lid": "100a"
                                }
                            }
                        }
                    },
                    "order": [
                        "5001"
                    ]
                },
                "other": null
            }
        },
        "major_version": 1,
        "minor_version": 1,
        "patch_version": 0,
        "created_on": "2017-03-17T06:27:58.884875Z"
    },
    {
        "id": 11,
        "name": "Single Soil Moisture",
        "slug": "single-soil-moisture-v2-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 23,
                "label": "IO 1",
                "lid_hex": "5003",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 24,
                "label": "Sensor 1",
                "lid_hex": "100f",
                "derived_lid_hex": "",
                "var_type": "soil-moisture-percent",
                "default_input_unit": "in--soil-moisture-percent--percent",
                "default_output_unit": "out--soil-moisture-percent--percent",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 15,
                "label": "IO 1",
                "lid_hex": "5003",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 16,
                "label": "IO Realtime 1",
                "lid_hex": "100f",
                "var_type": "soil-moisture-percent",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "5003": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Realtime IO 1",
                                    "lid": "100f"
                                }
                            }
                        }
                    },
                    "order": [
                        "5003"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 2,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-03-22T02:36:29.123923Z"
    },
    {
        "id": 20,
        "name": "Single Temp Sensor",
        "slug": "single-temp-sensor-v1-0-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 63,
                "label": "IO 1",
                "lid_hex": "500f",
                "derived_lid_hex": "",
                "var_type": "temp",
                "default_input_unit": "in--temp--lm35",
                "default_output_unit": "out--temp--celsius",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 64,
                "label": "Sensor 1",
                "lid_hex": "1019",
                "derived_lid_hex": "",
                "var_type": "temp",
                "default_input_unit": "in--temp--lm35",
                "default_output_unit": "out--temp--celsius",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 57,
                "label": "IO 1",
                "lid_hex": "500f",
                "var_type": "temp",
                "derived_unit_type": "",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 58,
                "label": "Sensor 1",
                "lid_hex": "1019",
                "var_type": "temp",
                "derived_unit_type": "",
                "show_in_app": true,
                "show_in_web": false
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "defaultCtrl",
                "template": "default",
                "ioInfo": {
                    "map": {
                        "500f": {
                            "label": "IO 1",
                            "settingsController": "defaultSettingsCtrl",
                            "settingsTemplate": "default-settings",
                            "derived": {
                                "realtime": {
                                    "label": "Sensor 1",
                                    "lid": "1019"
                                }
                            }
                        }
                    },
                    "order": [
                        "500f"
                    ]
                },
                "other": null
            },
            "web": {
                "pageTemplateSlug": "default"
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-06-23T05:40:38.486601Z"
    },
    {
        "id": 1,
        "name": "Water Meter",
        "slug": "water-meter-v1-0-0",
        "org": "arch-systems",
        "project_template": "water-meter-permanent-v1-0-0",
        "variable_templates": [],
        "display_widget_templates": [],
        "ui_extra": {
            "mobile": {
                "controller": "waterMeterCtrl",
                "template": "water-meter",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "waterMeterSettingsCtrl",
                            "settingsTemplate": "water-meter-settings",
                            "derived": {
                                "odometer": {
                                    "label": "Trip Computer",
                                    "lid": "100d"
                                },
                                "flow": {
                                    "label": "Flow",
                                    "lid": "100b",
                                    "type": "water-meter-flow"
                                }
                            }
                        },
                        "5002": {
                            "label": "IO 2",
                            "settingsController": "waterMeterSettingsCtrl",
                            "settingsTemplate": "water-meter-settings",
                            "derived": {
                                "odometer": {
                                    "label": "Trip Computer",
                                    "lid": "100e"
                                },
                                "flow": {
                                    "label": "Flow",
                                    "lid": "100c",
                                    "type": "water-meter-flow"
                                }
                            }
                        }
                    },
                    "order": [
                        "5001",
                        "5002"
                    ]
                },
                "other": {
                    "flowMdo": {
                        "d": 65536
                    }
                }
            }
        },
        "major_version": 1,
        "minor_version": 0,
        "patch_version": 0,
        "created_on": "2017-01-23T08:01:01.654057Z"
    },
    {
        "id": 6,
        "name": "Water Meter",
        "slug": "water-meter-v1-1-0",
        "org": "arch-systems",
        "project_template": "default-template-v1-0-0",
        "variable_templates": [
            {
                "id": 11,
                "label": "IO 1",
                "lid_hex": "5001",
                "derived_lid_hex": "",
                "var_type": "water-meter-volume",
                "default_input_unit": "in--water-meter-volume--gallons",
                "default_output_unit": "out--water-meter-volume--gallons",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 12,
                "label": "IO 2",
                "lid_hex": "5002",
                "derived_lid_hex": "",
                "var_type": "water-meter-volume",
                "default_input_unit": "in--water-meter-volume--gallons",
                "default_output_unit": "out--water-meter-volume--gallons",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": false,
                "web_only": false
            },
            {
                "id": 13,
                "label": "Pulse 1",
                "lid_hex": "100b",
                "derived_lid_hex": "",
                "var_type": "water-meter-flow",
                "default_input_unit": "in--water-meter-flow--gallons",
                "default_output_unit": "out--water-meter-flow--gallons-per-min",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 14,
                "label": "Pulse 2",
                "lid_hex": "100c",
                "derived_lid_hex": "",
                "var_type": "water-meter-flow",
                "default_input_unit": "in--water-meter-flow--gallons",
                "default_output_unit": "out--water-meter-flow--gallons-per-min",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 15,
                "label": "Odometer 1",
                "lid_hex": "100d",
                "derived_lid_hex": "",
                "var_type": "water-meter-volume",
                "default_input_unit": "in--water-meter-volume--gallons",
                "default_output_unit": "out--water-meter-volume--gallons",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            },
            {
                "id": 16,
                "label": "Odometer 2",
                "lid_hex": "100e",
                "derived_lid_hex": "",
                "var_type": "water-meter-volume",
                "default_input_unit": "in--water-meter-volume--gallons",
                "default_output_unit": "out--water-meter-volume--gallons",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "app_only": true,
                "web_only": false
            }
        ],
        "display_widget_templates": [
            {
                "id": 3,
                "label": "IO 1",
                "lid_hex": "5001",
                "var_type": "water-meter-volume",
                "derived_unit_type": "rate",
                "show_in_app": false,
                "show_in_web": true
            },
            {
                "id": 4,
                "label": "IO 2",
                "lid_hex": "5002",
                "var_type": "water-meter-volume",
                "derived_unit_type": "rate",
                "show_in_app": false,
                "show_in_web": true
            }
        ],
        "ui_extra": {
            "mobile": {
                "controller": "waterMeterCtrl",
                "template": "water-meter",
                "ioInfo": {
                    "map": {
                        "5001": {
                            "label": "IO 1",
                            "settingsController": "waterMeterSettingsCtrl",
                            "settingsTemplate": "water-meter-settings",
                            "derived": {
                                "odometer": {
                                    "label": "Trip Computer",
                                    "lid": "100d"
                                },
                                "flow": {
                                    "label": "Flow",
                                    "lid": "100b",
                                    "type": "water-meter-flow"
                                }
                            }
                        },
                        "5002": {
                            "label": "IO 2",
                            "settingsController": "waterMeterSettingsCtrl",
                            "settingsTemplate": "water-meter-settings",
                            "derived": {
                                "odometer": {
                                    "label": "Trip Computer",
                                    "lid": "100e"
                                },
                                "flow": {
                                    "label": "Flow",
                                    "lid": "100c",
                                    "type": "water-meter-flow"
                                }
                            }
                        }
                    },
                    "order": [
                        "5001",
                        "5002"
                    ]
                },
                "other": {
                    "flowMdo": {
                        "d": 65536
                    }
                }
            },
            "web": {
                "pageTemplateSlug": "water"
            }
        },
        "major_version": 1,
        "minor_version": 1,
        "patch_version": 0,
        "created_on": "2017-03-15T22:31:00.185099Z"
    }
];
var vartypes = [
    {
        "name": "420 Milliamps",
        "slug": "420-milliamps",
        "available_input_units": [
            {
                "slug": "in--420-milliamps--milliamps",
                "unit_full": "Milliamps",
                "unit_short": "mA",
                "m": 28,
                "d": 4095,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--420-milliamps--0-100-psi",
                "unit_full": "0-100 psi",
                "unit_short": "psi",
                "m": 100,
                "d": 16,
                "o": -25.0,
                "decimal_places": 0,
                "derived_units": {}
            },
            {
                "slug": "out--420-milliamps--0-200-psi",
                "unit_full": "0-200 psi",
                "unit_short": "psi",
                "m": 200,
                "d": 16,
                "o": -50.0,
                "decimal_places": 0,
                "derived_units": {}
            },
            {
                "slug": "out--420-milliamps--0-4000-gpm",
                "unit_full": "0-4000 GPM",
                "unit_short": "gpm",
                "m": 4000,
                "d": 16,
                "o": -1000.0,
                "decimal_places": 0,
                "derived_units": {}
            },
            {
                "slug": "out--420-milliamps--milliamps",
                "unit_full": "Milliamps",
                "unit_short": "mA",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            }
        ],
        "storage_units_full": "Milliamps",
        "storage_units_short": "mA"
    },
    {
        "name": "Default",
        "slug": "default",
        "available_input_units": [
            {
                "slug": "in--default--unit",
                "unit_full": "Unit",
                "unit_short": "u",
                "m": 1,
                "d": 1,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--default--unit",
                "unit_full": "Unit",
                "unit_short": "u",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            }
        ],
        "storage_units_full": "Unit",
        "storage_units_short": "u"
    },
    {
        "name": "Dust Density",
        "slug": "dust-density",
        "available_input_units": [
            {
                "slug": "in--dust-density--mgm3",
                "unit_full": "mg/m^3",
                "unit_short": "mg/m3",
                "m": 2000,
                "d": 14625,
                "o": -80.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--dust-density--mgm3",
                "unit_full": "mg/m^3",
                "unit_short": "mg/m3",
                "m": 1,
                "d": 1000,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--dust-density--ugm3",
                "unit_full": "ug/m^3",
                "unit_short": "ug/m3",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            }
        ],
        "storage_units_full": "ug/m^3",
        "storage_units_short": "ug/m3"
    },
    {
        "name": "Pressure",
        "slug": "pressure",
        "available_input_units": [
            {
                "slug": "in--pressure--lansmont-saver",
                "unit_full": "Lansmont Saver",
                "unit_short": "",
                "m": 100,
                "d": 1000000,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--pressure--millibar",
                "unit_full": "Millibar",
                "unit_short": "Mbar",
                "m": 1,
                "d": 100,
                "o": 0.0,
                "decimal_places": 4,
                "derived_units": {}
            },
            {
                "slug": "out--pressure--pascal",
                "unit_full": "Pascal",
                "unit_short": "Pa",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--pressure--psi",
                "unit_full": "PSI",
                "unit_short": "psi",
                "m": 145038,
                "d": 1000000000,
                "o": 0.0,
                "decimal_places": 4,
                "derived_units": {}
            }
        ],
        "storage_units_full": "Pascal",
        "storage_units_short": "Pa"
    },
    {
        "name": "Relative Humidity",
        "slug": "relative-humidity",
        "available_input_units": [
            {
                "slug": "in--relative-humidity--lansmont-saver",
                "unit_full": "Lansmont Saver",
                "unit_short": "% RH",
                "m": 1,
                "d": 1000000,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--relative-humidity--percent",
                "unit_full": "Percent",
                "unit_short": "% RH",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 3,
                "derived_units": {}
            }
        ],
        "storage_units_full": "Percent RH",
        "storage_units_short": "%"
    },
    {
        "name": "Soil Moisture",
        "slug": "soil-moisture",
        "available_input_units": [
            {
                "slug": "in--soil-moisture--percent",
                "unit_full": "Percent",
                "unit_short": "%",
                "m": 1,
                "d": 1,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--soil-moisture--percent",
                "unit_full": "Percent",
                "unit_short": "%",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 0,
                "derived_units": null
            }
        ],
        "storage_units_full": "Percent",
        "storage_units_short": "%"
    },
    {
        "name": "Soil Moisture Percent",
        "slug": "soil-moisture-percent",
        "available_input_units": [
            {
                "slug": "in--soil-moisture-percent--ec-5",
                "unit_full": "EC-5",
                "unit_short": "%",
                "m": 5908,
                "d": 40950,
                "o": -67.5
            },
            {
                "slug": "in--soil-moisture-percent--percent",
                "unit_full": "Percent",
                "unit_short": "%",
                "m": 100,
                "d": 4095,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--soil-moisture-percent--percent",
                "unit_full": "Percent",
                "unit_short": "%",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            }
        ],
        "storage_units_full": "Percent",
        "storage_units_short": "%"
    },
    {
        "name": "Temp",
        "slug": "temp",
        "available_input_units": [
            {
                "slug": "in--temp--lansmont-saver",
                "unit_full": "Lansmont Saver",
                "unit_short": "C",
                "m": 1,
                "d": 1000000,
                "o": 273.15
            },
            {
                "slug": "in--temp--lm35",
                "unit_full": "LM35",
                "unit_short": "mA",
                "m": 280,
                "d": 4095,
                "o": 273.15
            },
            {
                "slug": "in--temp--tmp36",
                "unit_full": "TMP36",
                "unit_short": "mA",
                "m": 280,
                "d": 4095,
                "o": 223.15
            }
        ],
        "available_output_units": [
            {
                "slug": "out--temp--celsius",
                "unit_full": "Celsius",
                "unit_short": "C",
                "m": 1,
                "d": 1,
                "o": -273.15,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--temp--fahrenheit",
                "unit_full": "Fahrenheit",
                "unit_short": "F",
                "m": 9,
                "d": 5,
                "o": -459.67,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--temp--kelvin",
                "unit_full": "Kelvin",
                "unit_short": "K",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            }
        ],
        "storage_units_full": "Kelvin",
        "storage_units_short": "K"
    },
    {
        "name": "Water Meter Flow",
        "slug": "water-meter-flow",
        "available_input_units": [
            {
                "slug": "in--water-meter-flow--acre-feet",
                "unit_full": "Acre Feet",
                "unit_short": "A.F.",
                "m": 123348185,
                "d": 6553600,
                "o": 0.0
            },
            {
                "slug": "in--water-meter-flow--cubic-meters",
                "unit_full": "Cubic Meters",
                "unit_short": "M^3",
                "m": 1000,
                "d": 65536,
                "o": 0.0
            },
            {
                "slug": "in--water-meter-flow--gallons",
                "unit_full": "Gallons",
                "unit_short": "G",
                "m": 3785,
                "d": 65536000,
                "o": 0.0
            },
            {
                "slug": "in--water-meter-flow--liters",
                "unit_full": "Liters",
                "unit_short": "L",
                "m": 1,
                "d": 65536,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--water-meter-flow--cubic-meters-per-hr",
                "unit_full": "Cubic Meters per Hr",
                "unit_short": "M^3/H",
                "m": 60,
                "d": 1000,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--water-meter-flow--gallons-per-hr",
                "unit_full": "Gallons per Hr",
                "unit_short": "GPH",
                "m": 6000000,
                "d": 378541,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--water-meter-flow--gallons-per-min",
                "unit_full": "Gallons per Min",
                "unit_short": "GPM",
                "m": 100000,
                "d": 378541,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--water-meter-flow--liters-per-hr",
                "unit_full": "Liters per Hr",
                "unit_short": "LPH",
                "m": 60,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            },
            {
                "slug": "out--water-meter-flow--liters-per-min",
                "unit_full": "Liters per Min",
                "unit_short": "LPM",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 1,
                "derived_units": {}
            }
        ],
        "storage_units_full": "LPM",
        "storage_units_short": "LPM"
    },
    {
        "name": "Water Meter Volume",
        "slug": "water-meter-volume",
        "available_input_units": [
            {
                "slug": "in--water-meter-volume--acre-feet",
                "unit_full": "Acre Feet",
                "unit_short": "A.F.",
                "m": 123348185,
                "d": 100,
                "o": 0.0
            },
            {
                "slug": "in--water-meter-volume--cubic-meters",
                "unit_full": "Cubic Meters",
                "unit_short": "M^3",
                "m": 1000,
                "d": 1,
                "o": 0.0
            },
            {
                "slug": "in--water-meter-volume--gallons",
                "unit_full": "Gallons",
                "unit_short": "G",
                "m": 378541,
                "d": 100000,
                "o": 0.0
            },
            {
                "slug": "in--water-meter-volume--liters",
                "unit_full": "Liters",
                "unit_short": "L",
                "m": 1,
                "d": 1,
                "o": 0.0
            }
        ],
        "available_output_units": [
            {
                "slug": "out--water-meter-volume--acre-feet",
                "unit_full": "Acre Feet",
                "unit_short": "A.F.",
                "m": 100,
                "d": 123348185,
                "o": 0.0,
                "decimal_places": 0,
                "derived_units": {}
            },
            {
                "slug": "out--water-meter-volume--cubic-meters",
                "unit_full": "Cubic Meters",
                "unit_short": "M^3",
                "m": 1,
                "d": 1000,
                "o": 0.0,
                "decimal_places": 0,
                "derived_units": {}
            },
            {
                "slug": "out--water-meter-volume--gallons",
                "unit_full": "Gallons",
                "unit_short": "G",
                "m": 100000,
                "d": 378541,
                "o": 0.0,
                "decimal_places": 0,
                "derived_units": {
                    "rate": {
                        "gph": {
                            "d": 1,
                            "m": 6
                        },
                        "gpm": {
                            "d": 10,
                            "m": 1
                        }
                    }
                }
            },
            {
                "slug": "out--water-meter-volume--liters",
                "unit_full": "Liters",
                "unit_short": "L",
                "m": 1,
                "d": 1,
                "o": 0.0,
                "decimal_places": 0,
                "derived_units": {
                    "rate": {
                        "lph": {
                            "d": 1,
                            "m": 6
                        },
                        "lpm": {
                            "d": 10,
                            "m": 1
                        }
                    }
                }
            }
        ],
        "storage_units_full": "Liter",
        "storage_units_short": "l"
    }
];
var variables = [
    {
        "id": "591c99b7-7f1c-4ec0-9d70-ebab4c6f71c4",
        "name": "Sensor 1",
        "lid": 4106,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.420468Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006d--100a"
    },
    {
        "id": "b6cf0971-4ff3-4c6c-b5bf-da50dd3ef4be",
        "name": "Sensor 2",
        "lid": 4107,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.449726Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006d--100b"
    },
    {
        "id": "31e00e27-635e-4958-9d3d-b7bf2144b3a3",
        "name": "Sensor 1",
        "lid": 4111,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-06-22T20:10:10.519755Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006d--100f"
    },
    {
        "id": "6f00abdd-9077-4e7f-9c1f-94f00974e34f",
        "name": "Sensor 2",
        "lid": 4112,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-06-22T20:10:10.552029Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006d--1010"
    },
    {
        "id": "e98f511e-bc2d-4c0e-b3f5-4550ada9703b",
        "name": "IO 1",
        "lid": 20481,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.353617Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": false,
        "slug": "v--0000-006d--5001"
    },
    {
        "id": "f3bf3ea0-f2c4-4a2c-beb7-c8aa881d20c0",
        "name": "IO 2",
        "lid": 20482,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.394323Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": false,
        "slug": "v--0000-006d--5002"
    },
    {
        "id": "47fff3f5-a383-48fa-9a6e-b773e8d5f9df",
        "name": "IO 1",
        "lid": 20483,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-06-22T20:10:10.594428Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": false,
        "slug": "v--0000-006d--5003"
    },
    {
        "id": "ef505cda-01d3-42a1-ab9e-e00a3d8518b5",
        "name": "IO 2",
        "lid": 20484,
        "var_type": "soil-moisture-percent",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-06-22T20:10:10.633701Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": false,
        "slug": "v--0000-006d--5004"
    },
    {
        "id": "b34508e1-d794-459f-bf45-c63e4220ec27",
        "name": "Pulse 1",
        "lid": 4107,
        "var_type": "water-meter-flow",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.639439Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006e--100b"
    },
    {
        "id": "244bffa1-93a6-45ae-af07-24b853e8aeb3",
        "name": "Pulse 2",
        "lid": 4108,
        "var_type": "water-meter-flow",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "derived_variable": null,
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.666780Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006e--100c"
    },
    {
        "id": "b4131dc8-7aac-41dd-b959-08af5f71cfe6",
        "name": "Odometer 1",
        "lid": 4109,
        "var_type": "water-meter-volume",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "derived_variable": null,
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.693612Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006e--100d"
    },
    {
        "id": "69ce6bdf-7b13-40e6-97a8-2b69b2bd3ada",
        "name": "Odometer 2",
        "lid": 4110,
        "var_type": "water-meter-volume",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "derived_variable": null,
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.719590Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": true,
        "slug": "v--0000-006e--100e"
    },
    {
        "id": "d8f6a0ab-c695-42d3-8e96-d56cf4b723f7",
        "name": "IO 1",
        "lid": 20481,
        "var_type": "water-meter-volume",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "derived_variable": null,
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.573129Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": false,
        "slug": "v--0000-006e--5001"
    },
    {
        "id": "17049870-01a4-423a-80d1-f6e38362f13a",
        "name": "IO 2",
        "lid": 20482,
        "var_type": "water-meter-volume",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "derived_variable": null,
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "org": "arch-internal",
        "about": "",
        "created_on": "2017-03-20T01:02:56.599271Z",
        "type": "N/A",
        "units": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "decimal_places": 2,
        "mdo_label": "",
        "web_only": false,
        "app_only": false,
        "slug": "v--0000-006e--5002"
    }
];
var devices = [
    {
        "id": 3,
        "slug": "d--0000-0000-0000-0003",
        "gid": "0000-0000-0000-0003",
        "label": "Double Soil Moisture",
        "active": true,
        "firmware_versions": [],
        "sg": "double-soil-moisture-v2-0-0",
        "template": "1d1p2bt103-v3-0-0",
        "org": "arch-internal",
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.188367Z"
    },
    {
        "id": 4,
        "slug": "d--0000-0000-0000-0004",
        "gid": "0000-0000-0000-0004",
        "label": "Single Soil Moisture",
        "active": true,
        "firmware_versions": [],
        "sg": "single-soil-moisture-v2-0-0",
        "template": "1d1p2bt103-v3-0-0",
        "org": "arch-internal",
        "project": "5311e938-1150-4d40-bc66-e2319d112655",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.197512Z"
    },
    {
        "id": 5,
        "slug": "d--0000-0000-0000-0005",
        "gid": "0000-0000-0000-0005",
        "label": "ES1 Prod Firmware, Robust Reports",
        "active": true,
        "firmware_versions": [],
        "sg": "water-meter-v1-1-0",
        "template": "1d1p2bt103-v3-0-0",
        "org": "arch-internal",
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.206822Z"
    },
    {
        "id": 6,
        "slug": "d--0000-0000-0000-0006",
        "gid": "0000-0000-0000-0006",
        "label": "POD1 Robust Reports",
        "active": true,
        "firmware_versions": [],
        "sg": "water-meter-v1-1-0",
        "template": "1d1p2bt103-v3-0-0",
        "org": "arch-internal",
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.215840Z"
    },
    {
        "id": 7,
        "slug": "d--0000-0000-0000-0007",
        "gid": "0000-0000-0000-0007",
        "label": "POD1 Old Reports",
        "active": true,
        "firmware_versions": [],
        "sg": "water-meter-v1-1-0",
        "template": "1d1p2bt103-v3-0-0",
        "org": "arch-internal",
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.225173Z"
    },
    {
        "id": 8,
        "slug": "d--0000-0000-0000-0008",
        "gid": "0000-0000-0000-0008",
        "label": "POD1 (Someone Always Connected)",
        "active": true,
        "firmware_versions": [],
        "sg": "water-meter-v1-1-0",
        "template": "1d1p2bt103-v3-0-0",
        "org": "arch-internal",
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.234169Z"
    },
    {
        "id": 9,
        "slug": "d--0000-0000-0000-0009",
        "gid": "0000-0000-0000-0009",
        "label": "Test Gateway Device (0009)",
        "active": true,
        "firmware_versions": [],
        "sg": "gateway-v1-0-0",
        "template": "internaltestingtemplate-v0-1-0",
        "org": "arch-internal",
        "project": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "lat": null,
        "lon": null,
        "created_on": "2016-11-04T00:42:34.244473Z"
    }
];
var streams = [
    {
        "id": "58d49eee-2ec0-4077-af20-0cb44072e3c8",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0005",
        "variable": "v--0000-006e--100b",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.650159Z",
        "slug": "s--0000-006e--0000-0000-0000-0005--100b",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "ac29a58c-a292-4a13-9cb7-0a7fbc54c6f6",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0005",
        "variable": "v--0000-006e--100c",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.677923Z",
        "slug": "s--0000-006e--0000-0000-0000-0005--100c",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "b56137b4-4e5a-48f9-ab91-ea800bf92ec8",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0005",
        "variable": "v--0000-006e--100d",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.704550Z",
        "slug": "s--0000-006e--0000-0000-0000-0005--100d",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "7a9c4f7c-8139-4d39-9028-a69d7dc2194b",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0005",
        "variable": "v--0000-006e--100e",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.738294Z",
        "slug": "s--0000-006e--0000-0000-0000-0005--100e",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "7715c416-9177-4915-b9f5-d9c7e6f50c60",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0005",
        "variable": "v--0000-006e--5001",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.584134Z",
        "slug": "s--0000-006e--0000-0000-0000-0005--5001",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "428631fc-55a9-422b-9a89-be7eeb1c7a27",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0005",
        "variable": "v--0000-006e--5002",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.624146Z",
        "slug": "s--0000-006e--0000-0000-0000-0005--5002",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "82345970-303a-432e-9c5d-6a27698f2586",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0006",
        "variable": "v--0000-006e--100b",
        "data_label": "Test",
        "input_unit": {
            "slug": "in--water-meter-flow--liters",
            "unit_full": "Liters",
            "unit_short": "L",
            "m": 1,
            "d": 65536,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--liters-per-min",
            "unit_full": "Liters per Min",
            "unit_short": "LPM",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "S",
        "mdo_label": "UPP",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.813585Z",
        "slug": "s--0000-006e--0000-0000-0000-0006--100b",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "eac042ee-eba9-4457-b478-40cd3edd62db",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0006",
        "variable": "v--0000-006e--100c",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.828623Z",
        "slug": "s--0000-006e--0000-0000-0000-0006--100c",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "1e40404b-4a2b-4a5f-a3f3-0d7ddb74b499",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0006",
        "variable": "v--0000-006e--100d",
        "data_label": "Test",
        "input_unit": {
            "slug": "in--water-meter-volume--liters",
            "unit_full": "Liters",
            "unit_short": "L",
            "m": 1,
            "d": 1,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--liters",
            "unit_full": "Liters",
            "unit_short": "L",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "lph": {
                        "d": 1,
                        "m": 6
                    },
                    "lpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "S",
        "mdo_label": "UPP",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.858347Z",
        "slug": "s--0000-006e--0000-0000-0000-0006--100d",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "3e7e020a-a3b5-4532-a35a-e6b184867f49",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0006",
        "variable": "v--0000-006e--100e",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.877594Z",
        "slug": "s--0000-006e--0000-0000-0000-0006--100e",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "82a0f87e-7ef3-4938-9e37-9ec2483871eb",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0006",
        "variable": "v--0000-006e--5001",
        "data_label": "Test 15",
        "input_unit": {
            "slug": "in--water-meter-volume--liters",
            "unit_full": "Liters",
            "unit_short": "L",
            "m": 1,
            "d": 1,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--liters",
            "unit_full": "Liters",
            "unit_short": "L",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "lph": {
                        "d": 1,
                        "m": 6
                    },
                    "lpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "S",
        "mdo_label": "UPP",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.784000Z",
        "slug": "s--0000-006e--0000-0000-0000-0006--5001",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "6027d8e3-46ad-4308-9afe-316a7d2bdde7",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0006",
        "variable": "v--0000-006e--5002",
        "data_label": "hello label",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.798885Z",
        "slug": "s--0000-006e--0000-0000-0000-0006--5002",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "c79cb44b-a2df-45e0-8617-d2abfc9e5e97",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0007",
        "variable": "v--0000-006e--100b",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.949821Z",
        "slug": "s--0000-006e--0000-0000-0000-0007--100b",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "0b2f7e91-a97a-4d1e-a3d7-84af954b7f34",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0007",
        "variable": "v--0000-006e--100c",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.976302Z",
        "slug": "s--0000-006e--0000-0000-0000-0007--100c",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "7f88753f-1944-495c-8dbb-90ce57355046",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0007",
        "variable": "v--0000-006e--100d",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.992066Z",
        "slug": "s--0000-006e--0000-0000-0000-0007--100d",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "2ebddea1-5d3c-4b73-85a4-c6b7211e3647",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0007",
        "variable": "v--0000-006e--100e",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.007105Z",
        "slug": "s--0000-006e--0000-0000-0000-0007--100e",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "93e736d3-1323-4c3d-b702-3792fadc0ed3",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0007",
        "variable": "v--0000-006e--5001",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.919917Z",
        "slug": "s--0000-006e--0000-0000-0000-0007--5001",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "e04bd92f-69f9-42d1-af86-34ec86065f0c",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0007",
        "variable": "v--0000-006e--5002",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.934767Z",
        "slug": "s--0000-006e--0000-0000-0000-0007--5002",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "c7cb8291-fbd6-46df-96e0-8f50b1da385c",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0008",
        "variable": "v--0000-006e--100b",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.091345Z",
        "slug": "s--0000-006e--0000-0000-0000-0008--100b",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "8c0b04a8-2b7e-4efc-94d4-58af7c742cf2",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0008",
        "variable": "v--0000-006e--100c",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-flow--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 3785,
            "d": 65536000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-flow--gallons-per-min",
            "unit_full": "Gallons per Min",
            "unit_short": "GPM",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.106543Z",
        "slug": "s--0000-006e--0000-0000-0000-0008--100c",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "43dbbeeb-9889-400c-afcc-25567957157f",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0008",
        "variable": "v--0000-006e--100d",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.121673Z",
        "slug": "s--0000-006e--0000-0000-0000-0008--100d",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "b3015202-2706-4efb-9016-aea548c28e21",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0008",
        "variable": "v--0000-006e--100e",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.136677Z",
        "slug": "s--0000-006e--0000-0000-0000-0008--100e",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "e46f138b-df7d-41c8-a383-f41d74597481",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0008",
        "variable": "v--0000-006e--5001",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.049497Z",
        "slug": "s--0000-006e--0000-0000-0000-0008--5001",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "619e5ee0-1d49-414e-b8b9-81adbdaa0213",
        "project_id": "04d10130-db9e-452e-a725-5cbb1a1e1ae4",
        "project": "p--0000-006e",
        "device": "d--0000-0000-0000-0008",
        "variable": "v--0000-006e--5002",
        "data_label": "",
        "input_unit": {
            "slug": "in--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 378541,
            "d": 100000,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--water-meter-volume--gallons",
            "unit_full": "Gallons",
            "unit_short": "G",
            "m": 100000,
            "d": 378541,
            "o": 0.0,
            "decimal_places": 0,
            "derived_units": {
                "rate": {
                    "gph": {
                        "d": 1,
                        "m": 6
                    },
                    "gpm": {
                        "d": 10,
                        "m": 1
                    }
                }
            }
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:57.064687Z",
        "slug": "s--0000-006e--0000-0000-0000-0008--5002",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "ac083f6a-d3e4-4f93-b1d1-88cf3204b8af",
        "project_id": "5311e938-1150-4d40-bc66-e2319d112655",
        "project": "p--0000-006d",
        "device": "d--0000-0000-0000-0003",
        "variable": "v--0000-006d--100f",
        "data_label": "test label acbc",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 1.0,
        "org": "arch-internal",
        "created_on": "2017-06-22T20:10:10.534164Z",
        "slug": "s--0000-006d--0000-0000-0000-0003--100f",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "b623c2a9-43ba-4da4-9a0d-e716d5617f12",
        "project_id": "5311e938-1150-4d40-bc66-e2319d112655",
        "project": "p--0000-006d",
        "device": "d--0000-0000-0000-0003",
        "variable": "v--0000-006d--1010",
        "data_label": "hello abdd",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-06-22T20:10:10.578028Z",
        "slug": "s--0000-006d--0000-0000-0000-0003--1010",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "f80a9a86-4d18-4b27-8d95-154fd67f6018",
        "project_id": "5311e938-1150-4d40-bc66-e2319d112655",
        "project": "p--0000-006d",
        "device": "d--0000-0000-0000-0003",
        "variable": "v--0000-006d--5003",
        "data_label": "test label acbc",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 1.0,
        "org": "arch-internal",
        "created_on": "2017-06-22T20:10:10.606357Z",
        "slug": "s--0000-006d--0000-0000-0000-0003--5003",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "dc765527-e8dd-48b4-9ac7-d3364321009e",
        "project_id": "5311e938-1150-4d40-bc66-e2319d112655",
        "project": "p--0000-006d",
        "device": "d--0000-0000-0000-0003",
        "variable": "v--0000-006d--5004",
        "data_label": "hello abdd",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "S",
        "mdo_label": "",
        "multiplication_factor": 1,
        "division_factor": 1,
        "offset": 0.0,
        "org": "arch-internal",
        "created_on": "2017-06-22T20:10:10.645839Z",
        "slug": "s--0000-006d--0000-0000-0000-0003--5004",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "a6597b54-a933-427e-b36e-2c4a80f957b2",
        "project_id": "5311e938-1150-4d40-bc66-e2319d112655",
        "project": "p--0000-006d",
        "device": "d--0000-0000-0000-0004",
        "variable": "v--0000-006d--100a",
        "data_label": "",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.530804Z",
        "slug": "s--0000-006d--0000-0000-0000-0004--100a",
        "type": "Num",
        "enabled": true
    },
    {
        "id": "622e9c8d-5dc7-416b-8df2-a39b58b90d89",
        "project_id": "5311e938-1150-4d40-bc66-e2319d112655",
        "project": "p--0000-006d",
        "device": "d--0000-0000-0000-0004",
        "variable": "v--0000-006d--5001",
        "data_label": "",
        "input_unit": {
            "slug": "in--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 100,
            "d": 4095,
            "o": 0.0
        },
        "output_unit": {
            "slug": "out--soil-moisture-percent--percent",
            "unit_full": "Percent",
            "unit_short": "%",
            "m": 1,
            "d": 1,
            "o": 0.0,
            "decimal_places": 1,
            "derived_units": {}
        },
        "mdo_type": "V",
        "mdo_label": "",
        "multiplication_factor": null,
        "division_factor": null,
        "offset": null,
        "org": "arch-internal",
        "created_on": "2017-03-20T01:02:56.515509Z",
        "slug": "s--0000-006d--0000-0000-0000-0004--5001",
        "type": "Num",
        "enabled": true
    }
];

export { catService, catCloud, DeltaStatus, ApiFilter, Credentials, DataBlock, DataFilterArgs, DataPage, DataPoint, Device, DeviceDelta, DeviceLocationDelta, DeviceDrifterDelta, DeviceLabelDelta, RPCArgs, StatefulRPCArgs, StatefulSwitchArgs, DisplayWidget, EventPage, EventPoint, FleetDevice, Fleet, GeneratedReport, DeviceGlobalId, HttpError, IndexFile, Invitation, IOTileSysVar, Mdo, Member, Membership, Note, OrgTemplate, Org, Page, Permissions, Project, ProjectTemplate, Property, PropertyTemplate, SensorGraph, Stats, Stream, StreamDelta, StreamLabelDelta, StreamMDODelta, UnitType, StreamUnitsDelta, StreamInputUnitsDelta, StreamOutputUnitsDelta, Streamer, Unit, User, Variable, VarType, streamInDevice, DataConflictError, IOTileCloud, ProjectOverlay, Response, MockCloud };
//# sourceMappingURL=iotile-cloud.es5.js.map
